/*
 * $Id: auto-backup.js,v 1.3 2018/12/26 11:58:08 ajith.k Exp $
 */

//ignorei18n_start
import Ember from 'ember';
import I18NUtil from '../utils/i18n-util';
import CommonUtil from '../utils/ads-common-util';
import AJAXUtil from '../utils/ads-ajax-util';
import DialogUtil from '../utils/ads-dialog-util';
import ValidationUtil from '../utils/ads-validation-util';

export default Ember.Component.extend({
    pageStatus:{},
    backupSchedulerData: null,
    backupCalendarData: null,
    configuredProducts: null,
    showSettings: false,

    didRender()
    {
        CommonUtil.renderTooltip();
        CommonUtil.renderScrollBar();
    },

    setup: Ember.on('init', function() {
        this.send('getAllBackupHistory');
    }),

    formatDate(history)
    {
        let timeFormat = this.get('GLOBAL_DATA.userDetails.DATE_FORMAT.TIME_FORMAT').replace(/d/g, 'D').replace(/y/g, 'Y').replace(/a/g, 'A');
        let timeZone = this.get('GLOBAL_DATA.userDetails.DATE_FORMAT.TIME_ZONE');
        let isTimeZone = timeFormat.indexOf('z') > 0;
        let isSeconds = timeFormat.indexOf('ss') > 0;

        if (history.LATEST_BACKUP != null)
        {
            let backupTime = moment(history.LATEST_BACKUP.BACKUP_TIME).format(timeFormat);
            history.LATEST_BACKUP.BACKUP_TIME = isTimeZone ? backupTime + " " + timeZone : backupTime;
        }
        if (history.BACKUP_LIST != null)
        {
            for (let j = 0; j < history.BACKUP_LIST.length; j++)
            {
                let backupTime = moment(history.BACKUP_LIST[j].BACKUP_TIME).format(timeFormat);
                history.BACKUP_LIST[j].BACKUP_TIME = isTimeZone ? backupTime + " " + timeZone : backupTime;
            }
        }
        if (history.SCHEDULE_TIME != null)
        {
            let scheduleTime = moment(history.SCHEDULE_TIME).format(timeFormat);
            if (isSeconds)
            {
                scheduleTime = scheduleTime.substring(0, scheduleTime.lastIndexOf(':') + 1) + '00';
            }
            history.SCHEDULE_TIME = isTimeZone ? scheduleTime + " " + timeZone : scheduleTime;
        }
        return history;
    },

    constructParams()
    {
        let params = {};
        let deleteBackup = this.get('backupSchedulerData.OVERWRITE.limit');
        let limit = deleteBackup.replace(/[DF]/, "");
        let overWrite = deleteBackup.indexOf("D") !== -1 ? { type: 'Days', limit: limit } : { type: 'Files', limit: limit };
        let selectedProduct = this.get('backupCalendarData.INTEGRATED_PRODUCTS');

        params[selectedProduct] = true;
        params.REPEAT_FREQUENCY = this.get('backupCalendarData.REPEAT_FREQUENCY');
        if (params.REPEAT_FREQUENCY === 'Hourly')
        {
            params.TIME_PERIOD = this.get('backupCalendarData.HOURS') * 60 + parseInt(this.get('backupCalendarData.MINUTES'));
            params.UNIT_OF_TIME = "Minutes";
            params.EXECUTE_IMMEDIATELY = 0;
        }
        else
        {
            params.DATE_OF_MONTH = params.REPEAT_FREQUENCY === 'Monthly' ? this.get('backupCalendarData.DATE_OF_MONTH') : '-1';
            params.DAY_OF_WEEK = params.REPEAT_FREQUENCY === 'Weekly' ? this.get('backupCalendarData.DAY_OF_WEEK') : '-1';
            params.HOURS = this.get('backupCalendarData.HOURS');
            params.MINUTES = this.get('backupCalendarData.MINUTES');
        }
        params.ENABLE_BACKUP = this.get('backupSchedulerData.ENABLE_BACKUP');
        params.LOCATION = encodeURIComponent(Ember.$.trim(this.get('backupSchedulerData.LOCATION')));
        if (this.get('backupSchedulerData.DAYS_TO_OVERWRITE'))
        {
            params.DAYS_TO_OVERWRITE = overWrite.limit;
        }
        else
        {
            params.OVERWRITE = JSON.stringify(overWrite);
            params.LOGON_NAME = this.get('backupSchedulerData.LOGON_NAME');
            params.PASSWORD = this.get('backupSchedulerData.PASSWORD');
        }

        if(this.get('backupSchedulerData.MAX_INCREMENTAL_BACKUP'))
        {
            params.MAX_INCREMENTAL_BACKUP = this.get('backupSchedulerData.MAX_INCREMENTAL_BACKUP');
        }
        params.IS_EMBER = true;
        return params;
    },

    isValidParams()
    {
        //Checks whether backup location is valid local path or share location
        let enableBackup = this.get('backupSchedulerData.ENABLE_BACKUP');
        let bkLocation = Ember.$.trim(this.get('backupSchedulerData.LOCATION'));
        if (enableBackup)
        {
            if (bkLocation == '')
            {
                this.set('showSettings', true);
                DialogUtil.alert(this, I18NUtil.translate('ads.admin.autobackup.enter_storage_path'));
                return false;
            }
            const MAX_PATH = 160;
            if (bkLocation.length > MAX_PATH)
            {
                DialogUtil.alert(this, I18NUtil.translate('ads.admin.autobackup.cannot_exceed_max_path'));
                return false;
            }
            bkLocation = bkLocation.replace("%installationDirectory%", "c:"); //for backward compatibility
            let locationType = this.get('backupSchedulerData.bkLocation');
            if ((locationType === 'Shared' && !ValidationUtil.isValidUNCPath(bkLocation)) || (locationType === 'Local' && !ValidationUtil.isValidLocalPath(bkLocation)))
            {
                DialogUtil.alert(this, I18NUtil.translate('ads.admin.autobackup.invalid_characters'));
                return false;
            }
        }

        //Checks whether access credentials are valid
        if (enableBackup && this.get('backupSchedulerData.SHOW_AUTHENTICATION_REQUIRED') && this.get('backupSchedulerData.isAuthenticationEnabled'))
        {
            let username = this.get('backupSchedulerData.LOGON_NAME') !== undefined ? this.get('backupSchedulerData.LOGON_NAME').trim() : "";
            let password = this.get('backupSchedulerData.PASSWORD') !== undefined ? this.get('backupSchedulerData.PASSWORD') : "";
            if (username == "" || password == "")
            {
                DialogUtil.alert(this, I18NUtil.translate('ads.admin.autobackup.username_or_password_cannot_be_empty'));
                return false;
            }
            if (!ValidationUtil.isValidLogonName(username))
            {
                DialogUtil.alert(this, I18NUtil.translate('ads_admin_product_settings_ha_userName_format_error'));
                return false;
            }
        }
        else
        {
            this.set('backupSchedulerData.LOGON_NAME', '');
            this.set('backupSchedulerData.PASSWORD', '');
        }

        //Checks whether max. incremental backup count is valid
        if(this.get('backupSchedulerData').hasOwnProperty('MAX_INCREMENTAL_BACKUP'))
        {
            let maxIncrementalBackup = this.get('backupSchedulerData.MAX_INCREMENTAL_BACKUP');
            if(maxIncrementalBackup == null || (typeof maxIncrementalBackup === 'string' && !ValidationUtil.isValidNumber(maxIncrementalBackup)) || maxIncrementalBackup < 0 || maxIncrementalBackup > 99)
            {
                DialogUtil.alert(this, I18NUtil.translate('ads.admin.autobackup.invalid_incremental_backup_count'));
                return false;
            }
        }
        return true;
    },

    isComponentRunning(productDetails)
    {
        if (productDetails.SCHEDULER_SETTINGS == null)
        {
            let msg = productDetails.STATUS;
            if(productDetails.STATUS_KEY == "ads.admin.logonsettings.status.communicationfailed")
            {
               msg = I18NUtil.translate("ads.admin.logonsettings.status.communicationfailed_help");
            }
            this.sendAction('showStatus', 'danger', msg, false);
            return false;
        }
        return true;
    },

    parseBackupHistory(history)
    {
        let self = this;
        for (let key in history)
        {
            if (key === 'STATUS')
            {
                history[key] = I18NUtil.translate(history[key]);
            }
        }
        history = self.formatDate(history);

        history.ICON_STATUS = "fw-icn-cancel";
        history.ENABLE_STATUS = false;
        history.ENABLE_STATUS_MESSAGE = I18NUtil.translate('ads.common.text.click_to_enable');

        if (history.SCHEDULER_SETTINGS != null)
        {
            if (history.SCHEDULER_SETTINGS.ENABLE_BACKUP == "true")
            {
                history.ICON_STATUS = "fw-icn-ok";
                history.ENABLE_STATUS = true;
                history.ENABLE_STATUS_MESSAGE = I18NUtil.translate('ads.common.text.click_to_disable');
            }

            if (history.SCHEDULER_SETTINGS.OVERWRITE)
            {
                history.SCHEDULER_SETTINGS.OVERWRITE = JSON.parse(history.SCHEDULER_SETTINGS.OVERWRITE);
                history.SCHEDULER_SETTINGS.OVERWRITE.limit = history.SCHEDULER_SETTINGS.OVERWRITE.limit + history.SCHEDULER_SETTINGS.OVERWRITE.type.charAt(0);
            }
            //for backward compatibility
            else
            {
                history.SCHEDULER_SETTINGS.OVERWRITE = {
                    type: 'Days',
                    limit: history.SCHEDULER_SETTINGS.DAYS_TO_OVERWRITE
                };
                history.SCHEDULER_SETTINGS.OVERWRITE.limit = history.SCHEDULER_SETTINGS.OVERWRITE.limit + history.SCHEDULER_SETTINGS.OVERWRITE.type.charAt(0);
            }
        }
        if (history.LATEST_BACKUP != null)
        {
            history.isBackupRunning = history.LATEST_BACKUP.STATUS == "ads.admin.autobackup.status.backup_running";
            if (history.isBackupRunning)
            {
                history.LATEST_BACKUP = history.BACKUP_LIST.shift();
            }
        }
        if (history.BACKUP_LIST != null && history.BACKUP_LIST.length > 0)
        {
            history.HAS_HISTORY = true;
        }
        return history;
    },

    actions:
    {
        getAllBackupHistory(async)
        {
            let self = this;
            let backupHistoryDetails = [];
            async = (async == undefined) ? 'true' : async;
            CommonUtil.showLoading();
            AJAXUtil.ajax('/RestAPI/WC/AutoBackupAction?mTCall=getBackupHistory', {}, async)
                .then(function(responseData)
                {
                    CommonUtil.hideLoading();
                    if (responseData.length == 0)
                    {
                        return;
                    }

                    for (let i = 0; i < responseData.length; i++)
                    {
                        let history = responseData[i];
                        history = self.parseBackupHistory(history);
                        history.INDEX = i;
                        backupHistoryDetails.push(history);
                    }
                    self.set('BACKUP_HISTORY_DETAILS', Ember.$.extend(true, [], backupHistoryDetails));
                });
        },

        getBackupHistory(productDetails, async)
        {
            if (productDetails == null)
            {
                return;
            }
            let self = this;
            let backupHistoryDetails = [];
            let index = productDetails.INDEX;
            async = (async == undefined) ? 'true' : async;
            CommonUtil.showLoading();
            AJAXUtil.ajax('/RestAPI/WC/AutoBackupAction?mTCall=getBackupHistory', { TAG_NAME: productDetails.TAG_NAME }, async)
                .then(function(responseData)
                {
                    CommonUtil.hideLoading();
                    if (responseData.length == 0)
                    {
                        return;
                    }
                    backupHistoryDetails = self.get('BACKUP_HISTORY_DETAILS');
                    let refreshedProduct = responseData;
                    if (refreshedProduct.SCHEDULER_SETTINGS == null)
                    {
                        if (refreshedProduct.STATUS != null)
                        {
                            refreshedProduct.STATUS_KEY = refreshedProduct.STATUS;
                            refreshedProduct.isBackupRunning = refreshedProduct.STATUS == 'ads.admin.autobackup.status.backup_running';
                            refreshedProduct.ICON_STATUS = "fw-icn-cancel";
                            refreshedProduct.ENABLE_STATUS = false;
                            refreshedProduct.ENABLE_STATUS_MESSAGE = I18NUtil.translate('ads.common.text.click_to_enable');
                            refreshedProduct.INDEX = index;
                            refreshedProduct.STATUS = I18NUtil.translate(refreshedProduct.STATUS);
                        }
                        if (self.get('failureReason') == null)
                        {
                            let msg = I18NUtil.translate(refreshedProduct.STATUS);
                            if(refreshedProduct.STATUS_KEY == "ads.admin.logonsettings.status.communicationfailed")
                            {
                               msg = I18NUtil.translate("ads.admin.logonsettings.status.communicationfailed_help");
                            }
                            self.sendAction('showStatus', 'danger', msg, false);
                        }
                        else
                        {
                            self.set('failureReason', null);
                        }
                    }
                    else
                    {
                        refreshedProduct = self.parseBackupHistory(refreshedProduct);
                    }
                    refreshedProduct.INDEX = index;
                    backupHistoryDetails[index] = refreshedProduct;
                    self.set('BACKUP_HISTORY_DETAILS', Ember.$.extend(true, [], backupHistoryDetails));
                });
        },

        editSettings(productDetails)
        {
            if (!this.isComponentRunning(productDetails))
            {
                return;
            }
            Ember.$('#FORM_STATUS').delay(500).slideUp('slow');
            this.send('getBackupSettings', productDetails);
            this.set('showSettings', true);
        },

        getBackupSettings(productDetails, status)
        {
            if (!this.isComponentRunning(productDetails))
            {
                return;
            }
            this.set('productDetails', productDetails);
            this.set('backupSchedulerData', Ember.$.extend(true, [], productDetails.SCHEDULER_SETTINGS));
            this.set('backupCalendarData', Ember.$.extend(true, [], productDetails.CALENDAR_SETTINGS));
            this.set('backupCalendarData.INTEGRATED_PRODUCTS', productDetails.TAG_NAME);
            this.set('configuredProducts', productDetails.PRODUCT_NAME);

            if(this.get('backupSchedulerData').hasOwnProperty('MAX_INCREMENTAL_BACKUP'))
            {
                this.set('backupSchedulerData.isIncrementalBackup',true);
            }

            let showAuthRequired = this.get('backupSchedulerData.DISABLE_LOCAL_PATH') || this.get('backupSchedulerData.LOCATION') == "" || ValidationUtil.isValidUNCPath(this.get('backupSchedulerData.LOCATION'));
            this.set('backupSchedulerData.SHOW_AUTHENTICATION_REQUIRED', showAuthRequired);
            this.set('backupSchedulerData.bkLocation', showAuthRequired ? I18NUtil.translate('ads.admin.autobackup.shared') : I18NUtil.translate('ads.admin.autobackup.local'));
            this.set('backupSchedulerData.isAuthenticationEnabled', this.get('backupSchedulerData.LOGON_NAME') !== undefined);

            let enableBackup = this.get('backupSchedulerData.ENABLE_BACKUP');
            if (this.get('backupCalendarData.DAY_OF_WEEK') == -1)
            {
                this.set('backupCalendarData.DAY_OF_WEEK', "1");
            }
            if (this.get('backupCalendarData.DATE_OF_MONTH') == -1)
            {
                this.set('backupCalendarData.DATE_OF_MONTH', "01");
            }
            if (this.get('backupCalendarData.HOURS') == -1)
            {
                this.set('backupCalendarData.HOURS', "00");
            }
            if (this.get('backupCalendarData.MINUTES') == -1)
            {
                this.set('backupCalendarData.MINUTES', "00");
            }
            if (enableBackup != 'true')
            {
                this.set('backupCalendarData.REPEAT_FREQUENCY', "Daily");
            }
            this.set('backupSchedulerData.ENABLE_BACKUP', 'true');
            this.set('backupCalendarData.showDayOfWeek', this.get('backupCalendarData.REPEAT_FREQUENCY') == 'Weekly');
            this.set('backupCalendarData.showDateOfMonth', this.get('backupCalendarData.REPEAT_FREQUENCY') == 'Monthly');

            //Enable or Disable Status
            if (status != null)
            {
                this.set('backupSchedulerData.ENABLE_BACKUP', !status);
                this.send('saveBackupSettings');
            }
        },

        backupNow(productDetails)
        {
            let self = this;
            if (!self.isComponentRunning(productDetails))
            {
                return;
            }

            self.send('getBackupSettings', productDetails);
            let params = self.constructParams();
            CommonUtil.showLoading();
            AJAXUtil.ajax('/RestAPI/WC/AutoBackupAction?mTCall=backupNow', params, true)
                .then(function(response)
                {
                    let backupDetails = response;
                    if ('sSTATUS' in backupDetails)
                    {
                        self.sendAction('showStatus', 'success', I18NUtil.translate(backupDetails.sSTATUS), true);
                        if (backupDetails.sSTATUS === "ads.admin.autobackup.backupnow.status")
                        {
                            self.set('productDetails.isBackupRunning', true);
                        }
                    }
                    else
                    {
                        self.sendAction('showStatus', 'danger', 'eSTATUS' in response ? I18NUtil.translate(response.eSTATUS) : I18NUtil.translate('ads.admin.autobackup.failure'), false);
                        if (response.eSTATUS == 'ads.admin.autobackup.savesettings.authenticationrequired' || response.eSTATUS == 'ads.admin.autobackup.savesettings.readwritepermissiondenied' || response.eSTATUS == 'ads.admin.autobackup.savesettings.invalidbackuplocation')
                        {
                            self.set('showSettings', true);
                        }
                        if (response.eSTATUS === 'ads.admin.autobackup.savesettings.authenticationrequired')
                        {
                          self.set('backupSchedulerData.ERROR',response.eSTATUS);
                          self.set('backupSchedulerData.isAuthenticationEnabled', true);
                        }
                    }
                    self.send('getBackupHistory', productDetails);
                });
        },

        saveBackupSettings()
        {
            let self = this;
            if (!this.isValidParams())
            {
                return;
            }
            let params = this.constructParams();
            CommonUtil.showLoading();
            AJAXUtil.ajax('/RestAPI/WC/AutoBackupAction?mTCall=saveSchedulerSettings', params, true)
                .then(function(response)
                {
                    CommonUtil.hideLoading();
                    let backupDetails = response;
                    let isSuccess = true;
                    if (response.hasOwnProperty('eSTATUS'))
                    {
                        self.sendAction('showStatus', 'danger', I18NUtil.translate(response.eSTATUS), false);
                    }
                    else if (backupDetails === 'Failure')
                    {
                        isSuccess = false;
                    }
                    else
                    {
                        let status = backupDetails[0];
                        let reason = null;
                        for (let key in status)
                        {
                            if (key === 'EXCEPTION')
                            {
                                isSuccess = false;
                                reason = {};
                                reason.key = status.PRODUCT_NAME;
                                reason.value = status[key];
                            }
                        }

                        if (isSuccess)
                        {
                            let message = I18NUtil.translate('ads.admin.personalize.message.success');
                            self.sendAction('showStatus', 'success', message, true);
                            self.set('showSettings', false);
                        }
                        else
                        {
                            Ember.$('#failureMsgDiv').text(I18NUtil.translate(reason.value));
                            Ember.$('#globalFailureMsg').html(Ember.$('#failureMsgDiv').html());
                            self.sendAction('showStatus', 'danger', Ember.$('#globalFailureMsg').html(), false);
                            self.set('showSettings', true);
                        }

                        if (status.EXCEPTION === 'ads.admin.autobackup.savesettings.authenticationrequired')
                        {
                            self.set('backupSchedulerData.ERROR',status.EXCEPTION);
                            self.set('backupSchedulerData.isAuthenticationEnabled', true);
                        }
                        else if(status.EXCEPTION === 'ads.login.common.error.invalid_login')
                        {
                            self.set('backupSchedulerData.PASSWORD','');
                        }
                    }
                    if(isSuccess)
                    {
                        let productDetails = self.get('productDetails');
                        self.send('getBackupHistory', productDetails);
                    }
                });
        }
    }
});
//ignorei18n_end
