/*
 * $Id: auto-update.js,v 1.14 2018/12/26 11:58:08 ajith.k Exp $
 */
import Ember from 'ember'; //NO I18N
import AJAXUtil from 'webclient/utils/ajax-util'; //NO I18N
import I18NUtil from "webclient/utils/i18n-util"; //NO I18N

//ignorei18n_start

export default Ember.Component.extend({
  routing: Ember.inject.service('-routing'),
  patchDetails: {},
  creatorURL: null,
  buttons: null,
  icon:null,
  proxyLink: I18NUtil.translate('ads.support.roboupdate.proxy_link_url'),
  openDialog: function() {
    if (this.get('show')) {
      this.send('closeAlert');
      this.$('.modal').modal({
        backdrop: 'static',
        keyboard: false
      });
      this.getPatchDetails();
    } else {
      this.$('.modal').modal('hide');
    }
  }.observes('show'), //NO I18N

  getPatchDetails: function() {
    var self = this;
    this.set('icon',null);
	self.set('settings',true);
    this.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.support.roboupdate.checking_updates'));
    this.set('buttons', null);
    AJAXUtil.ajax('/RestAPI/WC/RoboUpdateAction?mTCall=getPatchDetails', {})
      .then(function(patchDetails) {
		if(patchDetails.hasOwnProperty('IS_DB_SUPPORTED')&& !patchDetails.IS_DB_SUPPORTED )
		{ 
			
			self.set('settings',false);
			self.set('patchDetails',{});
            self.set('patchDetails.IS_PATCH_AVAILABLE',false);
            self.set('icon','icn-modal-error');
            self.set('patchDetails.CLASS','unsupport-error');
            if(patchDetails.hasOwnProperty('eSTATUS'))
            {
                self.set('patchDetails.PATCH_STATUS',I18NUtil.translate(patchDetails.eSTATUS));
		    }
		}
		else if(patchDetails.hasOwnProperty('IS_HA_ENABLED')&& patchDetails.IS_HA_ENABLED)
		{
			self.set('settings',false);
			self.set('patchDetails',{});
            self.set('patchDetails.IS_PATCH_AVAILABLE',false);
            self.set('icon','icn-modal-error');
            self.set('patchDetails.CLASS','unsupport-error');
            self.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.roboupdate.ha.unsupported_message'));
		}
		else{
        if (patchDetails.hasOwnProperty('CREATOR_URL')) {
          self.set('creatorURL', patchDetails['CREATOR_URL']);
        }
        if(patchDetails.hasOwnProperty('IS_PATCH_AVAILABLE')&& patchDetails.IS_PATCH_AVAILABLE === true) {
          self.setPatchDetails(patchDetails);
        }
        else if(patchDetails.hasOwnProperty('eSTATUS'))
        {
          self.set('icon','icn-modal-error');
          self.set('patchDetails',{});
          self.set('patchDetails.CLASS','download-demo-error');
          self.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.common.error.demo_mode')); 
        }
        else {
          self.checkServerSide();
        }
		}
      });
  },

  checkServerSide: function() {
    var self = this;
    AJAXUtil.ajax('/RestAPI/WC/RoboUpdateAction?mTCall=checkVersion', {}, false, "html")
      .then(function(serverPatchDetails) {
        try {
          var jsonResponse = $.parseJSON(serverPatchDetails);
          if (jsonResponse.hasOwnProperty('IS_PATCH_AVAILABLE') || jsonResponse.hasOwnProperty('IS_DOWNLOAD_DONE') || jsonResponse.hasOwnProperty('IS_PREVIOUS_UPGRADE_FAILED')) {
            self.setPatchDetails(jsonResponse);
          } else {
            self.checkClientSide();
          }
        } catch (e) {
          self.checkClientSide();
        }
      });
  },

  checkClientSide: function() {
    var self = this;
    var url = self.get('creatorURL') + "&variable=patchString";
    var successStatus=null;
    $.ajax({
      url: url,
      dataType: 'script',
      success: function(){
          successStatus='success';
          if (typeof patchString == 'undefined') {
            self.set('icon','icn-modal-error');
	    self.set('patchDetails',{});
            self.set('patchDetails.CLASS','download-error');
            self.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.connection_error'));
            self.set('patchDetails.PATCH_STATUS', Ember.$('#downloadErrorDiv').html());
          } else if (patchString['Robo_Update_Manager'].length == 0) {
            self.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.no_updates_available'));
            self.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.support.roboupdate.in_latest_version_ember'));
            self.set('patchDetails.CLASS','download-completed');
            self.set('icon','icn-modal-download');
          } else {
            var data = {};
            data['patchString'] = JSON.stringify(patchString);
            var response = AJAXUtil.syncAjax('/RestAPI/WC/RoboUpdateAction?mTCall=savePatchSession', data);
          
            if (response.hasOwnProperty('IS_PATCH_AVAILABLE')) {
              self.setPatchDetails(response);
            }
          }
      },
      error: function(){
        successStatus='error';
        self.set('icon','icn-modal-error');
        self.set('patchDetails',{});
        self.set('patchDetails.CLASS','download-error');
        self.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.connection_error'));
        self.set('patchDetails.PATCH_STATUS', Ember.$('#downloadErrorDiv').html());
      },
    }).then(function()
	{
	    if(successStatus==null)
		{
			  self.set('icon','icn-modal-error');
			  self.set('patchDetails',{});
			  self.set('patchDetails.CLASS','download-error');
			  self.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.connection_error'));
			  self.set('patchDetails.PATCH_STATUS', Ember.$('#downloadErrorDiv').html());
		}
	});
  },

  setPatchDetails: function(patchDetails) {
     if (patchDetails.hasOwnProperty('IS_DOWNLOAD_DONE') && patchDetails['IS_DOWNLOAD_DONE']) {
      var buttons = [];
      buttons[0] = {
        'text': I18NUtil.translate('ads.support.roboupdate.upgrade_now'),
        'targetObject': this,
        'action': 'upgradeNow',
        'class' : 'btn-primary'
      };
      buttons[1] = {
        'text': I18NUtil.translate('ads.support.roboupdate.upgrade_later'),
        'targetObject': this,
        'action': 'upgradeLater',
        'class' : 'btn-default btn-left-space'
      };
      this.set('icon','icn-modal-download');
      this.set('patchDetails', patchDetails);
      this.set('patchDetails.CLASS','download-completed');
      this.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.download_complete_text'));
      this.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.support.roboupdate.product_restart_text'));
      this.set('buttons', buttons);
    } 
    else if (patchDetails.hasOwnProperty('IS_PREVIOUS_UPGRADE_FAILED') && patchDetails['IS_PREVIOUS_UPGRADE_FAILED']) {
      this.set('icon','icn-modal-error');
      this.set('patchDetails', patchDetails);
      this.set('patchDetails.CLASS','download-error');
      this.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.upgrade_failed'));
      this.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.support.roboupdate.previous_upgrade_failed', [patchDetails['buildNo']]));
      this.set('buttons', null);
    } 
    else if (patchDetails.hasOwnProperty('IS_PATCH_AVAILABLE') && patchDetails.IS_PATCH_AVAILABLE == true) {
      this.set('patchDetails', patchDetails);
      this.set('icon','icn-modal-update');
      var buttons = [];
      buttons[0] = {
        'text': I18NUtil.translate('ads.support.roboupdate.download_now'),
        'targetObject': this,
        'action': 'downloadNow',
        'class' : 'btn-primary'
      };
      buttons[1] = {
        'text': I18NUtil.translate('ads.support.roboupdate.release_notes'),
        'targetObject': this,
        'action': 'showReleaseNotes',
        'class' : 'btn-default btn-left-space'
      };
      this.set('buttons', buttons);
    }else {
      this.set('icon','icn-modal-download');
      this.set('patchDetails', patchDetails);
      this.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.no_updates_available'));
      this.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.support.roboupdate.in_latest_version_ember'));
      this.set('patchDetails.CLASS','download-completed');
    }
  },

  actions: {
    closeDialog: function() {
      this.set('show', false); //No I18N
      this.send('toggleSettings',true);
    },
    performAction: function(button) {
      if (button != null) {
        if (button.hasOwnProperty('targetObject')) {
          button.targetObject.send(button.action);
        }
      }
    },
    downloadNow: function() {
      var self = this;
      self.set('icon',null);
      self.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.support.roboupdate.downloading'));
      self.set('buttons', null);

      AJAXUtil.ajax('/RestAPI/WC/RoboUpdateAction?mTCall=download', {})
        .then(function(response) {
          if (response.hasOwnProperty('IS_DOWNLOAD_DONE') && response['IS_DOWNLOAD_DONE']) {
            self.setPatchDetails(response);
          } else {
            self.set('patchDetails',{});
            self.set('patchDetails.IS_PATCH_AVAILABLE',false);
            self.set('icon','icn-modal-error');
            self.set('patchDetails.CLASS','download-error');
            self.set('patchDetails.PATCH_STATUS_HEADER', I18NUtil.translate('ads.support.roboupdate.connection_error'));
            self.set('patchDetails.PATCH_STATUS', Ember.$('#downloadErrorDiv').html());
          }
        });

    },
    showReleaseNotes: function() {
      var url = I18NUtil.translate('ads.support.roboupdate.release_notes_link');
      window.open(url);
    },
    upgradeNow: function() {
      AJAXUtil.ajax('/RestAPI/WC/RoboUpdateAction?mTCall=upgradeNow', {});
      this.set('icon',null);
      this.set('patchDetails.PATCH_STATUS', I18NUtil.translate('ads.support.roboupdate.upgrade_now_restart_message'));
      this.set('buttons', null);
    },
    upgradeLater: function() {
      this.set('show', false);
    },
    redirectToProxy: function() {
      this.get('routing').transitionTo(this.get('proxyLink'));
      this.set('show', false);
    },
    toggleSettings:function(hide)
    {
      if($('#SETTINGS').css('display')=='block' || hide)
      {
        $('#SETTINGS').hide();
        $('#ROBO_UPDATE').show();
      }
      else
      {
        $('#SETTINGS').show();
        $('#ROBO_UPDATE').hide();
      }
    },
    showStatus:function(alertType,message,id)
    {
      var self=this;
      self.$(".mini-status-alert").hide();
      self.set('configStatusMessage', message);
      self.set('configStatusAlertType', alertType);
      self.$(".mini-status-alert").delay(500).slideDown('slow');
      if(alertType=='success')
      {
        self.$(".mini-status-alert").delay(500).slideUp('slow'); 
      }
      Ember.$('[aria-controls]').unbind('click');
      Ember.$('[aria-controls]').on('click',function(){
        if(Ember.$(this).attr('aria-controls')!=id)
        {
          self.$(".mini-status-alert").delay(50).slideUp('slow');   
        }
      });
    },
    closeAlert: function() 
    {
      this.$(".mini-status-alert").delay(50).slideUp('slow');
    },
    refreshRoboUpdate: function()
    {
      if(this.get('controller')!=null)
      {
        var actionName=this.get('actionName');
        this.get('controller').send(actionName);
      }
    },
    onAction: function (action) {
      if (action == 'beforeSave') {
        this.set('isLoading', true);
      } else if (action == 'afterSave') {
        this.set('isLoading', false);
      }
    }
  },
  didInsertElement: function() {
    var self = this;
    self.$('.modal').on('hidden.bs.modal', function() {
      self.sendAction();
    });
  }
});

//ignorei18n_end