/*
 * $Id: autobackup-settings.js,v 1.2 2018/12/24 13:59:09 ajith.k Exp $
 */

//ignorei18n_start
import Ember from 'ember';
import I18NUtil from "../utils/i18n-util";
import CommonUtil from "../utils/ads-common-util";

export default Ember.Component.extend({
    backupSchedulerData: null,
    backupCalendarData: null,
    configuredProducts: null,
    usernamePlaceholder: I18NUtil.translate('ads_admin_product_settings_ha_credentials_popup_user_placeholder'),

    didUpdateAttrs()
    {
        //for backward compatibility
        if (this.get('backupSchedulerData.DAYS_TO_OVERWRITE'))
        {
            this.set('backupSchedulerData.bkLocation', I18NUtil.translate('ads.admin.autobackup.local'));
            this.set('backupSchedulerData.DISABLE_LOCAL_PATH', true);
            let clientValuesForDeleteBackup = [I18NUtil.translate('ads.admin.autobackup.delete_last_15days'), I18NUtil.translate('ads.admin.autobackup.delete_last_30days')];
            let serverValuesForDeleteBackup = ["15D", "30D"];
            let dropDownValuesForDeleteBackup = CommonUtil.setDropDownValues(clientValuesForDeleteBackup, serverValuesForDeleteBackup);
            this.set('DELETE_BACKUP', dropDownValuesForDeleteBackup);
            this.set('maintainBackupText', I18NUtil.translate('ads.admin.autobackup.delete_message_old'));
            Ember.$('#maintainBackupText').attr('data-original-title', this.get('maintainBackupText'));
        }
        else
        {
            let clientValuesForDeleteBackup = [
                [I18NUtil.translate('ads.admin.autobackup.delete_last_15days'), I18NUtil.translate('ads.admin.autobackup.delete_last_30days')],
                [I18NUtil.translate('ads.admin.autobackup.delete_last_10files'), I18NUtil.translate('ads.admin.autobackup.delete_last_20files'), I18NUtil.translate('ads.admin.autobackup.delete_last_30files')],
                [I18NUtil.translate('ads.admin.autobackup.maintain_backupfiles.all')]
            ];
            let serverValuesForDeleteBackup = [
                ["15D", "30D"],
                ["10F", "20F", "30F"],
                ["-1F"]
            ];
            let dropDownValuesForDeleteBackup = CommonUtil.setDropDownValues(clientValuesForDeleteBackup, serverValuesForDeleteBackup);
            this.set('DELETE_BACKUP', dropDownValuesForDeleteBackup);
            this.set('maintainBackupText', I18NUtil.translate('ads.admin.autobackup.delete_message'));
            Ember.$('#maintainBackupText').attr('data-original-title', this.get('maintainBackupText'));
        }

        //Show hourly backup only for existing users
        //TODO: need to remove this after all users have been updated to latest version, and no one is using hourly backup
        let clientValuesForRepeatFrequencies,
            serverValuesForRepeatFrequencies,
            minutes;
        if (this.get('backupCalendarData.REPEAT_FREQUENCY') === 'Hourly')
        {
            clientValuesForRepeatFrequencies = ["Hourly", I18NUtil.translate('ads.support.roboupdate.repeat.daily'), I18NUtil.translate('ads.support.roboupdate.repeat.weekly'), I18NUtil.translate('ads.support.roboupdate.repeat.monthly')];
            serverValuesForRepeatFrequencies = ["Hourly", "Daily", "Weekly", "Monthly"];
            this.set('repeatFrequencyText', I18NUtil.translate('ads.admin.autobackup.onceinevery'));
            minutes = ["05", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55"];
        }
        else
        {
            clientValuesForRepeatFrequencies = [I18NUtil.translate('ads.support.roboupdate.repeat.daily'), I18NUtil.translate('ads.support.roboupdate.repeat.weekly'), I18NUtil.translate('ads.support.roboupdate.repeat.monthly')];
            serverValuesForRepeatFrequencies = ["Daily", "Weekly", "Monthly"];
            this.set('repeatFrequencyText', I18NUtil.translate('ads.admin.autobackup.at'));
            minutes = ["00", "05", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55"];
        }
        let dropDownValuesForRepeatFrequencies = CommonUtil.setDropDownValues(clientValuesForRepeatFrequencies, serverValuesForRepeatFrequencies);
        this.set('REPEAT_FREQUENCIES', dropDownValuesForRepeatFrequencies);
        let dropDownValuesForMinutes = CommonUtil.setDropDownValues(minutes, minutes);
        this.set('MINUTES', dropDownValuesForMinutes);

        let isLocalPath = this.get('backupSchedulerData.bkLocation') == 'Local';
        Ember.run.scheduleOnce('afterRender', function() {
            Ember.$('#BACKUP_LOCATION').attr('placeholder', isLocalPath ? "<drive_letter>:\\<path>" : "\\\\server\\share\\path");
        });

        CommonUtil.renderSelect();
    },

    setup: Ember.on('init', function()
    {
        let clientValuesForRepeatFrequencies = [I18NUtil.translate('ads.support.roboupdate.repeat.daily'), I18NUtil.translate('ads.support.roboupdate.repeat.weekly'), I18NUtil.translate('ads.support.roboupdate.repeat.monthly')];
        let serverValuesForRepeatFrequencies = ["Daily", "Weekly", "Monthly"];
        let dropDownValuesForRepeatFrequencies = CommonUtil.setDropDownValues(clientValuesForRepeatFrequencies, serverValuesForRepeatFrequencies);
        this.set('REPEAT_FREQUENCIES', dropDownValuesForRepeatFrequencies);

        let clientValuesForDayOfWeek = [I18NUtil.translate('ads.support.roboupdate.day.sunday'), I18NUtil.translate('ads.support.roboupdate.day.monday'), I18NUtil.translate('ads.support.roboupdate.day.tuesday'), I18NUtil.translate('ads.support.roboupdate.day.wednesday'), I18NUtil.translate('ads.support.roboupdate.day.thursday'), I18NUtil.translate('ads.support.roboupdate.day.friday'), I18NUtil.translate('ads.support.roboupdate.day.saturday')];
        let serverValuesForDayOfWeek = ["1", "2", "3", "4", "5", "6", "7"];
        let dropDownValuesForDayOfWeek = CommonUtil.setDropDownValues(clientValuesForDayOfWeek, serverValuesForDayOfWeek);
        this.set('DAYS', dropDownValuesForDayOfWeek);

        let months = ["01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31"];
        let dropDownValuesForMonths = CommonUtil.setDropDownValues(months, months);
        this.set('MONTHS', dropDownValuesForMonths);

        let hours = ["00", "01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23"];
        let dropDownValuesForHours = CommonUtil.setDropDownValues(hours, hours);
        this.set('HOURS', dropDownValuesForHours);

        let minutes = ["00", "05", "10", "15", "20", "25", "30", "35", "40", "45", "50", "55"];
        let dropDownValuesForMinutes = CommonUtil.setDropDownValues(minutes, minutes);
        this.set('MINUTES', dropDownValuesForMinutes);

        let clientValuesForDeleteBackup = [
            [I18NUtil.translate('ads.admin.autobackup.delete_last_15days'), I18NUtil.translate('ads.admin.autobackup.delete_last_30days')],
            [I18NUtil.translate('ads.admin.autobackup.delete_last_10files'), I18NUtil.translate('ads.admin.autobackup.delete_last_20files'), I18NUtil.translate('ads.admin.autobackup.delete_last_30files')],
            [I18NUtil.translate('ads.admin.autobackup.maintain_backupfiles.all')]
        ];
        /* D - denotes Days, F - denotes Files */
        let serverValuesForDeleteBackup = [
            ["15D", "30D"],
            ["10F", "20F", "30F"],
            ["-1F"]
        ];
        let dropDownValuesForDeleteBackup = CommonUtil.setDropDownValues(clientValuesForDeleteBackup, serverValuesForDeleteBackup);
        this.set('DELETE_BACKUP', dropDownValuesForDeleteBackup);
    }),

    actions:
    {
        saveBackupSettings()
        {
            this.sendAction('saveBackupSettings');
        },

        toggleLocationType(isLocalPath)
        {
            let selected = this.get('backupSchedulerData.bkLocation') == I18NUtil.translate('ads.admin.autobackup.local');
            if (isLocalPath != selected)
            {
                this.set('backupSchedulerData.bkLocation', isLocalPath ? I18NUtil.translate('ads.admin.autobackup.local') : I18NUtil.translate('ads.admin.autobackup.shared'));
                this.set('backupSchedulerData.SHOW_AUTHENTICATION_REQUIRED', !isLocalPath);
                Ember.$('#BACKUP_LOCATION').attr('placeholder', isLocalPath ? "<drive_letter>:\\<path>" : "\\\\server\\share\\path");
                if (this.get('backupSchedulerData.LOCATION') !== '')
                {
                    this.set('backupSchedulerData.LOCATION', '');
                }
                if(isLocalPath)
                {
                  this.set('backupSchedulerData.isAuthenticationEnabled',false);
                  this.set('backupSchedulerData.LOGON_NAME','');
                  this.set('backupSchedulerData.PASSWORD','');
                }
            }
        },

        toggleAuthentication(val)
        {
            Ember.$('#SHARE_CREDENTIALS').slideToggle(800);
            this.set('backupSchedulerData.isAuthenticationEnabled', val);
            if(this.get('backupSchedulerData.ERROR') === 'ads.admin.autobackup.savesettings.authenticationrequired')
            {
                Ember.$('#SERVER_USERNAME').focus();
            }
        },

        repeatFrequencyChanged(text, value)
        {
            this.set('backupCalendarData.showDayOfWeek', value === 'Weekly');
            this.set('backupCalendarData.showDateOfMonth', value === 'Monthly');
            this.set('repeatFrequencyText', value === 'Hourly' ? I18NUtil.translate('ads.admin.autobackup.onceinevery') : I18NUtil.translate('ads.admin.autobackup.at'));
            CommonUtil.renderSelect();
        },

        cancel()
        {
            this.set('showSettings', false);
            Ember.$('#FORM_STATUS').delay(500).slideUp('slow');
        }
    }
});
//ignorei18n_end
