/*
 * $Id: contextbased-reverseproxy.js,v 1.19 2018/12/26 11:58:08 ajith.k Exp $
 */
//ignorei18n_start
import Ember from 'ember';
import AJAXUtil from '../utils/ads-ajax-util';
import I18NUtil from "../utils/i18n-util";
import ValidationUtil from "../utils/ads-validation-util";
import CommonUtil from '../utils/ads-common-util';
import DialogUtil from "../utils/ads-dialog-util";

export default Ember.Component.extend({
  config: {},
  isConfigured: false,
  protocol: "HTTP",
  port: 80,
  host: "",
  productConfig: [],
  integratedProducts: [],
  isEnabled: false,
  isDisabled: false,
  isProtocolSelectionDisabled: false,
  isHttps: false,
  freezeStyle: '',
  protocols: [{
    'CLIENT_VALUE': 'HTTP',
    'SERVER_VALUE': 'HTTP'
  }, {
    'CLIENT_VALUE': 'HTTPS',
    'SERVER_VALUE': 'HTTPS'
  }],
  pageStatus: {},
  getSettings: function() {
    var response = AJAXUtil.syncAjax("/RestAPI/WC/ReverseProxy?mTCall=getContextBasedConfig", {});
    var configId = null;
    this.set('config', response.CONFIG);
    this.set('productConfig', []);
    this.set('isEnabled', false);
    Ember.$('#FORM_STATUS').hide();
    if (response.CONFIG.hasOwnProperty('PROTOCOL')) {
      configId = response.CONFIG.CONFIG_ID;
      this.set('isConfigured', response.CONFIG.IS_ENABLED);
      this.set('isEnabled', response.CONFIG.IS_ENABLED);
      this.set('protocol', response.CONFIG.PROTOCOL.toUpperCase());
      this.set('port', response.CONFIG.PORT);

      for (var i = 0; i < response.CONFIG.PRODUCT_CONFIG.length; i++) {
        response.CONFIG.PRODUCT_CONFIG[i].PROTOCOL = response.CONFIG.PRODUCT_CONFIG[i].PROTOCOL.toUpperCase();
        
        if (!response.CONFIG.IS_ENABLED) {
          response.CONFIG.PRODUCT_CONFIG[i].IS_ENABLED = false;
        }
      }
      this.set('productConfig', response.CONFIG.PRODUCT_CONFIG);
    } else {
      this.set('isConfigured', false);
      this.set('isEnabled', false);
    }
    this.set('host', response.CONFIG.HOST);

    var productConfig = this.get('productConfig');
    for (var j = 0; j < response.PRODUCTS.length; j++) {
      response.PRODUCTS[j].CONTEXT = response.PRODUCTS[j].TAG_NAME.toLowerCase();
      response.PRODUCTS[j].PROTOCOL = response.PRODUCTS[j].PROTOCOL.toUpperCase();
      response.PRODUCTS[j].IS_ENABLED = configId == null ? true : false;
      productConfig[productConfig.length] = response.PRODUCTS[j];
      if (response.PRODUCTS[j].PROTOCOL == 'HTTPS') {
        if (this.get('isConfigured') == false) {
          this.set('protocol', 'HTTPS');
          this.set('port', 443);
        }
      }
    }
    this.setHttps();
    this.sortProductConfig();
    this.set('integratedProducts', response.PRODUCTS);
  }.on('init'),

  sortProductConfig: function() {
    var productConfig = this.get('productConfig');
    for (var i = 0; i < productConfig.length - 1; i++) {
      for (var j = i + 1; j < productConfig.length; j++) {
        if (productConfig[i].PRODUCT_ID > productConfig[j].PRODUCT_ID) {
          var tempConfig = productConfig[i];
          productConfig[i] = productConfig[j];
          productConfig[j] = tempConfig;
        }
      }
    }
  },
  setPort: function() {
    if (this.get('protocol') == 'HTTPS' && this.get('port') == 80) {
      this.set('port', 443);
    } else if (this.get('protocol') == 'HTTP' && this.get('port') == 443) {
      this.set('port', 80);
    }
  }.observes('protocol'),

  setProtocolEnabled: function() {
    if ((this.get('isHttps') == true && this.get('protocol') == 'HTTPS') || this.get('isDisabled') == true) {
      this.set('isProtocolSelectionDisabled', true);
    } else {
      this.set('isProtocolSelectionDisabled', false);
    }
  }.observes('isDisabled,isHttps'),

  enableDisableSettings: function() {
    if (this.get('isEnabled') === true) {
      this.set('freezeStyle', 'disable');
      this.set('isDisabled', false);
    } else {
      this.set('freezeStyle', '');
      this.set('isDisabled', true);
    }
  }.observes('isEnabled'),

  isValidContext: function(context) {
    if (context == null) {
      return 'ads.admin.reverseproxy.empty_context_for_product';
    } else if (context.length > 15) {
      return 'ads.admin.reverseproxy.invalid_context_length_for_product';
    } else if (!/^[a-zA-Z0-9]+$/.test(context) && context != '') {
      return 'ads.admin.reverseproxy.special_chars_in_context_for_product';
    } else {
      return 'true';
    }
  },

  isValidPort: function(port) {
    var intPort = parseInt(port);
    if (port == '' || port == null) {
      return 'ads.admin.reverseproxy.empty_port';
    } else if (!ValidationUtil.isValidPort(port)) {
      return 'ads.admin.reverseproxy.invalid_port';
    } else if (ValidationUtil.isBlockedPort(intPort)) {
      return 'ads.admin.reverseproxy.blocked_port';
    } else {
      return 'true';
    }
  },

  setHttps: function() {

    var productConfig = this.get('productConfig');
    var isHttpsEnabled = false;
    for (var i = 0; i < productConfig.length; i++) {
      if (productConfig[i].IS_ENABLED == true && productConfig[i].PROTOCOL == 'HTTPS') {
        isHttpsEnabled = true;
        break;
      }
    }

    if (isHttpsEnabled == true) {
      this.set('protocol', 'HTTPS');
      if (this.get('port') == 80) {
        this.set('port', 443);
      }
    }
    Ember.set(this, 'isHttps', isHttpsEnabled);
  },
  actions: {

    toggleAllEnabled: function(val) {

      if (val != this.get('isEnabled')) {
        var productConfig = this.get('productConfig');
        this.set('isEnabled', val);
        for (var i = 0; i < productConfig.length; i++) {
          Ember.set(productConfig[i], 'IS_ENABLED', val);
        }
      }
      this.setHttps();
    },

    enableSettings: function(val) {
      var self = this;

      var data = {
        'CONFIG_ID': this.get('config.CONFIG_ID'),
        'IS_ENABLED': val
      };
      CommonUtil.showLoading();
      AJAXUtil.ajax("/RestAPI/WC/ReverseProxy?mTCall=setEnabled", data).then(function(response) {
        if (response.hasOwnProperty('STATUS') && response.STATUS == 'SUCCESS') {
          self.getSettings();
          self.sendAction('showStatus','success', I18NUtil.translate('ads.admin.reverseproxy.saved_successfully'), true);
          window.WindowHandler.sendRequest(top, 'reloadAppsPane', '[]');
        } else {
          var message = response.hasOwnProperty('DATA') ? I18NUtil.translate(response.STATUS_MESSAGE, response.DATA) : I18NUtil.translate(response.STATUS_MESSAGE);
          self.sendAction('showStatus','danger', message, true);
        }
        CommonUtil.hideLoading();
      });

    },

    toggleEnabled: function(productConfig) {
      Ember.set(productConfig, 'IS_ENABLED', !productConfig.IS_ENABLED);
      this.setHttps();
    },

    saveSettings: function() {

      var configData = {};
      var self = this;
      var isAnyEnabled = false;
      var port = this.get('port');
      var isValidPort = self.isValidPort('' + port);
      if (isValidPort != 'true') {
        DialogUtil.alert(self, I18NUtil.translate(isValidPort));
        return;
      }
      
      this.set('port', parseInt(port, 10));
      
      configData.PROTOCOL = this.get('protocol');
      configData.PORT = "" + this.get('port');
      configData.IS_CONTEXT_BASED = "true";
      configData.IS_ENABLED = "true";

      if (this.get('config').hasOwnProperty('CONFIG_ID')) {
        configData.CONFIG_ID = "" + this.get('config.CONFIG_ID');
      } else if (this.get('isEnabled') == false) {
        // Returning since nothing is changed
        return;
      }


      var contextMap = {};
      var productConfigData = [];
      var productConfig = this.get('productConfig');
      for (var i = 0; i < productConfig.length; i++) {
        if (productConfig[i].IS_ENABLED == true) {
          isAnyEnabled = true;
          var context = productConfig[i].CONTEXT.toLowerCase();
          var isValidContext = self.isValidContext(context);
          if (isValidContext != 'true') {
            DialogUtil.alert(self, I18NUtil.translate(isValidContext, [productConfig[i].DISPLAY_NAME]), true);
            return;
          }
          if (contextMap.hasOwnProperty(context)) {
            DialogUtil.alert(self, I18NUtil.translate('ads.admin.reverseproxy.context_already_present_for_product', [productConfig[i].DISPLAY_NAME]), true);
            return;
          }
          if (productConfig[i].PRODUCT_NAME == 'ManageEngine Exchange Reporter Plus' && context == 'exchange') {
            DialogUtil.alert(self, I18NUtil.translate('ads.admin.reverseproxy.context_already_present_for_product', [productConfig[i].DISPLAY_NAME]), true);
            return;
          }
          contextMap[context] = context;
          if (productConfig[i].PROTOCOL == 'HTTPS' && configData.PROTOCOL == 'HTTP') {
            DialogUtil.alert(self, I18NUtil.translate('ads.admin.reverseproxy.select_https'), true);
            return;
          }
        }
        productConfigData[productConfigData.length] = {
          'PRODUCT_ID': "" + productConfig[i].PRODUCT_ID,
          'CONTEXT': productConfig[i].CONTEXT.toLowerCase(),
          'PROTOCOL': productConfig[i].PROTOCOL,
          'IS_ENABLED': productConfig[i].IS_ENABLED
        };

      }

      if (isAnyEnabled == false) {
        this.send('enableSettings', false);
        return;
      }

      configData['PRODUCT_CONFIG'] = productConfigData;
      CommonUtil.showLoading();
      AJAXUtil.ajax("/RestAPI/WC/ReverseProxy?mTCall=saveConfig", {
        'CONFIG': JSON.stringify(configData)
      }).then(function(response) {
        if (response.hasOwnProperty('STATUS') && response.STATUS == "SUCCESS") {
          self.getSettings();
          self.send('startServer');
        } else if (response.hasOwnProperty('eSTATUS')) {
           self.sendAction('showStatus','danger', response.eSTATUS, false);
        } else {
          var message = response.hasOwnProperty('DATA') ? I18NUtil.translate(response.STATUS_MESSAGE, response.DATA) : I18NUtil.translate(response.STATUS_MESSAGE);
          self.sendAction('showStatus','danger', message, false);
        }
        CommonUtil.hideLoading();
      });

    },

    cancelSettings: function() {
      this.getSettings();
    },

    startServer: function() {
      var self = this;
      var configId = this.get('config.CONFIG_ID');
      var response = AJAXUtil.syncAjax("/RestAPI/WC/ReverseProxy?mTCall=startServer", {
        'CONFIG_ID': configId
      });
      if (response.hasOwnProperty('STATUS') && response.STATUS == 'SUCCESS') {
        self.sendAction('showStatus','success', I18NUtil.translate('ads.admin.reverseproxy.saved_successfully'), true);
        window.WindowHandler.sendRequest(top, 'reloadAppsPane', '[]');
      } else {
        var message = response.hasOwnProperty('DATA') ? I18NUtil.translate(response.STATUS_MESSAGE, response.DATA) : I18NUtil.translate(response.STATUS_MESSAGE);
        self.sendAction('showStatus','danger', message, true);
      }
    }
  }
});


//ignorei18n_end