/*$Id$*/
/**
 * {{integration-settings visibleTabs=visibleTabs productName=productName doRefresh=doRefresh syncNow='syncNow' getDownTime='getProductDownTime' refreshGlobalData='refreshGlobalData' showStatus='showStatus' syncData=syncData}}
 */
//ignorei18n_start
import Ember from 'ember';
import I18NUtil from "../utils/i18n-util"; //NO I18N
import DialogUtil from "../utils/ads-dialog-util"; //NO I18N
import CommonUtil from "../utils/ads-common-util"; //NO I18N
import AJAXUtil from '../utils/ads-ajax-util'; //NO I18N

export default Ember.Component.extend({
  productName: null,
  pageStatus: {},
  currentTab: null,
  isIntegrated: null,
  isTabChanged: false,
  hideDetails: false,
  isEnabled: null,
  showSyncButton: false,
  enableDisableCheckBox: null,
  syncFailureReason: null,
  tabs: null,
  serverData: null,
  isSecondaryProductPresent: null,
  isTabToggleButtonEnabled: false,
  protocols: [{
    'CLIENT_VALUE': 'HTTP',
    'SERVER_VALUE': 'HTTP'
  }, {
    'CLIENT_VALUE': 'HTTPS',
    'SERVER_VALUE': 'HTTPS'
  }],

  init() {
    this._super();
    this.send('getSettings'); //No i18n
  },
  refreshSettings: Ember.observer('doRefresh', function () {
    this.send('getSettings'); //No i18n
  }),
  doSetCurrTab: Ember.observer('doSetCurrentData', function () {
    this.send('setCurrentTab');
  }),
  doSetServerData: Ember.observer('productsStatus', function () {
    this.set('serverData', null);
    this.setServerData(this.get('productsStatus'));
  }),
  syncListener: Ember.observer('syncData.isSyncStarted', function () {
    if (this.get('syncData.isSyncStarted')) {
      this.send('getIntegratedProductsStatus');
    }
  }),
  isHidden: function () {
    var currentTab = this.get('currentTab');
    if (currentTab != null) {
      return !(currentTab.IS_ENABLED == 'true' || currentTab.IS_ENABLED == true);
    }
    return false;
  }.property('currentTab.IS_ENABLED'),

  setCurrentTab: function () {
    var tab = this.get('currentTab');
    if (tab != null) {
      this.$("[INTEG_TAB_ID]").removeClass('active');
      this.$('[IS_PRIMARY_PRODUCT=false][IS_INTEGRATED=true]').each(function () {
        Ember.$(this).show();
      });
      this.$("[INTEG_TAB_ID='" + tab.PRODUCT_ID + "']").addClass(
        "active");
      if (tab.hasOwnProperty('IS_INTEGRATED')) {
        this.set('isIntegrated', true);
      } else {
        this.set('isIntegrated', null);
      }
      if (tab.IS_ENABLED) {
        this.set('isEnabled', true);
        this.set('hideDetails', false);
        this.set('enableDisableCheckBox', null);
      } else {
        this.set('isEnabled', null);
        this.set('hideDetails', true);
        this.set('enableDisableCheckBox', 'disabled');
      }
    }
  }.observes('currentTab.PRODUCT_ID'),

  setServerData: function (serverResponse) {

    var isInitialized = true;
    var index = 0;
    var self = this;
    var tabs = [];
    this.set('isSecondaryProductPresent', null);
    self.set('syncData.showSyncButton', false);
    if (this.get('serverData') == null) {
      this.set('serverData', {});
      this.set('tabs', []);
      isInitialized = false;
    }
    for (var i = 0; i < serverResponse.length; i++) {
      serverResponse[i].INDEX = i;
      if (serverResponse[i].hasOwnProperty('IS_INTEGRATED')) {
        this.set('syncData.showSyncButton', true);
      } else {
        serverResponse[i].HOST = "";
        serverResponse[i].PORT = "";
        serverResponse[i].PROTOCOL = "HTTP";
      }
      if (!serverResponse[i].IS_PRIMARY_PRODUCT) {
        this.set('isSecondaryProductPresent', true);
      }
      if (serverResponse[i].hasOwnProperty('PROMOTIONAL_DETAILS')) {
        serverResponse[i].PROMO_LOGO = serverResponse[i].TAG_NAME.toLowerCase();
      }

      this.set('serverData.' + serverResponse[i].PRODUCT_ID, serverResponse[i]);

      if (!isInitialized) {
        var tab = {};
        if (self.get('productName') != null && self.get('productName') == serverResponse[i].DISPLAY_NAME) {
          index = i;
        }
        tab.PRODUCT_ID = serverResponse[i].PRODUCT_ID;
        tab.PRODUCT_NAME = serverResponse[i].DISPLAY_NAME;
        tab.SERVER_STATUS = serverResponse[i].SERVER_STATUS;
        tab.TAG_NAME = serverResponse[i].TAG_NAME;
        tab.ICON_STYLE = tab.TAG_NAME.toLowerCase();
        tab.IS_PRIMARY_PRODUCT = serverResponse[i].IS_PRIMARY_PRODUCT;
        tab.IS_INTEGRATED = serverResponse[i].IS_INTEGRATED;
        tab.IS_ENABLED = serverResponse[i].IS_ENABLED;
        tabs[i] = tab;
      }
    }

    if (self.get('currentTab') != null) {
      var currentTab = self.get('currentTab');
      this.$('[integ_tab_id=' + currentTab.PRODUCT_ID + ']').show();
    }

    if (!isInitialized) {
      this.set('tabs', tabs);
      Ember.run.schedule('afterRender', this,function () //NO I18N
        {
          if (self.get('currentTab') == null && self.get('productName') == null) {
            self.set('currentTab', Ember.$.extend(true, {}, serverResponse[0]));
          } else if (self.get('productName') != null) {
            self.set('currentTab', Ember.$.extend(true, {}, serverResponse[index]));
            self.set('productName', null);
          } else {
            self.send('changeTab', self.get('currentTab'));
          }
          if (self.get('visibleTabs') != null) {
            var visibleTabs = self.get('visibleTabs');
            for (var j = 0; j < visibleTabs.length; j++) {
              this.$('[integ_tab_id=' + visibleTabs[j] + ']').show();
            }
          }
        });
    }
  },
  willDestroyElement: function () {
  },
  actions: {
    getSettings: function () {
      var responseData = AJAXUtil.syncAjax("/RestAPI/WC/Integration?mTCall=getIntegratedProducts", {});
      this.setServerData(responseData);
      this.send('getIntegratedProductsStatus');
    },
    getIntegratedProductsStatus: function () {
      var self = this;
      AJAXUtil.ajax("/RestAPI/WC/Integration?mTCall=getIntegratedProductsStatus",{}).then(function(responseData){
        try{
        self.set('productsStatus', responseData);//will trigger observer to set server status
        self.sendAction('refreshGlobalData',true); //refresh global application data if any
        self.sendAction('getDownTime', {
          responseData
        }); //No i18n
      }catch(error){
      }        
      });
    },
    setVisibleTabs: function () {
      var self = this;
      var visibleTabs = [];
      this.$('[IS_PRIMARY_PRODUCT=false]').each(function () {
        if (self.$(this).css('display') != 'none') {
          visibleTabs.push(self.$(this).attr('integ_tab_id'));
        }
      });
      self.set('visibleTabs', visibleTabs);
    },
    changeTab: function (tab) {
      this.$('#IS_AUTHENTICATION_REQUIRED').iCheck('uncheck'); //NO I18N
      var serverData = this.get('serverData');
      this.set('currentTab', Ember.$.extend(true, {}, serverData[tab.PRODUCT_ID]));
      this.set('serverTabData', Ember.$.extend(true, {}, serverData[tab.PRODUCT_ID]));
      CommonUtil.afterRender();
      this.set('LEFT_TOGGLE', true);
      this.set('RIGHT_TOGGLE', true);
      if ((this.get('tabs').length - 1) == this.get('currentTab').INDEX) {
        this.set('RIGHT_TOGGLE', false);
      } else if (this.get('currentTab').INDEX == 0) {
        this.set('LEFT_TOGGLE', false);
      }
      this.$('[integ_tab_id=' + tab.PRODUCT_ID + ']').show();

      var toolPosition = this.$('.tab-tool-set').position();
      var productPosition = this.$('[integ_tab_id=' + tab.PRODUCT_ID + ']').position();
      if (productPosition == null) {
        return;
      }

      var productWidth = this.$('[integ_tab_id=' + tab.PRODUCT_ID + ']').width();
      var tabPosition = parseInt(this.$('.slider-tab').css('margin-left'));
      var calc;
      if (productPosition.left < 0) {
        calc = tabPosition - productPosition.left;
        this.$('.slider-tab').animate({
          'margin-left': calc
        });
      } else {
        calc = productWidth - (toolPosition.left - productPosition.left);
        if (calc > 0) {
          calc += Math.abs(tabPosition);
          this.$('.slider-tab').animate({
            'margin-left': calc * -1
          });
        }
      }

    },

    toggleAuthentication: function (val) {
      if (!val) {
        this.set('currentTab.USERNAME', '');
        this.set('currentTab.PASSWORD', '');
      }
      $('#ADMIN_CREDENTIALS').slideToggle(800);
    },
    changeSideTab: function (val) {
      var currentTabIndex = this.get('currentTab').INDEX;
      var tabs = this.get('tabs');
      var nextTab = null;
      if (val) {
        nextTab = tabs[currentTabIndex - 1];
      } else {
        nextTab = tabs[currentTabIndex + 1];
      }
      if (nextTab) {
        this.send('changeTab', nextTab);
      }
    },
    enableDisable: function () {
      var status = {};
      var self = this;
      self.send('setVisibleTabs');
      var tab = this.get('currentTab');
      var params = {};
      params['PRODUCT_ID'] = tab.PRODUCT_ID;
      params['IS_ENABLED'] = !tab.IS_ENABLED;
      params['IS_EMBER'] = true;
      if (tab.IS_ENABLED) {
        var allowDisable = false;
        this.$('[IS_PRIMARY_PRODUCT=true][IS_ENABLED=true],[IS_INTEGRATED=true]').each(function () {
          if (Ember.$(this).attr("integ_tab_id") != tab.PRODUCT_ID) {
            allowDisable = true;
          }
        })
        if (!allowDisable) {
          self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.admin.integration_settings.message.disable_fail',), false);
          return;
        }
      }

      status = AJAXUtil.syncAjax('/RestAPI/WC/Integration?mTCall=enableDisable', params);
      if (status.hasOwnProperty('sSTATUS')) {
        self.$('#IS_AUTHENTICATION_REQUIRED').iCheck('uncheck'); //NO I18N
        self.sendAction('showStatus', 'success', status.sSTATUS, true);
        self.send('getSettings');
        if (self.get('syncData.showSyncButton')) {
          Ember.run.later((function () {
            self.sendAction('syncNow');
          }), 2000);
        }
      } else {
        self.sendAction('showStatus', 'danger', status.eSTATUS, false);
      }
      if (status.integrationStatus == 'success') {
        var appsPaneParams = [];
        appsPaneParams[0] = tab.PRODUCT_NAME;
        appsPaneParams[1] = !tab.IS_ENABLED ? 'true' : 'false';
        if (tab.IS_PRIMARY_PRODUCT || (!tab.IS_PRIMARY_PRODUCT && tab.IS_ENABLED)) {
          window.WindowHandler.sendRequest(parent, "appsPaneToggle", JSON.stringify(appsPaneParams)); // No I18n
        }
      }
    },

    integrate: function () {
      var self = this;
      self.send('setVisibleTabs');
      var tab = this.get('currentTab');
      var isAuthRequired = this.$('#IS_AUTHENTICATION_REQUIRED').is(
        ':checked');

      var message = null;
      if (!tab.hasOwnProperty('HOST') || !tab.hasOwnProperty('PORT') ||
        tab.HOST == '' || tab.PORT == '') {
        message = I18NUtil.translate('ads.common.alert.mandatory_fields');
      } else if (!(/^[0-9]+$/.test(tab.PORT)) || tab.PORT <= 0 || tab.PORT > 65535) {
        message = I18NUtil.translate('ads.admin.product_settings.connection.select_protocol.http_range');
      } else if (isAuthRequired === true && (!tab.hasOwnProperty(
          'USERNAME') || !tab.hasOwnProperty('PASSWORD') || (tab.USERNAME == '' && tab.PASSWORD == ''))) {
        message = I18NUtil.translate(
          'ads.common.alert.mandatory_username_password');
      } else if (isAuthRequired === true && tab.USERNAME == '') {
        message = I18NUtil.translate('ads.common.alert.mandatory_username');
      } else if (isAuthRequired === true && tab.PASSWORD == '') {
        message = I18NUtil.translate('ads.common.alert.mandatory_password');
      }

      if (message != null) {
        DialogUtil.alert(this, message); //No I18N
        return;
      }

      this.set('currentTab.PROTOCOL', this.$('#PROTOCOL').val());
      this.set('currentTab.UPDATE_TYPE', '');
      if (!tab.hasOwnProperty('CONTEXT')) {
        if (tab.PRODUCT_NAME === 'ManageEngine Exchange Reporter Plus')
          this.set('currentTab.CONTEXT', 'exchange');
        else {
          this.set('currentTab.CONTEXT', '');
        }
      }
      tab.IS_EMBER = true;
      CommonUtil.showLoading();
      AJAXUtil.ajax('/RestAPI/WC/Integration?mTCall=save', tab, true)
        .then(function (response) {
          var status = response;
          if (status.hasOwnProperty('sSTATUS')) {
            self.sendAction('showStatus', 'success', status.sSTATUS, true);
            self.send('getSettings');
            self.sendAction('syncNow', true);
            self.send('changeTab', self.get('currentTab'));
            window.WindowHandler.sendRequest(top, 'reloadAppsPane', '[]');
            if (tab.PRODUCT_NAME === 'ManageEngine ADSelfService Plus') {
              self.set("GLOBAL_DATA.HIDE_EMPLOYEE_SEARCH", false);
            }
          } else {
            self.sendAction('showStatus', 'danger', status.eSTATUS, false);
            if (status.eSTATUS == I18NUtil.translate('ads.admin.integration_settings.message.authentication_required')) {
              self.$('#IS_AUTHENTICATION_REQUIRED').iCheck('check'); //NO I18N
            }
          }
          CommonUtil.hideLoading();
        });

    },

    removeConfirm: function () {
      var self = this;
      var allowRemove = false;
      this.$('[IS_PRIMARY_PRODUCT=true][IS_ENABLED=true]').each(function () {
        allowRemove = true;
      });
      if (!allowRemove) {
        self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.admin.integration_settings.message.remove_fail'), false);
        return;
      }
      var tab = this.get('currentTab');
      var message = null;
      var isAuthRequired = this.$('#IS_AUTHENTICATION_REQUIRED').is(
        ':checked');

      if (!tab.hasOwnProperty('HOST') || !tab.hasOwnProperty('PORT') || tab.HOST == '' || tab.PORT == '') {
        message = I18NUtil.translate('ads.common.alert.mandatory_fields');
      } else if (!(/^[0-9]+$/.test(tab.PORT)) || tab.PORT <= 0 || tab.PORT > 65535) {
        message = I18NUtil.translate('ads.admin.product_settings.connection.select_protocol.http_range');
      } else if (isAuthRequired === true && (!tab.hasOwnProperty('USERNAME') || !tab.hasOwnProperty('PASSWORD') || (tab.USERNAME == '' && tab.PASSWORD == ''))) {
        message = I18NUtil.translate('ads.common.alert.mandatory_username_password');
      } else if (isAuthRequired === true && tab.USERNAME == '') {
        message = I18NUtil.translate('ads.common.alert.mandatory_username');
      } else if (isAuthRequired === true && tab.PASSWORD == '') {
        message = I18NUtil.translate('ads.common.alert.mandatory_password');
      }
      if (message != null) {
        DialogUtil.alert(this, message); //No I18N
        return;
      }
      var msg = 'ads.admin.integration_settings.confirm.delete';
      if (tab.SERVER_STATUS == "down") {
        msg = 'ads.admin.integration_settings.confirm.delete.details_not_removed';
      }
      DialogUtil.confirm(this, I18NUtil.translate(msg, [this.get('currentTab.DISPLAY_NAME')]), 'remove'); //No I18N
    },
    remove: function () {
      CommonUtil.showLoading();
      var self = this;
      self.send('setVisibleTabs');
      var tab = this.get('currentTab');

      this.set('currentTab.PROTOCOL', this.$('#PROTOCOL').val());
      this.set('currentTab.UPDATE_TYPE', '');
      if (!tab.hasOwnProperty('CONTEXT')) {
        this.set('currentTab.CONTEXT', '');
      }
      tab.IS_EMBER = true;
      tab.UPDATE_TYPE = "remove";
      AJAXUtil.ajax('/RestAPI/WC/Integration?mTCall=remove', tab, true)
        .then(function (response) {
          CommonUtil.hideLoading();
          var status = response;
          if (status.hasOwnProperty('sSTATUS')) {
            self.sendAction('showStatus', 'success', status.sSTATUS, true);
            self.send('getSettings');
            self.send('changeTab', self.get('currentTab'));
            if(self.get('notificationService')){
              self.get('notificationService').checkStatus('PRODUCT_DOWN_NOTIFIER');
            }
            if (self.get('syncData.showSyncButton')) {
              self.sendAction('syncNow', true);
            }
            window.WindowHandler.sendRequest(top, 'reloadAppsPane', '[]');
            if (tab.PRODUCT_NAME === 'ManageEngine ADSelfService Plus') {
              self.set("GLOBAL_DATA.HIDE_EMPLOYEE_SEARCH", true);
            }
          } else {
            self.sendAction('showStatus', 'danger', status.eSTATUS, false);
            if (status.eSTATUS == I18NUtil.translate('ads.admin.integration_settings.message.authentication_required')) {
              self.$('#IS_AUTHENTICATION_REQUIRED').iCheck('check'); //NO I18N
            }
          }
        });
    },

    cancel: function () {
      this.send('changeTab', this.get('currentTab'));
    },

    showSyncFailureReason: function () {
      DialogUtil.showReason(this, this.$('#syncFailReasonDiv').html());
    },
    enableTabToggleButtons: function () {
      this.set('isTabToggleButtonEnabled', true);
    }
  }
});
//ignorei18n_end
