/*$Id$*/
//ignorei18n_start
import Ember from 'ember';
import AJAXUtil from '../utils/ads-ajax-util';
import I18NUtil from '../utils/i18n-util';
import CommonUtil from '../utils/ads-common-util';
import ValidationUtil from '../utils/ads-validation-util';

export default Ember.Component.extend({
    init: function() {
        this._super();    
        this.set('disabled', false);   
        // if(this.get('showEnableCheckBox')){
        // }
      },
      didReceiveAttrs: function(){
        if(!this.hasOwnProperty('ipDetails')){
          this.send('getSettings');//No i18n          
        }
    },
    didInsertElement: function() {
        this.doShowModal();
        if(this.get('showEnableCheckBox')){
        this.set('disabled',!this.get('ipDetails.isEnabled'));//No i18n
        }
    },
    afterRender: function() {
        Ember.run.scheduleOnce('afterRender',this, function() {
          this.$(".fw-custom-scroll-hover").each(function() {
            if (Ember.$(this).attr('data-height'))
            {
              Ember.$(this).height(Ember.$(this).attr('data-height')).css({"overflow": "hidden"});
            }
            let theme=(Ember.$(this).attr("data-theme"))? Ember.$(this).attr("data-theme"): "dark";
            let sPosition=(Ember.$(this).attr("data-scrollbar-position"))? Ember.$(this).attr("data-scrollbar-position"): "inside";
            Ember.$(this).mCustomScrollbar({
              theme: theme,
              autoHideScrollbar: true,
              scrollbarPosition:sPosition,
              callbacks: {
                  onScroll: function(evt) {
                      return false;
                  },
                  onTotalScroll: function(evt) {
                      return false;
                  },
                  onTotalScrollBack: function(evt) {
                      return false;
                  }
              }
            });
          });
        });
      },
     //Returns valid IP ranges, otherwise null
     getValidIPRanges: function() {
        let self = this;
        let ipRanges = [];
        let invalidField = null;
        let message = I18NUtil.translate('ads.admin.logonsettings.message.invalidiprange');
        this.$('#IP_RANGE table').children('tr').each(function() {
          let fromIp = Ember.$(this).find('input[name=ip_range_from]').val().trim();
          let toIp = Ember.$(this).find('input[name=ip_range_to]').val().trim();
          if(fromIp != "" && toIp != "")
          {
            if(!ValidationUtil.isValidIP(fromIp))
            {
              invalidField = 'from';
            }
            else if(!ValidationUtil.isValidIP(toIp))
            {
              invalidField = 'to';
            }
            else if(!ValidationUtil.isSmallerIP(fromIp,toIp))
            {
              message = I18NUtil.translate('ads.admin.logonsettings.message.smalleripaddress');
              invalidField = 'to';
            }
    
            let obj = {
              fromIP: fromIp,
              toIP: toIp,
            };
            //Ignores duplicate entry
            if(!ipRanges.some(function(obj) { return obj.fromIP == fromIp && obj.toIP == toIp; } ))
            {
              ipRanges.push(obj);
            }
          }
          else if(fromIp == "" && toIp != "" || fromIp != "" && toIp == "")
          {
            invalidField = fromIp == "" ? 'from' : 'to';
          }
    
          if(invalidField != null)
          {
            Ember.$(this).find('input[name=ip_range_' + invalidField + ']').parent().addClass('has-error').children().focus();
            self.send('showAlert',message);
            return false;
          }
    
        });
        return invalidField == null ? ipRanges : null;
      },
    
      //Returns valid individual IP/Server Name, otherwise null
      getValidIndividualIPs: function() {
        let serverNames = [];
        let uniqueIps = this.$('input[name=ip_server_name]').val();
        let uniqueIp = (uniqueIps !== undefined) ? uniqueIps.split(",") : [];
        let start = 0;
        for(let i=0; i<uniqueIp.length; i++)
        {
          let end = uniqueIp[i].length;
          uniqueIp[i] = uniqueIp[i].trim();
          if(uniqueIp[i] != "")
          {
            if(ValidationUtil.isValidHostName(uniqueIp[i]))
            {
              //Ignores duplicate entry
              let duplicate = false;
              for(let j=0; j<serverNames.length; j++)
              {
                if(serverNames[j] == uniqueIp[i])
                {
                  duplicate = true;
                  break;
                }
              }
              if(!duplicate)
              {
                serverNames.push(uniqueIp[i]);
              }
            }
            else
            {
              let message = I18NUtil.translate('ads.admin.logonsettings.message.invalidipaddress');
              this.send('showAlert',message);
    
              //Highlights invalid IP or Server Name in textfield
              if(document.getElementsByName('ip_server_name')[0].setSelectionRange)
              {
                this.$('input[name=ip_server_name]').parent().addClass('has-error').children().focus();
                document.getElementsByName('ip_server_name')[0].setSelectionRange(start, start + end);
              }
              else if(document.getElementsByName('ip_server_name')[0].createTextRange)  //IE older version support
              {
                this.$('input[name=ip_server_name]').parent().addClass('has-error');
                var range = document.getElementsByName('ip_server_name')[0].createTextRange();
                range.collapse(true);
                range.moveEnd('character',start+end);
                range.moveStart('character',start);
                range.select();
              }
              return null;
            }
          }
          start += end + 1;
        }
        return serverNames;
      },
      doShowModal: function() {
        this.$('#IPRESTRICTION_SETTINGS').modal({
            backdrop: 'static',
            keyboard: false
          });
          this.afterRender();        
      },
      doHideModal: function(){
        
      },
    actions: {
      getSettings: function(){
        CommonUtil.showLoading();
        var self = this;
        this.sendAction('beforeLoading');
        Ember.run.schedule('afterRender', function(){
          AJAXUtil.ajax('/RestAPI/WC/IPRestriction?mTCall=getSettings',{}).then(function(response) {
            try{
              CommonUtil.hideLoading();
              if(response.eSTATUS){
                self.sendAction('showStatus','danger',I18NUtil.translate(response.eSTATUS),true);
                self.set('ipDetails.isEnabled', false);//No i18n
                self.set('disabled', false);   //No i18n          
              }else{
              self.set('ipDetails.isEnabled', response.IS_ENABLED);
              self.set('ipDetails.ipOption', response.IS_ALLOWED_IPS?'isAllowedIps':'isRestrictedIps');
              let IP_ADDRESS = JSON.parse(response.IP_ADDRESS);
              let ipServerName = IP_ADDRESS.uniqueAddress.length !=0 ? IP_ADDRESS.uniqueAddress[0] : "";
              for(let i=1; i<IP_ADDRESS.uniqueAddress.length; i++)
              {
                ipServerName += ", " + product.IP_ADDRESS.uniqueAddress[i];
              }
              self.set('ipDetails.ipRange', Ember.$.extend(true,[],IP_ADDRESS.ipRange));
              self.set('ipDetails.serverNames', ipServerName);
              self.set('ipDetails.componentName', response.COMPONENT_NAME);
              }
              self.sendAction('afterLoading');
            }catch(err){
            }
          });
        });
      },
      toggleIPSettings : function(isEnabled){
        this.set('ipDetails.isEnabled',isEnabled);
        this.set('disabled', !isEnabled);
      },
     //Adds two new textfields for IP Range
      addTextfield: function() {
        // if(this.get('ipDetails.isEnabled'))
        this.get('ipDetails.ipRange').pushObject({});
      },
  
      //Removes the textfield from IP Range
      removeTextfield: function(index) {
        // if(this.get('ipDetails.isEnabled'))
        this.get('ipDetails.ipRange').removeAt(index);
      },
  
      //Removes the error class when textfield value changes
      onTextfieldChange: function() {
        let element = event.target ? event.target : event.srcElement;
        this.$(element).parent().removeClass('has-error');
      },
  
      //Show/Hide individual IP textfield
      toggleTextfield: function() {
        this.$('.aiip-tog').toggleClass('hide');
        this.$('.aiip-link').next().toggleClass('right');
      },
       //Saves IP details to server after validation
      saveSettings: function() {
        var self = this;
        var isEnabled = this.get('showEnableCheckBox')?this.$('.SETTINGS_ENABLE_IP_RESTRICTION')[0].checked:true;//No i18n
        var params = null;
        if(isEnabled)
        {
          //Validates IP ranges
          let ipRanges = this.getValidIPRanges();
          if(ipRanges == null)
          {
            return;
          }
  
          //Validates individual IPs
          let serverNames = this.getValidIndividualIPs();
          if(serverNames == null)
          {
            return;
          }
  
          //Constructs params
          isEnabled = serverNames.length || ipRanges.length ? true : false;
          params = {
            PRODUCT_ID: self.get('ipDetails.productId'),
            IP_ADDRESS: {
              uniqueAddress: serverNames,
              ipRange: ipRanges,
            },
            IS_ALLOWED_IPS: self.get('ipDetails.isAllowedIps'),
            IS_ENABLED: isEnabled,
          };
        }else{
          params = {
            PRODUCT_ID: self.get('ipDetails.productId'),
            IS_ENABLED: isEnabled,
          };
        }
  
        //Sends params to servlet
        CommonUtil.showLoading();
        AJAXUtil.ajax('/RestAPI/WC/IPRestriction?mTCall=saveSettings', { ipDetails : JSON.stringify(params) }).then(function(responseData) {
          CommonUtil.hideLoading();
          let response = (responseData != null && responseData != "") ? responseData : null;
          if(response != null)
          {
            if(response.eSTATUS.trim() == "")
            {
              self.sendAction('showStatus','success',I18NUtil.translate('ads.admin.logonsettings.message.success'),true);
            }
            else
            {
              self.sendAction('showStatus','danger',I18NUtil.translate(response.eSTATUS),true);
            }
          }
          self.sendAction('afterSave');
        });
        this.send('cancel');
      },
      //Closes the modal box
      cancel: function() {
        var self = this;
        this.$('#IPRESTRICTION_SETTINGS').modal('hide');
        Ember.run.later(function(){
            self.sendAction('onCancel');
        },100);
        this.send('closeAlert');
      },
      //Closes the alert message inside modal box
      closeAlert: function() {
        this.$('.mini-status-alert').delay(50).slideUp('slow');
      },
      //Toggles radio button
      toggleRadioButton: function(params) {
        let option = JSON.parse(params).columnValue;
        if(option == 'isAllowedIps')
        {
          this.set('ipDetails.isAllowedIps', true);
        }
        else
        {
          this.set('ipDetails.isAllowedIps', false);
        }
        this.set('ipDetails.ipOption', option);
      },
      /**
       * Shows the alert message, if message is not null.
       * alertType defaults to 'danger' if not specified.
       */
      showAlert: function(message, alertType) {
        alertType = alertType != null ? alertType : 'danger';
        if(message != null)
        {
          this.set('configStatusAlertType', alertType);
          this.set('configStatusMessage', message);
          this.$('.mini-status-alert').delay(500).slideDown('slow');
        }
    },
    }
});
//ignorei18n_end