/* $Id$ */
//ignorei18n_start
import Ember from 'ember';
import AJAXUtil from '../utils/ads-ajax-util';
import I18NUtil from '../utils/i18n-util';
import CommonUtil from '../utils/ads-common-util';
import ValidationUtil from '../utils/ads-validation-util';

export default Ember.Component.extend({
    productId: null,
    componentName: null,
    ipServerName: null,
    ipRange: null,
    isAllowedIps: null,
    isEnabled: null,
    configStatusAlertType: 'danger',
    ipDetails: {},
    init(){
        this._super();
        this.send('getSettings');//No i18n
        this.set('showConfig',false);//No i18n
        this.set('showEnableCheckBox', false);//No i18n
    }, 
    afterRender: function() {
      Ember.run.scheduleOnce('afterRender',this, function() {
        this.$(".fw-custom-scroll-hover").each(function() {
          if (Ember.$(this).attr('data-height'))
          {
            Ember.$(this).height(Ember.$(this).attr('data-height')).css({"overflow": "hidden"});
          }
          let theme=(Ember.$(this).attr("data-theme"))? Ember.$(this).attr("data-theme"): "dark";
          let sPosition=(Ember.$(this).attr("data-scrollbar-position"))? Ember.$(this).attr("data-scrollbar-position"): "inside";
          Ember.$(this).mCustomScrollbar({
            theme: theme,
            autoHideScrollbar: true,
            scrollbarPosition:sPosition,
            callbacks: {
                onScroll: function(evt) {
                    return false;
                },
                onTotalScroll: function(evt) {
                    return false;
                },
                onTotalScrollBack: function(evt) {
                    return false;
                }
            }
          });
        });
      });
    },
     didRender:function(){
         CommonUtil.renderTooltip();
        },
    actions: {
  
      //Sets product IP details in dropdown
      showDropdown: function(product) {
        let ipRange = [];
        for(let i=0; i<product.IP_ADDRESS.ipRange.length; i++)
        {
          if(product.IP_ADDRESS.ipRange[i].fromIP != null)
          {
            ipRange.push({ fromIP : product.IP_ADDRESS.ipRange[i].fromIP, toIP : product.IP_ADDRESS.ipRange[i].toIP });
          }
        }
        if(ipRange.length)
        {
          this.set('ipRange',ipRange);
        }
        else
        {
          this.set('ipRange',null);
        }
        if(product.IP_ADDRESS.uniqueAddress[0] != "")
        {
          this.set('ipServerName',product.IP_ADDRESS.uniqueAddress);
        }
        else
        {
          this.set('ipServerName',null);
        }
        this.afterRender();
      },
  

  
  
      //Toggles enable status, and updates to server.
      toggleEnableStatus: function(product) {
        if(product.HAS_ERROR)
        {
          var status = I18NUtil.translate(product.STATUS);
          this.send('communicationFailStatusHandler',product);
          // this.sendAction('showStatus','danger',status,true);
          return;
        }
        let ipServerName = product.IP_ADDRESS.uniqueAddress;
        let ipRange = product.IP_ADDRESS.ipRange;
        if((ipServerName == null || ipServerName[0] == "") && (ipRange == null || ipRange[0].fromIP == null))
        {
          this.send('editSettings', product);
          return;
        }
        let params = { PRODUCT_ID : product.PRODUCT_ID, IS_ENABLED : !product.IS_ENABLED };
        this.send('saveSettings',params);
      },
  
      //Sets IP details of corresponding component for modal box
      editSettings: function(product) {
        if(product.HAS_ERROR)
        {
          var status = I18NUtil.translate(product.STATUS);
          this.send('communicationFailStatusHandler',product);
          // this.sendAction('showStatus','danger',status,true);
          return;
        }
  
        //set params needed for modal box
        this.set('ipDetails.productId',product.PRODUCT_ID);
        this.set('ipDetails.componentName',product.COMPONENT_NAME);
        let ipServerName = product.IP_ADDRESS.uniqueAddress.length !=0 ? product.IP_ADDRESS.uniqueAddress[0] : "";
        for(let i=1; i<product.IP_ADDRESS.uniqueAddress.length; i++)
        {
          ipServerName += ", " + product.IP_ADDRESS.uniqueAddress[i];
        }
        this.set('ipDetails.ipServerName',ipServerName);
        this.set('ipDetails.ipRange',Ember.$.extend(true, [],product.IP_ADDRESS.ipRange));
        this.set('ipDetails.isAllowedIps',product.IS_ALLOWED_IPS);
        if(product.IS_ALLOWED_IPS == true)
        {
          this.set('ipDetails.ipOption','isAllowedIps');
        }
        else
        {
          this.set('ipDetails.ipOption','isRestrictedIps');
        }
        this.set('ipDetails.isEnabled',product.IS_ENABLED);
  
        //Shows Individual IP textfield if not empty, otherwise hides
        if(ipServerName != "")
        {
          // Ember.$('.aiip-tog').removeClass('hide');
          // Ember.$('.aiip-link').next().removeClass('right');
          this.set('ipDetails.showIndividualIp',true);
        }
        else
        {
          // Ember.$('.aiip-tog').addClass('hide');
          // Ember.$('.aiip-link').next().addClass('right');
          this.set('ipDetails.showIndividualIp',false);
        }
        this.set('showConfig',true);
      },
  
      //Retrieves IP details from server
      getSettings: function() {
        let self = this;
        // this.sendAction('beforeLoading');
        CommonUtil.showLoading();
        Ember.run.schedule('afterRender',function(){
          AJAXUtil.ajax('/RestAPI/WC/IPRestriction?mTCall=getAllSettings', {}).then(function(responseData) {
            try{
            let allProductIPDetails = responseData!="" ? responseData : null;
            if(allProductIPDetails != null)
            {
              for(let i=0; i<allProductIPDetails.length; i++)
              {
                allProductIPDetails[i].ICON_STATUS = (allProductIPDetails[i].IS_ENABLED == true) ? 'fw-icn-ok' : 'fw-icn-cancel';
                allProductIPDetails[i].IP_ADDRESS = JSON.parse(allProductIPDetails[i].IP_ADDRESS);
                allProductIPDetails[i].COUNT = allProductIPDetails[i].IP_ADDRESS.uniqueAddress.length + allProductIPDetails[i].IP_ADDRESS.ipRange.length;
                if(allProductIPDetails[i].IP_ADDRESS.uniqueAddress.length == 0)
                {
                  allProductIPDetails[i].IP_ADDRESS.uniqueAddress.push("");
                }
                if(allProductIPDetails[i].IP_ADDRESS.ipRange.length == 0)
                {
                  allProductIPDetails[i].IP_ADDRESS.ipRange.push({fromIP : null, toIP : null});
                }
                if(allProductIPDetails[i].STATUS != "-")
                {
                  allProductIPDetails[i].STATUS_KEY = allProductIPDetails[i].STATUS;
                  allProductIPDetails[i].STATUS = I18NUtil.translate(allProductIPDetails[i].STATUS);
                } 
    
              }
            }
            Ember.set(self,'IPRESTRICTION_DETAILS',allProductIPDetails);
            // this.sendAction('afterLoading');
            CommonUtil.hideLoading();
          }catch(err){
          }
          });
        });
      },
  
      //Saves IP details to server after validation
      saveSettings: function(params) {
        var self = this;

        //Sends params to servlet
        CommonUtil.showLoading();
        AJAXUtil.ajax('/RestAPI/WC/IPRestriction?mTCall=saveSettings', { ipDetails : JSON.stringify(params) }).then(function(responseData) {
          CommonUtil.hideLoading();
          let response = (responseData != null && responseData != "") ? responseData : null;
          if(response != null)
          {
            if(response.eSTATUS.trim() == "")
            {
              self.sendAction('showStatus','success',I18NUtil.translate('ads.admin.logonsettings.message.success'),true);
            }
            else
            {
              self.sendAction('showStatus','danger',I18NUtil.translate(response.eSTATUS),true);
            }
          }
          self.send('getSettings');
        });
      },
      afterSave: function(){
        this.send('getSettings');
      },
      onCancel : function(){
        this.set('showConfig',false);        
      },
      showStatus: function(level,message,autoClose){
        this.sendAction('showStatus',level,message,autoClose);
      },
    // Displays the status message.
      communicationFailStatusHandler(product) {
        let status;
        if(product.STATUS_KEY == "ads.admin.logonsettings.status.communicationfailed")
        {
          status = I18NUtil.translate("ads.admin.logonsettings.status.communicationfailed_help");
        }
        else
        {
          status = product.STATUS;
        }
        this.sendAction('showStatus','danger',status,true);
    },  
    }
});
//ignorei18n_end
