/*
 * $Id: portbased-reverseproxy.js,v 1.15 2018/12/26 11:58:08 ajith.k Exp $
 */
//ignorei18n_start
import Ember from 'ember';
import AJAXUtil from '../utils/ads-ajax-util';
import I18NUtil from "../utils/i18n-util";
import ValidationUtil from "../utils/ads-validation-util";
import CommonUtil from '../utils/ads-common-util';
import DialogUtil from "../utils/ads-dialog-util";

export default Ember.Component.extend({
  config: {},
  isConfigured: false,
  integratedProducts: [],
  host: "",
  freezeStyle: '',
  protocols: [{
    'CLIENT_VALUE': 'HTTP',
    'SERVER_VALUE': 'HTTP'
  }, {
    'CLIENT_VALUE': 'HTTPS',
    'SERVER_VALUE': 'HTTPS'
  }],
  showEditSettings: false,
  pageStatus: {},

  getSettings: function() {
    var response = AJAXUtil.syncAjax("/RestAPI/WC/ReverseProxy?mTCall=getPortBasedConfig", {});
    this.set('host', response.HOST);
    this.set('config', response.CONFIG);
    this.set('isConfigured', false);
    this.set('isEnabled', false);
    Ember.$('#FORM_STATUS').hide();
    if (response.CONFIG.length > 0) {
      for (var j = 0; j < response.CONFIG.length; j++) {
        response.CONFIG[j].PROTOCOL = response.CONFIG[j].PROTOCOL.toUpperCase();
        response.CONFIG[j].PRODUCT_CONFIG[0].PROTOCOL = response.CONFIG[j].PRODUCT_CONFIG[0].PROTOCOL.toUpperCase();
        if (response.CONFIG[j].PRODUCT_CONFIG[0].PROTOCOL == "HTTPS" && response.CONFIG[j].PROTOCOL == 'HTTPS') {
          response.CONFIG[j].IS_PROTOCOL_SELECTION_DISABLED = true;
        } else {
          response.CONFIG[j].IS_PROTOCOL_SELECTION_DISABLED = false;
        }
        if (response.CONFIG[j].IS_ENABLED == true) {
          this.set('isEnabled', true);
        } else {
          response.CONFIG[j].IS_PROTOCOL_SELECTION_DISABLED = true;
        }

      }
      if (this.get('isEnabled') == true) {
        this.set('isConfigured', true);
        this.set('freezeStyle', 'disable');
      } else {
        for (var k = 0; k < response.CONFIG.length; k++) {
          response.CONFIG[k].IS_ENABLED = true;
        }
      }
    } else {
      this.set('isConfigured', false);
      this.set('freezeStyle', '');
    }
    for (var i = 0; i < response.PRODUCTS.length; i++) {
      var config = {};
      config.PORT = "900" + (response.CONFIG.length + 1);
      response.PRODUCTS[i].PROTOCOL = response.PRODUCTS[i].PROTOCOL.toUpperCase();
      config.PROTOCOL = response.PRODUCTS[i].PROTOCOL;
      config.PRODUCT_CONFIG = [response.PRODUCTS[i]];
      config.IS_ENABLED = this.get('isConfigured') == true ? false : true;
      config.IS_CONTEXT_BASED = false;
      if (config.PROTOCOL == 'HTTPS') {
        config.IS_PROTOCOL_SELECTION_DISABLED = true;
      } else {
        config.IS_PROTOCOL_SELECTION_DISABLED = false;
      }
      response.CONFIG[response.CONFIG.length] = config;
    }
    this.sortConfig();
  }.on('init'),

  enableDisableSettings: function() {
    if (this.get('isEnabled') === true) {
      this.set('freezeStyle', 'disable');
      this.set('isDisabled', false);
    } else {
      this.set('freezeStyle', '');
      this.set('isDisabled', true);
    }
  }.observes('isEnabled'),

  sortConfig: function() {
    var config = this.get('config');
    for (var i = 0; i < config.length - 1; i++) {
      for (var j = i + 1; j < config.length; j++) {
        if (config[i].PRODUCT_CONFIG[0].PRODUCT_ID > config[j].PRODUCT_CONFIG[0].PRODUCT_ID) {
          var tempConfig = config[i];
          config[i] = config[j];
          config[j] = tempConfig;
        }
      }
    }
  },

  isValidPort: function(port) {
    var intPort = parseInt(port);
    if (port == '' || port == null) {
      return 'ads.admin.reverseproxy.empty_port_for_product';
    } else if (!ValidationUtil.isValidPort(port)) {
      return 'ads.admin.reverseproxy.invalid_port_for_product';
    } else if (ValidationUtil.isBlockedPort(intPort)) {
      return 'ads.admin.reverseproxy.blocked_port_for_product';
    } else {
      return 'true';
    }
  },
  actions: {

    toggleAllEnabled: function(val) {
      if (val != this.get('isEnabled')) {
        this.set('isEnabled', val);
        var configData = this.get('config');
        var portMap = {};
        for (var i = 0; i < configData.length; i++) {
            this.send('setEnabled', configData[i], val);
        }
      }
    },

    setEnabled: function(configData, isEnabled) {
      Ember.set(configData, 'IS_ENABLED', isEnabled);
      if (isEnabled == false) {
        Ember.set(configData, 'IS_PROTOCOL_SELECTION_DISABLED', true);
      } else if (configData.PRODUCT_CONFIG[0].PROTOCOL == "HTTPS" && configData.PROTOCOL == 'HTTPS') {
        Ember.set(configData, 'IS_PROTOCOL_SELECTION_DISABLED', true);
      } else {
        Ember.set(configData, 'IS_PROTOCOL_SELECTION_DISABLED', false);
      }

    },

    cancelSettings: function() {
      this.getSettings();
    },

    saveSettings: function() {
      var self = this;
      var configData = this.get('config');
      var portMap = {};

      if (this.get('isConfigured') == false && this.get('isEnabled') == false) {
        return;
      }

      for (var i = 0; i < configData.length; i++) {
        var config = configData[i];
        var port = '' + config.PORT;
        var isValidPort = self.isValidPort(port);
        if (config.IS_ENABLED && config.PRODUCT_CONFIG[0].PROTOCOL == 'HTTPS' && config.PROTOCOL == 'HTTP') {
          var message = I18NUtil.translate('ads.admin.reverseproxy.select_https_for_product', [config.PRODUCT_CONFIG[0].DISPLAY_NAME]);
          DialogUtil.alert(self, message, true);
          return;
        }

        if (config.IS_ENABLED && isValidPort != 'true') {
          var message = I18NUtil.translate(isValidPort, [config.PRODUCT_CONFIG[0].DISPLAY_NAME]);
          DialogUtil.alert(self, message, true);
          return;
        }
        
        Ember.set(config, 'PORT', parseInt(port, 10));
        port = '' + config.PORT;
        
        if (config.IS_ENABLED && portMap.hasOwnProperty(port)) {
          var message = I18NUtil.translate('ads.admin.reverseproxy.port_already_present_for_product', [config.PRODUCT_CONFIG[0].DISPLAY_NAME]);
          DialogUtil.alert(self, message, true);
          return;
        }
        if (config.IS_ENABLED) {
          portMap[port] = port;
        }

      }

      CommonUtil.showLoading();
      AJAXUtil.ajax("/RestAPI/WC/ReverseProxy?mTCall=saveConfig", {
        'CONFIG': JSON.stringify(configData),
        'IS_PORT_BASED': true
      }).then(function(response) {
        if (response.hasOwnProperty('STATUS') && response.STATUS == "SUCCESS") {
          self.getSettings();
          self.send('startServer');
        } else if (response.hasOwnProperty('eSTATUS')) {
          self.sendAction('showStatus', 'danger', response.eSTATUS, false);
        } else {
          var message = response.hasOwnProperty('DATA') ? I18NUtil.translate(response.STATUS_MESSAGE, response.DATA) : I18NUtil.translate(response.STATUS_MESSAGE);
          self.sendAction('showStatus', 'danger', message, false);
        }
        CommonUtil.hideLoading();
      });


    },

    startServer: function() {
      var self = this;
      var response = AJAXUtil.syncAjax("/RestAPI/WC/ReverseProxy?mTCall=startServer", {
        'IS_PORT_BASED': true
      });
      if (response.STATUS == 'SUCCESS') {
        self.sendAction('showStatus','success', I18NUtil.translate('ads.admin.reverseproxy.saved_successfully'), true);
        window.WindowHandler.sendRequest(top, 'reloadAppsPane', '[]');
      } else {
        var message = response.hasOwnProperty('DATA') ? I18NUtil.translate(response.STATUS_MESSAGE, response.DATA) : I18NUtil.translate(response.STATUS_MESSAGE);
        self.sendAction('showStatus','danger', message, true);
      }
    }
  }
});
