/*
 * $Id: view-reports.js,v 1.3 2018/12/24 13:06:01 maharajan.velappan Exp $
 */

import Ember from 'ember'; //NO I18N
import AJAXUtil from 'webclient/utils/ajax-util'; //NO I18N
import I18NUtil from "webclient/utils/i18n-util"; //NO I18N
import CommonUtil from "webclient/utils/common-util"; // NO I18N
import StatusUtil from "webclient/utils/status-util"; //NO I18N

//ignorei18n_start
export default Ember.Component.extend({
  reportsList: [],
  reportDetailsMap: null,
  reportDetails: null,
  lhsMenu: null,
  clientURL: null,
  currentReport: null,
  currentProductId: null,
  currentMenuId : null,
  errorStatus: null,
  isFrameInitialized: true,
  isInitialized: true,
  errorData: null,
  showPromotion: null,
  promotionParams: null,
  promotionData: null,
  productDetailsMap: {},
  unSupportedProducts: [],
  currentTabReportsList:null,
  tabsList:null,
  showButtons:false,
  load: function() {
    window.reportsController = this;

    window.purge = function($frame) {
      var sem = $frame.length,
        deferred = $.Deferred();
      $frame.load(function() {
        var frame = this;
        frame.contentWindow.document.innerHTML = '';
        sem -= 1;
        if (sem <= 0) {
          $frame.remove();
          deferred.resolve();
        }
      });
      $frame.attr('src', 'about:blank');
      if ($frame.length === 0) {
        deferred.resolve();
      }
      return deferred.promise();
    };

    window.showReportsFrame = function() {
      window.reportsController.set('isFrameInitialized', true);
    };

    window.setErrorMessage = function(errorData) {
      window.reportsController.send('setErrorMessage', errorData);
    };

    window.openURL = function(url) {
      var productId = window.reportsController.get('currentProductId');
      if (url.indexOf('http') == -1) {
        url = window.reportsController.get('reportDetailsMap.' + productId + ".URL") + "/" + url;
      }
      window.open(url);
    };
    window.changeRoute = function(hashPath) {
        window.reportsController.send('changeReport', window.reportsController.get('currentProductId'), hashPath.split('/')[0], hashPath.split(/\/(.+)/)[1]);
    };
	this.send('resetSettings');	 
	 CommonUtil.afterRender();
	 }.on('init'),
   didInsertElement : function(){
	  var self=this;
	   Ember.run.later((function() {	
	self.send('getSettings');	
	  self.controller.set('canTrack', false);//On Entering this route, First report will be automatically selected, hence neglecting that report from tracking.
 }),100);
  },

   willDestroyElement: function() {
      this.send('resetSettings');
      window.purge($('#reportsFrame'));
      $('#reportsFrameWrapper').empty();
      $('.report-search').remove();
      $('.lnav').remove();
      $(document).off('keypress');
  },
  
  showFrame: function() {
    if (this.get('errorData') == null && this.get('promotionData') == null && this.get('isFrameInitialized')) {
      return true;
    } else {
      return false;
    }
  }.property('errorData', 'promotionData', 'isFrameInitialized'),

  initFrameLoad: function() {
    $('#reportsFrame').load(function() {
		 var responseText =$("#MigrateDBIFrame").contents().find("body").text();
		 var responseHtml =$("#MigrateDBIFrame").contents().find("body").html();
		  try{
			 var response=Ember.$.parseJSON(responseText);
			}
		 catch(e)
		   {
			   AJAXUtil.handleSessionTimeout("403", responseText);	
		   }
      var frameLocation = document.getElementById('reportsFrame').contentWindow.location;
      var frameURL = frameLocation.href;
      if (frameURL != 'about:blank') {
        if (frameURL.indexOf(window.currentURL) == -1) {
          frameURL = frameLocation.pathname + frameLocation.search;
          if (window.currentURL.indexOf(frameURL) == -1) {
            window.reportsController.set('isFrameInitialized', false);
          }
          frameLocation.href = window.currentURL;
        } else if ($("#reportsFrame").contents().find("body").html().indexOf("j_security_check") > 0) {
          location.href = "/";
        } else {
          window.reportsController.set('isFrameInitialized', true);
        }
      }
	   $(document).keyup(function(event){
		 if(event.ctrlKey && event.keyCode==32){
		 event.stopPropagation();
		 }
	 });
    });
  },
  actions: {

    resetSettings: function() {
      this.set('showReportSelection', false);
      this.set('errorData', null);
      this.set('errorStatus', null);
      this.set('clientURL', null);
      this.set('isFrameInitialized', false);
      this.set('isInitialized', false);
      this.set('frameHeight', window.reportsFrameHeight);
      this.set('showPromotion', null);
      this.set('promotionParams', null);
      this.set('unSupportedProducts', null);
      this.set('reportDetails', null);
      this.set('reportsList', null);
      this.set('searchReports', null);
      this.set('reportDetailsMap', null);
      this.set('currentMenuId', null);
      window.currentURL = "";
    },

    getSettings: function() {
      CommonUtil.showLoading();
      var self = this;
      self.set('dataHeight', $(window).height() - 135);
      window.reportsFrameHeight = $(window).height() - 90;

      this.send('resetSettings');

      var productsStatus = null;
      var reportsList = [];
      var searchReportsList = [];
      var statusList = [];
      var reportDetailsMap = {};
      var searchReports = [];
      var productDetailsMap = this.get('productDetailsMap');
	  var updatedTabDetails=[];

      AJAXUtil.ajax('/Reports.do?mTCall=getReportDetails').then(function(response) {
		  		  
		  
        var result = response;
        productsStatus = result["PRODUCTS_STATUS"];
        statusList = result["REPORTS_STATUS"];
        var reportDetails = result["REPORTS_DATA"];
        var tabDetails=Ember.$.extend(true, [],result["REPORTS_DATA"]);
        self.set('reportDetails', reportDetails);
		if(reportDetails.length>0)
		{
			self.set('currentTabReportsList', reportDetails[0].LIST);  
		}
		for(var i=0;i<tabDetails.length;i++)
		{
			if(tabDetails[i].hasOwnProperty('IS_CUSTOM_TAB'))
			{
				break;
			}
			else
			{
				updatedTabDetails[updatedTabDetails.length]=tabDetails[i];
				updatedTabDetails[updatedTabDetails.length-1].INDEX=updatedTabDetails.length-1;
			}
		}
        if (productsStatus.hasOwnProperty('NON_REPORTS_ENABLED_PRODUCTS') && productsStatus['NON_REPORTS_ENABLED_PRODUCTS'].length > 0) {
          var unSupportedProducts = [];
          for (var i = 0; i < productsStatus['NON_REPORTS_ENABLED_PRODUCTS'].length; i++) {
            var product = productsStatus['NON_REPORTS_ENABLED_PRODUCTS'][i];
			product.NAME=product.DISPLAY_NAME;
            unSupportedProducts[unSupportedProducts.length] = product;
			updatedTabDetails[updatedTabDetails.length]= product;
			updatedTabDetails[updatedTabDetails.length-1].INDEX=updatedTabDetails.length-1;
            productDetailsMap[product.TAG_NAME] = product;
          }
          self.set('unSupportedProducts', unSupportedProducts);
        }
		for(var i=0;i<tabDetails.length;i++)
		{
			if(tabDetails[i].hasOwnProperty('IS_CUSTOM_TAB'))
			{
				updatedTabDetails[updatedTabDetails.length]=tabDetails[i];
				updatedTabDetails[updatedTabDetails.length-1].INDEX=updatedTabDetails.length-1;
			}
		}
		self.set('tabsList',updatedTabDetails);
		self.set('currentTabDetails',updatedTabDetails[0]);
        if (!productsStatus.hasOwnProperty('REPORTS_ENABLED_PRODUCTS') || productsStatus['REPORTS_ENABLED_PRODUCTS'].length == 0) {
          var promotionParams = {};
          var unSupportedProducts = self.get('unSupportedProducts');
          if (unSupportedProducts.length > 1) {
            promotionParams.title = 'ads.reports.viewreports.promotion_title_all';
          } else {
            promotionParams.title = 'ads.reports.viewreports.promotion_title_' + unSupportedProducts[0].TAG_NAME;
          }
          promotionParams.products = self.get('unSupportedProducts');
          self.set('promotionParams', promotionParams);
          self.set('showPromotion', true);
          Ember.$('body').toggleClass('ad360-left-pane-lg', false);
        }
        
        if (self.get('showPromotion') == null && self.get('errorStatus') == null) {
          for (var i = 0; i < reportDetails.length; i++) {
            var productReportDetails = reportDetails[i];
            searchReportsList = [];
            searchReportsList['TAB_ID'] = productReportDetails.TAB_ID;
            reportDetailsMap[productReportDetails.PRODUCT_ID] = productReportDetails;
            if (self.get('currentProductId') == null) {
              self.set('currentProductId', productReportDetails.PRODUCT_ID);
            }

            if (productReportDetails.REPORTS_LIST.length > 0) {
              var searchReportIds = {};
              for (var j = 0; j < productReportDetails.REPORTS_LIST.length; j++) {
                var reportId = productReportDetails.REPORTS_LIST[j].REPORT_ID;
                reportsList[reportsList.length] = productReportDetails.REPORTS_LIST[j];
                if (!searchReportIds.hasOwnProperty(reportId)) {
                  searchReportsList[searchReportsList.length] = productReportDetails.REPORTS_LIST[j];
                  searchReportIds[reportId] = reportId;
                }
              }
            }
            searchReports[i] = searchReportsList;
			
          }
		  self.set('searchReports',searchReports);
          self.set('reportsList', reportsList);
          self.set('reportDetailsMap', reportDetailsMap);
          if (reportsList.length > 0) {
            self.set('currentReport', reportsList[0].REPORT_ID);
            self.set('currentProductId', reportsList[0].PRODUCT_ID);
            self.set('currentMenuId', reportsList[0].MENU_ID);
            self.send('changeReport', reportsList[0].PRODUCT_ID, reportsList[0].ROUTE_NAME, reportsList[0].REPORT_ID, reportsList[0].MENU_ID);
          } else if (statusList.length > 0) {
            var errorStatus = [];
            for (var k = 0; k < statusList.length; k++) {

              if (statusList[k]["STATUS"] != 'success') {
                var errorDetails = {};
                errorDetails['PRODUCT_NAME'] = statusList[k]["DISPLAY_NAME"];
                errorDetails['ERROR_MESSAGE'] = I18NUtil.translate(statusList[k]["MESSAGE"].STATUS_MESSAGE + '_description');
                errorStatus[errorStatus.length] = errorDetails;
              }
            }

            if (errorStatus.length > 0) {
              self.set('errorStatus', errorStatus);
            }
          }
        }
        self.set('isInitialized', true);
        

        Ember.run.schedule('afterRender', function() {
			
			Ember.$('body').tooltip({ selector: '[data-toggle="tooltip"]' });
			
          if (Ember.$('body').hasClass('no-left-pane')) {
            Ember.$(".left-navigation").hide();
          }
          Ember.run.later((function() {
            Ember.$('#reportsFrame').css('visibility', 'visible');
          }), 5000);

          Ember.$(".nav-tabs a").parent().each(function() {
            if ($(this).hasClass('active')) {
              $(this).removeClass('active');
            }
          });
          Ember.$("li[menu='reports']").addClass('active');
		  if(reportDetails[0]!=undefined)
		  {
			Ember.$("[VIEW_ID='" +reportDetails[0].TAB_ID + "']").addClass("active");
	Ember.$('.lnav').navgoco({
            accordion: true,
            caretHtml: '<span class="caret-arrow"></span>',
            openClass: 'open', //NO I18N
            save: true,
            cookie: {
              name: 'navgoco', //NO I18N
              expires: false,
              path: '/'
            },
            slide: {
              duration: 100,
              easing: 'linear' //NO I18N
            },
            onClickAfter: function(e, submenu) {
              e.preventDefault();
              if (submenu === false) {
                e.preventDefault();
                $(".lnav").find("li").removeClass("active");
                var li = $(this).parent();
                li.addClass("active"); //NO I18N
                if ($(this).attr('IS_PROMOTION') == 'true') {
                  self.send('showProductPromotion', $(this).attr('TAG_NAME'));
                } else {
                  self.send('changeReport', $(this).attr('PRODUCT_ID'), $(this).attr('ROUTE'), $(this).attr('REPORT_ID'), $(this).attr('MENU_ID').length == 0  ? undefined : $(this).attr('MENU_ID'));
                }

              }
            }
          });

          if (self.get('currentReport') != null) {
            self.initFrameLoad();
            var index = Ember.$('[REPORT_ID="' + self.get('currentReport') + '"][PRODUCT_ID="' + self.get('currentProductId') + '"]').parent().parent().attr('data-index');
            Ember.$('[REPORT_ID="' + self.get('currentReport') + '"][PRODUCT_ID="' + self.get('currentProductId') + '"]').parent().addClass('active');
            $('.lnav').navgoco('toggle', true, index);
          }
          // Search Logic Starts
          if (searchReports[0].length > 0) {
            //Search Query Matcher
            var substringMatcher = function(strs) {
              return function findMatches(query, func) {
                // an array that will be populated with substring matches
                var matches = [];

                // shortcut escaping
                if (query === '/') {
                  query = '';
                  $('.report-search input:text').typeahead('val', ''); //NO I18N
                  return matches.push({});
                }
                query = query.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
                // regex used to determine if a string contains the substring `query`
                var substrRegex = new RegExp(query, 'i');
                // iterate through the pool of strings and for any string that
                // contains the substring `query`, add it to the `matches` array
                $.each(strs, function(i, str) {
                  if (substrRegex.test(str.REPORT_NAME)) {
                    matches.push(str);
                  }
                });
                func(matches);
              };
            };

            $('.report-search input:text').typeahead({
                hint: true,
                highlight: true,
                minLength: 1
              },
              {
				   displayKey: 'REPORT_NAME', //NO I18N
				   source: substringMatcher(searchReports[0])
			  },

            ).on('typeahead:selected', function(obj, datum, dataSet) //NO I18N
              {
                window.reportsController.send('changeReport', datum.PRODUCT_ID, datum.ROUTE_NAME, datum.REPORT_ID, datum.MENU_ID); //NO I18N
                $(".lnav").find("li").removeClass("active");
                var li = $(this).parent();
                li.addClass("active"); //NO I18N
                var index = Ember.$('[REPORT_ID="' + window.reportsController.get('currentReport') + '"][PRODUCT_ID="' + window.reportsController.get('currentProductId') + '"]').parent().parent().attr('data-index');
				Ember.$('[REPORT_ID="' + window.reportsController.get('currentReport') + '"][PRODUCT_ID="' + window.reportsController.get('currentProductId') + '"]').parent().addClass('active');
                $('.lnav').navgoco('toggle', true, index);
              });
            $(document).keypress(function(e) {
              if (e.which == 47 && e.target.type != 'text' && e.target.type != 'password') {
                $(window.reportsController.get('element')).find('.report-search input:text').focus(); //NO I18N
                $(window.reportsController.get('element')).find('.report-search input:text').val(''); //NO I18N
              }
            });

            if ($(".report-search .tt-dropdown-menu").length) {
              $(".report-search .tt-dropdown-menu").mCustomScrollbar();
            }
          }
          // Search Logic ends

        var productPosition=Ember.$("[VIEW_ID='" + updatedTabDetails[updatedTabDetails.length-1].TAB_ID + "']").position();
		var productWidth=Ember.$('[VIEW_ID='+updatedTabDetails[updatedTabDetails.length-1].TAB_ID+']').width();
		var toolPosition = Ember.$('.sub-tab-settings').position();
		if(toolPosition!=undefined && productPosition !=undefined)
		{
		if(toolPosition.left-50<productPosition.left+productWidth)
		{
			self.set('showButtons',true);
		}
		else
		{
			self.set('showButtons',false);
		}
		}
		}
		});
        self.send('scrollBar');
        CommonUtil.hideLoading();
      });
	 
    },

    changeReport: function(productId, route, reportId, menuId) {
      var refreshParam = '';
      var refreshFrame = window.currentURL == "" ? true : false;
      if (this.get('currentProductId') == productId && this.get('errorData') != null) {
        refreshParam = '&uniqueId=' + Math.floor((Math.random() * 100) + 1);
      }

      if (this.get('currentProductId') != productId) {
        this.set('isFrameInitialized', false);
        refreshFrame = true;
      }


      this.set('currentProductId', productId);
      this.set('currentReport', reportId);
      this.set('errorData', null);
      this.set('promotionData', null);
      this.set('clientURL', "/Reports.do?mTCall=viewReport" + refreshParam + "&isRoutingRequired=true&ignoreRouting=true&productId=" + productId + "#/" + route + "/" + reportId);
      window.currentURL = this.get('clientURL');
      if (refreshFrame) {
        var reportFrame = '<iframe id="reportsFrame" src="about:blank" scrolling="no" style="border:0;width: 100%;height:' + window.reportsFrameHeight + 'px"></iframe>';
        window.purge($('#reportsFrame'));
        $('#reportsFrameWrapper').empty().append(reportFrame);
        this.initFrameLoad();
      }
      $('#reportsFrame').attr('src', window.currentURL);
	  var reportsFrame=$('#reportsFrame');
	  reportsFrame.notificationDetails="null";

      if(this.get('canTrack'))//This flag helps to remove tracking of first selected Report on entering this route.
      {
        var url = '/Reports.do?mTCall=unspecified&productId='+productId+'&reportId='+reportId;
        if(menuId!=undefined) { url+='&menuId=' + menuId; }
        AJAXUtil.ajax(url);//Dummy Connection for Tracking reports usage
      }
      else
      {
        this.toggleProperty('canTrack');
      }
    },

    showAddReports: function() {
		this.sendAction('configureReports');
    },

    showProductPromotion: function(tagName) {
      var productDetailsMap = this.get('productDetailsMap');
      var product = productDetailsMap[tagName];
      var promotionParams = {};
      promotionParams.title = 'ads.reports.viewreports.promotion_title_' + tagName;
      promotionParams.products = [product];
      this.set('promotionData', promotionParams);
      this.set('errorData', null);
    },

    setErrorMessage: function(errorData) {
      if (errorData != null && errorData != undefined) {
        if (errorData.hasOwnProperty('STATUS_MESSAGE')) {
          errorData['ERROR_MESSAGE'] = errorData['STATUS_MESSAGE'];
        }
        this.set('errorData', errorData);
      } else {
        this.set('errorData', {});
      }
    },

    toggleLHS: function() {
      Ember.$("body").toggleClass('no-left-pane');
      Ember.$(".left-navigation").toggle();
    },
    scrollBar: function() {
      var self = this;
      Ember.run.scheduleOnce('afterRender', function() //NO I18N
        {
          $(window).resize(function() {
            self.set('dataHeight', $(window).height() - 135);
            $(".fw-custom-scroll-hover").height($(window).height() - 135);
          })
          $(".fw-custom-scroll-hover").each(function() {
            if ($(this).attr('data-height')) {
              $(this).height($(this).attr('data-height')).css({});
            }
            var theme = ($(this).attr("data-theme")) ? $(this).attr("data-theme") : "dark";
            var sPosition = ($(this).attr("data-scrollbar-position")) ? $(this).attr("data-scrollbar-position") : "inside";
            $(this).mCustomScrollbar({
              theme: theme,
              autoHideScrollbar: true,
              scrollbarPosition: sPosition,
              callbacks: {
                onScroll: function(evt) {
                  return false;
                },
                onTotalScroll: function(evt) {
                  return false;
                },
                onTotalScrollBack: function(evt) {
                  return false;
                }
              }
            });
          });
        });
    },
	changeTab: function(reportDetails)
	{
		if(Ember.$("[VIEW_ID='" + reportDetails.TAB_ID + "']").hasClass('active'))
		{
			return;
		}
		CommonUtil.showLoading();
		this.set('currentTabDetails',reportDetails);
		var reportList=reportDetails.LIST;
		Ember.$('.fw-left-pane').css('display','block');
		var self=this;
		try
		{
			if(reportList[0].LIST != undefined)
			{
			  self.send('callChangeReport',reportList);
			}
		}
		catch (e) 
		{
			self.send('showProductPromotion',reportDetails.TAG_NAME);
			Ember.$('.fw-left-pane').css('display','none');
		}
		$('.report-search input:text').val(''); //NO I18N
		$('.lnav').navgoco('destroy').removeData();
		self.set('currentTabReportsList',reportList);
		Ember.run.scheduleOnce('afterRender', function() //NO I18N
        {
			Ember.$('.lnav').navgoco({
            accordion: true,
            caretHtml: '<span class="caret-arrow"></span>',
            openClass: 'open', //NO I18N
            save: true,
            cookie: {
              name: 'navgoco', //NO I18N
              expires: false,
              path: '/'
            },
            slide: {
              duration: 100,
              easing: 'linear' //NO I18N
            },
            onClickAfter: function(e, submenu) {
              e.preventDefault();
              if (submenu === false) {
                e.preventDefault();
                $(".lnav").find("li").removeClass("active");
                var li = $(this).parent();
                li.addClass("active"); //NO I18N
                  self.send('changeReport', $(this).attr('PRODUCT_ID'), $(this).attr('ROUTE'), $(this).attr('REPORT_ID'), $(this).attr('MENU_ID').length == 0  ? undefined : $(this).attr('MENU_ID'));
              }
            }
          });
			var index = Ember.$('[REPORT_ID="' + self.get('currentReport') + '"][PRODUCT_ID="' + self.get('currentProductId') + '"]').parent().parent().attr('data-index');
            Ember.$('[REPORT_ID="' + self.get('currentReport') + '"][PRODUCT_ID="' + self.get('currentProductId') + '"]').parent().addClass('active');
            $('.lnav').navgoco('toggle', true, index);
			var searchReportDetails=self.get('searchReports');
			
			//Search Query Matcher
			
			var substringMatcher = function(strs) {
					return function findMatches(query, func) {
					// an array that will be populated with substring matches
					var matches = [];
					// shortcut escaping
					if (query === '/') {
					query = '';
					$('.report-search input:text').typeahead('val', ''); //NO I18N
					return matches.push({});
					}
					query = query.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
					// regex used to determine if a string contains the substring `query`
					var substrRegex = new RegExp(query, 'i');

					// iterate through the pool of strings and for any string that
					// contains the substring `query`, add it to the `matches` array
					
					$.each(strs, function(i, str) {
					if (substrRegex.test(str.REPORT_NAME)) {
                    matches.push(str);
					}
					});
					
					func(matches);
					};
					};
			for(var i=0;i<searchReportDetails.length;i++)
			{
				if(searchReportDetails[i].TAB_ID==reportDetails.TAB_ID)
				{
					$(".typeahead").typeahead("destroy");
					$('.report-search input:text').typeahead({
						hint: true,
						highlight: true,
						minLength: 1
					},
					{
						displayKey: 'REPORT_NAME', //NO I18N
						source: substringMatcher(searchReportDetails[i])
					},

					)			
					if ($(".report-search .tt-dropdown-menu").length) {
						$(".report-search .tt-dropdown-menu").mCustomScrollbar();
					}
				}
			}
		});
		
		
		Ember.$("[VIEW_ID]").removeClass("active");
		if(reportDetails.TAB_ID==undefined || reportDetails.TAB_ID == '')
		{
			return;
		}
		Ember.$("[VIEW_ID='" + reportDetails.TAB_ID + "']").addClass("active");
		var toolPosition = Ember.$('.sub-tab-settings').position();
		var productPosition = Ember.$('[VIEW_ID='+reportDetails.TAB_ID+']').position();
		if(productPosition==null)
		{
			return;
		}
		var productWidth = Ember.$('[VIEW_ID='+reportDetails.TAB_ID+']').width();
		var tabPosition = parseInt(Ember.$('.slider-tab').css('margin-left'));
		var calc;
		if(productPosition.left<0)
		{
			calc= tabPosition - (productPosition.left-15);
			Ember.$('.slider-tab').animate({'margin-left':calc});
		}
		else
		{
			calc = productWidth - ((toolPosition.left-50) - (productPosition.left));
			if(calc>0)
			{
				calc+=Math.abs(tabPosition);
				Ember.$('.slider-tab').animate({'margin-left':calc*-1});
			}
		}
		CommonUtil.hideLoading();
	},
	callChangeReport:function(reportData)
	{
		if(reportData[0].LIST!= undefined)
		{
			this.send('callChangeReport',reportData[0].LIST);
		}
		else
		{
		    this.send('changeReport', reportData[0].PRODUCT_ID,reportData[0].ROUTE_NAME, reportData[0].REPORT_ID,reportData[0].MENU_ID);
		}
	},
	changeSideTab:function(val)
	{
		var currentTabIndex=this.get('currentTabDetails').INDEX;
		var tabs = this.get('tabsList');
		var nextTab = null;
		if (val)
		{
			nextTab = tabs[currentTabIndex - 1];
		} 
		else 
		{
			nextTab = tabs[currentTabIndex + 1];
		}
		if(nextTab) 
		{
			this.send('changeTab', nextTab);
		}
	}
  }
});

//ignorei18n_end
