/* $Id: ssl-tool.js,v 1.8 2018/11/21 19:27:28 dineshbabu.k Exp $ */
/**
 * {{ssl-tool showStatus='showStatus'}} 
 */
//ignorei18n_start
import Ember from 'ember';
import I18NUtil from "../utils/i18n-util";
import AJAXUtil from '../utils/ads-ajax-util';
import DialogUtil from "../utils/ads-dialog-util";
import CommonUtil from "../utils/ads-common-util"; //NO I18N




const {
    A,
    set,
    run,
    isBlank,
    isEmpty,
    computed,
    isPresent,
    Component,
} = Ember;

const {
    scheduleOnce,
    later
} = run;

const {
    gt,
    alias,
    oneWay,
    filter,
    readOnly
} = computed;



let CSR = Ember.Object.extend({

    isValidCountryCode: computed('COUNTRY_CODE', function() {
        let countryCode = this.COUNTRY_CODE;
        return isPresent(countryCode) && countryCode.length === 2 && countryCode.match(/^[a-zA-Z]+$/) !== null;
    }),
    isValidDuration: computed('VALIDITY', function() {
        let validity = this.VALIDITY;
        return isBlank(validity) || (validity.match(/^\d+$/i) !== null && validity > 0 && validity < 7300);
    }),
    isValidKeyLength: computed('PUBLIC_KEY_LENGTH', function() {
        let pkl = this.PUBLIC_KEY_LENGTH;
        return isBlank(pkl) || (pkl.match(/^\d+$/i) !== null && pkl >= 2048 && pkl <= 4096 && pkl % 64 === 0);
    }),
    isValidCommonName: computed('COMMON_NAME', function() {
        let cn = this.COMMON_NAME;
        return !isBlank(cn) && cn.match(/^(([*a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9-]*[A-Za-z0-9])$/);
    }),

    isValidOU: computed('ORGANIZATION_UNIT', function() {
        return !isBlank(this.ORGANIZATION_UNIT);
    }),

    isValidOrg: computed('ORGANIZATION', function() {
        return !isBlank(this.ORGANIZATION);
    }),

    isValidCity: computed('CITY', function() {
        let city = this.CITY;
        return !isBlank(city) && city.match(/^([a-zA-Z]+\s)*[a-zA-Z]+$/) !== null;
    }),

    isValidState: computed('STATE', function() {
        let state = this.STATE;
        return !isBlank(this.STATE) && state.match(/^([a-zA-Z]+\s)*[a-zA-Z]+$/) !== null;
    }),

    validate() {
        if (!this.get('isValidCommonName')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_invalid_cn'));
            return false;
        }
        if (!this.get('isValidOU')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_invalid_ou'));
            return false;
        }
        if (!this.get('isValidOrg')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_invalid_org'));
            return false;
        }
        if (!this.get('isValidCity')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_invalid_city'));
            return false;
        }
        if (!this.get('isValidState')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_invalid_state'));
            return false;
        }
        if (!this.get('isValidCountryCode')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_entries_notnumeral'));
            return false;
        }
        if (isBlank(this.PASSWORD) || this.get('PASSWORD').length < 6) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_entries_pwdlength'));
            return false;
        }
        if (!this.get('isValidKeyLength')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_entries_multiple64'));
            return false;
        }
        if (!this.get('isValidDuration')) {
            this.set('errorMessage', I18NUtil.translate('ads_admin_ssl_tool_alert_entries_lessthan7300'));
            return false;
        }
        return true;
    },
    empty() {
        this.setProperties({
            COMMON_NAME: '',
            ORGANIZATION_UNIT: '',
            ORGANIZATION: '',
            CITY: '',
            STATE: '',
            COUNTRY_CODE: '',
            PASSWORD: '',
            VALIDITY: '',
            PUBLIC_KEY_LENGTH: '',
            SAN_NAMES: ''
        });
    }
});
export default Component.extend({
    init: function() {
        this._super();
        this.set('pageStatus', {});
        this.set('routingService', Ember.inject.service('-routing'));
        this.set('status', {});
        this.set('csrData', CSR.create());
        this.set('apiNamespace', '/RestAPI/WC/SSLAction');
        this.send('resetCSRPage'); //NO I18N
        this.set('showDownload', false); //NO I18N           
        this.set('showUploadForm', true); //NO I18N
        this.set('uploadOptions', A(['ZIP', 'CERT_FILE', 'CERT_CONTENT']));
        this.set('selectedUploadOption', this.get('uploadOptions.firstObject')); //NO I18N
        this.set('selectedOption', 'applycertificate');
        this.set('showComponentSelection', false);
        this.set('showUpload', true);

        this.set("Modal", {});
        this.send('getSSLSettings');
    },
    didRender:function(){
        Ember.$("#SSLToolForm").on("keypress",function(e) {
            var key = e.charCode || e.keyCode || 0;     
            if (key == 13) {
              e.preventDefault();
            }
          });
    },
    statusList: alias('applyStatus'),
    errorList: filter('statusList', function(status) {
        return isPresent(status.eSTATUS);
    }),
    successList: filter('statusList', function(status) {
        return isPresent(status.sSTATUS);
    }),
    hasMixedStatus: computed('errorList', 'successList', function() {
        return this.get('errorList').length > 0 && this.get('successList').length > 0;
    }),

    showRestartButton: computed('successList', function() {
        return this.get('successList').length > 0;
    }),
 
    processApplyStatus: function(response) {
        /** @namespace response.CERT_APPLY_STATUS */
        if (!isEmpty(response.CERT_APPLY_STATUS)) {
            this.set('applyStatus', response.CERT_APPLY_STATUS);
            scheduleOnce('afterRender', this, function() {
                this.$("#status1").modal('show');
                // this.$('.nav-tabs').find('a').last().tab('show'); //Import JQuery UI in the app to make sure this statement works
            });
            return true;
        } else {
            this.sendAction('showStatus', {
                eSTATUS: response.eSTATUS
            });
            return false;
        }
    },
    showLoading: function() {
        Ember.$("#applying").modal('show');
    },
    hideLoading: function() {
        Ember.$("#applying").modal('hide');
    },

    actions: {

        getSSLSettings: function() {
            var self = this

            AJAXUtil.ajax(this.get('apiNamespace') + '?mTCall=getSSLToolSettings', {}).then(function(response) {
                Ember.run.schedule('afterRender', self, function() {
                    try {
                        self.set('sslSett', response)
                        self.set('sslSettings', oneWay('sslSett'));
                        self.set('oldData', readOnly('sslSettings'));
                        self.set('products', alias('sslSettings.products'));
                        self.set('hasMultipleComponents', gt('products.length', 1));
                        self.set('showComponentSelection', alias('hasMultipleComponents'));
                        CommonUtil.afterRender(); //no i18n                
                    } catch (error) {}
                }); //NO I18N
            })
        },

        helpDoc: function() {
            window.open("/help/admin/general-settings/what-is-ssl.html");
        },

        changeUploadType: function(param) {
            let type = JSON.parse(param).columnValue;
            this.set('selectedUploadOption', type);

            switch (type) {
                case this.uploadOptions.objectAt(0):
                    this.$(".zip").removeClass("hide");
                    this.$(".certFile, .certContent").addClass("hide");
                    break;

                case this.uploadOptions.objectAt(1):
                    this.$(".certFile").removeClass("hide");
                    this.$(".zip, .certContent").addClass("hide");
                    break;

                case this.uploadOptions.objectAt(2):
                    this.$(".zip, .certFile").addClass("hide");
                    this.$(".certContent").removeClass("hide");
                    break;
            }
            this.$("#SSLToolForm").find("input[type=text], input[type=password], input[type=file] ,textarea").val("");
        },

        renderFileName: function(uploadType) {
            let path = this.$('[name="' + uploadType + '"]').val().split('\\').pop();
            if (path.length > 20) {
                path = path.substring(0, 20) + "...";
            }
            this.$('#' + uploadType + '.file-upload-placeholder').val(path);
        },

        uploadCertificate: function(products) {
            let self = this;
            if (products == undefined || (products != undefined && products.length == 0)) {
                if (this.get('hasMultipleComponents') && this.$("[name = 'SELECT_PRODUCTS'] option:selected").text() === "") {
                    DialogUtil.alert(this, I18NUtil.translate('ads_admin_ssl_tool_alert_no_selected_components'));
                    return;
                }
            }

            let sslForm = this.$("#SSLToolForm");
            switch (this.get('selectedUploadOption')) {
                case 'ZIP':
                    if (sslForm.find("[name='ZIP']").get(0).files.length === 0) {
                        DialogUtil.alert(this, I18NUtil.translate('ads_admin_ssl_tool_alert_empty_zip_file'));
                        return;
                    }
                    break;
                case 'CERT_FILE':
                    if (sslForm.find("[name='CERT_FILE']").get(0).files.length === 0) {
                        DialogUtil.alert(this, I18NUtil.translate('ads_admin_ssl_tool_alert_empty_cert_file'));
                        return;
                    }
                    break;
                case 'CERT_CONTENT':
                    if (sslForm.find("[name='CERT_CONTENT']").val() === "") {
                        DialogUtil.alert(this, I18NUtil.translate('ads_admin_ssl_tool_alert_empty_string_content'));
                        return;
                    }
                    break;
            }
            self.showLoading();
            if (this.get('hasMultipleComponents')) {
                var value = products != undefined ? products.toString() : this.$("[name='SELECT_PRODUCTS']").val().toString();
                Ember.$('[name=PRODUCTS]').val(value);
                Ember.$("[name='SELECT_PRODUCTS']").attr('disabled', 'disabled');
                sslForm.submit();
                Ember.$("[name='SELECT_PRODUCTS']").removeAttr('disabled');
            } else {
                Ember.$("[name='PRODUCTS']").attr('value', this.get('products')[0].PRODUCT_ID);
                sslForm.submit();
            }
            this.$('.fw-ssl-res').removeClass("hide");

            this.$('#SSLToolIFrame').load(function() {
                self.hideLoading();
                let responseHtml = self.$("#SSLToolIFrame").contents().find("body").html();
                try {
                    if (self.processApplyStatus(Ember.$.parseJSON(responseHtml))) {
                        self.send('resetUploadForm');
                    }
                } catch (e) {
                    AJAXUtil.handleSessionTimeout("403", responseHtml);
                }
            });
        },

        showProductSelection: function() {
            if (this.csrData.validate()) {
                if (this.get('hasMultipleComponents')) {

                    Ember.set(this, "Modal.heading", "apply SelfSigned certificate");
                    Ember.$("#productSelect").modal('show');

                }
            } else {
                DialogUtil.alert(this, this.get('csrData.errorMessage'));
            }
        },
        getProducts: function(id, funcName) {

            var $el = $("#" + id);
            var data = [];
            var products = this.get("products");
            $el.find('option:selected').each(function() {
                var prod_Name = $(this).val();
                for (var i = 0; i < products.length; i++) {
                    if (products[i].DISPLAY_NAME == prod_Name) {
                        data.push(products[i].PRODUCT_ID);
                    }
                }
            });

            this.send(funcName, data);

        },

        applySelfSigned: function(products) {
            if (products == undefined || (products != undefined && products.length == 0)) {
                if (this.get('hasMultipleComponents') && Ember.$("[name = 'SELECT_PRODUCTS'] option:selected").text() === "") {
                    Ember.set(this, "Modal.notSelected", true);
                    DialogUtil.alert(this, I18NUtil.translate('ads_admin_ssl_tool_alert_no_selected_components'));
                    return;
                }
            }
            if (this.csrData.validate()) {
                let data = this.csrData.getProperties('COMMON_NAME', 'ORGANIZATION_UNIT', 'ORGANIZATION', 'CITY', 'STATE', 'COUNTRY_CODE', 'PASSWORD', 'SAN_NAMES');
                if (isBlank(this.csrData.VALIDITY)) {
                    data.VALIDITY = this.csrData.VALIDITY;
                }
                if (isBlank(this.csrData.PUBLIC_KEY_LENGTH)) {
                    data.PUBLIC_KEY_LENGTH = this.csrData.PUBLIC_KEY_LENGTH;
                }

                if (this.get('hasMultipleComponents')) {
                    data.PRODUCTS = products != undefined ? products.toString() : this.$("[name='SELECT_PRODUCTS']").val().toString();
                } else {
                    data.PRODUCTS = this.get('products')[0].PRODUCT_ID;
                }

                let self = this;
                self.showLoading();
                AJAXUtil.ajax(this.apiNamespace + '?mTCall=applySelfSignedCertificate', data, null, 'json').then(function(response) {
                    self.hideLoading();
                    if (self.processApplyStatus(response)) {
                        self.csrData.empty();
                    }
                });
            }
        },

        generateCSR: function() {
            let self = this;
            self.set('status.icon', 'fw-icn-status-alert-danger');
            self.set('status.type', 'danger');

            if (this.csrData.validate()) {
                let data = this.csrData.getProperties('COMMON_NAME', 'ORGANIZATION_UNIT', 'ORGANIZATION', 'CITY', 'STATE', 'COUNTRY_CODE', 'PASSWORD', 'SAN_NAMES');
                if (!isBlank(this.csrData.VALIDITY)) {
                    data.VALIDITY = this.csrData.VALIDITY;
                }
                if (!isBlank(this.csrData.PUBLIC_KEY_LENGTH)) {
                    data.PUBLIC_KEY_LENGTH = this.csrData.PUBLIC_KEY_LENGTH;
                }
                AJAXUtil.ajax(this.apiNamespace + '?mTCall=generateCSR', data, null, 'json').then(function(response) {
                    if ('sSTATUS' in response) {
                        self.csrData.empty();
                        self.set('showDownload', true);
                        scheduleOnce('afterRender', this, function() {


                        });

                    } else {
                        self.sendAction('showStatus', {
                            eSTATUS: response.eSTATUS
                        });
                    }
                });
            } else {
                DialogUtil.alert(self, self.csrData.errorMessage);
            }
        },

        downloadCSR: function() {
            window.open(this.apiNamespace + '?mTCall=downloadCSR');
        },

        resetCSRPage: function() {
            this.csrData.empty();
        },

        resetUploadForm: function() {
            if (this.get('showComponentSelection')) {
                this.$("[name = 'SELECT_PRODUCTS']").val('default').selectpicker('refresh');
            }
            this.$("#SSLToolForm")[0].reset();
        },

        restart: function() {
            this.$('.fw-ssl-res').addClass("hide");
            var self = this;
            this.get('successList').forEach(function(item) {

                let product = {
                    PRODUCT_ID: item.PRODUCT_ID
                };

                set(item, 'RESTART_MESSAGE', '- ' + I18NUtil.translate('ads.ssl_tool.message.restarting'));
                set(item, 'RESTARTING', true)

                AJAXUtil.ajax(this.apiNamespace + '?mTCall=restartProduct', product).then(function(response) {
                    if (isPresent(response.sSTATUS)) {
                        later(function() {
                            if (isPresent(response.IS_PARENT_PRODUCT)) {
                                scheduleOnce('afterRender', function() {
                                    self.$('#restart-modal').modal();
                                    self.$("#status1").modal('hide');
                                });
                            }
                            set(item, 'RESTART_MESSAGE', '');
                            set(item, 'ICON_CLASS', 'fw-icn-success');
                            set(item, 'RESTARTING', false)
                        }, 2000);
                    } else {
                        later((function() {
                            set(item, 'RESTART_MESSAGE', I18NUtil.translate(response.eSTATUS));
                            set(item, 'ICON_CLASS', 'fw-icn-failure');
                            set(item, 'RESTARTING', false)
                        }), 2000);
                    }
                });
            }, this);
        },
        toggleCheckBox: function(val, key) {},
        toggleRadioButtons: function(value) {
            var selectedButton = JSON.parse(value).columnValue;
            if (selectedButton == "applycertificate") {
                $(".gc").addClass("hide");
                $(".zip,.common").removeClass("hide");
                Ember.set(this, "selectedOption", "applycertificate");
                this.set('selectedUploadOption', this.get('uploadOptions.firstObject'));
                var products = this.get("products");
                products.setEach("IS_ENABLED", false);
                Ember.set(this, "products", products);
            } else if (selectedButton == "generatecertificate") {
                $(".ac").addClass("hide");
                $(".gc").removeClass("hide");
                Ember.set(this, "selectedOption", "generatecertificate");
            }
        }
    }


});
//ignorei18n_end
