/*
 * $Id: tfa-config.js,v 1.16.4.3 2018/12/05 11:12:37 kamalraj.d Exp $
 */

//ignorei18n_start
import Ember from 'ember';
import AJAXUtil from '../utils/ads-ajax-util';
import I18NUtil from "../utils/i18n-util";
import DialogUtil from "../utils/ads-dialog-util";
import CommonUtil from "../utils/ads-common-util";
import ValidationUtil from "../utils/ads-validation-util";

export default Ember.Component.extend({
    router: Ember.inject.service('-routing'),
    pageStatus: {},
    IS_ENABLED: false,
    TFA_CONFIG: [],
    mailEditorOptions: [1, 2, 3, 4, 5, 7],
    showIntegratedProductsList: false,
    contextPath:'',
    getSettings: function() {
        if((AJAXUtil.context !== undefined) && AJAXUtil.context != '') {
            this.set('contextPath', AJAXUtil.context);
        }
        var response = AJAXUtil.syncAjax('/RestAPI/WC/TwoFactorAction?mTCall=getTwoFactorAuthConfig', {});
        var tfaConfig = response['TFA_CONFIG_LIST'];
        this.set('IS_ENABLED', response['IS_ENABLED']);
        this.set('INITIAL_ENABLED_STATUS', response['IS_ENABLED']);
        this.set('NAVIGATION', response['USER_ENROLLMENT_NAVIGATION']);
        this.set('MODE_OPTIONS', response['MODE_OPTIONS']);
        for (var i = 0; i < tfaConfig.length; i++) {
            tfaConfig[i]['TEMP_IS_ENABLED'] = tfaConfig[i]['IS_ENABLED'];
        }
        this.set('TFA_CONFIG', tfaConfig);
        var integratedProdctDetails = response['TFA_INTEGRATED_PRODUCTS'];
        if (integratedProdctDetails['PRODUCTS_LIST'].length > 0) {
            this.set('showIntegratedProductsList', true);
            this.set('TFA_INTEGRATED_PRODUCTS', integratedProdctDetails);
        }
        this.isTFAModeEnabled();
        CommonUtil.afterRender();
    }.on('init'),
    refreshTFAMode: Ember.observer('options.refreshModeName', function() {
        this.getTFAModeConfig(this.get('options.refreshModeName'));
    }),
    getTFAModeConfig(modeName) {
        var data = {};
        var self = this;
        data['TFA_MODE_NAME'] = modeName;
        var response = AJAXUtil.syncAjax('/RestAPI/WC/TwoFactorAction?mTCall=getTwoFactorModeConfig', data);
        var tfaModeConfig = response['TFA_MODE_CONFIG'];
        tfaModeConfig['TEMP_IS_ENABLED'] = tfaModeConfig['IS_ENABLED'];
        var tfaConfig = Ember.$.extend(true, [], self.get('TFA_CONFIG'));
        for (var i = 0; i < tfaConfig.length; i++) {
            if (tfaConfig[i].MODE_NAME === modeName) {
                tfaModeConfig['SHOW_PANEL'] = true;
                tfaConfig[i] = tfaModeConfig;
            } else {
                tfaConfig[i]['SHOW_PANEL'] = false;
            }
        }
        self.set('TFA_CONFIG', tfaConfig);
        self.isTFAModeEnabled();
        CommonUtil.afterRender();
    },
    isTFAModeEnabled: function () {
        Ember.run.schedule('afterRender', this, function () {
            var self = this;
            var isTFAEnabled = this.get('IS_ENABLED');
            var isTFAModeEnabled = false;
            if (self.$('.fw-inline-icon').hasClass('fw-icn-sm-ok') && isTFAEnabled) {
                isTFAModeEnabled = true;
            } else if (self.$('.fw-inline-icon').hasClass('fw-icn-sm-cancel') || isTFAEnabled === false) {
                isTFAModeEnabled = false;
            }
            if (isTFAEnabled === true && isTFAModeEnabled === false) {
                var tfaConfig = self.get('TFA_CONFIG');
                for (var i = 0; i < tfaConfig.length; i++) {
                    if (tfaConfig[i].MODE_NAME === "TFA_BACKUP_VERIFICATION_CODE_AUTHENTICATOR") {
                        tfaConfig[i]['IS_ENABLED'] = false;
                    }
                }
                self.set('TFA_CONFIG', tfaConfig);
            }
            self.set('IS_TFA_MODE_ENABLED', isTFAModeEnabled);
        });
    },
    disableEnrollView: function(){
        var id = this.get('pageStatus.show');
        if (id === undefined || id === '') {
            if (this.$('#selectUsers').find('.tfa-ovrlay').hasClass('disable')) {
                this.$('#selectUsers').find('.tfa-ovrlay').removeClass('disable');
            }
        } else {
            if (this.$('.modal-backdrop').length > 1) {
                this.$('.modal-backdrop').last().removeClass('in');
                this.$('#selectUsers').find('.tfa-ovrlay').addClass('disable');
            }
        }
    }.observes('pageStatus.show'),
    didInsertElement: function() {
        Ember.run.scheduleOnce('afterRender',this, this.disableEnrollView);
        this.$('.tfa-panel-group .panel-collapse').on("show.bs.collapse", function() {
            Ember.$(this).closest('.panel').addClass("open");
        })
        this.$('.tfa-panel-group .panel-collapse').on("hide.bs.collapse", function() {
            Ember.$(this).closest('.panel').removeClass("open");
        })
    },
    getSerchQuery: function() {
        var data = {};
        var userName = this.get('SEARCH_USER_NAME');
        if (userName !== undefined && userName !== '') {
            data['SEARCH_USER_NAME'] = userName;
        }
        var domainName = this.get('SEARCH_DOMAIN_NAME');
        if (domainName !== undefined && domainName !== '') {
            data['SEARCH_DOMAIN_NAME'] = domainName;
        }
        var modeOption = this.get('SEARCH_MODE_OPTION');
        if (modeOption !== undefined && modeOption !== 'none') {
            data['SEARCH_MODE_OPTION'] = modeOption;
        }
        return data;
    },
    resetTFAEnrolledUsersTable: function(tfaEnrolledUsers) {
        this.$('#ENABLE_DISABLE_ALL').prop('checked', false);
        this.$('#ENABLE_DISABLE_ALL').iCheck('update');
        var data = this.getSerchQuery();
        data['RECORDS_PER_PAGE'] = this.get('NAVIGATION.RECORDS_PER_PAGE');
        data['PAGE'] = this.get('NAVIGATION.PAGE');
        this.set('isLoading', true);
        Ember.$('.no-data').addClass('hide');
        var self = this;
        AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=getUserEnrollmentConfig', data).then(function(response) {
            if ('TFA_ENROLLED_USERS' in response) {
                var tfaEnrolledUsersCount = response['TFA_ENROLLED_USERS_COUNT'];
                self.set('NAVIGATION.TOTAL_COUNT', tfaEnrolledUsersCount);
                self.performNavigation(response["TFA_ENROLLED_USERS"]);
            }
            self.set('isLoading', false);
            Ember.$('.no-data').removeClass('hide');
        });
    },
    performNavigation: function(tfaEnrolledUsers) {
        Ember.run.schedule('afterRender', this, function() {
            var tableConfig = this.get('NAVIGATION');
            if (tfaEnrolledUsers.length !== 0) {
                var page = tableConfig.PAGE;
                var rowCount = tableConfig.RECORDS_PER_PAGE;
                var totalCount = tableConfig.TOTAL_COUNT;
                //set start count
                if ((tableConfig.PAGE - 1) * tableConfig.RECORDS_PER_PAGE + 1 <= totalCount) {
                    Ember.set(tableConfig, 'START_COUNT', (tableConfig.PAGE - 1) * tableConfig.RECORDS_PER_PAGE + 1);
                } else {
                    Ember.set(tableConfig, 'PAGE', tableConfig.PAGE - 1);
                    Ember.set(tableConfig, 'START_COUNT', (tableConfig.PAGE - 1) * tableConfig.RECORDS_PER_PAGE + 1);
                }
                //end count
                Ember.set(tableConfig, 'END_COUNT', tableConfig.PAGE * tableConfig.RECORDS_PER_PAGE < totalCount ? tableConfig.PAGE * tableConfig.RECORDS_PER_PAGE : totalCount);
                this.set('NAVIGATION', tableConfig);
            } else {
                Ember.set(tableConfig, 'START_COUNT', 0);
                Ember.set(tableConfig, 'END_COUNT', 0);
            }
            this.set('TFA_ENROLLED_USERS', tfaEnrolledUsers);
            CommonUtil.afterRender();
        });
    },
    resetSearch: function() {
        this.set('SEARCH_USER_NAME', '');
        this.set('SEARCH_DOMAIN_NAME', '');
        this.set('SEARCH_MODE_OPTION', 'none');
        this.set('NAVIGATION.PAGE', 1);
        this.resetTFAEnrolledUsersTable();
    },
    validateModeConfig: function(modeName, modeConfig) {
        var self = this;
        var isEnabled = modeConfig.IS_ENABLED;
        if (isEnabled === true) {
            var CONFIG = modeConfig;
            if (modeName === 'TFA_MAIL_AUTHENTICATOR') {
                if (CONFIG.PARAMS.SUBJECT === undefined || CONFIG.PARAMS.SUBJECT.trim() === '') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_email_subject')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.SUBJECT.length > 999) {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_smaller_mail_subject')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.MESSAGE.indexOf('%confirmCode%') === -1) {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_mail_confirm_code_ismandatory')); //No I18N
                    return false;
                } else if (CONFIG.IS_SERVER_CONFIGURED === false) {
                    if(this.get('options.mailconfig_path')){
                        DialogUtil.confirm(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_mail_server_not_configured'), 'redirect', 'ads.common.text.configure_now', this.get('options.mailconfig_path'));
                    }else{
                        this.sendAction('handleMailConfig');
                    }
                    return false;
                }
            } else if (modeName === 'TFA_SMS_AUTHENTICATOR') {
                if (CONFIG.PARAMS.MESSAGE === undefined || CONFIG.PARAMS.MESSAGE === '') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_sms_message')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.MESSAGE.length > 999) {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_smaller_sms_message')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.MESSAGE.indexOf('%confirmCode%') === -1) {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_sms_confirm_code_ismandatory')); //No I18N
                    return false;
                } else if (CONFIG.IS_SERVER_CONFIGURED === false) {
                    if(this.get('options.smsconfig_path')){
                        DialogUtil.confirm(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_sms_server_not_configured'), 'redirect', 'ads.common.text.configure_now', this.get('options.smsconfig_path'));
                    }else{
                        this.sendAction('handleSMSConfig');
                    }
                    return false;
                }
            } else if (CONFIG.MODE_NAME === 'TFA_RSA_AUTHENTICATOR') {
                var certificateFile = CONFIG.RSA_FILE_LOCATION;
                if (certificateFile === undefined || certificateFile.split(/(\\|\/)/g).pop() !== 'sdconf.rec') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_select_valid_sdconf_file')); //No I18N
                    return false;
                }
            } else if (CONFIG.MODE_NAME === 'TFA_DUO_AUTHENTICATOR') {
                if (CONFIG.PARAMS.I_KEY === undefined || CONFIG.PARAMS.I_KEY === '') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_duo_ikey')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.S_KEY === undefined || CONFIG.PARAMS.S_KEY === '') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_duo_skey')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.API_HOST_NAME === undefined || CONFIG.PARAMS.API_HOST_NAME === '') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_duo_apihostname')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.DUO_USER_NAME_PREFIX.indexOf('userName') === -1 && CONFIG.PARAMS.DUO_USER_NAME_SUFIX.indexOf('userName') === -1) {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.duo.alert_enter_valid_username_pattern')); //No I18N
                    return false;
                }
            } else if (CONFIG.MODE_NAME === 'TFA_RADIUS_AUTHENTICATOR') {
                if (CONFIG.PARAMS.SERVER_NAME === undefined || CONFIG.PARAMS.SERVER_NAME === '') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_radius_server_name')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.SERVER_PORT === undefined || CONFIG.PARAMS.SERVER_PORT === '' || !ValidationUtil.isValidPort(CONFIG.PARAMS.SERVER_PORT)) {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_valid_radius_server_port')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.SERVER_SECRET === undefined || CONFIG.PARAMS.SERVER_SECRET === '') {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_enter_radius_server_secretkey')); //No I18N
                    return false;
                } else if (CONFIG.PARAMS.RADIUS_USER_NAME_PREFIX.indexOf('userName') === -1 && CONFIG.PARAMS.RADIUS_USER_NAME_SUFIX.indexOf('userName') === -1 && CONFIG.PARAMS.RADIUS_USER_NAME_PREFIX.indexOf('capsUserName') === -1 && CONFIG.PARAMS.RADIUS_USER_NAME_SUFIX.indexOf('capsUserName') === -1) {
                    DialogUtil.alert(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.radius.alert_enter_valid_username_pattern')); //No I18N
                    return false;
                }
            }
        }
        return true;
    },
    actions: {
        redirect: function(path) {
            this.$('.ember-application.modal-open').removeClass('modal-open'); //To Remove the modal in the body if exists before redirecting to a page
            this.get('router').transitionTo(path);
        },
        resetUserModeDetails: function() {
            this.set('SEARCH_USER_NAME', '');
            this.set('SEARCH_DOMAIN_NAME', '');
            this.set('SEARCH_MODE_OPTION', 'none');
            this.set('NAVIGATION.PAGE', 1);
            this.resetTFAEnrolledUsersTable();
            this.set('isSearchBarOpen', false);
            if (this.$(".fw-icn-search-clear").length) {
                this.$(".fw-icn-search-clear").removeClass("fw-icn-search-clear").addClass("fw-icn-table-search");
            }
            this.$(".target_class .search-bar").hide();
        },
        enableDisableTFA: function() {
            var self = this;
            var isEnabled = self.get('IS_ENABLED');
            var data = {};
            data['IS_ENABLED'] = isEnabled;
            AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=enableDisableTwoFactorAuthConfig', data).then(function(response) {
                if ('eSTATUS' in response) {
                    self.sendAction('showStatus','danger', I18NUtil.translate(response['eSTATUS']), false);
                } else if ('sSTATUS' in response) {
                    self.sendAction('showStatus','success', I18NUtil.translate(response['sSTATUS']), true);
                } else if ('wSTATUS' in response) {
                    self.sendAction('showStatus','warning', I18NUtil.translate(response['wSTATUS']), true);
                }
            });
            self.isTFAModeEnabled();
        },
        enableDisableMode: function(isEnabled, params) {
            this.isTFAModeEnabled();
            Ember.set(params, 'TEMP_IS_ENABLED', isEnabled);
        },
        enableDisableModeConfig: function(isEnabled, config) {
            var self = this;
            var modeConfig = Ember.$.extend(true, {}, config);
            modeConfig.TEMP_IS_ENABLED = isEnabled;
            if (isEnabled === false && isEnabled !== modeConfig['IS_ENABLED']) {
                DialogUtil.confirm(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_confirm_disable_mode'), 'saveConfig', 'ads.common.text.ok', modeConfig);
            } else {
                this.send('saveConfig', modeConfig);
            }
        },
        uploadSDConfFile: function(CONFIG) {
            var sdconfPath = this.$('[name="RSA_SD_CONF_PATH"]').val().split('\\').pop();
            if (sdconfPath.length > 20) {
                sdconfPath = sdconfPath.substring(0, 20) + "...";
            }
            this.$('#RSA_SD_CONF_PATH .file-upload-placeholder').val(sdconfPath);
            Ember.set(CONFIG, 'RSA_FILE_LOCATION', this.$('[name="RSA_SD_CONF_PATH"]').val());
        },
        cancelModeConfig: function(modeConfig) {
            var modeName = modeConfig['MODE_NAME'];
            this.getTFAModeConfig(modeName);
        },
        saveModeConfig: function(modeConfig) {
            var self = this;
            var isEnabled = modeConfig['TEMP_IS_ENABLED'];
            if (isEnabled === false && isEnabled !== modeConfig['IS_ENABLED']) {
                DialogUtil.confirm(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_confirm_disable_mode'), 'saveConfig', 'ads.common.text.ok', modeConfig);
            } else {
                this.send('saveConfig', modeConfig);
            }
        },
        enableDisableBVC: function (isEnabled, modeConfig) {
            if (isEnabled !== modeConfig.IS_ENABLED) {
                Ember.set(modeConfig, 'TEMP_IS_ENABLED', isEnabled);
                var self = this;
                var isEnabled = modeConfig['TEMP_IS_ENABLED'];
                if (isEnabled === false && isEnabled !== modeConfig['IS_ENABLED']) {
                    DialogUtil.confirm(self, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_confirm_disable_bvc_mode'), 'saveConfig', 'ads.common.text.ok', modeConfig);
                    self.getTFAModeConfig(modeConfig.MODE_NAME);
                } else {
                    self.send('saveConfig', modeConfig);
                }
            }
        },
        toggleTFAPanel: function () {
            Ember.$('.tfa-panel-group .panel-collapse').on("show.bs.collapse", function () {
                Ember.$(this).closest('.panel').addClass("open");
            })
            Ember.$('.tfa-panel-group .panel-collapse').on("hide.bs.collapse", function () {
                Ember.$(this).closest('.panel').removeClass("open");
            })
        },
        toggleBackupCodeInfo: function (res) {
            var self = this;
            if (res) {
                self.set('TFA_BACKUP_INFO_CLASS', "text-green");
                self.set('TFA_BACKUP_INFO_MSG', I18NUtil.translate('ads.admin.logon_settings.tfa_settings.bvc_enabled_successfully'));
            }
            else {
                self.set('TFA_BACKUP_INFO_CLASS', "text-red opacity-8");
                self.set('TFA_BACKUP_INFO_MSG', I18NUtil.translate('ads.admin.logon_settings.tfa_settings.bvc_disabled_successfully'));
            }
            self.$('#TFA_BACKUP_INFO').delay(500).fadeIn('slow');
            self.$('#TFA_BACKUP_INFO').delay(2000).fadeOut('slow');
        },
        saveConfig: function(config) {
            var self = this;
            var isEnabled = config['TEMP_IS_ENABLED'];
            var modeConfig = Ember.$.extend(true, {}, config);
            Ember.set(modeConfig, 'IS_ENABLED', isEnabled);
            var modeName = modeConfig['MODE_NAME'];
            if (self.validateModeConfig(modeName, modeConfig)) {
                if(modeName === 'TFA_BACKUP_VERIFICATION_CODE_AUTHENTICATOR') {
                    self.$('#TFA_BACKUP_INFO').removeClass('hide');
                    self.send('toggleBackupCodeInfo',isEnabled);
                    self.set('SHOW_STATUS_MSG',false);
                    self.$('#TFA_BACKUP_INFO').hide();
                }
                else{
                    CommonUtil.showLoading();
                    self.set('SHOW_STATUS_MSG',true);
                }
                if (modeName === 'TFA_RSA_AUTHENTICATOR') {
                    this.$('#TFA_MODE_CONFIG').val(JSON.stringify(modeConfig));
                    this.$('#TFA_MODE_NAME').val(modeName);
                    this.$('[id="TFAConfigForm"]').submit();
                    this.$('#TFAConfigIFrame').load(function(responseData) {
                        CommonUtil.hideLoading();
                        var responseHtml = self.$("#TFAConfigIFrame").contents().find("body").html();
                        try {
                            var response = Ember.$.parseJSON(responseHtml);
                            if ('DISABLE_TFA' in response) {
                                self.sendAction('showStatus', 'success', I18NUtil.translate(response['sSTATUS']), true);
                                self.getSettings();
                            } else if ('sSTATUS' in response) {
                                self.sendAction('showStatus', 'success', I18NUtil.translate(response['sSTATUS']), true);
                                self.getTFAModeConfig(modeName);
                            } else if ('eSTATUS' in response) {
                                self.sendAction('showStatus', 'danger', I18NUtil.translate(response['eSTATUS']), false);
                            }else if(response.hasOwnProperty("ERROR_CODE") && response.ERROR_CODE=="00000014"){
                                self.sendAction('showStatus','danger',I18NUtil.translate('ads.common.error.demo_mode'),false);
                            }
                        } catch (e) {
                            AJAXUtil.handleSessionTimeout("403", responseHtml);
                        }
                    });
                } else {
                    var data = {};
                    data['TFA_MODE_CONFIG'] = JSON.stringify(modeConfig);
                    data['TFA_MODE_NAME'] = modeName;
                    AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=saveTwoFactorModeConfig', data).then(function(response) {
                        if ('DISABLE_TFA' in response) {
                            self.sendAction('showStatus', 'success', I18NUtil.translate(response['sSTATUS']), true);
                            self.getSettings();
                        } else if ('eSTATUS' in response) {
                            self.sendAction('showStatus', 'danger', I18NUtil.translate(response['eSTATUS']), false);
                        } else if ('sSTATUS' in response) {
                            self.sendAction('showStatus', 'success', I18NUtil.translate(response['sSTATUS']), true);
                            self.getTFAModeConfig(modeName);
                        }
                        CommonUtil.hideLoading();
                    });
                }
            }
        },
        setIntegratedProducts: function() {
            var list = this.$('#TFA_CHOOSE_COMPONENTS').val();
            if (list === null) {
                list = [];
            }
            var self = this;
            var data = {};
            data['ENABLED_PRODUCTS_LIST'] = JSON.stringify(list);
            AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=setTwoFactorIntegratedProducts', data).then(function(response) {
                if ('eSTATUS' in response) {
                    self.sendAction('showStatus', 'danger', I18NUtil.translate(response['eSTATUS']), false);
                } else if ('sSTATUS' in response) {
                    self.sendAction('showStatus', 'success', I18NUtil.translate(response['sSTATUS']), true);
                }
            });
        },
        deleteEnrollment: function(userDetails) {
            var enrollmentDetails = [];
            var details = Ember.$.extend(true, {}, userDetails);
            details['IS_SELECTED'] = true;
            enrollmentDetails[enrollmentDetails.length] = details;
            DialogUtil.confirm(this, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_confirm_delete_userenrollment'), 'deleteEnrollments', I18NUtil.translate('ads.common.text.delete'), enrollmentDetails);
        },
        deleteAllEnrollment: function(enrollmentDetails) {
            var atleastOneSelected = false;
            for (var i = 0; i < enrollmentDetails.length; i++) {
                var user = enrollmentDetails[i];
                if (user.IS_SELECTED === true) {
                    atleastOneSelected = true;
                    break;
                }
            }
            if (atleastOneSelected) {
                DialogUtil.confirm(this, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_confirm_delete_multiple_userenrollment'), 'deleteEnrollments', I18NUtil.translate('ads.common.text.delete'), enrollmentDetails);
            } else {
                DialogUtil.alert(this, I18NUtil.translate('ads.login.twofactor.alert_atleast_one_userenrollment_must_be_selected_to_delete'));
            }
        },
        deleteEnrollments: function(enrollmentDetails) {
            var data = {};
            var deleteUserIds = [];
            for (var i = 0; i < enrollmentDetails.length; i++) {
                var user = enrollmentDetails[i];
                if (user.IS_SELECTED === true) {
                    deleteUserIds[deleteUserIds.length] = user.USER_ID;
                }
            }
            if (deleteUserIds.length > 0) {
                var self = this;
                data['DELETE_USER_IDS'] = JSON.stringify(deleteUserIds);
                AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=deleteEnrolledUsers', data).then(function(response) {
                    if ('sSTATUS' in response) {
                        var totalCount = self.get('NAVIGATION.TOTAL_COUNT');
                        var page = self.get('NAVIGATION.PAGE');
                        var rowCount = self.get('NAVIGATION.RECORDS_PER_PAGE');
                        if (page * rowCount > totalCount && ((page - 1) * rowCount) + deleteUserIds.length === totalCount) { //If elemets from last page is deleted it must be moved to previous page
                            self.set('NAVIGATION.PAGE', page - 1);
                        }
                        self.resetTFAEnrolledUsersTable();
                    }
                });
            }
        },
        enableDisableUser: function(val, params) {
            var totalCount = (this.get('NAVIGATION.END_COUNT') - this.get('NAVIGATION.START_COUNT')) + 1;
            Ember.set(params, "IS_SELECTED", val);
            var tfaEnrolledUsers = this.get('TFA_ENROLLED_USERS');
            var count = 0;
            for (var i = 0; i < tfaEnrolledUsers.length; i++) {
                var config = tfaEnrolledUsers[i];
                if (config.IS_SELECTED === true) {
                    count++;
                }
            }
            if (count === totalCount) {
                this.$('#ENABLE_DISABLE_ALL').prop('checked', true);
                this.$('#ENABLE_DISABLE_ALL').iCheck('update');
            } else {
                this.$('#ENABLE_DISABLE_ALL').prop('checked', false);
                this.$('#ENABLE_DISABLE_ALL').iCheck('update');
            }
        },
        enableDisableAll: function(val, params) {
            for (var i = 0; i < params.length; i++) {
                Ember.set(params[i], "IS_SELECTED", val);
            }
            if (val == true) {
                this.$('#ENABLE_DISABLE_ALL').prop('checked', true);
                this.$('#ENABLE_DISABLE_ALL').iCheck('update');
            } else {
                this.$('#ENABLE_DISABLE_ALL').prop('checked', false);
                this.$('#ENABLE_DISABLE_ALL').iCheck('update');
            }
        },
        previewChangeRowCount(count) {
            this.set('NAVIGATION.RECORDS_PER_PAGE', count);
            this.set('NAVIGATION.PAGE', 1);
            this.resetTFAEnrolledUsersTable();
        },
        previewGotoPage(page) {
            var pageVal = this.get('NAVIGATION.PAGE');
            if (page == 'first') { //NO I18N
                pageVal = 1;
            } else if (page == 'next') { //NO I18N
                pageVal = pageVal + 1;
            } else if (page == 'prev') { //NO I18N
                pageVal = pageVal - 1;
                if (pageVal < 1) { //NO I18N
                    pageVal = 1;
                }
            } else if (page == 'end') { //NO I18N
                pageVal = Math.ceil(this.get('NAVIGATION.TOTAL_COUNT') / this.get('NAVIGATION.RECORDS_PER_PAGE'));
            } else {
                pageVal = 1;
            }
            //update only if new page is less than total pages
            var totalCount = this.get('NAVIGATION.TOTAL_COUNT') + this.get('NAVIGATION.RECORDS_PER_PAGE');
            totalCount = totalCount - (totalCount % this.get('NAVIGATION.RECORDS_PER_PAGE'));
            if (totalCount >= pageVal * this.get('NAVIGATION.RECORDS_PER_PAGE')) {
                this.set('NAVIGATION.PAGE', pageVal);
                this.resetTFAEnrolledUsersTable();
            }
        },
        refresh: function() {
            this.resetTFAEnrolledUsersTable();
        },
        toggleSearchBox: function() {
            if (this.$(".fw-icn-table-search").length) {
                this.set('isSearchBarOpen', true);
                this.$(".fw-icn-table-search").removeClass("fw-icn-table-search").addClass("fw-icn-search-clear");
            } else {
                this.set('isSearchBarOpen', false);
                this.resetSearch();
                this.$(".fw-icn-search-clear").removeClass("fw-icn-search-clear").addClass("fw-icn-table-search");
            }
            this.$(".target_class .search-bar").toggle();
            Ember.run.schedule('afterRender', this, function() {
                this.$('#USER_ENROLLMENT_DETAILS').find('.mCustomScrollbar').mCustomScrollbar("scrollTo", "top", {
                    scrollInertia: 200
                });
            });
        },
        searchUsers: function() {
            this.set('NAVIGATION.PAGE', 1);
            this.resetTFAEnrolledUsersTable();
        }
    },
});
//ignorei18n_end