/*
 * $Id: tfa-user-enrollment.js,v 1.17.4.4 2018/12/18 21:38:41 kamalraj.d Exp $
 */

//ignorei18n_start
import Ember from 'ember';
import AJAXUtil from '../utils/ads-ajax-util';
import I18NUtil from "../utils/i18n-util";
import DialogUtil from "../utils/ads-dialog-util";
import CommonUtil from "../utils/ads-common-util";
import ValidationUtil from "../utils/ads-validation-util";

export default Ember.Component.extend({
    pageStatus: {},
    TRUST_BROWSER: false,
    TFA_USER_ENROLLMENT_DETAILS: true,
    CURRENT_VIEW: '',
    IS_SINGLE_ENROLLMENT: false,
    RESET_RSA_AUTH: false,
    CURRENT_RSA_OPERATION: 'RSA_VERIFICATION',
    RSA_VERIFICATION_MODE: 'RSA_PASSCODE',
    TFA_COOKIE_VALIDITY: 180,
    MAX_BVC_CODES: 5,
    alertType: '',
    alertMessage: '',
    notificationService: Ember.inject.service(),
    getSettings: function() {
        var response = AJAXUtil.syncAjax('/RestAPI/WC/TwoFactorAction?mTCall=getSelfEnrollmentConfiguration', {});
        var userEnrollmentConfig = response['TFA_USER_DETAILS'];
        if (userEnrollmentConfig.hasOwnProperty("MODE_ICON")) {
            userEnrollmentConfig.MODE_ICON = userEnrollmentConfig.MODE_ICON.substring(3);
        }
        this.set('TFA_COOKIE_VALIDITY', response['TFA_COOKIE_VALIDITY']);
        this.set('TRUST_BROWSER', response['IS_TFA_TRUST_ENABLED']);
        this.set('TFA_USER_ENROLLMENT', userEnrollmentConfig);
        this.set('NAVIGATION', response['TRUSTED_BROWSERS_NAVIGATION']);
        this.set('IS_BACKUP_VERIFICATION_CODE_ENABLED', response['IS_BACKUP_VERIFICATION_CODE_ENABLED']);
        this.set("MAX_BVC_CODES", response["BVC_NO_OF_CODES"]);
        var configuredTFAs = response['CONFIGURED_TFA_ARRAY'];
        if (configuredTFAs !== undefined && configuredTFAs.length > 1) {
            this.set('CONFIGURED_TFA_MODES', configuredTFAs);
            this.set('CURRENT_TFA_MODE', userEnrollmentConfig.MODE_NAME?userEnrollmentConfig.MODE_NAME:configuredTFAs[0].MODE_NAME);
            this.set('CURRENT_VIEW', 'SELECT_AUTH'); //No I18N
        } else if (configuredTFAs !== undefined && configuredTFAs.length === 1) {
            this.set('IS_SINGLE_ENROLLMENT', true);
            var currentTFAMode = configuredTFAs[0].MODE_NAME;
            this.set('CURRENT_TFA_MODE', currentTFAMode);
        }
        this.set('TFA_USER_ENROLLMENT_DETAILS', true);
        CommonUtil.afterRender();
    }.on('init'),
    didInsertElement: function() {
        var id = this.get('pageStatus.show');
        Ember.run.scheduleOnce('afterRender', function() {
            if (id === undefined || id === '') {
                if (Ember.$('#trustedBrowsers').find('.tfa-ovrlay').hasClass('disable')) {
                    Ember.$('#trustedBrowsers').find('.tfa-ovrlay').removeClass('disable');
                }
            } else {
                if (Ember.$('.modal-backdrop').length > 1) {
                    Ember.$('.modal-backdrop').last().removeClass('in');
                    Ember.$('#trustedBrowsers').find('.tfa-ovrlay').addClass('disable');
                }
            }
        });
        var self = this;
        Ember.$('#DuoAuthIframe').load(function(responseData) {
            var responseHtml = Ember.$("#DuoAuthIframe").contents().find("body").html();
            try {
                var response = Ember.$.parseJSON(responseHtml);
                if (response.hasOwnProperty("IS_VALID") && response.IS_VALID) {
                    self.sendAction('showStatus','success', I18NUtil.translate('ads.login.twofactor.two_factor_enrollment_success'), true);
                    self.getSettings();
                } else {
                    Ember.run.scheduleOnce('afterRender', function() {
                        self.set('TFA_USER_ENROLLMENT_DETAILS', false);
                        self.set('CURRENT_TFA_MODE', '');
                        self.send('selectAuth', 'TFA_DUO_AUTHENTICATOR');
                        self.sendAction('showStatus','danger', I18NUtil.translate(response.ERROR_MESSAGE), true);
                    });
                }
            } catch (e) {
                AJAXUtil.handleSessionTimeout("403", responseHtml);
            }
        });
        CommonUtil.afterRender();
    }.observes('pageStatus.show'),
    resetRSAAuthenticator: function() {
        this.set('CURRENT_RSA_OPERATION', 'RSA_VERIFICATION');
        this.set('RSA_VERIFICATION_MODE', 'RSA_PASSCODE');
    },
    viewChange: function() {
        var enrollment = this.get('TFA_USER_ENROLLMENT_DETAILS');
        if (enrollment == true) {
            Ember.$('#USER_ENROLLEMENT_PAGE').show();
            Ember.$('#USER_ENROLLEMENT_MODIFICATION_PAGE').hide();
        } else {
            Ember.$('#USER_ENROLLEMENT_PAGE').hide();
            Ember.$('#USER_ENROLLEMENT_MODIFICATION_PAGE').show();
        }
    }.observes('TFA_USER_ENROLLMENT_DETAILS'),
    getSerchQuery: function() {
        var data = {};
        var ipAddress = this.get('SEARCH_IP_ADDRESS');
        if (ipAddress !== undefined && ipAddress !== '') {
            data['SEARCH_IP_ADDRESS'] = ipAddress;
        }
        var userAgent = this.get('SEARCH_USER_AGENT');
        if (userAgent !== undefined && userAgent !== '') {
            data['SEARCH_USER_AGENT'] = userAgent;
        }
        return data;
    },
    resetTFATrustedBrowsersTable: function() {
        Ember.$('#ENABLE_DISABLE_ALL').prop('checked', false);
        Ember.$('#ENABLE_DISABLE_ALL').iCheck('update');
        var data = this.getSerchQuery();
        data['RECORDS_PER_PAGE'] = this.get('NAVIGATION.RECORDS_PER_PAGE');
        data['PAGE'] = this.get('NAVIGATION.PAGE');
        this.set('isLoading', true);
        Ember.$('.no-data').addClass('hide');
        var self = this;
        AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=getUserTrustedBrowsers', data).then(function(response) {
            if ('TRUSTED_BROWSERS' in response) {
                var tfaTrustedBrowserCount = response['TRUSTED_BROWSERS_COUNT'];
                self.set('NAVIGATION.TOTAL_COUNT', tfaTrustedBrowserCount);
                self.performNavigation(response["TRUSTED_BROWSERS"]);
            }
            self.set('isLoading', false);
            Ember.$('.no-data').removeClass('hide');
        });
        CommonUtil.afterRender();
    },
    getTFABackupVerificationCode: function () {
        var data = {};
        var self = this;
        self.set('isLoadingCodes', true);
        AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=getBackupVerificationCode', data).then(function (response) {
            self.get('notificationService').checkStatus('TWO_FACTOR_AUTHENTICATION_NOTIFIER');
            if (response.hasOwnProperty('TFA_BACKUP_VERIFICATION_CODE')) {
                var res = response["TFA_BACKUP_VERIFICATION_CODE"];
                if (res.hasOwnProperty('VERIFICATION_CODE')) {
                    self.setVerificationCode(res.VERIFICATION_CODE);
                    self.setGeneratedTime(res.GENERATED_TIME);
                }
            }
            else {
                self.$('#backupCodes').modal('hide');
                self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.login.twofactor.unable_retrieve_bvc_please_contact_administrator'), false);
                self.getSettings();
            }
            self.set('isLoadingCodes', false);
        });
        Ember.$('#exportCodes').attr("href", AJAXUtil.get("context") + "/RestAPI/WC/TwoFactorAction?mTCall=exportBackupVerificationCode");
    },
    setVerificationCode: function (codes) {
        Ember.run.schedule('afterRender', this, function () {
            Ember.$('#codeList').remove();
            Ember.$('#codeBlock').append('<ol id="codeList" class="fw-pl-15 fw-mb-0">');
            if (codes === null || codes === undefined) {
                codes = {};
            }
            for (var i = 0; i < this.MAX_BVC_CODES - 1; i++) {
                if (codes[i]) {
                    Ember.$('#codeList').append('<li class="fw-mb-10"><strong class="verdana">' + codes[i] + '</strong></li>');
                }
                else {
                    Ember.$('#codeList').append('<li class="adsulNoStyle fw-mb-10"><strong class="verdana">&nbsp;</strong></li>');
                }
            }
            if (codes[this.MAX_BVC_CODES - 1]) {
                Ember.$('#codeList').append('<li class=""><strong class="verdana">' + codes[this.MAX_BVC_CODES - 1] + '</strong></li>');
            }
            else {
                Ember.$('#codeList').append('<li class="adsulNoStyle"><strong class="verdana">&nbsp;</strong></li>');
            }
            Ember.$('#codeList').append('</ol>');
            CommonUtil.afterRender();
        });
    },
    setGeneratedTime: function (time) {
        Ember.run.schedule('afterRender', this, function () {
            this.set('GENERATED_TIME', time);
            CommonUtil.afterRender();
        });
    },
    generateTFABackupVerificationCode: function () {
        var data = {};
        var self = this;
        self.set('isLoadingCodes', true);
        self.$('#generateCodes').css("pointer-events", "none");
        AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=generateBackupVerificationCode', data).then(function (response) {
            if (response.hasOwnProperty('TFA_BACKUP_VERIFICATION_CODE')) {
                var res = response["TFA_BACKUP_VERIFICATION_CODE"];
                if (res.hasOwnProperty('VERIFICATION_CODE')) {
                    self.setVerificationCode(res.VERIFICATION_CODE);
                    self.setGeneratedTime(res.GENERATED_TIME);
                }
            }
            else {
                self.getSettings();
                self.setVerificationCode(null);
                self.setGeneratedTime(null);
            }
            self.$('#generateCodes').css("pointer-events", "auto");
            self.set('isLoadingCodes', false);
        });
    },
    performNavigation: function(trustedBrowsers) {
        Ember.run.schedule('afterRender', this, function() {
            var tableConfig = this.get('NAVIGATION');
            if (trustedBrowsers.length !== 0) {
                var page = tableConfig.PAGE;
                var rowCount = tableConfig.RECORDS_PER_PAGE;
                var totalCount = tableConfig.TOTAL_COUNT;
                //set start count
                if ((tableConfig.PAGE - 1) * tableConfig.RECORDS_PER_PAGE + 1 <= totalCount) {
                    Ember.set(tableConfig, 'START_COUNT', (tableConfig.PAGE - 1) * tableConfig.RECORDS_PER_PAGE + 1);
                } else {
                    Ember.set(tableConfig, 'PAGE', tableConfig.PAGE - 1);
                    Ember.set(tableConfig, 'START_COUNT', (tableConfig.PAGE - 1) * tableConfig.RECORDS_PER_PAGE + 1);
                }
                //end count
                Ember.set(tableConfig, 'END_COUNT', tableConfig.PAGE * tableConfig.RECORDS_PER_PAGE < totalCount ? tableConfig.PAGE * tableConfig.RECORDS_PER_PAGE : totalCount);
                this.set('NAVIGATION', tableConfig);
            } else {
                Ember.set(tableConfig, 'START_COUNT', 0);
                Ember.set(tableConfig, 'END_COUNT', 0);
            }
            this.set('TRUSTED_BROWSERS', trustedBrowsers);
            CommonUtil.afterRender();
        });
    },
    resetSearch: function() {
        this.set('SEARCH_USER_AGENT', '');
        this.set('SEARCH_IP_ADDRESS', '');
        this.set('NAVIGATION.PAGE', 1);
        this.resetTFATrustedBrowsersTable();
    },
    setCurrentView: function(viewName, selectedAuth) {
        this.set('CURRENT_VIEW', viewName);
        if (selectedAuth != undefined) {
            this.set('CURRENT_TFA_MODE', selectedAuth);
            if (selectedAuth == 'TFA_DUO_AUTHENTICATOR' || selectedAuth == 'TFA_RSA_AUTHENTICATOR' || selectedAuth == 'TFA_RADIUS_AUTHENTICATOR') {
                this.set('SHOW_VERIFY_AUTH_OPERATIONS', false);
            } else {
                this.set('SHOW_VERIFY_AUTH_OPERATIONS', true);
            }
        }
    },
    setModeDetails: function(selectedAuth, modeDetails) {
        var self = this;
        if (selectedAuth === "TFA_SMS_AUTHENTICATOR" || selectedAuth === "TFA_MAIL_AUTHENTICATOR") {
            self.setCurrentView('ENROLL_AUTH', selectedAuth);
        } else if (selectedAuth === "TFA_DUO_AUTHENTICATOR") {
            self.setCurrentView('VERIFY_AUTH', selectedAuth);
            Ember.run.scheduleOnce('afterRender', self, function() {
                if (modeDetails.SIGN_ERROR !== undefined && modeDetails.SIGN_ERROR !== '') {
                    self.setStatusMessage('danger', I18NUtil.translate(modeDetails.SIGN_ERROR));
                } else {
                    Ember.run.scheduleOnce('afterRender', function() {
                        Ember.$('#duo_loading').show();
                        Ember.$('#duo_script').append('<script type="text/javascript" src="vendor/js/Duo-Web-v2.min.js"></script>');
                        Duo.init({ //NO I18N
                            'host': modeDetails.API_HOST_NAME, //NO I18N
                            'sig_request': modeDetails.SIGN_REQUEST, //NO I18N
                            'post_action': AJAXUtil.get("context") + '/RestAPI/WC/TwoFactorAction?mTCall=verifySelfEnrollmentDUOAuth' //NO I18N
                        });
                        Ember.$('#duo_iframe').load(function() {
                            Ember.$('#duo_loading').hide();
                        });
                    });
                }
            });
        } else if (selectedAuth === "TFA_GOOGLE_AUTHENTICATOR") {
            self.setCurrentView('VERIFY_AUTH', selectedAuth);
            if (modeDetails.hasOwnProperty('PATH')) {
                modeDetails.PATH = modeDetails.PATH + "?random=" + Math.random();
            }
        } else if (selectedAuth === "TFA_RSA_AUTHENTICATOR") {
            self.resetRSAAuthenticator();
            self.setCurrentView('VERIFY_AUTH', selectedAuth);
        } else if (selectedAuth === "TFA_RADIUS_AUTHENTICATOR") {
            self.setCurrentView('VERIFY_AUTH', selectedAuth);
        }
        self.set(selectedAuth, modeDetails);
    },
    setStatusMessage: function(alertType, alertMessage) {
        Ember.$('#CUSTOMIZED_ALERT').show();
        this.set('alertType', alertType);
        this.set('alertMessage', alertMessage);
    },
    checkStatus: function(secretKey, key) {
        var self = this;
        if(secretKey === undefined || secretKey === '') {
            if(key === undefined) {
                self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.login.twofactor.enter_valid_secret_code'), true);
            } else {
                self.sendAction('showStatus', 'danger', I18NUtil.translate(key), true);
            }
            return true;
        }
        return false;
    },
    actions: {
        resetTrsutedBrowserDetails: function() {
            this.set('SEARCH_USER_AGENT', '');
            this.set('SEARCH_IP_ADDRESS', '');
            this.set('NAVIGATION.PAGE', 1);
            this.resetTFATrustedBrowsersTable();
            this.set('isSearchBarOpen', false);
            if (Ember.$(".fw-icn-search-clear").length) {
                Ember.$(".fw-icn-search-clear").removeClass("fw-icn-search-clear").addClass("fw-icn-table-search");
            }
            Ember.$(".target_class .search-bar").hide();
        },
        getBackupVerificationCode: function () {
            this.send("toggleBackupCodes");
            this.getTFABackupVerificationCode();
        },
        generateBackupVerificationCode: function () {
            this.generateTFABackupVerificationCode();
        },
        printBackupVerificationCode: function () {
            var form = document.createElement("form");
            form.action = "/PrintReport.do";
            form.method = "POST"; //No I18N
            form.setAttribute("rel", "noopener"); //No I18N
            var url = document.createElement("textarea");
            url.name = "URL";
            url.value = AJAXUtil.get("context") + "/RestAPI/WC/TwoFactorAction?mTCall=printBackupVerificationCode"; //No I18N
            form.appendChild(url);
            window.open('', 'ReportPrint', 'scrollbars=no,resizable=yes');
            form.target = "ReportPrint";
            form.setAttribute('enctype', 'application/x-www-form-urlencoded;charset=UTF-8');
            form.style.display = 'none';
            document.body.appendChild(form);
            form.submit();
        },
        toggleBackupCodes: function () {
            Ember.$(".mbvc").removeClass("hide");
            Ember.$(".semail").addClass("hide");
            this.send('resetEmail');
        },
        toggleMail: function () {
            Ember.$(".mbvc").addClass("hide");
            Ember.$(".semail").removeClass("hide");
            this.send('resetEmail');
        },
        sendMailVerificationCode: function () {
            var self = this;
            var config = {};
            var emailId = Ember.$('#USER_MAILID').val();
            var domainPassword = Ember.$('#DOMAIN_PASSWORD').val();
            self.send('resetEmail');
            if (emailId == '' || emailId == undefined || domainPassword == undefined || domainPassword == '' || !ValidationUtil.isValidEmail(emailId)) {
                self.$('#ALERT_DANGER').delay(500).slideDown('slow');
                self.set("SMAIL_ERR_MESSAGE", I18NUtil.translate('ads.login.twofactor.enter_valid_mail_address'));
            }
            else {
                config['TO_MAILID'] = emailId;
                config['DOMAIN_PASSWORD'] = domainPassword;
                self.set('isSendingMail',true);
                AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=emailBackupVerificationCode', config).then(function (response) {
                    self.set('isSendingMail',false);
                    if (response.hasOwnProperty("IS_SUCCESS") && response.IS_SUCCESS === true) {
                        self.set("SMAIL_SUCC_MESSAGE", I18NUtil.translate('ads.login.twofactor.successfully_sent_mail'));
                        self.$('#ALERT_SUCCESS').delay(500).slideDown('slow');
                        self.send('setAlertInterval', "ALERT_SUCCESS");
                    } else {
                        if (response.hasOwnProperty("ERROR_MESSAGE")) {
                            self.set("SMAIL_ERR_MESSAGE", I18NUtil.translate(response.ERROR_MESSAGE));
                        }
                        else {
                            self.set("SMAIL_ERR_MESSAGE", I18NUtil.translate('ads.login.twofactor.unable_to_send_mail'));
                        }
                        self.$('#ALERT_DANGER').delay(500).slideDown('slow');
                    }
                });
            }
        },
        resetEmail: function () {
            Ember.$('#USER_MAILID').val("");
            Ember.$('#DOMAIN_PASSWORD').val("");
            this.send('closeAlert');
        },
        setAlertInterval: function (alertName) {
            var timer = setInterval(function () {
                Ember.$('#' + alertName).delay(3000).slideUp('slow');
                clearTimeout(timer);
            }, 5000);
            Ember.$('#' + alertName).attr('TIMER', timer);//NO I18N
        },
        closeAlert: function () {
            Ember.$('.mini-status-alert').delay(50).slideUp('slow');
        },
        toggleAuthMode: function(params) {
            var currentView = JSON.parse(params).columnValue;
            this.set('CURRENT_TFA_MODE', currentView); //No I18N
        },
        back: function() {
            Ember.$('#CUSTOMIZED_ALERT').hide();
            var currentView = this.get('CURRENT_VIEW');
            var selectedAuth = this.get('CURRENT_TFA_MODE');
            var isSingleEnrollment = this.get('IS_SINGLE_ENROLLMENT');
            if (isSingleEnrollment === true) {
                if (currentView === 'VERIFY_AUTH' && (selectedAuth == "TFA_SMS_AUTHENTICATOR" || selectedAuth === "TFA_MAIL_AUTHENTICATOR")) {
                    this.setCurrentView('ENROLL_AUTH', selectedAuth);
                } else {
                    this.set('TFA_USER_ENROLLMENT_DETAILS', true);
                }
            } else {
                if (currentView == 'ENROLL_AUTH') {
                    this.setCurrentView('SELECT_AUTH');
                } else if (currentView == 'VERIFY_AUTH') {
                    if (selectedAuth == "TFA_SMS_AUTHENTICATOR" || selectedAuth === "TFA_MAIL_AUTHENTICATOR") {
                        this.setCurrentView('ENROLL_AUTH', selectedAuth);
                    } else {
                        this.setCurrentView('SELECT_AUTH');
                    }
                }
            }
            if (selectedAuth === "TFA_RSA_AUTHENTICATOR") {
                this.resetRSAAuthenticator();
            }
        },
        selectAuth: function(modeName) {
            var self = this;
            self.resetRSAAuthenticator();
            var selectedAuth = modeName !== undefined ? modeName : self.get('CURRENT_TFA_MODE');
            if (selectedAuth == 'TFA_RSA_AUTHENTICATOR') {
                self.set('RESET_RSA_AUTH', true);
                self.setCurrentView('VERIFY_AUTH', selectedAuth);
                self.set(selectedAuth, {});
                return;
            }
            CommonUtil.showLoading();
            var data = {};
            data['AUTH_RULE'] = selectedAuth;
            AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=getSelfEnrollmentDetails', data).then(function(response) {
                self.setModeDetails(selectedAuth, response.MODE_DETAILS);
                CommonUtil.hideLoading();
            });
        },
        sendCode: function(resendCode) {
            var self = this;
            var selectedAuth = self.get('CURRENT_TFA_MODE');
            var modeDetails = self.get(selectedAuth);
            var enrollmentKey = modeDetails.AUTH_SECRET_KEY.trim();
            if (selectedAuth == 'TFA_MAIL_AUTHENTICATOR' && (enrollmentKey == undefined || enrollmentKey == '' || !ValidationUtil.isValidEmail(enrollmentKey))) {
              //  self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.login.twofactor.enter_valid_mail_address'), false);
              DialogUtil.alert(self,I18NUtil.translate('ads.login.twofactor.enter_valid_mail_address'));  
              return;
            } else if (selectedAuth == 'TFA_SMS_AUTHENTICATOR' && (enrollmentKey == undefined || enrollmentKey == '' || isNaN(enrollmentKey))) {
               // self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.login.twofactor.enter_valid_phone_number'), false);
               DialogUtil.alert(self,I18NUtil.translate('ads.login.twofactor.enter_valid_mail_address'));
               return;
            }
            var data = {};
            data['AUTH_RULE'] = selectedAuth;
            data['ENROLLMENT_KEY'] = enrollmentKey;
            CommonUtil.showLoading();
            AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=sendSelfEnrollmentSecretCode', data).then(function(response) {
                if (response.hasOwnProperty("IS_SUCCESS") && response.IS_SUCCESS) {
                    self.setCurrentView('VERIFY_AUTH', selectedAuth);
                    if (resendCode !== undefined && resendCode === true) {
                        self.sendAction('showStatus','success', I18NUtil.translate(response.MESSAGE), true);
                    }
                } else {
                    self.sendAction('showStatus','danger', I18NUtil.translate(response.ERROR_MESSAGE), false);
                }
                CommonUtil.hideLoading();
            });
        },
        trustBrowser: function(val) {
            this.set('TRUST_BROWSER', val);
        },
        toggle: function(id) {
            Ember.$('#' + id).toggle();
        },
        verifyCode: function() {
            var self = this;
            var currentFactor = self.get('CURRENT_TFA_MODE');
            var modeDetails = self.get(currentFactor);
            var config = {};
            config['AUTH_RULE'] = currentFactor;
            config['TRUSTED_BROWSER'] = self.get('TRUST_BROWSER');
            if (currentFactor == 'TFA_GOOGLE_AUTHENTICATOR') {
                var time = new Date().getTime();
                config['TIME'] = time;
                if(self.checkStatus(modeDetails.SECRET_KEY)) {
                    return;
                }
                var secretKey = modeDetails.SECRET_KEY.trim();
                if (self.checkStatus(secretKey)) {
                    return;
                }
                config['SECRET_KEY'] = secretKey;
            } else if (currentFactor == 'TFA_SMS_AUTHENTICATOR' || currentFactor == 'TFA_MAIL_AUTHENTICATOR' || currentFactor == 'TFA_RADIUS_AUTHENTICATOR') {
                config['AUTH_SECRET_KEY'] = modeDetails.AUTH_SECRET_KEY;
                if(self.checkStatus(modeDetails.SECRET_KEY)) {
                    return;
                }
                var secretKey = modeDetails.SECRET_KEY.trim();
                if(self.checkStatus(secretKey)) {
                    return;
                }
                config['SECRET_KEY'] = secretKey;
            } else if (currentFactor === 'TFA_RSA_AUTHENTICATOR') {
                var passCode = 0;
                if (self.get('CURRENT_RSA_OPERATION') === "RSA_VERIFICATION") {
                    if(self.checkStatus(modeDetails.SECRET_KEY)) {
                        return;
                    }
                    passCode = modeDetails.SECRET_KEY.trim();
                    if(self.checkStatus(passCode)) {
                        return;
                    }
                } else if (self.get('CURRENT_RSA_OPERATION') === "RSA_PIN_CHANGE") {
                    var pattern = modeDetails.RSA_PIN_PATTERN;
                    if(self.checkStatus(modeDetails.RSA_NEW_PIN, 'ads.login.twofactor.enter_valid_pin') || self.checkStatus(modeDetails.RSA_CONFIRM_PIN, 'ads.login.twofactor.enter_valid_pin')) {
                        return;
                    }
                    passCode = modeDetails.RSA_NEW_PIN.trim();
                    var confirmCode = modeDetails.RSA_CONFIRM_PIN.trim();
                    if (passCode == '') {
                        self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.login.twofactor.enter_valid_pin'), true);
                        return;
                    } else if (passCode != confirmCode) {
                        self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.login.twofactor.rsa_new_confirm_code_mismatch'), true);
                        return;
                    } else if (passCode.search(new RegExp(pattern)) < 0) {
                        self.sendAction('showStatus', 'danger', I18NUtil.translate('ads.login.twofactor.rsa_invalid_pattern'), true);
                        return;
                    }
                    Ember.set(modeDetails, 'RSA_NEW_PIN', '');
                    Ember.set(modeDetails, 'RSA_CONFIRM_PIN', '');
                }
                config['PASS_CODE'] = passCode;
                config['RESET'] = self.get('RESET_RSA_AUTH');
            }
            CommonUtil.showLoading();
            var data = {};
            data['VERIFY_AUTH'] = JSON.stringify(config);
            AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=verifySelfEnrollmentSecretCode', data).then(function(response) {
                if (response.hasOwnProperty("IS_VALID") && response.IS_VALID === true) {
                    self.getSettings();
                    self.sendAction('showStatus', 'success', I18NUtil.translate('ads.login.twofactor.two_factor_enrollment_success'), true);
                } else {
                    var errorMessage = "ads.login.twofactor.enter_valid_secret_code";
                    if (response.hasOwnProperty('ERROR_MESSAGE')) {
                        errorMessage = response.ERROR_MESSAGE;
                    }
                    if (currentFactor === "TFA_RSA_AUTHENTICATOR") {
                        self.send('RSAErrorHandling', response);
                    } else {
                        self.sendAction('showStatus', 'danger', I18NUtil.translate(errorMessage), true);
                    }
                }
                if (modeDetails.hasOwnProperty('SECRET_KEY')) {
                    Ember.set(modeDetails, 'SECRET_KEY', '');
                }
                CommonUtil.hideLoading();
            });
        },
        RSAErrorHandling: function(response) {
            var errorStatus = false;
            var errorMessage = "ads.login.twofactor.enter_valid_secret_code";
            if (response.hasOwnProperty('ERROR_MESSAGE')) {
                errorMessage = response.ERROR_MESSAGE;
            }
            if (response.hasOwnProperty('ERROR_STATUS')) {
                errorStatus = response.ERROR_STATUS;
            }
            if (errorMessage == 'ads_login_twofactor_rsa_new_pin_required') {
                this.set('RESET_RSA_AUTH', false);
                var passCodePolicy = response.PASS_CODE_POLICY;
                var minLen = passCodePolicy['MIN_LEN'];
                var maxLen = passCodePolicy['MAX_LEN'];
                var isAlphaNumeric = passCodePolicy['IS_ALPHA_NUMERIC'];
                var state = I18NUtil.translate('ads.login.twofactor.rsa_new_pin_numeric');
                if (isAlphaNumeric) {
                    state = I18NUtil.translate('ads.login.twofactor.rsa_new_pin_alphanumeric');
                }
                var helpText = I18NUtil.translate('ads.login.twofactor.rsa_new_pin_policy').replace("{0}", state);
                helpText = helpText.replace("{1}", minLen);
                helpText = helpText.replace("{2}", maxLen);
                this.set('TFA_RSA_AUTHENTICATOR.RSA_PIN_CHANGE_NOTE', helpText);

                var pattern = "";
                if (isAlphaNumeric) {
                    pattern += "^([A-Za-z0-9]+)"; //NO I18N
                } else {
                    pattern += "^([0-9]+)"; //NO I18N
                }
                if (minLen != '' && maxLen != '') {
                    if (pattern == '') {
                        pattern = "^.";
                    }
                    pattern += "{" + minLen + "," + maxLen + "}"; //NO I18N
                }
                if (pattern != '') {
                    pattern += "$"; //NO I18N
                }
                this.set('TFA_RSA_AUTHENTICATOR.RSA_PIN_PATTERN', pattern);
                this.set('CURRENT_RSA_OPERATION', 'RSA_PIN_CHANGE');
            } else if (errorMessage == 'ads_login_twofacto_rsa_new_pin_accepted' || errorMessage == 'ads_login_twofactor_rsa_new_oda_pin_accepted') {
                this.set('RESET_RSA_AUTH', false);
                this.set('CURRENT_RSA_OPERATION', 'RSA_VERIFICATION');
                this.set('RSA_VERIFICATION_MODE', 'RSA_PASSCODE');
            } else if (errorMessage == 'ads_login_twofactor_rsa_next_code_required') {
                this.set('RESET_RSA_AUTH', false);
                this.set('CURRENT_RSA_OPERATION', 'RSA_VERIFICATION');
                this.set('RSA_VERIFICATION_MODE', 'NEXT_PASSCODE');
            } else {
                this.set('RESET_RSA_AUTH', true);
                this.set('CURRENT_RSA_OPERATION', 'RSA_VERIFICATION');
                this.set('RSA_VERIFICATION_MODE', 'RSA_PASSCODE');
            }
            this.sendAction('showStatus', errorStatus === true ? 'success' : 'danger', I18NUtil.translate(errorMessage), true);
        },
        modifyAuthentication: function() {
            this.set('TFA_USER_ENROLLMENT_DETAILS', false);
            var currentModeName = this.get('TFA_USER_ENROLLMENT.MODE_NAME');
            if(currentModeName){
            this.set('CURRENT_TFA_MODE',currentModeName)
            }else{
                currentModeName = this.get('CURRENT_TFA_MODE');
            }
            if (this.get('CURRENT_VIEW') !== 'SELECT_AUTH') {

                this.set('CURRENT_TFA_MODE', '');
                this.send('selectAuth', currentModeName);
            }
        },
        cancel: function() {
            this.set('TFA_USER_ENROLLMENT_DETAILS', true);
        },
        deleteEnrollment: function(browserDetails) {
            var trustedBrowsers = [];
            var details = Ember.$.extend(true, {}, browserDetails);
            details['IS_SELECTED'] = true;
            trustedBrowsers[trustedBrowsers.length] = details;
            DialogUtil.confirm(this, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_confirm_delete_trustedBrowser'), 'deleteEnrollments', I18NUtil.translate('ads.common.text.delete'), trustedBrowsers);
        },
        deleteAllEnrollment: function(trustedBrowsers) {
            var atleastOneSelected = false;
            for (var i = 0; i < trustedBrowsers.length; i++) {
                var browser = trustedBrowsers[i];
                if (browser.IS_SELECTED === true) {
                    atleastOneSelected = true;
                    break;
                }
            }
            if (atleastOneSelected) {
                DialogUtil.confirm(this, I18NUtil.translate('ads.admin.logon_settings.tfa_settings.alert_confirm_delete_multiple_trustedBrowser'), 'deleteEnrollments', I18NUtil.translate('ads.common.text.delete'), trustedBrowsers);
            } else {
                DialogUtil.alert(this, I18NUtil.translate('ads.login.twofactor.alert_atleast_one_browser_must_be_selected_to_delete'));
            }
        },
        deleteEnrollments: function(trustedBrowsers) {
            var data = {};
            var deleteBrowserIds = [];
            for (var i = 0; i < trustedBrowsers.length; i++) {
                var browser = trustedBrowsers[i];
                if (browser.IS_SELECTED === true) {
                    deleteBrowserIds[deleteBrowserIds.length] = browser.ID;
                }
            }
            if (deleteBrowserIds.length > 0) {
                var self = this;
                data['DELETE_BROWSER_IDS'] = JSON.stringify(deleteBrowserIds);
                AJAXUtil.ajax('/RestAPI/WC/TwoFactorAction?mTCall=deleteUserTrustedBrowser', data).then(function(response) {
                    if ('sSTATUS' in response) {
                        var totalCount = self.get('NAVIGATION.TOTAL_COUNT');
                        var page = self.get('NAVIGATION.PAGE');
                        var rowCount = self.get('NAVIGATION.RECORDS_PER_PAGE');
                        if (page * rowCount > totalCount && ((page - 1) * rowCount) + deleteBrowserIds.length === totalCount) { //If elemets from last page is deleted it must be moved to previous page
                            self.set('NAVIGATION.PAGE', page - 1);
                        }
                        self.resetTFATrustedBrowsersTable();
                    }
                });
            }
        },
        enableDisableBrowser: function(val, params) {
            var totalCount = (this.get('NAVIGATION.END_COUNT') - this.get('NAVIGATION.START_COUNT')) + 1;
            Ember.set(params, "IS_SELECTED", val);
            var trustedBrowsers = this.get('TRUSTED_BROWSERS');
            var count = 0;
            for (var i = 0; i < trustedBrowsers.length; i++) {
                var config = trustedBrowsers[i];
                if (config.IS_SELECTED === true) {
                    count++;
                }
            }
            if (count === totalCount) {
                Ember.$('#ENABLE_DISABLE_ALL').prop('checked', true);
                Ember.$('#ENABLE_DISABLE_ALL').iCheck('update');
            } else {
                Ember.$('#ENABLE_DISABLE_ALL').prop('checked', false);
                Ember.$('#ENABLE_DISABLE_ALL').iCheck('update');
            }
        },
        enableDisableAll: function(val, params) {
            for (var i = 0; i < params.length; i++) {
                Ember.set(params[i], "IS_SELECTED", val);
            }
            if (val == true) {
                Ember.$('#ENABLE_DISABLE_ALL').prop('checked', true);
                Ember.$('#ENABLE_DISABLE_ALL').iCheck('update');
            } else {
                Ember.$('#ENABLE_DISABLE_ALL').prop('checked', false);
                Ember.$('#ENABLE_DISABLE_ALL').iCheck('update');
            }
        },
        previewChangeRowCount(count) {
            this.set('NAVIGATION.RECORDS_PER_PAGE', count);
            this.set('NAVIGATION.PAGE', 1);
            this.resetTFATrustedBrowsersTable();
        },
        previewGotoPage(page) {
            var pageVal = this.get('NAVIGATION.PAGE');
            if (page == 'first') { //NO I18N
                pageVal = 1;
            } else if (page == 'next') { //NO I18N
                pageVal = pageVal + 1;
            } else if (page == 'prev') { //NO I18N
                pageVal = pageVal - 1;
                if (pageVal < 1) { //NO I18N
                    pageVal = 1;
                }
            } else if (page == 'end') { //NO I18N
                pageVal = Math.ceil(this.get('NAVIGATION.TOTAL_COUNT') / this.get('NAVIGATION.RECORDS_PER_PAGE'));
            } else {
                pageVal = 1;
            }
            //update only if new page is less than total pages
            var totalCount = this.get('NAVIGATION.TOTAL_COUNT') + this.get('NAVIGATION.RECORDS_PER_PAGE');
            totalCount = totalCount - (totalCount % this.get('NAVIGATION.RECORDS_PER_PAGE'));
            if (totalCount >= pageVal * this.get('NAVIGATION.RECORDS_PER_PAGE')) {
                this.set('NAVIGATION.PAGE', pageVal);
                this.resetTFATrustedBrowsersTable();
            }
        },
        refresh: function() {
            this.resetTFATrustedBrowsersTable();
        },
        toggleSearchBox: function() {
            if (Ember.$(".fw-icn-table-search").length) {
                this.set('isSearchBarOpen', true);
                Ember.$(".fw-icn-table-search").removeClass("fw-icn-table-search").addClass("fw-icn-search-clear");
                Ember.$(".mCustomScrollbar").mCustomScrollbar('scrollTo', 'top');
            } else {
                this.set('isSearchBarOpen', false);
                this.resetSearch();
                Ember.$(".fw-icn-search-clear").removeClass("fw-icn-search-clear").addClass("fw-icn-table-search");
            }
            Ember.$(".target_class .search-bar").toggle();
            Ember.run.schedule('afterRender', this, function() {
                Ember.$('#TRUSTED_BROWSERS_DETAILS').find('.mCustomScrollbar').mCustomScrollbar("scrollTo", "top", {
                    scrollInertia: 200
                });
            });
        },
        searchTrustedBrowsers: function() {
            this.set('NAVIGATION.PAGE', 1);
            this.resetTFATrustedBrowsersTable();
        }
    }
});
//ignorei18n_end
