/* $Id: notification-service.js,v 1.11.4.1 2018/12/22 23:42:44 kamalraj.d Exp $ */
//ignorei18n_start
import Ember from 'ember'; //NO I18N
import AJAXUtil from '../utils/ads-ajax-util'; //NO I18N

let Notification = Ember.Object.extend({
  isDetailsCollected: false,
  icon: null,
  message: null,
  isDismissable: null,
  actionText: null,
  action: null,
  notificationName: null,
  notificationId: null,
  isEnabled: true,
  canShow: true,
  iconClass: Ember.computed('icon', {
    get(key) {
      return 'notification-center-icon icon-notification-'.concat(this.get('icon')).toLowerCase() + ' fw-mt-m1';
    }
  }),
});

export default Ember.Service.extend({
  notifications: Ember.ArrayProxy.create({ content: Ember.A([]) }),

  getNotifications: function () {
    AJAXUtil.ajaxNoScroll('/RestAPI/WC/Notification?mTCall=getAllNotifications').then(function (response) {
      this.set("isDetailsCollected", true);
      response.NOTIFICATIONS.forEach(function (notification) {
        this.notifications.pushObject(this.createNotification(notification));
      }, this);
    }.bind(this));
  }.on('init'),

  currentActiveNotificationsCount: Ember.computed('notifications.@each.canShow', function () {
    if(this.notifications.filterBy('icon', 'CRITICAL').filterBy('canShow', true).get('length')) {
    return (this.notifications.filterBy('canShow', true).get('length') - this.get("activeCriticalNotificationsCount"));
    } else {
      return (this.notifications.filterBy('canShow', true).get('length'));
    }
  }),
  currentUnDissmisableNotificationsCount: Ember.computed('notifications.@each.canShow', function () {
    if(this.notifications.filterBy('canShow', true).filterBy('isDismissable', false).get('length')) {
      return (this.notifications.filterBy('canShow', true).filterBy('isDismissable', false).get('length') - this.notifications.filterBy('isCritical', true).filterBy('isDismissable', false).get('length'));
    } else {
    return this.notifications.filterBy('canShow', true).filterBy('isDismissable', false).get('length');
    }
  }),
  activeNotificationsCount: Ember.computed('notifications.@each.isEnabled', function () {
    return (this.notifications.filterBy('isEnabled', true).get('length') - this.get("activeCriticalNotificationsCount"));
  }),
  activeCriticalNotificationsCount: Ember.computed('notifications.@each.isEnabled', function () {
    return this.notifications.filterBy('isCritical', true).filterBy('isEnabled', true).get('length');
  }),

  getNotification: function (name) {
    return this.notifications.filterBy('notificationName', name);
  },

  getNotificationById: function (name, id) {
    return this.getNotification(name).findBy('notificationId', id)
  },

  disableNotificationById: function (name, id) {
    this.getNotificationById(name, id).set('isEnabled', false);
    this.hideNotificationById(name, id);
  },

  disableNotification: function (name) {
    this.hideNotification(name);
    return this.getNotification(name).forEach(function (notification) {
      notification.set('isEnabled', false);
    });
  },

  enableNotificationById: function (name, id) {
    this.getNotificationById(name, id).set('isEnabled', true);
  },

  showNotificationById: function (name, id) {
    this.getNotificationById(name, id).set('canShow', true);
  },

  hideNotificationById: function (name, id) {
    this.getNotificationById(name, id).set('canShow', false);
  },

  hideNotification: function (name) {
    return this.getNotification(name).forEach(function (notification) {
      notification.set('canShow', false);
    });
  },

  getNotificationObject: function () {
    return this.notifications;
  },

  modifyNotification: function (name, id, notification) {
    let notificationObj = this.getNotificationById(name, id);
    if (notificationObj !== undefined) {
      notificationObj.setProperties({
        notificationName: notification.NOTIFICATION_NAME,
        notificationId: notification.NOTIFICATION_ID,
        isDismissable: notification.IS_DISMISSABLE,
        actionText: notification.ACTION_TEXT,
        isEnabled: notification.IS_ENABLED,
        canShow: true,
        message: notification.MESSAGE,
        action: notification.ACTION,
        icon: notification.ICON,
      });
    } else {
      this.setNotification(notification);
    }
  },

  setNotification: function (notification) {
    this.notifications.pushObject(this.createNotification(notification));
  },

  createNotification: function (notification) {
    return Notification.create({
      notificationName: notification.NOTIFICATION_NAME,
      notificationId: notification.NOTIFICATION_ID,
      isDismissable: notification.IS_DISMISSABLE ? notification.IS_DISMISSABLE : false,
      actionText: notification.ACTION_TEXT,
      isEnabled: notification.IS_ENABLED,
      canShow: true,
      message: notification.MESSAGE,
      action: notification.ACTION,
      icon: notification.ICON,
      isCritical: notification.IS_CRITICAL ? notification.IS_CRITICAL : false
    });
  },

  checkStatus: function (name) {
    var self = this;
    AJAXUtil.ajaxNoScroll('/RestAPI/WC/Notification?mTCall=getNotification&NOTIFICATION_NAME=' + name).then(function (response) {
      var newNotification = response[name];
      if (Ember.isPresent(newNotification)) {
        newNotification.forEach(function (notification) {
          self.modifyNotification(notification.NOTIFICATION_NAME, notification.NOTIFICATION_ID, notification);
        });
      } else {
        self.disableNotification(name);
      }
    });
  }
});

//ignorei18n_end
