/* $Id: ads-ajax-util.js,v 1.10.4.2 2018/12/03 17:58:45 ganesh.venkatraman Exp $ */
import I18NUtil from "../utils/i18n-util";//No I18N
import CommonUtil from "../utils/ads-common-util";//No I18N
import Ember from 'ember';//NO I18N
import config from '../config/environment';//No i18n

export default Ember.Object.create({
	csrfParamName: null,
	csrfCookieValue: null,
	context: '',
	init : function(){
		if(config.APP.context) {
			this.set('context', config.APP.context);//No i18n
		}
	},
	ajax : function(url, data, resolveOn401, dataType, addCsrf)
	{
		var self = this;
		url = this.get('context')? this.get('context')+url : url;//No i18n
		dataType = (dataType === undefined) ? 'json' : dataType; // No i18n

		//To specify the type for the request as GET/POST  param 'data' format should be "{TYPE : 'POST'/'GET' , PARAMS : {}}"

		var reqType = data === undefined ? 'POST' : data.TYPE === undefined ? 'POST' : data.TYPE; // NO I18N
		var params = data === undefined ? '' : data.PARAMS === undefined ? data.TYPE === undefined ? data : '' : data.PARAMS; // NO I18N

		if(reqType.toUpperCase() == 'POST' && addCsrf)
		{
			var csrfParam = this.get("csrfParamName");//NO I18N

			if(params.constructor === {}.constructor)
			{
				params[csrfParam] = this.get("csrfCookieValue"); // NO I18N
			}
			else
			{
				params += '&'+csrfParam+'=' + this.get("csrfCookieValue"); // NO I18N
			}
		}


		return new Ember.RSVP.Promise(function (resolve,reject)
		{
			window.scrollTo(0,0);
			Ember.$.ajax(
			{
				url: url,
				data: params,
				async: true,
				type : reqType, //NO I18N
				'dataType': dataType //NO I18N

			})
			.done(function(json)
			{
				if(dataType =='json')
				{
					if(self.handleDemoMode(json))
					{
						resolve(json);
					}
					else
					{
						var json={};
						json["eSTATUS"]=I18NUtil.translate('ads.common.error.demo_mode');//No I18N
						resolve(json);
					}
				}
				else
				{
					resolve(json);
				}
			})
			.fail(function(jqXHR, textStatus, errorThrown)
			{
				if(resolveOn401 && jqXHR.status == '401')
				{
					resolve({'status':'401'}); //NO I18N
				}
				else
				{
					self.handleAjaxFail(jqXHR);
				}
			});
		});
	},
	syncAjax : function(url, data, resolveOn401,dataType)
	{
		var self = this;
		url = this.get('context')? this.get('context')+url : url;//No i18n
		var ret = {};
		dataType = (dataType === undefined) ? 'json' : dataType; // No i18n
		window.scrollTo(0,0);
		Ember.$.ajax(
		{
			url: url,
			data: data,
			async: false,
			type : 'POST', //NO I18N
			'dataType': dataType //NO I18N

		})
		.done(function(response)
		{
			if(dataType=='json')
			{
				if(self.handleDemoMode(response))
				{
					ret = response;
				}
				else
				{
					ret["eSTATUS"]=I18NUtil.translate('ads.common.error.demo_mode');//No I18N
				}
			}
			else
			{
				ret = response;
			}
		})
		.fail(function(jqXHR)
		{
			if(resolveOn401 && jqXHR.status == '401')
			{
				resolve({'status':'401'}); //NO I18N
			}
			else
			{
				self.handleAjaxFail(jqXHR);
			}
		});
		return ret;
	},

	ajaxNoScroll : function(url, data, resolveOn401)
	{
		var self = this;
		url = this.get('context')? this.get('context')+url : url;//No i18n
		return new Ember.RSVP.Promise(function (resolve)
		{
			Ember.$.ajax(
			{
				url: url,
				data: data,
				async: true,
				type : 'POST', //NO I18N
				dataType : 'json', //NO I18N
			})
			.done(function(json)
			{
				if(self.handleDemoMode(json))
				{
					resolve(json);
				}
				else
				{
					var json={};
					json["eSTATUS"]=I18NUtil.translate('ads.common.error.demo_mode');//No I18N
					resolve(json);
				}
			})
			.fail(function(jqXHR)
			{
				if(resolveOn401 && jqXHR.status == '401')
				{
					resolve({'status':'401'}); //NO I18N
				}
				else
				{
					self.handleAjaxFail(jqXHR);
				}
			});
		});
	},

	handleAjaxFail : function(jqXHR)
	{
		if (jqXHR.status == '401')
		{
			this.get('appModel').set('ajax401', true); //NO I18N
		}
		else if (jqXHR.status == '200')
		{
			this.handleSessionTimeout(jqXHR.status, jqXHR.responseText);
		}
		else if (jqXHR.status != '0')
		{
			alert("Connection to Server Failed. Error " + jqXHR.status + " " + jqXHR.statusText + "."); //NO I18N
		}
	},

	handleSessionTimeout : function(status, response)
	{
		if (status == '200' || status == '403')
		{
			var isLoginPage = (response !='' && ((response.indexOf('j_security_check') > -1) || (response.indexOf('HTTP Status 403 - The request body was too large to be cached during the authentication process') > -1))); //NO I18N
			if (isLoginPage)
			{
				location.href = "/";
			}
		}
	},

	handleDemoMode : function(dataModel)
	{

		if('STATUS_MESSAGE' in dataModel)
		{
			if(dataModel.STATUS_MESSAGE == I18NUtil.translate('ads.common.error.demo_mode'))
			{
				return false;
			}
		}
		return true;
	},
	//function to set csrf cookie value if provided
	setCsrfCookie: function(paramName,cookieVal) {
		this.set('csrfParamName',paramName);//NO I18N
		this.set('csrfCookieValue',cookieVal);//NO I18N
	}
});