/*
  $Id: ads-common-util.js,v 1.11 2018/12/24 13:59:11 ajith.k Exp $
*/

import Ember from 'ember';//NO I18N

export default Ember.Object.create
({
    showLoading: function()
    {
        if(Ember.$('#loader').css('display')=='block')
        {
            return;
        }
        Ember.$('#loader').fadeIn();
    },

    hideLoading: function()
    {
        Ember.$('#loader').fadeOut();
    },
    showTextLoading: function()
    {
        if(Ember.$('#text-loader').css('display')=='block')
        {
            return;
        }
        Ember.$('#text-loader').fadeIn();//NO I18N
    },

    hideTextLoading: function()
    {
        Ember.$('#text-loader').fadeOut();//NO I18N
    },

    showNotification: function(text,delay,style) {
        Ember.$('.notifyjs-corner').empty();
        let notifyJSON = {};
        if(typeof delay === "undefined") {
            notifyJSON.autoHideDelay = 1800;
        }else{
            notifyJSON.autoHideDelay = delay;
        }
        if(typeof style !== "undefined" && style === "success"){
            notifyJSON.style = "success_green";
        }
        Ember.$.notify(text,notifyJSON);
    },

    /**
     * clientValues - represents array of arrays [ [], [], ...] or, array of values
     * serverValues - represents array of arrays [ [], [], ...] or, array of values
     */
    setDropDownValues: function(clientValues,serverValues)
    {
        let optgroup=[];
        if(typeof clientValues[0] === "object")
        {
            for (let i = 0; i < clientValues.length; i++)
            {
                let dropDownValues = [];
                for(let j=0; j<clientValues[i].length; j++)
                {
                    dropDownValues.push({CLIENT_VALUE :clientValues[i][j],SERVER_VALUE : serverValues[i][j]});
                }
                optgroup.push({OPT_GROUP : dropDownValues});
            }
        }
        else
        {
            for(let i = 0; i < clientValues.length; i++)
            {
                optgroup.push({CLIENT_VALUE :clientValues[i],SERVER_VALUE : serverValues[i]});
            }
        }
        return optgroup;
    },

    renderNavigation()
    {
        Ember.run.scheduleOnce('afterRender', function() //NO I18N
        {
            Ember.$('.lnav li.open').removeClass('open');
            Ember.$('.lnav li.active').removeClass('active');

            Ember.$('.lnav a').each(function()
            {
                if(Ember.$(this).hasClass('active'))
                {
                    Ember.$(this).parent().addClass('active'); //css styling for active sub-menu link
                    Ember.$('.lnav ul').css('display','none');
                    Ember.$(this).closest('ul').css('display','block');//NO I18N
                    Ember.$(this).closest('ul').parent().addClass('open');	//NO I18N
                }
            });
        });
    },

    renderSelect()
    {
        Ember.run.scheduleOnce('afterRender', function() //NO I18N
		{
			//Select Box - Style Init
			Ember.$("select").selectpicker({size:false});//NO I18N
			Ember.$(".bootstrap-select").each(function(){
				if(!Ember.$(this).hasClass('bs-custom-scroll') && !Ember.$(this).hasClass('noScrollbar') && !$(this).find('.mCustomScrollbar').length)
				{
					Ember.$(this).find('ul').css('display','block');
					Ember.$(this).find('ul').wrap('<div></div>');
					Ember.$(this).find('ul').parent().css('max-height','150px');//NO I18N
					Ember.$(this).find('ul').parent().addClass('fw-custom-scroll');//NO I18N
					Ember.$(this).find('.inner').removeAttr('role');
					Ember.$(this).find('ul').parent().attr('role','menu');//NO I18N
				}
			});
		});
		this.renderScrollBar();

    },

    renderScrollBar()
    {
        Ember.run.scheduleOnce('afterRender', function() //NO I18N
        {
            //automatic height setter and custom scrollbar enabled and hover option
            if(Ember.$(".fw-custom-scroll-hover").length){
                Ember.$(".fw-custom-scroll-hover").each(function () {
                    if (Ember.$(this).attr('data-height')) {
                        Ember.$(this).height(Ember.$(this).attr('data-height')).css({
                            "overflow": "hidden" //NO I18N
                        });
                    }
                    var  theme=(Ember.$(this).attr("data-theme"))? Ember.$(this).attr("data-theme"): "dark"; //NO I18N
                    var  sPosition=(Ember.$(this).attr("data-scrollbar-position"))? Ember.$(this).attr("data-scrollbar-position"): "inside"; //NO I18N
                    Ember.$(this).mCustomScrollbar({
                        theme: theme,
                        autoHideScrollbar: true,
                        scrollbarPosition:sPosition,
                        callbacks: {
                            onScroll: function (evt) {
                                return false;
                            },
                            onTotalScroll: function (evt) {
                                return false;
                            },
                            onTotalScrollBack: function (evt) {
                                return false;
                            }
                        }
                    });
                });
            }

            //Scroll Bar - Starts
            Ember.$(".fw-custom-scroll").each(function ()
            {
                let mCSBParam = {
                    theme:"dark",//NO I18N
                    autoHideScrollbar: false,
                    snapAmount:28,
                    autoScrollOnFocus:false,
                    keyboard:false,
                    scrollInertia: 500,
                    callbacks:
                        {
                            onScroll: function (evt) {
                                return false;
                            },
                            onTotalScroll: function (evt) {
                                return false;
                            },
                            onTotalScrollBack: function (evt) {
                                return false;
                            }
                        }
                };

                if (Ember.$(this).attr('data-height'))
                {
                    Ember.$(this).height(Ember.$(this).attr('data-height')).css({"overflow":"hidden"});//NO I18N
                }
                else
                {
                    let dropdown = Ember.$(this).parent().siblings('select[data-height]');
                    if(dropdown != null && dropdown.length)
                    {
                        let height = dropdown.data('height');//NO I18N
                        Ember.$(this).height(height).css({"max-height": height,"overflow":"hidden"});//NO I18N

                        let amount = 22.33;
                        mCSBParam.snapAmount=amount;
                    }
                }

                Ember.$(this).mCustomScrollbar(mCSBParam);
            });

            //Drag-n-drop
            Ember.$(".mCSB_dragger_bar,.mCSB_draggerContainer").on("click", function (evt)
            {
                evt.stopPropagation();
            });

            Ember.$(".fw-custom-scroll-hover").each(function () {
                if (Ember.$(this).attr('data-height')) {
                    Ember.$(this).height(Ember.$(this).attr('data-height')).css({"overflow": "hidden"});//NO I18N
                }
                var  theme=(Ember.$(this).attr("data-theme"))? Ember.$(this).attr("data-theme"): "dark"; //NO I18N
                var  sPosition=(Ember.$(this).attr("data-scrollbar-position"))? Ember.$(this).attr("data-scrollbar-position"): "inside";  //NO I18N
                Ember.$(this).mCustomScrollbar({
                    theme: theme,
                    autoHideScrollbar: true,
                    scrollbarPosition:sPosition,
                    callbacks: {
                        onScroll: function (evt) {
                            return false;
                        },
                        onTotalScroll: function (evt) {
                            return false;
                        },
                        onTotalScrollBack: function (evt) {
                            return false;
                        }
                    }
                });
            });

            Ember.$(".scrollBox").each(function()
            {
                Ember.$(this).height(Ember.$(this).attr('data-height')).mCustomScrollbar();

            });

            var isRendered = false;
            Ember.$('.modal').on('shown.bs.modal', function (e)
            {
                if(!isRendered)
                {
                    var _this = Ember.$(".fixTable table") ;
                    var _parent = _this.closest("div.fixTable");//No I18N
                    _parent.height(_parent.attr('data-height'));//No I18N

                    isRendered = true;
                }
            });

            Ember.$(".fixTable").each(function ()
            {
                var _this = Ember.$(this);
                _this.height(_this.attr('data-height')).mCustomScrollbar({axis:"y",callbacks: //No I18N
                        {
                            whileScrolling: function()
                            {

                                Ember.$(this).trigger('whileScrolling',[this.mcs.left,Math.abs(this.mcs.top)]);
                            }
                        }});

            });
            //Scroll Bar - Ends
        });
    },

    renderTooltip()
    {
        Ember.run.scheduleOnce('afterRender', function() //NO I18N
        {
            //Tooltip
            Ember.$("input[data-toggle='switch']").bootstrapToggle();
            Ember.$('[data-toggle-hover="tooltip"]').tooltip();
            Ember.$('[data-toggle="tooltip"]').tooltip();
            Ember.$('[role=tooltip]').remove();
            Ember.$('[data-toggle="ui-tooltip-with-arrow"]').each(function(){
                if(Ember.$(this).length){
                    Ember.$(this).tooltip();
                    var stylingObj={
                        tooltipClass: "ui-tooltip-with-arrow", //NO I18N
                        track: true,
                        position: {
                            my: "left-30 top+20", //NO I18N
                            at: "left bottom", //NO I18N
                            using: function( position, feedback ) {
                                Ember.$( this ).css( position );
                                Ember.$(".arrow").each(function()
                                {
                                    if(!Ember.$(this).hasClass(feedback.vertical))
                                    {
                                        Ember.$(this).remove();
                                    }
                                });
                                Ember.$( "<div>" ).addClass( "arrow" ).addClass( feedback.vertical ).addClass( feedback.horizontal ).appendTo( this );
                            }
                        }
                    };
                    Ember.$(this).tooltip(stylingObj);
                }
            }).off("focusin focusout");	//NO I18N

            Ember.$('[data-toggle=ui-tooltip-with-arrow]>input').unbind();
            Ember.$('[data-toggle=ui-tooltip-with-arrow]>input').on("focusout",function() {
                Ember.$('[role=tooltip]').remove();
            });
        });
    },

    afterRender: function(moduleName,self)
    {
        let _this = this;
        Ember.run.scheduleOnce('afterRender', function() //NO I18N
        {
            _this.renderNavigation();
            //handled in select-input
            // _this.renderSelect();
            _this.renderScrollBar();
            //Page Navigation btn group
            Ember.$('.dropdown').unbind();

            //Loading
            if(self){self.controllerFor('application').set('isLoading',false);}//NO I18N

            _this.renderTooltip();
        });
    }
});
