/*
   $Id: ads-validation-util.js,v 1.5 2018/12/24 13:59:12 ajith.k Exp $
   */
//ignorei18n_start
import Ember from 'ember'; //NO I18N

export default Ember.Object.create({

  blockedPorts: [1, 7, 9, 11, 13, 15, 17, 19, 20, 21, 22, 23, 25, 37, 42, 43, 53, 77, 79, 87, 95, 101, 102, 103, 104, 109, 110, 111, 113, 115, 117, 119, 123, 135, 139, 143, 179, 389, 465, 512, 513, 514, 515, 526, 530, 531, 532, 540, 556, 563, 587, 601, 636, 993, 995, 2049, 4045, 6000],
  fileNameRegEx: "^[a-zA-Z0-9.-_ ]{0,255}$", //NO I18N

  isValidEmail: function(mailId) {
    var re = /^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/;
    return re.test(mailId);
  },

  //Checks whether address is valid IPv4 address or not
  isValidIP: function(address) {
    //octets represent number between two dots, IPv4 address has 4 octets
    let octets = address.split(".");
    //IP address cannot start with 0
    if (octets[0] == 0 || octets.length !== 4) {
      return false;
    }
    for (let i = 0; i < octets.length; i++) {
      if (octets[i].trim() == "" || octets[i].length > 3 || !this.isPositiveInteger(octets[i]) || parseInt(octets[i], 10) > 255 || /\s/.test(address)) {
        return false;
      }
    }
    return true;
  },

  isPositiveInteger: function(number) {
    return number >= 0;
  },

  isSmallerIP: function(ip1, ip2) {
    var ip1Blocks = ip1.split(".");
    var ip2Blocks = ip2.split(".");
    for (var i = 0; i < ip1Blocks.length; i++) {
      if (parseInt(ip2Blocks[i]) > parseInt(ip1Blocks[i])) {
        return true; //ip2>ip1
      } else if (parseInt(ip1Blocks[i]) > parseInt(ip2Blocks[i])) {
        return false; //ip1>ip2
      }
    }
    return true; //ip2>ip1
  },

  isValidHostName: function(hostname) {
    //Checks whether the hostname matches IP address pattern
    if (/^[\-0-9][\-0-9\.\*]+[\-0-9\.\*]+$/.test(hostname) && !/^[0-9]+$/.test(hostname)) {
      if (hostname.split(".")[0] == 0 || hostname.search("-") != -1) {
        return false;
      } // 0 in first octet is invalid, for example : 0.*.*.*
      return this.isValidIPMacro(hostname);
    } else {
      return this.isValidServerName(hostname);
    }
  },

  isValidIPMacro: function(ip) {
    //IP Macro (192.168.4.5 , 192.168.4.* , 192.168.*.5 ) returns true
    return /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)|(\*))\.((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)|(\*))\.((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)|(\*))$/.test(ip);
  },

  isValidServerName: function(name) {
    //Server Name should not contain othet than a-z 0-9 - .
    if (name.length < 255 && /^[a-zA-Z0-9\-](\.?[a-zA-Z0-9\-])*$/.test(name)) {
      name += "-"; //to compensate for dot at the end in FQDN
      let labels = name.split(".");
      for (let i = 0; i < labels.length; i++) {
        if (labels[i].length > 63) //max limit of each label
        {
          return false;
        }
      }
      return true;
    }
    return false;
  },

  isValidNumber: function(number) {
    if (number !== '') {
      return !!number.match(/^[0-9]+$/);
    }
    return false;
  },

  isValidPort: function(port) {
    if (port.match(/^[0-9]+$/)) {
      if (!(port <= 0 || port > 65535)) {
        return true;
      }
    }
    return false;
  },

  isBlockedPort: function(port) {
    if (Ember.$.inArray(port, this.blockedPorts) > -1) {
      return true;
    }
    return false;
  },

  isDomainAccountName: function(userName) {
    if (userName.indexOf("\\") == -1 || userName.indexOf("\\") == 0) {
      return false;
    }
    return true;
  },

  isValidFileName : function(fileName)
  {
    var fileNameRegExp= /^[a-zA-Z0-9.\-_ ]{0,255}$/; //NO I18N
    return fileNameRegExp.test(fileName);
  },

  isValidName: function(value) {
    var pattern = /"[@#*()&=+}|><\-/:-?{-~!"^_`[\]]"/;
    return pattern.test(value);
  },

  isInvalidForm: function(parentSelector) {
    let hasError = false;
    let self = this;
    let parent = Ember.$(parentSelector);
    parent.find(".validate-text,.validate-number").addBack(".validate-text,.validate-number").each(function() {
      let enabledInputs = Ember.$(this).find("textarea:not([disabled]):not(.hidden),input:not([disabled]):not(.hidden):not([data-element='search-bar'])");
      let spanElements = Ember.$(this).find("span.error-text");
      if(enabledInputs.length > 0) {
        let val = enabledInputs.val();
        if(!val || val.trim().length === 0) {
          hasError = true;
          Ember.$(this).addClass("error-control").addClass("empty-entry");
          if(enabledInputs.attr("data-custom-span")){
            Ember.$("#"+enabledInputs.attr("data-custom-span")).closest(".form-group").addClass("error-control").addClass("invalid-entry");
          }
        }
      }
    });
    parent.find(".validate-number").addBack(".validate-number").each(function() {
      let enabledInputs = Ember.$(this).find("input:not([disabled]):not(.hidden)");
      let spanElements = Ember.$(this).find("span.error-text");
      let hasInvalid = false;
      if(enabledInputs.length > 0) {
        let val = enabledInputs.val();
        if(val && val.trim().length !== 0) {
          if(!Ember.$.isNumeric(val.trim())) {
            hasInvalid = true;
          }
          else {
            let minval = enabledInputs.attr("data-min-val");
            let maxval = enabledInputs.attr("data-max-val");
            if(minval) {
              if(parseInt(val.trim()) < parseInt(minval)) {
                hasInvalid = true;
              }
            }
            if(maxval) {
              if(parseInt(val.trim()) > parseInt(maxval)) {
                hasInvalid = true;
              }
            }
          }
          if(hasInvalid) {
            hasError = true;
            Ember.$(this).addClass("error-control").removeClass("empty-entry").addClass("invalid-entry");
            if(enabledInputs.attr("data-custom-span")){
              Ember.$("#"+enabledInputs.attr("data-custom-span")).closest(".form-group").addClass("invalid-entry").addClass("error-control");
            }
          }
        }
      }
    });
    parent.find(".validate-special-characters").addBack(".validate-special-characters").each(function() {
      let enabledInputs = Ember.$(this).find("textarea:not([disabled]):not(.hidden),input:not([disabled]):not(.hidden)");
      let spanElements = Ember.$(this).find("span.error-text.empty-error");
      if(enabledInputs.length > 0) {
        let val = enabledInputs.val();
        if(self.isValidName(val)) {
          hasError = true;
          Ember.$(this).addClass("error-control").removeClass("empty-entry").addClass("invalid-entry");
        }
      }
    });
    parent.find(".validate-max-length").addBack(".validate-max-length").each(function() {
      let enabledInputs = Ember.$(this).find("textarea:not([disabled]):not(.hidden),input:not([disabled]):not(.hidden)");
      let spanElements = Ember.$(this).find("span.error-text.empt");
      if(enabledInputs.length > 0) {
        let val = enabledInputs.val();
        let maxLength = enabledInputs.attr('max-length') ? enabledInputs.attr('max-length') : 250;
        if(val.length > parseInt(maxLength)){
          hasError = true;
          let text = enabledInputs.attr('max-length-i18n');
          Ember.$(this).addClass("error-control").removeClass("invalid-entry").addClass("empty-entry");
          Ember.$(this).find('span.error-text.empty-error').each(function(){
            if(text){
              Ember.$(this).text("* "+text);
            }else{
              Ember.$(this).text("* "+I18NUtil.translate("ads.ember_input_maximum_length_250"));  
            }
          });
        }
      }
    });
    parent.find(".error-control").addBack(".error-control").find("textarea:not([disabled]):not(.hidden),input:not([disabled]):not(.hidden)").each(function(){
      Ember.$(this).on("focus",function(){
        Ember.$(this).closest(".error-control").removeClass("error-control").removeClass("empty-entry").removeClass("invalid-entry");
        Ember.$(this).off("focus");
      });
    });
    return hasError;
  },

  isValidUNCPath(path)
  {
	return /^\\\\[^\\/*?"<>|\s]+(?:\\[^/:*.?"<>|]+)+$/.test(path);
  },

  isValidLocalPath: function(path)
  {
  	return /^(?:[a-zA-Z]:\\)(?:(?:[^/:*?"<>|]\\?)+$)?$/.test(path);
  },

  isValidLogonName(name)
  {
	return /^(?:[^"/\\:;|=,+*?<>])+\\(?:[^"/\\:;|=,+*?<>])+$/.test(name);
  }

});
//ignorei18n_end