/*
  $Id$
*/
import Ember from 'ember';		//NO I18N

export default Ember.Object.create({
	escapable : /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
	splchars : /[\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
	meta : {    // table of character substitutions
		'\b': '\\b',	//No I18N
		'\t': '\\t',	//No I18N
		'\n': '\\n',	//No I18N
		'\f': '\\f',	//No I18N
		'\r': '\\r',	//No I18N
		'"' : '\\"',	//No I18N
		'\\': '\\\\'	//No I18N
	},
	charToEntityRegex : new RegExp(),
    entityToCharRegex : new RegExp(),
    charToEntity : {},
    entityToChar : {},
    resetCharacterEntities : function() {
        this.set('charToEntity', {});		//NO I18N
        this.set('entityToChar', {});		//NO I18N
        // add the default set
		var entities = {};
		Ember.set(entities, '&amp;', '&');	//NO I18N
		Ember.set(entities, '&gt;', '>');	//NO I18N
		Ember.set(entities, '&lt;', '<');	//NO I18N
		Ember.set(entities, '&quot;', '"');	//NO I18N
		Ember.set(entities, '&#39;', "'");	//NO I18N
        this.addCharacterEntities(entities);
    },
    addCharacterEntities : function(newEntities) {
        var charKeys = Ember.A([]),
            entityKeys = Ember.A([]),
            key, echar;
		var entityToChar = this.get('entityToChar');		//NO I18N
		var charToEntity = this.get('charToEntity');		//NO I18N
        for (key in newEntities) {
            echar = newEntities[key];
            Ember.set(entityToChar, key, echar);
            Ember.set(charToEntity, echar, key);
            charKeys.pushObject(echar);
            entityKeys.pushObject(key);
        }
        this.set('charToEntityRegex', new RegExp('(' + charKeys.join('|') + ')', 'g'));		//NO I18N
        this.set('entityToCharRegex', new RegExp('(' + entityKeys.join('|') + '|&#[0-9]{1,5};' + ')', 'g'));	//NO I18N
    },
    htmlEncode : function(value){
		this.resetCharacterEntities();
		var self = this;
        var htmlEncodeReplaceFn = function(match, capture) {
            return self.charToEntity[capture];
        };
		var retVal = (!value) ? value : String(value).replace(this.charToEntityRegex, htmlEncodeReplaceFn);
        return retVal;
    },
    htmlDecode : function(value) {
		var self =this;
        var htmlDecodeReplaceFn = function(match, capture) {
            return (capture in self.entityToChar) ? self.entityToChar[capture] : String.fromCharCode(parseInt(capture.substr(2), 10));
        };
		var retVal = (!value) ? value : String(value).replace(this.entityToCharRegex, htmlDecodeReplaceFn);
        return retVal;
    },
	scriptEscape : function(val) {
		return val.replace(/("|#|\{|=|<|>|\;|\,|\:|\\|\s)/g, function($1, $2) {
	        return "\\" + $2;
	    });
	},
	escapeSelectorId : function(val) {
		return val.replace(/(!|"|#|\$|%|\'|\(|\)|\*|\+|\,|\.|\/|\:|\;|<|=|>|-|_|\?|@|&|\[|\]|\^|`|\{|\||\}|~|\\|\s)/g, function($1, $2) {
			return "\\" + $2;
		});
	},
	getEncodedJSONStringWithQuotes : function(val) {
		if(val) {
			val = this.getJSONEscapeString(val);
			val = encodeURIComponent(val);	
			val = '"' + val + '"';			//No I18N
		}
		else {  // If it is empty. just we need to send Double Quotes only..
			val = '"' + '"';			//No I18N
		}	
		return val;
	},
	getEncodedJSONString : function(val) {
		if(val) {
			val = this.getJSONEscapeString(val);
			val = encodeURIComponent(val);	
		}
		return val;
	},
	getJSONStringWithQuotes : function(val) {
		if(val) {
			val = this.getJSONEscapeString(val);
			val = '"' + val + '"';			//No I18N
		}	
		else { 
			val = '"' + '"';			//No I18N
		}
		return val;
	},
	getJSONEscapeString : function(val) {
		if(val) {	
			this.escapable.lastIndex = 0;
			var self = this;
				return self.escapable.test(val) ? val.replace(self.escapable, function (a) {
					var c = self.meta[a];
					return typeof c === 'string' ? c :	'\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4); 	//No I18N
				}) : val ;
		}

		return val;	
	},
	getSplCharEscapedEncodedString : function(val) {
		if(val) {	
			this.splchars.lastIndex = 0;
			var self=this;
				return self.splchars.test(val) ? val.replace(self.splchars, function (a) {
					var c = self.meta[a];
					return typeof c === 'string' ? c :	'\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4); 	//No I18N
				}) : val ;
			val = encodeURIComponent(val);	
		}
		return val;	
	}
});
