/* $Id$ */

/* Here multiple DialogBoxes are going to be displayed in window. 
 * Hence, maintaining 'DialogBoxGroup' -> contains array of 'DialogBox' object
 */  


var DialogBoxGroup = new function() {
	this.dialogBoxArray = new Array();
}

/* This fn is used to delete the DialogBox
 * @parameter - dialogId :: Id of the DialogBox, which has to be deleted
 */ 
DialogBoxGroup.deleteDialogBox = function(dialogId) {
	for(var i=0; i<DialogBoxGroup.dialogBoxArray.length; i++) {
		var dialogBoxObj = DialogBoxGroup.dialogBoxArray[i];
		if(dialogBoxObj.dialogId==dialogId) {
			DialogBoxGroup.dialogBoxArray.splice(i,1);
			break;
		}	
	}	
}	

var DialogBox = function() {
	this.dialogId = 0;	// very important property. This attribute only is an unique.. Using this only, we are separating Pop-ups

	this.oDialog = undefined; 
	this.doc = undefined;  
	this.srcEl = undefined; 
	this.closeOnEscKey = true, 
	this.closeOnBodyClick = false, 
	this.iframeIEHack = undefined; 
	this.onCloseCallBack = undefined; 
	this.dialogProperties = { "position":"", "top":"", "left":"", "height":"", "width":"", "srcElement":"", "modal":"", "draggable":"", "title":"", "divCloseBtn":"", "closeOnEscKey":"", "transitionType":"", "transitionInterval":"", "closeOnBodyClick":"", "freezeLayerBGColor":"", "freezeLayerOpacity":"", "className":"", "cursor_left":"", "cursor_top":""};//NO I18N
	this.dialogEl = undefined; 
	this.dialogContentEl = undefined; 
}	

/***** The given below below variables are used to Drag-n-Drop the current Dialog box ****/
var diffLeft=0, diffTop=0;
var capturedDialogId = undefined;
var capturedoDialog = undefined;
var captuedIframeIEHack = undefined;

/* This fn is used to fill the UI related preoperties (such as width, height, etc... ) of the current window in the 'DialogBox' object
 */ 
DialogBox.prototype.initDialogProperties = function(features) {
	if (typeof(features) == "undefined") 
		features = "position=absmiddle";	//NO I18N

	features = features.split(",");

	for (var i=0; i<features.length; i++) {
		var key = (features[i].substr(0, features[i].indexOf("="))).trim();
		var value = (features[i].substr(features[i].indexOf("=")+1, features[i].lengt)).trim();

		this.dialogProperties[key] = value;
 	}
}	

/**
* <h3>Example:</h3>
*<br/>	Following are the different ways the showDialog method can be used:
*<br/>	1. showDialog( html);
*<br/>	2. showDialog( html, "position=relative" );
*<br/>	3. showDialog( html, "position=absolute, top=50, left=400, height=200, width=400",event);
*<br/>	4. showDialog( html, "position=relative, top=10, left=-30" );
*<br/>	5. showDialog( html, "position=relative, modal=yes, closeOnEscKey=no" );
*<br/>	6. showDialog( html, "position=relative, transitionType=boxIn, transitionInterval=20" );
*<br/>	
*<br/>
*<br/>	@param sHTML 	Mandatory. String that specifies the HTML content to display. 	
*<br/>		   
*<br/>	@param sFeatures Optional. This String parameter is a list of items separated by commas.
*<br/>			Each item consists of an option and a value, separated by an equals sign
*<br/>			(for example, "position=relative, modal=yes"). 
*<br/>
*<br/>
*<br/>
*<br/><h3> The following features are supported.</h3>
*<br/>	
*<br/>		 	<h3>position = { absmiddle | absolute | relative }</h3>	Specifies how the dialog should be positioned.
*<br/>									The "absmiddle" type displays the dialog exactly
*<br/>									at the center of the page. The "absolute" type
*<br/>									displays the dialog based on the "top" and "left"
*<br/>									(mentioned below) parameters provided. The "relative"
*<br/>									type displays it exactly below the element from
*<br/>									where the dialog is opened or from the element id
*<br/>									specified in "srcElement" parameter. [absmiddle]
*<br/>
*<br/>									Note:- "relative" type also accepts "top" and 
*<br/>									"left" parameters where the top and left values are
*<br/>									relative to the element from where the dialog is
*<br/>									opened or from the element id specified in
*<br/>									"srcElement" parameter.
*<br/>
*<br/>			<h3>srcEl = id</h3>					Specifies the HTML element from where the Dialog
*<br/>									should be positioned relatively. The value given is
*<br/>									the HTML element's id.
*<br/>							
*<br/>			<h3>top = number</h3>					Specifies the top position of the dialog, in pixels.
*<br/>									This value is relative to the upper-left corner of
*<br/>									the screen.
*<br/>
*<br/>			<h3>left = number</h3>					Specifies the left position of the dialog, in pixels.
*<br/>									This value is relative to the upper-left corner of
*<br/>									the screen.					
*<br/>			
*<br/>			<h3>height = number</h3>					Specifies the height of the dialog, in pixels.
*<br/>									If not specified, the default value is the content's
*<br/>									height.					
*<br/>
*<br/>			<h3>width = number</h3>					Specifies the width of the dialog, in pixels.
*<br/>									If not specified, the default value is the content's
*<br/>									width.
*<br/>
*<br/>			<h3>modal = { yes | no }</h3>				Specifies whether the dialog should be opened as a
*<br/>									modal dialog or not. [no]
*<br/>			
*<br/>			<h3>title = text</h3>			Specifies the title text to be displayed.
*<br/>									Note: If title is not specified and also if 
*<br/>									closeButton is set as "no", then the dialog box
*<br/>									displays only the HTML content passed and the
*<br/>									surrounding box won't be displayed.
*<br/>
*<br/>			<h3>closeButton = { yes | no }</h3>	Specifies whether the close button should be 
*<br/>									displayed or not. If the value is "no" the button
*<br/>									won't be displayed, vice versa. [yes]
*<br/>
*<br/>			<h3>closeOnEscKey = { yes | no }</h3>	Specifies whether the dialog should be closed or not
*<br/>									when "ESC" key is pressed. [yes]
*<br/>
*<br/>			<h3>draggable = { yes | no }</h3>			Specifies whether dragging/moving the Dialog Box is
*<br/>									allowed or not. [yes]
*<br/>
*<br/>			<h3>transitionType = { boxIn }</h3>	Specifies the type of transition effect to be used
*<br/>									when the dialog is displayed. [boxIn]
*<br/>
*<br/>			<h3>transitionInterval = number</h3>	Specifies the transition interval, in milliseconds.
*<br/>									[10]
*<br/>
*<br/>
*<br/>
*<br/>			<h3>closeOnBodyClick = { yes | no }</h3>Specifies whether to close on click [no]. 
*<br/>									[10]
*<br/>
*<br/>
*<br/>Road Map:
*<br/>
*<br/>	Following are the features that will be provided in future:
*<br/>	
*<br/>	1. Restrict Dragging
*<br/>	2. Resizeable Dialogs
*<br/>	3. Close Button hiding
*<br/>	4. Different types of transition effects will be provided
*<br/>
*<br/>**/

DialogBox.prototype.showDialog = function(content, features, callBackFunc, closeCallBackFunc) {
	
	this.initDialogProperties(features);

	/*** Intializing the Popup property values starts ***/
	var classNameProp = this.dialogProperties["className"];
	var draggableProp = this.dialogProperties["draggable"];
	var titleProp = this.dialogProperties["title"];
	var closeButtonProp = this.dialogProperties["divCloseBtn"];
	var widthProp = this.dialogProperties["width"];
	var heightProp = this.dialogProperties["height"];
	var closeOnEscKeyProp = this.dialogProperties["closeOnEscKey"];
	var closeOnBodyClickProp = this.dialogProperties["closeOnBodyClick"];
	var modalProp = this.dialogProperties["modal"];
	var leftProp = this.dialogProperties["left"];	
	var topProp = this.dialogProperties["top"];
	var positionProp = this.dialogProperties["position"];	
	var srcElementProp = this.dialogProperties["srcElement"];	
	var cursor_leftProp = this.dialogProperties["cursor_left"];	
	var cursor_topProp = this.dialogProperties["cursor_top"];
	var transitionTypeProp = this.dialogProperties["transitionType"];	
	var transitionIntervalProp = this.dialogProperties["transitionInterval"];
	/*** Intializing the Popup property values ends ***/
	
	this.oDialog = document.createElement("DIV");
	this.oDialog.id = "_DIALOG_LAYER"+"_"+this.dialogId;
	
	if(classNameProp!="" && classNameProp=="no") {
		this.oDialog.className="";
	}
	else {
		this.oDialog.className="dialogLayer common-bordercolor";
	}
	document.body.appendChild(this.oDialog);
	
	this.dialogEl = this.oDialog;
	
	if (typeof closeCallBackFunc != "undefined" && closeCallBackFunc != null) this.onCloseCallBack = closeCallBackFunc;
	
	var isContentDOMElement = ((typeof content) != "string");//NO I18N
	var contentElement = content;
	var dialogContentDivId = '_DIALOG_CONTENT'+'_'+this.dialogId;	//NO I18N
	content = '<div id="'+dialogContentDivId+'">' + ((isContentDOMElement) ? "" : content) + '</div>';

	var box = '<table class="DialogBox" border="0" cellspacing="0" cellpadding="0" width="100%"><tr height="24">';

	
	if (draggableProp=="no") 
		box += '<td class="boxHeader1 whitetxtbold common-bgcolor" height="24" align="left" width="97%">';
	else 
		box += '<td style="cursor:move;" class="boxHeader1 whitetxtbold common-bgcolor" height="24" width="97%" onMouseDown="DialogBox.captureDialog(event)" align="left"><img height="14" width="10" class="hideElement"/><div class="flLeft drag-icon"></div>';
	
	if (titleProp!="") {
		if (titleProp.charAt(0) == "'" && titleProp.charAt(titleProp.length-1)=="'") 
			titleProp = titleProp.substr(1, titleProp.length - 2);
		if (titleProp.trim().length == 0) 
			titleProp = "&nbsp;";//NO I18N
	} else 
		titleProp = "&nbsp;";//NO I18N

	var dialogTitleId = "dialogTitle"+"_"+this.dialogId;	//NO I18N
	box += '<span id="'+dialogTitleId+'" class="drag1 flLeft">'+titleProp + '</span></td><td class="boxHeader1 common-bgcolor" height="24" align="right" style="padding-right:4px;">';
	
	
	if(closeButtonProp=="no") 
		box += '&nbsp;</td>';
	else 
		box += '<input type="button" class="divCloseBtn" onClick="DialogBox.closeDialog();" style="border-width: 0px;"></td>';	
	
	box += '</tr><tr><td colspan="4" class="boxContent">' + content + '</td></tr>';
	box+='</table>';
	
	this.oDialog.style.display = "block";
	var showInBox = true;
	if (titleProp=="&nbsp;" && closeButtonProp=="no") 
		showInBox = false;

	if (showInBox) 
		this.oDialog.innerHTML = "<table cellpadding='0' cellspacing='0'><tr><td height='100%' style='display:;'>" + box + "</td></tr></table>";	
	else
		this.oDialog.innerHTML = "<table cellpadding='0' cellspacing='0'><tr><td height='100%' style='display:;'>" + content + "</td></tr></table>";	

	this.oDialog.style.position = "absolute";
	this.oDialog.style.left = "-1000px";
	this.oDialog.style.top = "-1000px";
	this.oDialog.style.zIndex = 100000 + this.dialogId + '';

	var scriptTags = this.oDialog.getElementsByTagName("SCRIPT");
	for (var i = 0; i < scriptTags.length; i++) {
		var scriptTag = document.createElement("SCRIPT");
		scriptTag.type = "text/javascript";
		scriptTag.language = "javascript";
		if (scriptTags[i].src != "") { scriptTag.src = scriptTags[i].src;}
		scriptTag.text = scriptTags[i].text;
		
		if (typeof document.getElementsByTagName("HEAD")[0] == "undefined") {
			document.createElement("HEAD").appendChild(scriptTag)
		} else {
			document.getElementsByTagName("HEAD")[0].appendChild(scriptTag);
		}			
	}

	if (browser_opera) {
		var temp = content;
		var styleTags = this.oDialog.getElementsByTagName("STYLE");
		for (var i = 0; i < styleTags.length; i++) {
			styleTags[i].innerHTML = temp.substring(temp.indexOf("<style>") + 7, temp.indexOf("</style>") - 1);
			temp = temp.substring(temp.indexOf("</style>") + 8, temp.length);
		}
	}

	
	if (widthProp!="") {
		if(browser_ie)	
			this.oDialog.childNodes[0].style.width = parseInt(widthProp) + "px";
		else if (browser_nn4 || browser_nn6) 
			this.oDialog.childNodes.item(0).style.width = parseInt(widthProp) + "px";
	}
	
	
	if (heightProp!="") {
		if (browser_ie) 
			this.oDialog.childNodes[0].style.height = parseInt(heightProp) + "px";
		else if (browser_nn4 || browser_nn6) 
			this.oDialog.childNodes.item(0).style.height = parseInt(heightProp) + "px";
	}

	oDialogContent = getObj("_DIALOG_CONTENT"+"_"+this.dialogId);
	
	this.dialogContentEl = oDialogContent;
	
	if (isContentDOMElement) 
		oDialogContent.appendChild(contentElement);
	
	var left = 0, top = 0;

	if (browser_opera) {
		if (widthProp!="") {
			oDialogContent.style.width = parseInt(widthProp) + "px";
		} else {
			oDialogContent.style.width = oDialogContent.offsetWidth + "px";
			this.oDialog.style.width = oDialogContent.offsetWidth + "px";
		}
	}

	if (browser_nn4 || browser_nn6) {
		if (widthProp != "undefined") 
			oDialogContent.style.width = parseInt(widthProp) + "px";
		else 
			oDialogContent.style.width = (oDialogContent.offsetWidth + 20) + "px";
	}

	if (heightProp!="") {
		if (browser_ie && (parseInt(heightProp) < oDialogContent.offsetHeight)) left = -15;
		oDialogContent.style.height = parseInt(heightProp) + "px";
    }
	
    oDialogContent.style.overflow = "auto";

	var width = this.oDialog.offsetWidth;
	var height = this.oDialog.offsetHeight;
	this.doc = findDocDim();
	
	
	if (closeOnEscKeyProp=="no") 
		this.closeOnEscKey = false;
	else 
		this.closeOnEscKey = true;
	
	
	if (closeOnBodyClickProp=="yes") 
		this.closeOnBodyClick = true;
	else 
		this.closeOnBodyClick = false;

	if (!browser_opera) {
		if (modalProp=="yes") {
			this.freezeBackground();
		} else if (document.getElementById("FreezeLayer_"+this.dialogId) != null) 
			document.body.removeChild(document.getElementById("FreezeLayer_"+this.dialogId));	
	}

		
	if (leftProp!="")
		left += parseInt(leftProp);
	if (topProp!="") 
		top += parseInt(topProp);
	
	var scrlBarWd = (document.body.scrollLeft > 0) ? 15 : 0;
	var scrlBarHt = (document.body.scrollTop > 0) ? 15 : 0;

		
	if (positionProp=="relative") {
		if(srcElementProp!="") 
			this.srcEl = getObj(srcElementProp);
		else if (this.srcEl == null) 
			this.srcEl = document.body;
		
		var srcElWidth = (this.srcEl.offsetWidth) ? this.srcEl.offsetWidth : 0;
		var srcElHeight = (this.srcEl.offsetHeight) ? this.srcEl.offsetHeight : 0;
				
		if (findPosX(this.srcEl) + width > this.doc.width - scrlBarWd) left += findPosX(this.srcEl) + srcElWidth - width;
		else left += findPosX(this.srcEl);					
		
		if (findPosY(this.srcEl) + srcElHeight + height > this.doc.height - scrlBarHt) top += findPosY(this.srcEl) - height;
		else top += findPosY(this.srcEl) + srcElHeight + 2;
	} else if (positionProp=="current") {	//NO I18N
		if (cursor_leftProp != null && cursor_topProp != null) {
			left = cursor_leftProp;
			top = cursor_topProp;
		} else 
			left = top = 0;
		
		left = (cursor_leftProp != null) ? cursor_leftProp : 0;
		top = (cursor_topProp != null) ? cursor_topProp : 0;
		
		if (left + width > this.doc.width - scrlBarWd) left -= width;		
		if (top + height > this.doc.height - scrlBarHt) top -= height;
	} else if (positionProp=="absolute") {//NO I18N
		if (leftProp=="" || leftProp=="absmiddle") 
			left = (this.doc.width / 2 ) - (width / 2) + document.body.scrollLeft;
		if (topProp=="" || topProp=="absmiddle") 
			top = (this.doc.height / 2) - (height / 2) + document.body.scrollTop;
		
		left += document.body.scrollLeft;
		top += document.body.scrollTop;
	} else {
		left = (this.doc.width / 2 ) - (width / 2) + document.body.scrollLeft + left;
		top = (this.doc.height / 2) - (height / 2) + document.body.scrollTop + top;		
	}
	
	left = (left > 0) ? left : 0;
	top = (top > 0) ? top : 0;

		
	if (transitionTypeProp!="") {
		if (transitionIntervalProp=="") 
			transitionIntervalProp = 10;	
		Effect.init( 
			{ 
				type : transitionTypeProp, speed : transitionIntervalProp ,
				layerId : "_DIALOG_LAYER"+"_"+this.dialogId, layerTop : top, layerLeft : left//NO I18N
			 } 
		);
		Effect.display();		
	} else {
		this.oDialog.style.left = parseInt(left) + "px";
		this.oDialog.style.top = parseInt(top) + "px";
	}

	if (browser_ie && !browser_opera) {
		this.iframeIEHack = document.createElement("IFRAME");
		this.iframeIEHack.scrolling = "no";
		this.iframeIEHack.frameBorder = 0;
                if(window["CONTEXT_PATH"] != null)
                {
                   this.iframeIEHack.src= CONTEXT_PATH + "/framework/html/blank.html";
                }
		this.iframeIEHack.style.position = "absolute";
		this.iframeIEHack.style.zIndex = 99998 + this.dialogId + '';
		this.iframeIEHack.style.filter = 'progid:DXImageTransform.Microsoft.Alpha(style=0,opacity=0)';
		
		if (modalProp=="yes") {
			this.iframeIEHack.style.width = document.getElementById("FreezeLayer_"+this.dialogId).style.width;
			this.iframeIEHack.style.top = "0px";
			this.iframeIEHack.style.left = "0px";
		} else { 
			this.iframeIEHack.style.width = this.oDialog.offsetWidth + "px";
			this.iframeIEHack.style.height = this.oDialog.offsetHeight + "px";
			this.iframeIEHack.style.top = parseInt(top) + "px";
			this.iframeIEHack.style.left = parseInt(left) + "px";
		}
		
		document.body.appendChild(this.iframeIEHack);
	}
	

	
	if (!browser_opera) {
		if (modalProp=="yes") {
			document.getElementById("FreezeLayer_"+this.dialogId).style.height = (document.body.scrollHeight) + "px";	
			if (browser_ie) this.iframeIEHack.style.height = document.getElementById("FreezeLayer_"+this.dialogId).style.height;	
		}
	}
	
	if (typeof callBackFunc != "undefined" && callBackFunc != null && callBackFunc != "") callBackFunc();

	return this.oDialog;
}

DialogBox.prototype.showFTDialog = function(content, features, callBackFunc, closeCallBackFunc) {

	this.initDialogProperties(features);

	/*** Intializing the Popup property values starts ***/
	var classNameProp = this.dialogProperties["className"];
	var draggableProp = this.dialogProperties["draggable"];
	var titleProp = this.dialogProperties["title"];
	var closeButtonProp = this.dialogProperties["divCloseBtn"];
	var widthProp = this.dialogProperties["width"];
	var heightProp = this.dialogProperties["height"];
	var closeOnEscKeyProp = this.dialogProperties["closeOnEscKey"];
	var closeOnBodyClickProp = this.dialogProperties["closeOnBodyClick"];
	var modalProp = this.dialogProperties["modal"];
	var leftProp = this.dialogProperties["left"];	
	var topProp = this.dialogProperties["top"];
	var positionProp = this.dialogProperties["position"];	
	var srcElementProp = this.dialogProperties["srcElement"];	
	var cursor_leftProp = this.dialogProperties["cursor_left"];	
	var cursor_topProp = this.dialogProperties["cursor_top"];
	var transitionTypeProp = this.dialogProperties["transitionType"];	
	var transitionIntervalProp = this.dialogProperties["transitionInterval"];
	/*** Intializing the Popup property values ends ***/
	
	this.oDialog = document.createElement("DIV");
	this.oDialog.id = "_DIALOG_LAYER"+"_"+this.dialogId;
	
	if(classNameProp != "" && classNameProp == "no") 
	{
		this.oDialog.className="";
	}
	else 
	{
		this.oDialog.className = "modal modal-show1 flatTheme";		
	}
	document.body.appendChild(this.oDialog);
	
	this.dialogEl = this.oDialog;
	
	if (typeof closeCallBackFunc != "undefined" && closeCallBackFunc != null) this.onCloseCallBack = closeCallBackFunc;
	
	var isContentDOMElement = ((typeof content) != "string");//NO I18N
	var contentElement = content;
	var dialogContentDivId = '_DIALOG_CONTENT'+'_'+this.dialogId;	//NO I18N
	content = '<div id="'+dialogContentDivId+'">' + ((isContentDOMElement) ? "" : content) + '</div>';

	var box = '<div class="modal-content">';

	// Select Atleast one ou/group alert
	box += '<div id="status-areaougroup" class="mini-status-alert status-alert status-alert-xs status-alert-danger status-has-parent alert-dismissible" align="center" role="alert">'
	+'<button type="button" id="status-dismissougroup" class="close flatTheme" data-dismiss="alert" aria-label="Close" onclick="this.parentElement.style.display=\'none\';"><span aria-hidden="true" style="font-size:11px;">&#x2716;</span></button>'
	+'<i id="status-iconougroup" class="ssp-inline-icon icn-cross"></i>'
	+'<span class="text-sm" id="status-messageougroup" style="text-align: center;"></span></div>';

	if(draggableProp == "no")
	{
		box += '<div class="modal-header">';
	}	
	else
	{
		box += '<div class="modal-header">';
	}

	if (titleProp != "") 
	{
		if (titleProp.charAt(0) == "'" && titleProp.charAt(titleProp.length-1) == "'") 
			titleProp = titleProp.substr(1, titleProp.length - 2);
		if (titleProp.trim().length == 0) 
			titleProp = "&nbsp;";//NO I18N
	} 
	else
		titleProp = "&nbsp;";//NO I18N
	
	if(closeButtonProp == "no") 
	{
		box += '&nbsp;</td>';
	}
	else 
	{
		box += '<button type="button" class="close flatTheme" data-dismiss="modal" onclick="DialogBox.closeDialog()" aria-lable="Close"><span aria-hidden="true" style="font-size:11px;">&#x2716;</span></button>';		
	}

	box += '<div id="summaryBackBtn_'+ this.dialogId +'" class="pull-right ssp-pr-10 ssp-mr-7 ssp-mt-2"><div class="arrow-btn back-to-list hide" onclick="SummaryView.showPrevUI();">'+
		'<div class="arrow"></div>Back</div></div>';

	var dialogTitleId = "dialogTitle"+"_"+this.dialogId;	//NO I18N
	box += '<h4 id="' + dialogTitleId + '" class="modal-title flatTheme">' + titleProp + '</h4></div>';

	box += '<div class="modal-body modal-body-sm">' + content + '</div>';

	this.oDialog.style.display = "block";
	var showInBox = true;
	if (titleProp == "&nbsp;" && closeButtonProp=="no") 
		showInBox = false;

	if (showInBox) 
		this.oDialog.innerHTML = "<div class='modal-dialog modal-size-md '>" + box + "</div>";
	else
		this.oDialog.innerHTML = "<div class='modal-dialog modal-size-md '>" + content + "</div>";

	this.oDialog.style.zIndex = 100000 + this.dialogId + '';

	var scriptTags = this.oDialog.getElementsByTagName("SCRIPT");
	for (var i = 0; i < scriptTags.length; i++) {
		var scriptTag = document.createElement("SCRIPT");
		scriptTag.type = "text/javascript";
		scriptTag.language = "javascript";
		if (scriptTags[i].src != "") { scriptTag.src = scriptTags[i].src;}
		scriptTag.text = scriptTags[i].text;
		
		if (typeof document.getElementsByTagName("HEAD")[0] == "undefined") {
			document.createElement("HEAD").appendChild(scriptTag)
		} else {
			document.getElementsByTagName("HEAD")[0].appendChild(scriptTag);
		}			
	}

	if (browser_opera) {
		var temp = content;
		var styleTags = this.oDialog.getElementsByTagName("STYLE");
		for (var i = 0; i < styleTags.length; i++) {
			styleTags[i].innerHTML = temp.substring(temp.indexOf("<style>") + 7, temp.indexOf("</style>") - 1);
			temp = temp.substring(temp.indexOf("</style>") + 8, temp.length);
		}
	}

	
	if (widthProp!="") {
		if(browser_ie)	
			this.oDialog.childNodes[0].style.width = parseInt(widthProp) + "px";
		else if (browser_nn4 || browser_nn6) 
			this.oDialog.childNodes.item(0).style.width = parseInt(widthProp) + "px";
	}
	
	
	if (heightProp!="") {
		if (browser_ie) 
			this.oDialog.childNodes[0].style.height = parseInt(heightProp) + "px";
		else if (browser_nn4 || browser_nn6) 
			this.oDialog.childNodes.item(0).style.height = parseInt(heightProp) + "px";
	}

	oDialogContent = getObj("_DIALOG_CONTENT"+"_"+this.dialogId);
	
	this.dialogContentEl = oDialogContent;
	
	if (isContentDOMElement) 
		oDialogContent.appendChild(contentElement);
	
	var left = 0, top = 0;

	if (browser_opera) {
		if (widthProp!="") {
			oDialogContent.style.width = parseInt(widthProp) + "px";
		} else {
			oDialogContent.style.width = oDialogContent.offsetWidth + "px";
			this.oDialog.style.width = oDialogContent.offsetWidth + "px";
		}
	}

	if (browser_nn4 || browser_nn6) {
		if (widthProp != "undefined") 
			oDialogContent.style.width = parseInt(widthProp) + "px";
		else 
			oDialogContent.style.width = (oDialogContent.offsetWidth + 20) + "px";
	}

	if (heightProp!="") {
		if (browser_ie && (parseInt(heightProp) < oDialogContent.offsetHeight)) left = -15;
		oDialogContent.style.height = parseInt(heightProp) + "px";
    }
	
	oDialogContent.style.overflow = "auto";
	
	document.body.style.overflow = "hidden";// Locking body scroll

	var width = this.oDialog.offsetWidth;
	var height = this.oDialog.offsetHeight;
	this.doc = findDocDim();
	
	
	if (closeOnEscKeyProp == "no") 
		this.closeOnEscKey = false;
	else 
		this.closeOnEscKey = true;
	
	
	if (closeOnBodyClickProp=="yes") 
		this.closeOnBodyClick = true;
	else 
		this.closeOnBodyClick = false;

	if (!browser_opera) {
		if (modalProp=="yes") {
			this.freezeBackground();
		} else if (document.getElementById("FreezeLayer_"+this.dialogId) != null) 
			document.body.removeChild(document.getElementById("FreezeLayer_"+this.dialogId));	
	}

		
	if (leftProp!="")
		left += parseInt(leftProp);
	if (topProp!="") 
		top += parseInt(topProp);
	
	var scrlBarWd = (document.body.scrollLeft > 0) ? 15 : 0;
	var scrlBarHt = (document.body.scrollTop > 0) ? 15 : 0;

		
	if (positionProp=="relative") {
		if(srcElementProp!="") 
			this.srcEl = getObj(srcElementProp);
		else if (this.srcEl == null) 
			this.srcEl = document.body;
		
		var srcElWidth = (this.srcEl.offsetWidth) ? this.srcEl.offsetWidth : 0;
		var srcElHeight = (this.srcEl.offsetHeight) ? this.srcEl.offsetHeight : 0;
				
		if (findPosX(this.srcEl) + width > this.doc.width - scrlBarWd) left += findPosX(this.srcEl) + srcElWidth - width;
		else left += findPosX(this.srcEl);					
		
		if (findPosY(this.srcEl) + srcElHeight + height > this.doc.height - scrlBarHt) top += findPosY(this.srcEl) - height;
		else top += findPosY(this.srcEl) + srcElHeight + 2;
	} else if (positionProp=="current") {	//NO I18N
		if (cursor_leftProp != null && cursor_topProp != null) {
			left = cursor_leftProp;
			top = cursor_topProp;
		} else 
			left = top = 0;
		
		left = (cursor_leftProp != null) ? cursor_leftProp : 0;
		top = (cursor_topProp != null) ? cursor_topProp : 0;
		
		if (left + width > this.doc.width - scrlBarWd) left -= width;		
		if (top + height > this.doc.height - scrlBarHt) top -= height;
	} else if (positionProp=="absolute") {//NO I18N
		if (leftProp=="" || leftProp=="absmiddle") 
			left = (this.doc.width / 2 ) - (width / 2) + document.body.scrollLeft;
		if (topProp=="" || topProp=="absmiddle") 
			top = (this.doc.height / 2) - (height / 2) + document.body.scrollTop;
		
		left += document.body.scrollLeft;
		top += document.body.scrollTop;
	} else {
		left = (this.doc.width / 2 ) - (width / 2) + document.body.scrollLeft + left;
		top = (this.doc.height / 2) - (height / 2) + document.body.scrollTop + top;		
	}
	
	left = (left > 0) ? left : 0;
	//top = (top > 0) ? top : 0;
	top = 0; //Modal should always be on top in flatTheme

		
	if (transitionTypeProp!="") {
		if (transitionIntervalProp=="") 
			transitionIntervalProp = 10;	
		Effect.init( 
			{ 
				type : transitionTypeProp, speed : transitionIntervalProp ,
				layerId : "_DIALOG_LAYER"+"_"+this.dialogId, layerTop : top, layerLeft : left//NO I18N
			 } 
		);
		Effect.display();		
	} 
	else {
		this.oDialog.style.left = parseInt(left) + "px";
		this.oDialog.style.top = parseInt(top) + "px";
	}

	if (browser_ie && !browser_opera) {
		this.iframeIEHack = document.createElement("IFRAME");
		this.iframeIEHack.scrolling = "no";
		this.iframeIEHack.frameBorder = 0;
        if(window["CONTEXT_PATH"] != null)
		{
			this.iframeIEHack.src= CONTEXT_PATH + "/framework/html/blank.html";
		}
		this.iframeIEHack.style.position = "absolute";
		this.iframeIEHack.style.zIndex = 99998 + this.dialogId + '';
		this.iframeIEHack.style.filter = 'progid:DXImageTransform.Microsoft.Alpha(style=0,opacity=0)';
		
		if (modalProp=="yes") {
			this.iframeIEHack.style.width = document.getElementById("FreezeLayer_"+this.dialogId).style.width;
			this.iframeIEHack.style.top = "0px";
			this.iframeIEHack.style.left = "0px";
		} else { 
			this.iframeIEHack.style.width = this.oDialog.offsetWidth + "px";
			this.iframeIEHack.style.height = this.oDialog.offsetHeight + "px";
			this.iframeIEHack.style.top = parseInt(top) + "px";
			this.iframeIEHack.style.left = parseInt(left) + "px";
		}
		
		document.body.appendChild(this.iframeIEHack);
	}
	

	
	if (!browser_opera) {
		if (modalProp=="yes") {
			document.getElementById("FreezeLayer_"+this.dialogId).style.height = (document.body.scrollHeight) + "px";	
			if (browser_ie) this.iframeIEHack.style.height = document.getElementById("FreezeLayer_"+this.dialogId).style.height;	
		}
	}
	
	if (typeof callBackFunc != "undefined" && callBackFunc != null && callBackFunc != "") callBackFunc();

	return this.oDialog;
}

DialogBox.prototype.freezeBackground = function() {
	var freezeLayerBGColorProp = this.dialogProperties["freezeLayerBGColor"];
	var freezeLayerOpacityProp = this.dialogProperties["freezeLayerOpacity"];
	
	var oFreezeLayer = document.createElement("DIV");
	oFreezeLayer.id = "FreezeLayer_"+this.dialogId;
	oFreezeLayer.className = "freezeLayer";
	oFreezeLayer.style.width = "100%";
	oFreezeLayer.style.zIndex = 99999 + this.dialogId + '';
	
	if (freezeLayerBGColorProp!="") 
		oFreezeLayer.style.backgroundColor = freezeLayerBGColorProp;
	
	if (freezeLayerOpacityProp!="") {
		var opacity = (freezeLayerOpacityProp.indexOf("%") < 0) ? freezeLayerOpacityProp : freezeLayerOpacityProp.substr(0, freezeLayerOpacityProp.length - 1);
		if (browser_ie) oFreezeLayer.style.filter = "alpha(opacity=" + opacity +")";
		else oFreezeLayer.style.opacity = opacity / 100;
	}

	  if( typeof( window.innerHeight ) == 'number' )
	  {
	  	if(window.innerHeight>document.body.offsetHeight)
	  	{
	    		myHeight = window.innerHeight;
	    	}
	    	else
	    	{
	    		myHeight = document.body.offsetHeight;
	    	}
	  }
	  else if( document.documentElement && document.documentElement.clientHeight  )
	  {
	    //IE 6+ in 'standards compliant mode'
	    	if(document.documentElement.clientHeight>document.body.offsetHeight)
	    	{
	    	    	myHeight = document.documentElement.clientHeight;
	    	}
	   	else
	   	{
	    		myHeight = document.body.offsetHeight;
	    	}

	  }
	  else if( document.body && document.body.clientHeight)
	  {
	    //IE 4 compatible
	    	if(document.body.clientHeight>document.body.offsetHeight)
	    	{
	    	    	myHeight = document.body.clientHeight;
	    	}
	    	else
	    	{
	    	    	myHeight = document.body.offsetHeight;
	    	}


  	 }
	oFreezeLayer.style.height = myHeight+"px";

	document.body.appendChild(oFreezeLayer);
}

/* The current Dialog can be only captured
 */
DialogBox.captureDialog = function(ev) {
	var dialogBox = DialogBoxGroup.dialogBoxArray[DialogBoxGroup.dialogBoxArray.length-1];
	dialogBox.captureDialog(ev);
}

DialogBox.prototype.captureDialog = function(ev) {
	this.oDialog.style.cursor = "move";
	
	if (browser_ie) {
		diffLeft = window.event.clientX + document.body.scrollLeft - parseInt(findPosX(this.oDialog));
		diffTop = window.event.clientY + document.body.scrollTop - parseInt(findPosY(this.oDialog));
	} else if (browser_nn4 || browser_nn6) {
		diffLeft = ev.pageX - parseInt(findPosX(this.oDialog));
		diffTop = ev.pageY - parseInt(findPosY(this.oDialog));
	}
	
	capturedDialogId = this.dialogId;
	capturedoDialog = this.oDialog;
	captuedIframeIEHack = this.iframeIEHack;

	document.onmousemove = DialogBox.moveDialog;	
	document.onmouseup = DialogBox.releaseDialog;
}

DialogBox.moveDialog = function(ev) {	
	clearTextSelection();

	if (browser_ie) {

		var left = window.event.clientX + document.body.scrollLeft - diffLeft;
		var top = window.event.clientY + document.body.scrollTop - diffTop;
		
		left = (left >= 0) ? left : 0;
		top = (top >= 0) ? top : 0;
	
		if(document.getElementById("FreezeLayer_"+capturedDialogId) != null || browser_opera) {
			capturedoDialog.style.left = left + "px";
			capturedoDialog.style.top = top + "px";
		} else {
			capturedoDialog.style.left = captuedIframeIEHack.style.left = left + "px";
			capturedoDialog.style.top = captuedIframeIEHack.style.top = top + "px";
		}
	} else if(browser_nn4 || browser_nn6) {
		capturedoDialog.style.left = ((ev.pageX - diffLeft > 0) ? ev.pageX - diffLeft : 0) + "px";
		capturedoDialog.style.top = ((ev.pageY - diffTop > 0) ? ev.pageY - diffTop : 0) + "px";	
	}
}

DialogBox.releaseDialog = function() {
	capturedoDialog.style.cursor = "default";
	document.onmousemove = null;
	document.onmouseup = null;
}

DialogBox.showDialog = function(content, features, callBackFunc, closeCallBackFunc) {
	var dialogBox = new DialogBox();
	dialogBox.dialogId = DialogBoxGroup.dialogBoxArray.length;
	DialogBoxGroup.dialogBoxArray.push(dialogBox);

	dialogBox.showDialog(content, features, callBackFunc, closeCallBackFunc);
}

/**
 * Used to show the contents of the url in a dialog.
 * @param sURL		Mandatory. String that specifies the URL to display.
 * @param Features	Optional. Sames as mentioned in showDialog() function
 * <h3>Example:</h3>
 *  showURLInDialog( "InstantFeedback.cc", "position=relative" );	
 */

DialogBox.showURLInDialog = function (url, features, callBackFunc, closeCallBackFunc) {
  	callBack = function(xmlhttp) {
		var oDialog = DialogBox.showDialog(xmlhttp.responseText, features, callBackFunc, closeCallBackFunc);
	}	
  AjaxAPI.sendRequest({METHOD:"GET",URL:url,ONSUCCESSFUNC:callBack});//NO I18N
}

DialogBox.setPopupTitle = function(titleStr) {
	var dialogBox = DialogBoxGroup.dialogBoxArray[DialogBoxGroup.dialogBoxArray.length-1];
	adsjQuery('#dialogTitle_'+dialogBox.dialogId).text(titleStr);	//NO I18N
}

DialogBox.closeDialog = function() {
	var dialogBox = DialogBoxGroup.dialogBoxArray[DialogBoxGroup.dialogBoxArray.length-1];
	dialogBox.closeDialog();
}

DialogBox.prototype.closeDialog = function() {
	if (this.oDialog!=null && this.oDialog.style.display != "none") {
		this.oDialog.style.display = "none";
		
		if (document.getElementById("FreezeLayer_"+this.dialogId) != null) 
			document.body.removeChild(document.getElementById("FreezeLayer_"+this.dialogId));

		if (browser_ie && !browser_opera) {
			document.body.removeChild(this.iframeIEHack);
		}
		
		if (typeof this.onCloseCallBack != "undefined" && this.onCloseCallBack != null)
			this.onCloseCallBack();
		
		document.body.removeChild(this.oDialog);
	}

	if(popup!=undefined && popup.isFlatTheme)
	{
		document.body.style.overflow = 'auto';
	}

	// Removing the Dialog Object from DialogBoxGroup
	DialogBoxGroup.deleteDialogBox(this.dialogId);
}

/* There is a chance for loading 'Dialog.js' & 'ADSDialog.js'.. 
 * 'document.onkeydown' fn defn is available in these two JS.
 * Whatever the fn is called, depends the situation, we need to decide.
 * That is, If 'DialogBoxGroup.dialogBoxArray.length>0', dialog thorugh ADSDIalog is called... Else dialog through DIalog.js is called..
 *
 *
 * It is for , while pressing 'Esc' key
 *  Key code = 27 --> 'Esc' key..
 *  The last DialogBox only can be closed.
 */ 
document.onkeydown = function(ev) {
	if(typeof DialogBoxGroup !='undefined' && DialogBoxGroup.dialogBoxArray.length>0)
		closeADSDialogOnEscKey(ev);
	else if(typeof closeDialogOnEscKey != 'undefined')	
		closeDialogOnEscKey(ev);
}

function closeADSDialogOnEscKey(ev) {
	var keyCode = undefined;
	if (browser_ie) 
		keyCode = window.event.keyCode;
	else if (browser_nn4 || browser_nn6) 
		keyCode = ev.which;
	
	var dialogBox = DialogBoxGroup.dialogBoxArray[DialogBoxGroup.dialogBoxArray.length-1];
	
	if (keyCode && keyCode==27 && dialogBox && dialogBox.closeOnEscKey==true && dialogBox.oDialog!=null && dialogBox.oDialog.style.display!="none") 
		dialogBox.closeDialog();
}

/* There is a chance for loading 'Dialog.js' & 'ADSDialog.js'.. 
 * 'document.onmousedown' fn defn is available in these two JS.
 * Whatever the fn is called, depends the situation, we need to decide.
 * That is, If 'DialogBoxGroup.dialogBoxArray.length>0', dialog thorugh ADSDIalog is called... Else dialog through DIalog.js is called..
 *
 *
 * It is for , while pressing outside of the 'Dialog Box'
 *  The last DialogBox only can be closed.
 */ 
document.onmousedown = function(ev) {
	if(typeof DialogBoxGroup !='undefined' && DialogBoxGroup.dialogBoxArray.length>0)
		closeADSDialogOnMouseDown(ev);
	else if(typeof closeDialogOnMouseDown != 'undefined')	
		closeDialogOnMouseDown(ev);
}

function closeADSDialogOnMouseDown(ev) {
	var cursorPos = getCursorPos(ev);
	var x = cursorPos.x;
	var y = cursorPos.y;
	
	var dialogBox = DialogBoxGroup.dialogBoxArray[DialogBoxGroup.dialogBoxArray.length-1];
	if ( dialogBox && dialogBox.closeOnBodyClick==true && dialogBox.oDialog!=null && dialogBox.oDialog.style.visibility!="hidden") {
		if ((x < findPosX(dialogBox.oDialog) || x >= findPosX(dialogBox.oDialog) + dialogBox.oDialog.offsetWidth) || (y < findPosY(dialogBox.oDialog) || y >= findPosY(dialogBox.oDialog) + dialogBox.oDialog.offsetHeight))
			dialogBox.closeDialog();
	}
}



