//$Id: EditorAction.js,v 1.8 2018/12/24 13:47:28 jagadesh.manickamurthy Exp $
//ignorei18n_start

/*global ZE*/
ZE.create = function ( initobj ) {
  "use strict";
  return new ZE(initobj);
};

ZE.prototype.execCommand = function ( ev, command ) {

  "use strict";
  var editor = this,
  elem,
  ty,
  oldTempContent = editor.getContent();

  editor._stopEvent(ev);
  switch (command) {
    case 'forecolor'://No I18N
    case 'backcolor'://No I18N
    case 'fontfamily'://No I18N
    case 'fontsize'://No I18N
      editor.showDropDown(ev,command);
      break;
    case 'alignoptions':		//No I18N
      editor.showDropDown(ev,command, 'align');		//No I18N
      break;
    case 'listoptions':		//No I18N
      editor.showDropDown(ev, command, 'list');		//No I18N
      break;
    case 'directionoptions':    //No I18N
      editor.showDropDown(ev, command, 'textDir');
      break;
    case 'indentoptions':		//No I18N
      editor.showDropDown(ev, command, 'indent');			//No I18N
      break;
    case 'otheroptions'://No I18N
      editor.showDropDown(ev, command, 'others');		//No I18N
      break;
    case 'heading'://No I18N
      editor.createHeadingDiv(ev);
      break;
    case 'smiley'://No I18N
      editor.showDropDown(ev,command);
      break;
    case 'link'://No I18N
      editor.createLink();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
      case 'tableGrid':
      editor._createTableGrid(ev,command);
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'image'://No I18N
      editor.createImage();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'table'://No I18N
      editor.createTable();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'save'://No I18N
      if (editor.initobj.saveContent) {
        var _doc = editor.doc;
        var editor_content = '<html><head>' + _doc.getElementsByTagName('head')[0].innerHTML + '</head><body>' + _doc.body.innerHTML + '</body></html>';//No I18N
        editor.initobj.saveContent(editor_content);
      }
      break;
    case 'spellcheck'://No I18N
      editor.spellcheck(ev);
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'spellcheckoptions': //No I18N
      editor.spellcheckOptions(ev);
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'insertoptions'://No I18N
      editor.insertOptions(ev);
      break;
    case 'quote'://No I18N
      editor.insertQuote();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'object'://No I18N
      editor.insertObj();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'code'://No I18N
      editor.insertCode();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'edithtml':	//No I18N
      editor.htmlView();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
      break;
    case 'more':			//No I18N
      editor.expandToolbar(ev);
      break;
    case 'attach':		//No I18N
      elem = ev.target || ev.srcElement;

      if (ZE.hasClass(elem,'zei-arrow')) {
        editor.showDropDown(ev,'attach');		//No I18N
      }else {
        if (editor.initobj.id) {
          ZE_Init.attach(editor.initobj.id);
        } else {
          ZE_Init.attach();
        }
      }
      break;
    case 'bold':                         //No I18N
      var currentState = editor.doc.queryCommandState('bold');
      currentState ? editor.squireInstance.removeBold() : editor.squireInstance.bold();
      editor.saveCurrentState();
      editor.updateToolbar();
      break;
    case 'italic':                         //No I18N
      var currentState = editor.doc.queryCommandState('italic');
      currentState ? editor.squireInstance.removeItalic() : editor.squireInstance.italic();
      editor.saveCurrentState();
      editor.updateToolbar();
      break;
    case 'underline':                         //No I18N
      var currentState = editor.doc.queryCommandState('underline');
      currentState ? editor.squireInstance.removeUnderline() : editor.squireInstance.underline();
      editor.saveCurrentState();
      editor.updateToolbar();
      break;
    case 'j-left':                         //No I18N
    case 'j-right':                         //No I18N
    case 'j-center':                         //No I18N
    case 'j-justify':                         //No I18N
      editor.squireInstance.setTextAlignment(command.split('-')[1]);
      editor.saveCurrentState();
      editor.updateToolbar();
      break;
    case 'insertorderedlist':   //No I18N
      editor.insertListOperation('OL');  //No I18N
      editor.saveCurrentState();
      break;
    case 'insertunorderedlist':  //No I18N
      editor.insertListOperation('UL');   //No I18N
      editor.saveCurrentState();
      break;
    case 'insertHTML':
      editor.showInsertHTMLDialog();
      break;
    default:
      var newContent,
      oldContent = editor.getContent();
      editor.win.focus();
      editor.doc.execCommand('command', false, undefined);
      newContent = editor.getContent();
      if (newContent != oldContent) {
        editor.saveCurrentState();
      }
      editor.updateToolbar();
      if (ZE_Init.needEditorStats) {
        editor.updateCount(command);
      }
  }
};

ZE.prototype.insertListOperation = function(command) {
  var editor = this;
  switch (command){
    case 'UL':    //No I18N
      var olparent = editor.getPosFromCursor('OL');
      var ulparent = editor.getPosFromCursor('UL');
      if (olparent == -1 && ulparent == -1) {
        editor.squireInstance.makeUnorderedList();
      } else if (olparent > ulparent) {
        editor.squireInstance.makeUnorderedList();
      } else if (ulparent > olparent) {
        if (olparent > 0 || editor.getPosFromCursor('UL',1) > 0) {
          editor.squireInstance.decreaseListLevel();
        } else {
          editor.squireInstance.removeList();
        }
      }
      editor.updateToolbar();
      break;
    case 'OL':    //No I18N
      var olparent = editor.getPosFromCursor('OL');
      var ulparent = editor.getPosFromCursor('UL');
      if (olparent == -1 && ulparent == -1) {
        editor.squireInstance.makeOrderedList();
      } else if (ulparent > olparent) {
        editor.squireInstance.makeOrderedList();
      } else if (olparent > ulparent) {
        if (ulparent > 0 || editor.getPosFromCursor('OL',1) > 0) {
          editor.squireInstance.decreaseListLevel();
        } else {
          editor.squireInstance.removeList();
        }
      }
      break;
  }
};

/* used to drag the dialog*/
ZE.drag = function(ev, divid) {
  var _document = document,
  _body = _document.body,
  div = _document.getElementById(divid),
  _div_style = div.style,
  dialogposition = ZE.getPos(div),
  xpos = ev.clientX - dialogposition.offsetLeft,
  ypos = ev.clientY - dialogposition.offsetTop,
  maxleft = _body.clientWidth - div.offsetWidth,
  maxtop = Math.max(_body.scrollHeight,_document.documentElement.scrollHeight) - div.offsetHeight;

  _div_style.cursor = 'move';
  _div_style.filter = 'alpha(opacity="90")';
  _div_style.opacity = '0.9';

  _document.onmousemove = function(ev) {
    ev = ev || window.event;
    var _left = ev.clientX - xpos,
    _top = ev.clientY - ypos;

    if (_left >= 0 && _left <= maxleft) {
      _div_style.left = _left + 'px';
    } else if (_left < 0) {
      _div_style.left = '0px';
    } else if (_left > maxleft) {
      _div_style.left = maxleft + 'px';
    }

    if (_top >= 0 && _top <= maxtop) {
      _div_style.top = _top + 'px';
    } else if (_top < 0) {
      _div_style.top = '0px';
    } else if (_top > maxtop) {
      _div_style.top = maxtop + 'px';
    }

    return false;
  };

  _document.onmouseup = function() {
    _div_style.cursor = '';
    _div_style.filter = 'alpha(opacity="100")';
    _div_style.opacity = '1';
    _document.onmousemove = null;
    _document.onmouseup = null;
    return false;
  };
  return false;
};

/*used to set the dialog at the center of the screen*/
ZE.setPosition = function(div, editordiv) {
  var _document = document,
  _body = _document.body,
  _documentElement = _document.documentElement,
  _style = div.style,
              temp;
  if (ZE_Init.is_ie)  //Checking for IE
               {
    temp = (_body.clientHeight - div.offsetHeight) / 3 + Math.max(_body.scrollTop,_document.documentElement.scrollTop);
  } else {
    temp = (Math.min(_body.clientHeight,_documentElement.clientHeight) - div.offsetHeight) / 3 + Math.max(_body.scrollTop,_documentElement.scrollTop);
  }

  if (temp < 0) {
    temp = 10;
  }
  _style.top = temp + 'px';

  temp = (_body.clientWidth - div.offsetWidth) / 3 + ZE.getPos(editordiv).offsetLeft / 2;
  if (temp < 50) {
    temp = 100;
  }
  _style.left = temp + 'px';
};

/* For focussing the editor/textarea only for services team*/
ZE.prototype.focus = function() {
  var editor = this;
  if (editor.mode === 'plaintext') {
    editor._textarea.focus();
  } else {
    editor.win.focus();
  }
};

/*ZE.getPos = function(el)
{
	var r = { offsetLeft: el.offsetLeft, offsetTop: el.offsetTop };
	if (el.offsetParent) {
		var tmp = ZE.getPos(el.offsetParent);
		r.offsetLeft += tmp.offsetLeft;
		r.offsetTop  += tmp.offsetTop;
		if(r.scrollTop) {
		r.offsetTop += r.scrollTop;
		}
	}
	return r;
};  */

ZE.getPos = (function() {

  var docElementRect = {};
  docElementRect.left = 0;
  docElementRect.top = 0;
  if (ZE_Init.is_ie) {
    docElementRect = document.documentElement.getBoundingClientRect(); // IE 7 handling
  }
  return function(e1) {
    var clientRect = e1.getBoundingClientRect(),
    scrollY = window.scrollY || window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop,  //Mulitple browser support
    scrollX = window.scrollX || window.pageXOffset || document.documentElement.scrollLeft || document.body.scrollLeft;

    return {offsetLeft: clientRect.left + scrollX - docElementRect.left, offsetTop: clientRect.top + scrollY - docElementRect.top};
  };
})();

ZE.prototype.updateCount = function(command) {
  var editor = this;
  switch (command) {
    case 'bold':		//No I18N
      command = 'b';		//No I18N
      break;
    case 'italic':		//No I18N
      command = 'i';		//No I18N
      break;
    case 'underline':		//No I18N
      command = 'u';		//No I18N
      break;
    case 'strikethrough':		//No I18N
      command = 'st';		//No I18N
      break;
    case 'justifyleft':		//No I18N
      command = 'jl';		//No I18N
      break;
    case 'justifyright':		//No I18N
      command = 'jr';		//No I18N
      break;
    case 'justifyfull':		//No I18N
      command = 'jf';		//No I18N
      break;
    case 'justifycenter':		//No I18N
      command = 'jc';		//No I18N
      break;
    case 'insertunorderedlist':		//No I18N
      command = 'ul';		//No I18N
      break;
    case 'insertorderedlist':		//No I18N
      command = 'ol';		//No I18N
      break;
    case 'outdent':		//No I18N
      command = 'od';		//No I18N
      break;
    case 'indent':		//No I18N
      command = 'id';		//No I18N
      break;
    case 'removeformat'://No I18N
      //command = 'rf';		//No I18N
      break;
    case 'link':		//No I18N
      command = 'li';		//No I18N
      break;
    case 'unlink':		//No I18N
      command = 'uli';		//No I18N
      break;
    case 'table':		//No I18N
      command = 'ta';		//No I18N
      break;
    case 'inserthorizontalrule':		//No I18N
      command = 'hr';		//No I18N
      break;
    case 'quote':		//No I18N
      command = 'qu';		//No I18N
      break;
    case 'image':		//No I18N
      command = 'img';		//No I18N
      break;
    case 'spellcheck':		//No I18N
      command = 'sp';		//No I18N
      break;
    case 'subscript':		//No I18N
      command = 'ss';		//No I18N
      break;
    case 'superscript':		//No I18N
      command = 'sps';		//No I18N
      break;
    case 'forecolor':		//No I18N
      command = 'fc';		//No I18N
      break;
    case 'hilitecolor':		//No I18N
      command = 'bc';		//No I18N
      break;
    case 'object':		//No I18N
      command = 'ihtm';		//No I18N
      break;
    case 'edithtml':		//No I18N
      command = 'ehtm';		//No I18N
      break;
    case 'code':		//No I18N
      command = 'cod';		//No I18N
      break;
  }
  if (editor.clickCount[command]) {
    editor.clickCount[command] ++;
  } else {
    editor.clickCount[command] = 1;
  }
};

ZE.prototype.resize = function(obj) {
  var editor = this,
  _iframe = editor.iframe,
  _editordiv = editor.editordiv;
  if (obj.height) {
    _editordiv.style.height = obj.height + 'px';
    _iframe.style.height = obj.height + 'px';
  }
  if (obj.width) {
    _editordiv.style.height = obj.height + 'px';
    _iframe.style.height = obj.height + 'px';
  }
};
/* This function will create the freeze layer*/
ZE.prototype.freeze = function()
{
	var _document = document,
	    _body = _document.body,
	    _freeze_div = _document.getElementById("ze_freeze");//for first time it is undefined

	if(_freeze_div)
	{
		var _style = _freeze_div.style;
		_style.height = Math.max(_body.scrollHeight,_document.documentElement.scrollHeight)+"px";
		_style.width = _body.clientWidth+"px";
		_style.display="";
	}
	else
	{
		var _div = _document.createElement("div"),
		    _style = _div.style;
		_div.id = _div.className = "ze_freeze";
		_style.height = Math.max(_body.scrollHeight,_document.documentElement.scrollHeight)+"px";
		_style.width = _body.clientWidth+"px";
		document.body.appendChild(_div);

                window.addEventListener("resize", function(ev)
                {
                        var _document = document,
                            freezeDiv = _document.getElementById("ze_freeze"),
                            freezeDiv_style = freezeDiv.style;
                        if(freezeDiv && freezeDiv_style && freezeDiv_style.display !== "none")
                        {
                                var _body = _document.body;
                                freezeDiv_style.height = Math.max(_body.scrollHeight,_document.documentElement.scrollHeight)+"px";
                                freezeDiv_style.width = _body.clientWidth+"px";
                        }
                }, true);
	}
};

/* This function will hide the freeze layer*/
ZE.prototype.hideFreeze = function()
{
	var _freeze_div = document.getElementById("ze_freeze");//for first time it is undefined
	(_freeze_div) && (_freeze_div.style.display="none");
};

ZE.conDrop=function(options,_editor){
  var I18N = ZE.i18n;
	var divElem, ulElem, liElem, i,optlen=options["list"].length;
	divElem=document.createElement("div");
	divElem.id="ze_dropdown";
	divElem.className="ze_dd shw";
	ulElem=document.createElement("ul");
	if(options["ulClass"]){
		ulElem.className=options["ulClass"];
	}

	attachOnClick = function(_list){
					return function(){
								_list.clk(_editor.initobj.id);
				};
	};
	for(i=0;i<optlen;i++){
		liElem=document.createElement("li");
		if(options["type"]=="fontsize"){
			liElem.setAttribute("data-size",options["list"][i]["datAttr"]);
		}else if(options["type"]=="fontfamily"){						//No I18N
			liElem.style.fontFamily=options["list"][i]["ff"];
		}else if(options["type"]=="colorpicker"){						//No I18N
			liElem.style.backgroundColor=options["list"][i];
		}else if(options["type"]=="align" || options["type"]=="list" || options["type"]=="indent"|| options["type"] == "textDir" || options["type"]=="others"){						//No I18N
			liElem.setAttribute("data-"+options["type"], options["list"][i]["datAttr"]);
		}
		if(options["list"][i]["htm"]){
			if(options["list"][i]["datAttr"] && options["list"][i]["datAttr"]=="switchmode"){
				if(!_editor.initobj.avoidPlainText && ZE_Init.needplaintext){
					if(options["editr"].mode=="richtext"){
						liElem.innerHTML="Plain Text mode";						//No I18N
					}else if(options["editr"].mode=="plaintext"){		//No I18N
						liElem.innerHTML="Rich Text mode";						//No I18N
					}
				}
				else{
					continue;
				}
			}else {

				liElem.innerHTML=I18N(options["list"][i]["htm"]);
			}
		}
		if(options["list"][i]["liClass"]){
			liElem.className=options["list"][i]["liClass"];
		}
		ulElem.appendChild(liElem);
		if(options["list"][i]["clk"]){
			var _list=options.list[i];
			ZE._addEvent(liElem,"click",attachOnClick(_list));    //No I18N
		}

		if(options["type"]=="others"){
			ZE._addEvent(liElem,"mouseover",function(){
				
			});

		}

	}

	divElem.appendChild(ulElem);
	document.body.appendChild(divElem);

};

ZE.prototype.showDropDown = function(ev,command,action) {
	var editor=this,
		_anchorelement=ev.currentTarget,//holds the anchor element;
        _document=document,
        curtoolbarobject,
		_doc=editor.doc,
		ze_dropdowndiv,
        ul_click,
        mouse_down,
        offsets,
        _style,
	    ddoptions,
	    hideDropDown,
	    _target,
	    colors,
	    smileys,
	    selectedRange;


	colors=["#ffffff","#cceeff","#ccccff","#e5ccff","#ffccff","#ffccee","#ffcccc","#ffe5cc","#ffffcc","#ccffcc","#ccffff",		//No I18N
              "#cccccc","#99ccff","#9999ff","#cc99ff","#ff99ff","#ff99cc","#ff9999","#ffcc99","#ffff99","#99ff99","#99ffff",	//No I18N
              "#c0c0c0","#66ccff","#6666ff","#b266ff","#ff66fe","#ff66b2","#ff6666","#ffb266","#feff66","#66ff66","#66feff",	//No I18N
              "#999999","#399cfd","#3333ff","#9933ff","#ff33fe","#ff3398","#ff3333","#ff9933","#feff33","#33ff33","#33feff",	//No I18N
              "#666666","#3399ff","#0000ff","#7700ff","#ff00ee","#ff0077","#ff0000","#ff7f00","#feff00","#00ff00","#00feff",	//No I18N
              "#444444","#0065cc","#0000cc","#6600cc","#cc00cb","#cc00cb","#cc0000","#cc6600","#cbcc00","#00cc00","#00cbcc",	//No I18N
              "#333333","#004c99","#000099","#4B0099","#990098","#99004c","#990000","#994c00","#989900","#009900","#009899",	//No I18N
              "#000000","#003366","#000066","#330066","#660066","#660032","#660000","#663300","#666600","#006600","#006666"];	//No I18N


        smileys=[{"htm":"<i class='ze_smilenew'></i>"},{"htm":"<i class='ze_sad'></i>"},{"htm":"<i class='ze_lol'></i>"},{"htm":"<i class='ze_angry'></i>"},{"htm":"<i class='ze_tongueout'></i>"},{"htm":"<i class='ze_coolnew'></i>"},{"htm":"<i class='ze_winknew'></i>"},{"htm":"<i class='ze_meh'></i>"},{"htm":"<i class='ze_tearofjoy'></i>"}
		,{"htm":"<i class='ze_shocked'></i>"},{"htm":"<i class='ze_loveit'></i>"},{"htm":"<i class='ze_neutral'></i>"},{"htm":"<i class='ze_worried'></i>"},{"htm":"<i class='ze_yummy'></i>"},{"htm":"<i class='ze_sleepy'></i>"},{"htm":"<i class='ze_dizzy'></i>"},
	{"htm":"<i class='ze_sick'></i>"},{"htm":"<i class='ze_injured'></i>"},{"htm":"<i class='ze_idea'></i>"},{"htm":"<i class='ze_doubtful'></i>"},{"htm":"<i class='ze_tensed'></i>"},{"htm":"<i class='ze_searching'></i>"},{"htm":"<i class='ze_anxious'></i>"},
	{"htm":"<i class='ze_lipssealed'></i>"},{"htm":"<i class='ze_halo'></i>"},{"htm":"<i class='ze_like'></i>"},{"htm":"<i class='ze_dislike'></i>"},{"htm":"<i class='ze_claps'></i>"},{"htm":"<i class='ze_yoyo'></i>"},{"htm":"<i class='ze_ontarget'></i>"}];

	curtoolbarobject=editor.toolbarobject[command];

	hideDropDown=function(){
			if(ze_dropdowndiv){
				document.body.removeChild(ze_dropdowndiv);
				ZE.removeClass(curtoolbarobject, "ze_dn");
				if(command!="attach")
				{
						ZE.removeClass(curtoolbarobject, "ze_Sel");
				}
				ZE._removeEvent(_document,"mousedown",mouse_down);		//No I18N
				ZE._removeEvent(_doc,"mousedown",mouse_down);		//No I18N
				ZE._removeEvent(_doc,"keydown",mouse_down);		//No I18N
		}
	};

	mouse_down=function(ev){

		ze_dropdowndiv=document.getElementById("ze_dropdown");
		if(ev){
			_target=ev.target;
			for (; _target !== null && _target !== ze_dropdowndiv; _target = _target.parentNode);
		}
		if(!_target){
			hideDropDown();
		}
	};

	ul_click=function(ev){
		var _target = ev.target;
		if(editor.mode=="richtext"){
			if (selectedRange) {
				editor.win.focus();
  				editor.restoreSelection(selectedRange);
  			}
  		}
		switch(command){

			case "fontfamily":		//No I18N
				editor.win.focus();						//No I18N
				editor.updateFontfamily(_target,curtoolbarobject);
				break;
			case "fontsize":						//No I18N
				editor.win.focus();
				editor.updateFontsize(_target,curtoolbarobject);
				break;
			case "forecolor":						//No I18N
			case "backcolor":		//No I18N
			editor.win.focus();				//No I18N
				editor.updateColor(_target,_anchorelement,command);
				break;
			case "alignoptions":						//No I18N
			case "listoptions":						//No I18N
			case "indentoptions":						//No I18N
			editor.updateFormatoptions(_target,curtoolbarobject,action);
				break;
			case "directionoptions":
				//editor.updateDirectionOptions(_target,curtoolbarobject,action);

				break;
			case "otheroptions":						//No I18N
				editor.updateOtheroptions(_target,action);
				break;
            case "smiley":						//No I18N
                editor.insertSmiley(_target);
                break;
		}

		hideDropDown();
	};

	switch(command){
		case "fontfamily":
    // debugger;   															//No I18N
            ddoptions={"type":command, "list":ZE_Init[command]};						//No I18N
            var _queryCommandFontFamilyValue = editor.doc.queryCommandValue("fontname"),//No I18N
		    _firstFontFamilyValue,
            fontFamilyLiArrayLength = ZE_Init[command].length,
		    count;

            if(_queryCommandFontFamilyValue )
            {
                _firstFontFamilyValue = _queryCommandFontFamilyValue.split(",")[0].toLowerCase();
                for (count = 0; count <  fontFamilyLiArrayLength; count++ )
                {
                    fontFamilyLiObj = ZE_Init[command][count];
                    if(fontFamilyLiObj.ff.split(",")[0].toLowerCase() === _firstFontFamilyValue){
                    //if (fontFamilyLiObj.ff.indexOf(_firstFontFamilyValue)!=-1){
                        fontFamilyLiObj.liClass = "sel";        //No I18N
                    }else{
                        fontFamilyLiObj.liClass = "";
                    }
                }
            }
			break;
		case "fontsize":																//No I18N
			ddoptions={"type":command, "list":ZE_Init[command]};						//No I18N
            var _fontSizeValue = editor.doc.queryCommandValue("fontSize"), i, data_size;//No I18N
		    fontSizeAnchorArray = ZE_Init[command];
		    fontSizeAnchorArrayLength =fontSizeAnchorArray.length;

            if(!_fontSizeValue){
            		_fontSizeValue = editor.getFormattingValues("size");
            }

            if ( _fontSizeValue){
                switch(_fontSizeValue){
                    case "1" :
                    case 1:
                    case "10px":   // to deal with chrome  //No I18N
                        data_size = "1";
                    break;
                    case "2":
                    case 2:
                    case "13px":        //No I18N
                        data_size = "2";
                    break;
                    case "3":
                    case 3:
                    case "16px":        //No I18N
                        data_size = "3";
                    break;

                    case "4":
                    case 4:
                    case "18px":        //No I18N
                        data_size = "4";
                    break;

                    case "5":
                    case 5:
                    case "24px":        //No I18N
                        data_size = "5";
                    break;

                    case "6":
                    case 6:
                    case "32px":        //No I18N
                        data_size = "6";
                    break;

                    case "7":
                    case 7:
                    case "48px":        //No I18N
                        data_size = "7";
                    break;

                }
                for( i=0; i < fontSizeAnchorArrayLength; i++){
                    if ( fontSizeAnchorArray[i].datAttr === data_size){
                        fontSizeAnchorArray[i].liClass = "sel";
                    }else{
                        fontSizeAnchorArray[i].liClass = "";
                    }
                }
            }
            else{
            	for( i=0; i < fontSizeAnchorArrayLength; i++){
                        fontSizeAnchorArray[i].liClass = "";
                }
            }
			break;
		case "forecolor":																//No I18N
		case "backcolor":																//No I18N
			ddoptions={"type":"colorpicker", "ulClass":"ze_cb",	"list":colors};		//No I18N
			break;
		case "smiley":																//No I18N
			ddoptions={"type":command, "ulClass":"ze_sb", "list":smileys};			//No I18N
			break;
		case "otheroptions":																//No I18N
			ddoptions={"type":action, "list":ZE_Init[action], "editr":editor};		//No I18N
			ddoptions["ulClass"]="ze_ddr";											//No I18N
			break;
		case "alignoptions":																//No I18N
		case "listoptions":																//No I18N
		case "indentoptions":
				if(action==="indent"){
					var Ok=function(){
						// alert("from Ok button");
					}
					var Cancel=function(){
						// alert("from cancel button");
					}
					//var centerDom='<form><table><tr><td><input type="text" value="2" size="2"></td></tr><tr><td><input type="text" value="12" size="2"></td></tr></table></form>';

					var _form=document.createElement("form");
					var _table=document.createElement("table");
					var _tr=document.createElement("tr");
					var _td=document.createElement("td");
					var _input=document.createElement("input");
					_input.type="text";
					_input.value="2";
					_input.size="2";
					_td.appendChild(_input);
					_tr.appendChild(_td);
					_table.appendChild(_tr);
					var _tr1=document.createElement("tr");
					var _td1=document.createElement("td");
					var _input1=document.createElement("input");
					_input1.type="text";
					_input1.value="2";
					_input1.size="2";
					_td1.appendChild(_input1);
					_tr1.appendChild(_td1);
					_table.appendChild(_tr1);
					_form.appendChild(_table);
					var tests=_form;
					

				var test=	editor.createDialog({headerTitle:"TestDialogBox",centerHTML:tests,isMask:true,onOk:Ok,onCancel:Cancel});																//No I18N
				/*test.centerHTML.addEventListener("click",function(ev){
					alert("from centerHTML clicked event");
				});*/
				var divs=test.refs.$bottomDom;

				var confirm=divs.getElementsByTagName("span");
				confirm[0].addEventListener("click",function(ev){
					// alert("from confirm button");
				});
				confirm[1].addEventListener("click",function(ev){
				test.remove_Dom;
				});
			//	test.remove_Dom();
									//editor.createDialogBox();
			return false;
		}
		else {
			ddoptions={"type":action, "list":ZE_Init[action]};
			break;
		}
		
			//alert("instead of insert options");
			break;
		case "directionoptions":
			ddoptions = {"type":action , "list":ZE_Init[action]};
			break;
		case "attach":																//No I18N
			ddoptions={"type":command, "list":ZE_Init.attachDrop};						//No I18N
			break;
	}
	editor.win.focus();
	if(editor.mode=="richtext"){
 		selectedRange=editor.saveSelection();  //save the selection since selection gets lost in ie
 	}
	ZE.conDrop(ddoptions,editor);
	/*for ie save the selection because when clicked outside the selection gets lost*/

  	ze_dropdowndiv=_document.getElementById("ze_dropdown");
	if(command=="fontfamily"){
		ze_dropdowndiv.style.width="175px";
	}else if(command=="fontsize"){						//No I18N
		ze_dropdowndiv.style.width="60px";
	}
	ZE.addClass(curtoolbarobject,"ze_dn");
	ZE.addClass(curtoolbarobject,"ze_Sel");

	/*ul_click present above  */

	ZE._addEvent(ze_dropdowndiv,"click",ul_click);		//No I18N
	ZE._addEvent(_document,"mousedown",mouse_down);		//No I18N
	ZE._addEvent(_doc,"mousedown",mouse_down);		//No I18N
	ZE._addEvent(_doc,"keydown",mouse_down);		//No I18N
	while(_anchorelement.nodeName!=="B"){         //No I18N
		_anchorelement=_anchorelement.parentNode;
	}
	/* setting the position of the div*/
	offsets=ZE.getPos(_anchorelement);
	_style=ze_dropdowndiv.style;
	// debugger;
	if(command === "otheroptions"){
		_style.left=(offsets.offsetLeft - ze_dropdowndiv.offsetWidth) + _anchorelement.getBoundingClientRect().width +  "px";
		// _style.left = (_anchorelement.offsetParent.offsetLeft+_anchorelement.offsetLeft + _anchorelement.offsetWidth) - _style.offsetWidth + "px"; // NO I18N
		// _style.left = (_anchorelement.offsetParent.offsetWidth - _anchorelement.offsetWidth) +"px";
		// _style.right=(document.body.scrollWidth - (offsets.offsetLeft + _anchorelement.getBoundingClientRect().width) + "px";						//No I18N
		// _style.right = "600px";
		
	
	}else if(command === "smiley"){
		//_style.right= offsets.offsetRight + "px";
		// _style.right=(document.body.scrollWidth - (offsets.offsetLeft + _anchorelement.getBoundingClientRect().width) - 5) + "px";						//No I18N
		_style.left=(offsets.offsetLeft - ze_dropdowndiv.offsetWidth) + _anchorelement.getBoundingClientRect().width +  "px";
		// _style.left = (_anchorelement.offsetParent.previousElementSibling.offsetLeft+_anchorelement.offsetLeft + _anchorelement.offsetWidth) - editor.alterTool.offsetWidth + "px";
	}else{
		_style.left=offsets.offsetLeft+"px";
	}
	_style.top=offsets.offsetTop+_anchorelement.offsetHeight+"px";

	ze_dropdowndiv.style.display="block";

    rectObj = document.body.getBoundingClientRect();
    dropRectObj = ze_dropdowndiv.getBoundingClientRect();

    if((dropRectObj.height + dropRectObj.top) > rectObj.height){
        var space_to_remove=dropRectObj.height + dropRectObj.top - rectObj.height ;
        ze_dropdowndiv.firstChild.style.height = (dropRectObj.height - space_to_remove - 50) + "px";
    }

};

ZE.prototype.updateFontfamily=function(_target,curtoolbarobject){
	var selaction, editor=this, _doc=editor.doc,temp_html=editor.getContent(),newContent;;
	selaction = _target.style.fontFamily;
	editor.win.focus();
	editor.squireInstance.setFontFace(selaction);
	editor.saveCurrentState();
};

ZE.prototype.updateFontsize=function(_target,curtoolbarobject){
	var editor=this, _doc=editor.doc , temp_html=editor.getContent(),newContent;
	curtoolbarobject.firstChild.innerHTML=_target.innerHTML;
	editor.win.focus();
	var dataAtt= _target.getAttribute("data-size");

	editor.squireInstance.setFontSize(editor.fontsizeConversion("fontvaltopx",dataAtt)+"px");			//No I18N
	editor.saveCurrentState();
};

ZE.prototype.updateColor=function(_target,_anchorelement,command){
	var col,i,collen, editor=this, _doc=editor.doc,temp_html=editor.getContent(),newContent;
	col = _target.style.backgroundColor;
	col = col.replace(/rgb\(|\)/g, "").split(",");
	collen=col.length;
	for(i=0;i<collen;i++){
		col[i]=parseInt(col[i], 10).toString(16);
		col[i]=(col[i].length==1) ? '0' + col[i] : col[i];
	}
	col='#'+col.join("");
	editor.win.focus();
	if(command == "backcolor"){    //No I18N
		editor.squireInstance.setHighlightColour(col);
	}
	else if(command == "forecolor"){     //No I18N
		editor.squireInstance.setTextColour(col);
	}
	if(command=="backcolor"){

		var value=_doc.queryCommandValue("backcolor");		//No I18N
		if(typeof(value)=="number"){    //for ie the query returns a number
	               _anchorelement.firstChild.style.borderBottom="3px rgb(" + (value & 0xFF) + "," + ((value >> 8) & 0xFF) + "," + ((value >> 16) & 0xFF) + ") solid";		//No I18N
		}
		else{	 //for other browsers
				 if(value == "transparent"){
				 	value = editor.getFormattingValues("highlight") || "white"; //No I18N
				 }
				  _anchorelement.firstChild.style.borderBottom="3px "+value+" solid";						//No I18N
        }
	}else{
		var value=_doc.queryCommandValue("forecolor");		//No I18N
		if(typeof(value)=="number"){  //for ie the query returns a number
			_anchorelement.firstChild.style.color="rgb(" + (value & 0xFF) + "," + ((value >> 8) & 0xFF) + "," + ((value >> 16) & 0xFF) + ")";
		}
		else{     //for other browsers
			_anchorelement.firstChild.style.color=_doc.queryCommandValue("forecolor");
        }
	}
	editor.saveCurrentState();
};

ZE.prototype.updateDirectionOptions=function(_target,curtoolbarObject,action){

	var editor =this,
		selection = _target.getAttribute("data-"+action);
	editor.win.focus();
	switch(selection){
		case "rtl":
			editor.squireInstance.setTextDirection("rtl");
			break;
		case "ltr":
			editor.squireInstance.setTextDirection("ltr");
			break;
	}
	editor.saveCurrentState();
}
ZE.prototype.updateFormatoptions=function(_target,curtoolbarobject,action){
	var selaction, editor=this, _doc=editor.doc;
	selaction = _target.getAttribute("data-" + action);
	editor.win.focus();
	switch (selaction) {
	case "justifyleft":						//No I18N
		editor.squireInstance.setTextAlignment("left");
		curtoolbarobject.firstChild.className="zei-textleft";
		break;
	case "justifyright":						//No I18N
		editor.squireInstance.setTextAlignment("right");
		curtoolbarobject.firstChild.className="zei-textright";
		break;
	case "justifyfull":						//No I18N
		editor.squireInstance.setTextAlignment("justify");
		curtoolbarobject.firstChild.className="zei-textjustify";
		break;
	case "justifycenter":						//No I18N
		editor.squireInstance.setTextAlignment("center");
		curtoolbarobject.firstChild.className="zei-textcenter";
		break;
	case "insertunorderedlist":						//No I18N
		editor.insertListOperation("UL");		//No I18N
		curtoolbarobject.firstChild.className="zei-unorder";
		break;
	case "insertorderedlist":						//No I18N
		editor.insertListOperation("OL");   //No I18N
		curtoolbarobject.firstChild.className="zei-order";
		break;
	case "removelist":
		editor.squireInstance.removeList();
		break;
	case "indent":						//No I18N
		if(editor.getPosFromCursor("UL") > 0 || editor.getPosFromCursor("OL") > 0)  {
			editor.squireInstance.increaseListLevel();
		}
		else{
			editor.squireInstance.increaseQuoteLevel();
		}
		curtoolbarobject.firstChild.className="zei-outdent";
		break;
	case "outdent":						//No I18N
		var olparent = editor.getPosFromCursor("OL");
		var ulparent = editor.getPosFromCursor("UL");
		if(olparent == -1 && ulparent == -1){
			editor.squireInstance.decreaseQuoteLevel();
		}
		else if(ulparent > olparent){
			if( editor.getPosFromCursor("UL",1) > 0 || editor.getPosFromCursor("OL") > 0){
				editor.squireInstance.decreaseListLevel();
			}
			else{
				editor.squireInstance.removeList();
			}
		}
		else if(olparent > ulparent){
			if( editor.getPosFromCursor("OL",1) > 0 || editor.getPosFromCursor("UL") > 0){
				editor.squireInstance.decreaseListLevel();
			}
			else{
				editor.squireInstance.removeList();
			}
		}
		curtoolbarobject.firstChild.className="zei-indent";
		break;
	}

	editor.saveCurrentState();
};

ZE.prototype.updateOtheroptions=function(_target,action){
	var editor=this;
	var selaction = _target.getAttribute("data-" + action);
	
	editor.win.focus();
	if(selaction=="switchmode"){
		if(editor.mode=="richtext"){
			editor.confirmPlainText(editor.getContent());
			//editor.plainText(editor.getContent());
		}else if(editor.mode=="plaintext"){						//No I18N
			editor.richText(editor.getContent());
		}
	}else if(selaction=="spellcheck"){						//No I18N
		editor.spellcheck();
	}
};


ZE.prototype.insertSmiley=function(_target){
    var editor = this,
			value,
			contextVal = ZE.getContextValue(),
			smileyPath = ZE_Init.smileyPath || contextVal+"/ze/images/",//No I18N
			imgStyles = "margin: 0px 10px; vertical-align:middle; width:24px; height:24px;";//No I18N

    editor.win.focus();
    if(_target.nodeName == "LI"){
    	_target=_target.firstChild;
    }
    if(_target.className.indexOf("ze_")!=0 || _target.nodeName != "I"){
    	return;
    }
    value = _target.className.replace("ze_","");//No I18N
    //Can change to squire's insert image method once the issue regarding it is fixed
	editor.pasteHTML("<IMG style='"+imgStyles+"' src='"+smileyPath+value+".gif'></IMG>");//No I18N
	editor.saveCurrentState();
};

/* For testing only*/

ZE.prototype.createDialogBox=function(){
  "use strict" //No I18N
  var editor = this,
  _document = document,
  ze_ins_table_div = _document.getElementById("ze_ins_table"),
  hideTableDiv,
  esckey,
  tblhtml,
  hideDialogBox,
  _input,
  row_input,
  col_input,
  div1,
    I18N=ZE.i18n;
    tblhtml='<div class="zep_PUtt">'+I18N("Test DialogBox")+'<i class="zei-close"></i></div>';
    tblhtml+='<div class="zep_PUcen">';
    tblhtml+='<form><table class="ze_ptble"><tr><td>'+I18N("Rows")+'</td><td><input type="text" class="ze_m20" value="10" size="2"></td></tr><tr><td>'+I18N("column")+'</td><td><input type="text" class="ze_m20" value="10" size="2"></td></tr></table></form></div>';
    tblhtml+='<div class="zep_PUbtm"><span class="sel">'+I18N("OK")+'</span><span data-val="Cancel">'+I18N("CANCEL")+'</span></div>';
    ZE.showOverlay();
     hideDialogBox=function(){
      var _form=ze_ins_table_div.getElementsByTagName("form")[0];
      ze_ins_table_div.parentElement.removeChild(ze_ins_table_div);
      ZE.hideOverlay();
    }
    div1=_document.createElement("div");
    div1.setAttribute("class","zep_PU zep_arrb");
    div1.innerHTML=tblhtml;
    div1.id="ze_ins_table";
    _document.body.appendChild(div1);
    ZE.setPosition(div1,editor.editordiv);
    ze_ins_table_div=_document.getElementById("ze_ins_table");
    var buttons=ze_ins_table_div.getElementsByTagName("span");
    _input=ze_ins_table_div.getElementsByTagName("input");
    var close_buttons=ze_ins_table_div.getElementsByClassName("zei-close")[0];
    close_buttons.onclick=buttons[1].onclick=function(ev){
      editor._stopEvent(ev);
      hideDialogBox();
    }
    buttons[0].onclick=saveButton;
    function saveButton(ev){
      editor._stopEvent(ev);
      row_input=_input[0].value;
      col_input=_input[1].value;
      if(row_input<=20 && col_input<=20){
        // alert("row value is"+row_input+"column  value is"+col_input);
        hideDialogBox();
      }
      else {
          _input[0].value=10;
          _input[1].value=10;
        _input[0].focus();
      }
    }
    //}
};
/* This function will crete the Dialog Component and its handling

args - createDialogTest(args);
headerTitle - Title for the DialogBox

centerDom - The Dom which is to be appended in the center

isMask - Whether need to mask the background content or not

OK -  Function name for the ok button click event

Cancel - Function name for the Cancel buttom click event

Sample: {headerTitle:"TestDialogBox",centerHTML:"centerDom",isMask:true,onOk:Ok,onCancel:Cancel}
*/

 /* global ZE */
ZE.prototype.createDialog = function (args) {
  "use strict"; //  NO I18N
  var editor = this,
    _document = document,
    dialogContents = args,
    hideDialogBox,
    div1,
    zeInsTableDiv,
    escKey,
    setContent,
    I18N = ZE.i18n;

  var topTemp = [
    "<div ref='topDiv' class='zep_PUtt'>",
    "<span ref='Content'></span>",
    "<i class='zei-close' ref='closeIcon'></i>",
    "</div>"
  ].join('');


  var bottomTemp = [
    "<div class='zep_PUbtm'>",
    "<span class='sel' ref='saveButton'></span>",
    "<span data-val='Cancel' ref='cancelButton'></span>",
    "</div>"
  ].join('');

  setContent = function (htmlContent, dataAttr) {
    var testDiv = _document.createElement("div");
    var tempObj = {};
    testDiv.innerHTML = htmlContent;
    var getRefEle = testDiv.querySelectorAll('[' + dataAttr + ']');
    for (var i = 0; i < getRefEle.length; i++) {
      var value = getRefEle[i].getAttribute(dataAttr);
      tempObj[value] = getRefEle[i];
      getRefEle[i].removeAttribute(dataAttr);
    }
    return {
      refs: tempObj,
      dom: testDiv.firstChild
    };
  };
  var topBar = setContent (topTemp, "ref");
  topBar.refs.Content.innerHTML = I18N(dialogContents.headerTitle);
  var centerBar = _document.createElement("div");
  centerBar.className = "zep_PUcen";
  centerBar.appendChild(dialogContents.centerHTML);
  if (dialogContents.isMask) {
    ZE.showOverlay();
  }
  var bottomBar = setContent(bottomTemp, "ref");
  var bottombarButtons = bottomBar.refs;
  bottombarButtons.saveButton.innerText = I18N("OK");
  bottombarButtons.cancelButton.innerText = I18N("Cancel");
  var removeDom = function () {
    zeInsTableDiv.parentElement.removeChild(zeInsTableDiv);
    if (dialogContents.isMask) {
      ZE.hideOverlay();
    }
  };

  escKey = function (ev) {
    if (ev.keyCode === 27) {
      hideDialogBox();
    }
    if (ev.keyCode === 13) {
      dialogContents.onOk();
      hideDialogBox();
    }
  };


  hideDialogBox = function () {
    ZE._removeEvent(_document, "keydown", escKey);
    zeInsTableDiv.parentElement.removeChild(zeInsTableDiv);
    if (dialogContents.isMask) {
      ZE.hideOverlay();
    }
  };


  div1 = _document.createElement("div");
  div1.setAttribute("class", "zep_PU zep_arrb");
  div1.id = "ze_ins_table"; // NO I18n
  div1.appendChild(topBar.dom);
  div1.appendChild(centerBar);
  div1.appendChild(bottomBar.dom);
  _document.body.appendChild(div1);
  ZE.setPosition(div1, editor.editordiv);
  zeInsTableDiv = _document.getElementById("ze_ins_table");


  topBar.refs.closeIcon.onclick = bottomBar.refs.cancelButton.onclick = function (ev) {
    editor._stopEvent(ev);
    hideDialogBox();
  };


  bottombarButtons.saveButton.onclick = function (ev) {
    editor._stopEvent(ev);
    dialogContents.onOk();
    hideDialogBox();
  };
  ZE._addEvent(_document, "keydown", escKey);
  return ({refs: {$centerDom: centerBar, $bottomDom: bottomBar.dom}, removeElem: removeDom});
};
/*  Table Grid  */
/* global ZE */
ZE.prototype._createTableGrid = function (ev, command) {
  "use strict";
  var editor = this,
    _document = document,
    _doc = editor.doc,
    _anchorElement = ev.currentTarget,
    _initobj = editor.initobj,
    maxRow = 5,
    maxCol = 5,
    _target,
    rowCount,
    tr,
    td,
    colCount,
    tableGrid,
    selectedRange,
    gridRows = [],
    deleteRow = 0,
    deleteCol = 0,
    _offset,
    tableGridid,
    sel,
    range,
    clickAction,
    mouseMove,
    removeEvents,
    curtoolbarobject;
  curtoolbarobject = editor.toolbarobject[command];
  ZE.addClass(curtoolbarobject, "ze_dn ze_Sel");
  var CONSTANTS = {
    TABLEID: "tablegen_div",
    DROPDOWNID: "ze_dropdown",
    ROWATTR: "data-row_num",
    COLATTR: "data-col_num"
  };
  selectedRange = editor.saveSelection();

  var setProperty = function (node, propName, value) {
    node.setAttribute(propName, value);
  };

  var fillGrid = function (_rowCount, _colCount) {
    var i, j;
    for (i = 0; i < maxRow; i++) {
      for ( j = 0; j < maxCol; j++) {
        if (i < _rowCount && j < _colCount) {
          var displayDiv = _document.getElementById("displayDiv");
          displayDiv.innerHTML = _rowCount + "x" + _colCount;
          gridRows[i].childNodes[j].style.backgroundColor = "#F4F4F4";
        } else {
          gridRows[i].childNodes[j].style.backgroundColor = "#fff";
        }
      }
    }
  };

  var insertTable = function () {
    var gridTable = _document.createElement("div");
    gridTable.id = CONSTANTS.DROPDOWNID;
    gridTable.className = "ze_dd shw ze_dropDown";
    var displayDiv = _document.createElement("div");
    displayDiv.innerHTML = "1 x 1";
    displayDiv.align = "center";
    displayDiv.id = "displayDiv";
    displayDiv.className = "ze_tableDtl";
    var tablegenDiv = document.createElement("table");
    setProperty(tablegenDiv, "id", CONSTANTS.TABLEID);
    tablegenDiv.className = "ze_mainTable";
    for (var row = 1; row <= maxRow; row++) {
      tr = _document.createElement("tr");
      for (var col = 1; col <= maxCol; col++) {
        td = _document.createElement("td");
        td.className = "ze_tableGridCol";
        ZE._setAttribute(td, CONSTANTS.ROWATTR, row);
        ZE._setAttribute(td, CONSTANTS.COLATTR, col);
        ZE._appendChildren(tr, [td]);
      }
      gridRows.push(tr);
      ZE._appendChildren(tablegenDiv, [tr]);
    }
    var ulLists = _document.createElement("ul");
    var ul1 = _document.createElement("li");
    ul1.className = "iTable";
    ZE._appendChildren(ul1, [displayDiv, tablegenDiv]);
    ZE._appendChildren(ulLists, [ul1]);
    ZE._appendChildren(gridTable, [ulLists]);
    return gridTable;
  };

  tableGrid = insertTable();
  _offset = ZE.getPos(_anchorElement);
  tableGrid.style.left = _offset.offsetLeft + "px";
  tableGrid.style.top = _offset.offsetTop + _anchorElement.offsetHeight + "px";
  _document.body.appendChild(tableGrid);
  var tablegenDivId = _document.getElementById(CONSTANTS.TABLEID);

  var mouseDown = function (event) {
    tableGrid = document.getElementById(CONSTANTS.DROPDOWNID);
    if (event) {
      _target = event.target;
      for (; _target !== null && _target !== tableGrid;) {
        _target = _target.parentNode;
      }
    }
    if (!_target) {
      removeEvents();
      tableGrid.parentElement.removeChild(tableGrid);
    }
  };

  mouseMove = function (event) {
    var tableRows, tableRow;
    if (rowCount) {
      deleteRow = rowCount;
    }

    if (colCount) {
      deleteCol = colCount;
    }

    rowCount = event.target.dataset.row_num;
    colCount = event.target.dataset.col_num;
    if (Number(deleteRow) > Number(rowCount)) {
      if (Number(deleteRow) >= 5) {
        tableGridid = _document.getElementById(CONSTANTS.TABLEID);
        maxRow--;
        tableGridid.deleteRow(maxRow);
        gridRows.pop();
      }
    } else if (Number(rowCount) === maxRow) {
      if (maxRow !== 10) {
        tableGridid = _document.getElementById(CONSTANTS.TABLEID);
        tr = _document.createElement("tr");
        tr.style.border = "2";
        maxRow++;
        for (var rows = 0; rows < maxCol; rows++) {
          td = _document.createElement("td");
          td.className = "ze_tableGridCol";
          ZE._setAttribute(td, CONSTANTS.ROWATTR, maxRow);
          ZE._setAttribute(td, CONSTANTS.COLATTR, rows + 1);
          tr.appendChild(td);
        }
        gridRows.push(tr);
        tableGridid.insertBefore(tr, tableGridid.lastChild.nextSibling);
      }
    }
    if (Number(deleteCol) > Number(colCount)) {
      if (Number(deleteCol) >= 5) {
        tableRows = _document.getElementsByTagName("TR");
        var maxcols;
        for (var _rows = 0; _rows < tableRows.length; _rows++) {
          maxcols = maxCol;
          var tabCols = tableRows[_rows].getElementsByTagName("TD");
          for (var _cols = 0; _cols < 1; _cols++) {
            tableRows[_rows].removeChild(tabCols[maxcols - 1]);
            maxcols--;
          }
        }
        maxCol--;
      }
    } else if (Number(colCount) === Number(maxCol)) {
      if (maxCol !== 10) {
        gridRows = [];
        maxCol += 1;
        var cols = maxCol;
        tableRow = _document.getElementsByTagName("TR");
        tableGridid = _document.getElementById(CONSTANTS.TABLEID);
        for (var k = 0; k < tableRow.length; k++) {
          td = _document.createElement("td");
          var tableCol = tableRow[k].getElementsByTagName("TD");
          td.className = "ze_tableGridCol";
          ZE._setAttribute(td, CONSTANTS.ROWATTR, k + 1);
          ZE._setAttribute(td, CONSTANTS.COLATTR, cols);
          tableRow[k].insertBefore(td, tableCol[tableCol.length - 1].nextSibling);
          gridRows.push(tableRow[k]);
        }
      }
    }
    if (!rowCount && !colCount) {
      fillGrid(deleteRow, deleteCol);
    } else if (!rowCount) {
      fillGrid(deleteRow, colCount);
    } else if (!colCount) {
      fillGrid(rowCount, deleteCol);
    } else {
      fillGrid(rowCount, colCount);
    }
  };

  var drawTable = function (_rowCount, _colCount) {
    var i, j;
    editor.win.focus();
    if (selectedRange) {
      editor.restoreSelection(selectedRange);
    }
    var fragment = _doc.body.ownerDocument.createDocumentFragment();
    fragment.appendChild(_document.createElement("br"));

    var _table = _document.createElement("table");
    var tableStyle = _table.style;
    tableStyle.fontSize = _initobj.defaultfontsize || ZE_Init.defaultFontSize || "";
    tableStyle.fontFamily = _initobj.defaultfontfamily || ZE_Init.defaultFontFamily || "";
    tableStyle.width = "100%";
    tableStyle.borderStyle = "solid";
    tableStyle.borderCollapse = "collapse";
    _table.cellPadding = "2";
    _table.cellSpacing = "2";
    _table.cellPadding = "2";
    _table.cellSpacing = "2";
    _table.border = "1";
    var row,
      cell;
    var	_tbody = _document.createElement("tbody");
    for (i = 0; i < _rowCount; i++) {
      row = _document.createElement("tr");
      for (j = 0; j < _colCount; j++) {
        cell = _document.createElement("td");
        var newDiv = _document.createElement("div");
        newDiv.appendChild(_document.createElement("br"));
        cell.appendChild(newDiv);
        row.appendChild(cell);
      }
      _tbody.appendChild(row);
    }
    _table.appendChild(_tbody);
    fragment.appendChild(_table);
    fragment.appendChild(_document.createElement("br"));
    editor.win.focus();
    sel = editor._getSelection();
    try	{
      if (!sel.isCollapsed) {
        sel.deleteFromDocument();
      }
      range = sel.getRangeAt(0);
    } catch (e) {
      range = editor._createRange(sel);
    }
    try	{
      editor.win.focus();
      range.insertNode(fragment);
    } catch (e1) {
    }
    editor.saveCurrentState();
  };

  removeEvents = function () {
    ZE.removeClass(curtoolbarobject, "ze_dn");
    ZE._removeEvent(tablegenDivId, "click", clickAction);
    ZE._removeEvent(tablegenDivId, "mousemove", mouseMove);
    ZE._removeEvent(_document, "mousedown", mouseDown);
    ZE._removeEvent(_doc, "mousedown", mouseDown);
    ZE._removeEvent(_doc, "keydown", mouseDown);
  };

  clickAction = function (event) {
    editor._stopEvent(ev);
    if (event.target.hasAttribute(CONSTANTS.ROWATTR) && event.target.hasAttribute(CONSTANTS.COLATTR)) {
      drawTable(rowCount, colCount);
    } else {
      drawTable(deleteRow, deleteCol);
    }
    tableGrid = _document.getElementById(CONSTANTS.DROPDOWNID);
    removeEvents();
    tableGrid.parentElement.removeChild(tableGrid);
  };

  ZE._addEvent(_document, "mousedown", mouseDown);
  ZE._addEvent(_doc, "mousedown", mouseDown);
  ZE._addEvent(_doc, "keydown", mouseDown);
  ZE._addEvent(tablegenDivId, "click", clickAction);
  ZE._addEvent(tablegenDivId, "mousemove", mouseMove);

};
/* For Resizing the Table */
/* global ZE */

ZE.prototype.resizeTable = function (_target) {
  "use strict"; // No I18N
  var editor = this,
    _doc = editor.doc,
    _document = document,
    _anchorTarget = _target,
    mouseDown,
    stopDrag,
    keyDown,
    doDrag,
    values,
    posx,
    posy,
    removeEvents,
    removeListeners,
    addEvents,
    resizeDiv,  // name for creating the resize div (ie the small div in the left corner of the table)
    resize, // to find the div with the id resizeDiv
    _enclosingDiv, // name for generating the enclosing div (ie . div around the table)
    _encloseDiv; // To find the div with the id enclosingDiv
  _encloseDiv = _doc.getElementById("_enclosingDiv");
  resize = _doc.getElementById("resizeDiv");
  _enclosingDiv = _document.createElement("div");
  _enclosingDiv.id = "_enclosingDiv";
  var setValues = function () {
    values = _anchorTarget.getBoundingClientRect();
    posx = values.left;
    posy = values.top;
    if (editor.win.scrollX) {
      _enclosingDiv.style.left = (posx + editor.win.scrollX) + "px";
    } else {
      _enclosingDiv.style.left = (posx + editor.win.pageXOffset) + "px";
    }
    if (editor.win.scrollY) {
      _enclosingDiv.style.top = (values.top + editor.win.scrollY) + "px";
    } else {
      _enclosingDiv.style.top = (values.top + editor.win.pageYOffset) + "px";
    }
    if (editor.win.scrollY) {
      posy += editor.win.scrollY;
    }	else {
      posy += editor.win.pageYOffset;
    }

    if (editor.win.scrollX) {
      posx += editor.win.scrollX;
    }	else {
      posx += editor.win.pageXOffset;
    }
  };
  addEvents = function () {
    ZE._addEvent(_document, "mousedown", mouseDown);
    ZE._addEvent(_doc, "mousedown", mouseDown);
    ZE._addEvent(_doc, "keydown", keyDown);
  };
  removeEvents = function () {
    ZE._removeEvent(_doc, "mousedown", mouseDown);
    ZE._removeEvent(_document, "mousedown", mouseDown);
    ZE._removeEvent(_doc, "keydown", keyDown);
  };
  removeListeners = function () {
    ZE._removeEvent(_doc, "mousemove", doDrag);
    ZE._removeEvent(_doc, "mouseup", stopDrag);
    ZE._removeEvent(_document, "mouseup", stopDrag);

  };
  keyDown = function () {
    var value = _anchorTarget.getBoundingClientRect();
    resizeDiv.style.top = (value.height + posy) - 4 + "px";
    resizeDiv.style.left = (value.width + value.left) - 4 + "px";
  };
  var initDrag = function (ev) {
    _encloseDiv = _doc.getElementById("_enclosingDiv");
    var height = ev.clientY;
    var width = ev.clientX;
    var values1 = _anchorTarget.getBoundingClientRect();
    var startHeight = values1.height;
    var startWidth = values1.width;
    stopDrag = function () {
      removeListeners();
      resize = _doc.getElementById("resizeDiv");
      if (resize !== null && _encloseDiv !== null) {
        _anchorTarget.style.width = _encloseDiv.offsetWidth - 4 + "px";
        _anchorTarget.style.height = _encloseDiv.offsetHeight - 4 + "px";
        // resize.parentElement.removeChild(resize);
        var value = _anchorTarget.getBoundingClientRect();
        resizeDiv.style.top = (value.height + posy) - 4 + "px";
        resizeDiv.style.left = (value.width + value.left) - 4 + "px";
        _encloseDiv.parentElement.removeChild(_encloseDiv);
        // _doc.body.appendChild(resizeDiv);
        // resizeDiv.addEventListener("mousedown", initDrag, false);
        addEvents();
      }
    };
    doDrag = function (event) {
      _encloseDiv.style.width = (startWidth + event.clientX - width) + "px";
      if (parseInt(_encloseDiv.style.width) <= 25) {
        _encloseDiv.style.width = "25px";
      }
      _encloseDiv.style.height = (startHeight + event.clientY - height) + "px";
      if (parseInt(_encloseDiv.style.height) <= 25) {
        _encloseDiv.style.height = "25px";
      }
      var value = _encloseDiv.getBoundingClientRect();
      setValues();
      resizeDiv.style.top = (value.height + posy) - 4 + "px";
      resizeDiv.style.left = (posx + value.width) - 4 + "px";


    };
    removeEvents();
    ZE._addEvent(_doc, "mousemove", doDrag);
    ZE._addEvent(_doc, "mouseup", stopDrag);
    ZE._addEvent(_document, "mouseup", stopDrag);
  };
  mouseDown = function (ev) {
    if (ev.target.id === "resizeDiv") {
      removeEvents();
      removeListeners();
      setValues();
      _enclosingDiv.style.height = (values.height) + "px";
      _enclosingDiv.style.width = (values.width) + "px";
      _doc.body.appendChild(_enclosingDiv);
      editor._stopEvent(ev);
      initDrag(ev);
    } else if (_doc.getElementById("resizeDiv")) {
      resizeDiv.parentElement.removeChild(resizeDiv);
      removeListeners();
      removeEvents();
    }
  };
  setValues();
  _enclosingDiv.style.position = "absolute";
  _enclosingDiv.style.border = "2px dashed #555";
  resizeDiv = _document.createElement("div");
  resizeDiv.id = "resizeDiv";
  _doc.body.appendChild(resizeDiv);
  resizeDiv.style.top = (values.height + posy ) - 4 + "px";
  resizeDiv.style.left = (posx + values.width) - 4 + "px";
  resizeDiv.style.height = "16px";
  resizeDiv.style.width = "16px";
  resizeDiv.style.backgroundImage = "url(//192.168.230.120:9090/zep/images/resize.svg)";
  // resizeDiv.style.border = "2px solid #696969";
  // resizeDiv.style.backgroundColor = "#696969";
  resizeDiv.style.position = "absolute";
  resizeDiv.style.backgroundRepeat = "no-repeat";
  resizeDiv.style.cursor = "se-resize";
  resizeDiv.contentEditable = false;
//  resizeDiv.style.backgroundPosition = "center";
  addEvents();
};
/* global ZE */
ZE.prototype.resizeColumn = function (_target) {
  "use strict";
  var editor = this,
    _doc = editor.doc,
    _document = document,
    _anchorTarget = _target,
    mouseDown,
    keyDown;
    if (_doc.getElementById("_resizecolDivs")) {
    var _resize = _doc.getElementById("_resizecolDivs");
    _resize.parentElement.removeChild(_resize);
  }
  keyDown = function () {
    if (_doc.getElementById("_resizecolDivs")) {
      var _resize = _doc.getElementById("_resizecolDivs");
      _resize.parentElement.removeChild(_resize);
      delete _doc["event"];
      ZE._removeEvent(_doc, "keydown", keyDown);
    }
  };
  var initDrag = function (ev) {
    var height = ev.clientY;
    var width = ev.clientX;
    var _colEncloseDiv = _doc.getElementById("_colEncloseDiv");
    var values1 = _colEncloseDiv.getBoundingClientRect();
    var startHeight = values1.height;
    var startWidth = values1.width;
    var stopDrag = function () {
      var len = tableRows.length;
      var id = parseInt(ev.target.id)
      for (var i = 0; i < len; i++) {
        tableRows[i].getElementsByTagName("TD")[id].style.width = _colEncloseDiv.offsetWidth - 9 + "px";
      }
      _doc.removeEventListener("mousemove", doDrag, false);
      _doc.removeEventListener("mouseup", stopDrag, false);
      delete _doc["event"];
      ZE._removeEvent(_doc , "keydown",keyDown);

      _colEncloseDiv.parentElement.removeChild(_colEncloseDiv);
      var _removeDiv = _doc.getElementById("_resizecolDivs");
      _removeDiv.parentElement.removeChild(_removeDiv);
      // _setDivs();
    }
    var doDrag = function (event) {
      var len = tableCols.length;
      var minwid = 75;
      var maxwid = (_anchorTarget.offsetWidth) / len;
      maxwid *= 1.7;
      var _width = (startWidth + event.clientX - width);
      if (_width <= 75) {
        _colEncloseDiv.style.width = minwid + "px";
      // } else if (_width >= maxwid) {
      //   _colEncloseDiv.style.width = maxwid + "px";
      } else {
        _colEncloseDiv.style.width = _width + "px";
      }
      _colEncloseDiv.style.height = _anchorTarget.offsetHeight + "px";
      }
    _doc.addEventListener("mousemove", doDrag, false);
    _doc.addEventListener("mouseup", stopDrag, false);
  }
  mouseDown = function (ev) {
    var _colEncloseDiv = _document.createElement("div");
    var id = parseInt(ev.target.id);
    _colEncloseDiv.id = "_colEncloseDiv";
    _colEncloseDiv.style.position = "absolute";
    _colEncloseDiv.style.left = tableCols[id].offsetLeft + 13 + "px";
    _colEncloseDiv.style.top = _anchorTarget.offsetTop + "px";
    _colEncloseDiv.style.height = _anchorTarget.offsetHeight + "px";
    _colEncloseDiv.style.width = tableCols[id].offsetWidth+ "px";
    _colEncloseDiv.style.border = "1px dashed black";
    _doc.body.appendChild(_colEncloseDiv);
    initDrag(ev);
  };
  var tableRows = _anchorTarget.getElementsByTagName("tr");
  var tableCols = tableRows[0].getElementsByTagName("td");
  var _resizecolDivs = document.createElement("div");
  _resizecolDivs.id = "_resizecolDivs";
  var len = tableCols.length;
  for (var i = 1; i < len; i++) {
    var _div = document.createElement("div");
    var _style = _div.style;
    _div.className = "ze_colResize";
    _div.id = (i - 1);
    _style.top = _anchorTarget.offsetTop + "px";
    _style.left = (tableCols[i].offsetLeft + 13) + "px";
    _style.width = "3px";
    _style.height = _anchorTarget.offsetHeight + "px";
    _resizecolDivs.appendChild(_div);
  }
  _doc.body.appendChild(_resizecolDivs);
  ZE._addEvent(_resizecolDivs, "mousedown", mouseDown);
  var a = _doc["event"];
  if (a === undefined) {
    _doc["event"] = "added";
    ZE._addEvent(_doc, "keydown", keyDown);
 }
};
ZE.prototype.showContextMenu = function(ev, type, object) {
	var editor = this,
	    I18N = ZE.i18n,
	//_anchorelement=ev.currentTarget, //holds the anchor element;
	_document = document, cmoptions, curtoolbarobject,fragment, _doc = editor.doc, ze_dropdowndiv, ul_click, mouse_down, offsets, _style, hideDropDown, _target, colors, smileys, ul_Elem, current_row, i, j, _target1 = ev.target;

	
	delete_table = function() {
		editor.win.focus();
		object.parentNode.removeChild(object);
		hideContextMenu();
		editor.win.focus();
		editor.saveCurrentState();
	};

	delete_current_row = function() {
		editor.win.focus();
		current_row=get_current_row();
		if(!current_row){
			return;
        }
		current_row.parentNode.removeChild(current_row);
		if (object.rows.length == 0) {
			delete_table();
			return;
		}
		hideContextMenu();
		editor.saveCurrentState();
	};
	delete_current_column=function(){
		editor.win.focus();
		current_row=get_current_row();
		if(!current_row){
			return;
        }
		var current_column=get_current_column();
		var currentPos=getPosition(current_row,current_column);
		var tbody=current_row.parentNode;
		var tr_list=tbody.getElementsByTagName("TR");       //No I18N
		for(i=0;i<tr_list.length;i++)
		{
		    if(tr_list[i].parentNode==tbody)
            {
			    var td_list=tr_list[i].getElementsByTagName("TD");	       //No I18N
			    tr_list[i].removeChild(td_list[currentPos]);
			}
		}
		if(tr_list[0].getElementsByTagName("TD").length==0)
		{
				delete_table();
				return;
		}
		hideContextMenu();
		editor.saveCurrentState();
  		};

	getColumnsNo=function(_current_row)
	{
		var td_list=_current_row.getElementsByTagName("TD");
		return td_list.length;
	};
	constructRow=function(_col_no)
	{
	    if('clone' in ZE_Init.jQuery)
	    {
	        var temp_fragment=ZE_Init.jQuery.clone(current_row);
            var TDs=temp_fragment.getElementsByTagName("TD");
            for(var i=0;i<TDs.length;i++)
            {
                ZE_Init.jQuery(TDs[i]).html("<div><br></div>");
            }
            return temp_fragment;
	    }
	    else
	    {
	        var temp_fragment=_doc.createDocumentFragment();
            var trEle=_doc.createElement("tr");
            temp_fragment.appendChild(trEle);
            for(i=0;i<_col_no;i++)
            {
                var tdElem=_doc.createElement("td");
                var divElem = _doc.createElement("div");
                divElem.appendChild(_doc.createElement("br"));
                tdElem.appendChild(divElem);
                trEle.appendChild(tdElem);
            }
            return temp_fragment;
	    }
	};
	insert_row_above=function()
	{
		editor.win.focus();
		current_row=get_current_row();
		if(!current_row){
			return;
        }
		var col_no=getColumnsNo(current_row);
		fragment=constructRow(col_no);
		current_row.parentNode.insertBefore(fragment, current_row);
		hideContextMenu();
									if (selectedRange) {
  			editor.restoreSelection(selectedRange);
  		}
  		editor.win.focus();
  		editor.saveCurrentState();
		
	};
	insert_row_below=function()
	{
		editor.win.focus();
		current_row=get_current_row();
		if(!current_row){
			return;
        }
		var col_no=getColumnsNo(current_row);
		fragment=constructRow(col_no);
		current_row.parentNode.insertBefore(fragment, current_row.nextSibling);
		hideContextMenu();
									if (selectedRange) {
  			editor.restoreSelection(selectedRange);
  		}
  		editor.win.focus();
  		editor.saveCurrentState();
	};
	insert_column_left=function()
	{
		editor.win.focus();
		current_row=get_current_row();
		if(!current_row){
			return;
        }
		var current_column=get_current_column();
		var currentPos=getPosition(current_row,current_column);
		var tbody=current_row.parentNode;
		var tr_list=tbody.getElementsByTagName("TR");
		for(i=0;i<tr_list.length;i++)
		{
			if(tr_list[i].parentNode==tbody)
			{
			    var td_list=tr_list[i].getElementsByTagName("TD");
                var tdElem='clone' in ZE_Init.jQuery?ZE_Init.jQuery.clone(current_column):_doc.createElement("td");
                ZE_Init.jQuery(tdElem).text("");//No I18N
                var divElem = _doc.createElement("div");
                divElem.appendChild(_doc.createElement("br"));
                tdElem.appendChild(divElem);
                tr_list[i].insertBefore(tdElem,td_list[currentPos]);
			}
		}
		hideContextMenu();
		editor.saveCurrentState();
	};
	getPosition=function(_current_row,_current_column)
	{
		var td_list=_current_row.getElementsByTagName("TD");
		for(i=0;i<td_list.length;i++)
		{
			if(_current_column===td_list[i])
			{
				return i;
			}
		}
	};
	get_current_row = function() {
		_target = _target1;
		
		if (_target.nodeName != "TR"){
			for (; _target !== null; _target = _target.parentNode){
							if(_target.nodeName == "TR"){
								break;
							}
			}
		}
		return _target;
	};
	get_current_column=function()
	{
		_target = _target1;
		
		if (_target.nodeName != "TD") {
			for (; _target !== null; _target = _target.parentNode){
				if(_target.nodeName == "TD"){
					break;
				}
			}
		}
	
		//current_row=_target;
		//_target.parentNode.removeChild(_target);
		return _target;
	};
	insert_column_right=function()
	{
		editor.win.focus();
		current_row=get_current_row();
		
		if(!current_row){
			return;
        }
		var current_column=get_current_column();
		
		var currentPos=getPosition(current_row,current_column);
		
		var tbody=current_row.parentNode;
		var tr_list=tbody.getElementsByTagName("TR");
		for(i=0;i<tr_list.length;i++)
		{
		    if(tr_list[i].parentNode==tbody)
            {
			    var td_list=tr_list[i].getElementsByTagName("TD");
                var tdElem='clone' in ZE_Init.jQuery?ZE_Init.jQuery.clone(current_column):_doc.createElement("td");
                ZE_Init.jQuery(tdElem).text("");//No I18N
                var divElem = _doc.createElement("div");
                divElem.appendChild(_doc.createElement("br"));
                tdElem.appendChild(divElem);
                tr_list[i].insertBefore(tdElem,td_list[currentPos].nextSibling);
			}
		}
		hideContextMenu();
		editor.saveCurrentState();
	};
	edit_table=function(){
		var _table=object;
		editor.createTable(_table);
		hideContextMenu(1);
	};
	var ContextMenu = {
		"table" : [[{            //No I18N
			"cmd" : I18N('ads.rteditor.tableoperations.insertrowabove'),            //No I18N
			"id" : "insert_row",            //No I18N
			"class" : "li_class",            //No I18N
			"method" : insert_row_above            //No I18N
		}, {
			"cmd" : I18N('ads.rteditor.tableoperations.insertrowbelow'),            //No I18N
			"class" : "li_class",            //No I18N
			"method" : insert_row_below            //No I18N
		},
		{
			"cmd" : I18N('ads.rteditor.tableoperations.insertcolumnleft'),            //No I18N
			"class" : "li_class",            //No I18N
			"method" : insert_column_left            //No I18N
		},
		{
			"cmd" : I18N('ads.rteditor.tableoperations.insertcolumnright'),            //No I18N
			"class" : "li_class",            //No I18N
			"method" : insert_column_right            //No I18N
		}
		//{"ircEvent": "PRIVMSG", "method": "deleteURI", "regex": "^delete.*"}
		], [{
			"cmd" : I18N('ads.rteditor.tableoperations.deleterow'),            //No I18N
			"id" : "delete_row",            //No I18N
			"method" : delete_current_row            //No I18N
		}, {
			"cmd" : I18N('ads.rteditor.tableoperations.deletecolumn'),            //No I18N
			"class" : "li_class",            //No I18N
			"method" : delete_current_column            //No I18N

		}, {
			"cmd" : I18N('ads.rteditor.tableoperations.deletetable'),            //No I18N
			"method" : delete_table            //No I18N
		}],[
			{
			"cmd" : I18N('ads.rteditor.tableoperations.edittable'),
			"method" : edit_table
			}
		]]
	};
	executeFunction = function(temp_val, temp_list) {
	
		//temp_list[temp_val]["method"]();
		temp_list[temp_val].method();
	};
	switch(type) {
			//context menu can be used for other elements if needed
		case "table":            //No I18N
			if(!get_current_row()){  //to ensure that click is made in one of the rows in table and not on border
				return;
			}
				cmoptions=ContextMenu.table;
			break;
	}

hideContextMenu = function(editorFocus) {

		if(!editorFocus){
			if (selectedRange) {
  				editor.restoreSelection(selectedRange);
  			}
  			editor.win.focus();
		}
  		ze_dropdowndiv = document.getElementById("ze_contextMenudd");
		if (ze_dropdowndiv) {
			document.body.removeChild(ze_dropdowndiv);
			ZE._removeEvent(_document,"mousedown", mouse_down);           //No I18N
			ZE._removeEvent(_doc,"mousedown", mouse_down);           //No I18N
			ZE._removeEvent(_doc,"keydown", mouse_down);			           //No I18N
		}
	};
	mouse_down = function(ev) {//if user clicks outside the iframe
		ze_dropdowndiv = document.getElementById("ze_contextMenudd");
		if (ev) {
			_target = ev.target;
			for (; _target !== null ; _target = _target.parentNode){
				if(_target === ze_dropdowndiv){
					break;
				}
			}
		}
		if (!_target) {
			hideContextMenu();
			//hide the context menu
		}
	};
	setPositions = function(ev) {
		var posx = 0;
		var posy = 0,
		$document = document,
		$body = document.body,
		$documentElement = $document.documentElement,
		scrollTopValue = Math.max($body.scrollTop, $documentElement.scrollTop);

		var value1=editor.iframe.getBoundingClientRect();
		var value2 = _target1.getBoundingClientRect();
		if (ev.pageX || ev.pageY) {
				posx=value1.left+value2.left+(ev.pageX-value2.left);
				if(editor.win.scrollY){
					posy=value1.top+value2.top+(ev.pageY-value2.top)-editor.win.scrollY;
				}
				else{
					posy=value1.top+value2.top+(ev.pageY-value2.top)-editor.win.pageYOffset;
				}
			} else {
					posx=value1.left+value2.left+(ev.clientX-value2.left);
					if(editor.win.scrollY){
						posy=value1.top+value2.top+(ev.clientY-value2.top)-editor.win.scrollY;
					}
				else{
					posy=value1.top+value2.top+(ev.clientY-value2.top)-editor.win.pageYOffset;
				}
		}
		posy = posy + (scrollTopValue || 0);
		ze_dropdowndiv.style.left = parseInt(posx) +"px";
		ze_dropdowndiv.style.top = parseInt(posy) + "px";

		var editor_pos = ZE.getPos(editor.editordiv),_style = ze_dropdowndiv.style;
		var ze_dropdowndiv_offsetheight = ze_dropdowndiv.offsetHeight;
		var _docWidth=document.body.getBoundingClientRect().width;

		if(posx + ze_dropdowndiv.offsetWidth + 10 > _docWidth){
			_style.left="auto";   //No I18N
			posx=window.innerWidth-posx;
			_style.right=parseInt(posx) + "px";  //No I18N
		}

		if(posy + ze_dropdowndiv_offsetheight > (window.innerHeight-20))
		{
			var tempTop = posy - ze_dropdowndiv_offsetheight;
			if (tempTop < 10) {
				_style.top = "40px";
			}
		else{
			_style.top = parseInt(tempTop)+"px";
			}
		}

	};
	//constructContextMenu(cmoptions);
	editor.constructContextMenu(cmoptions,"ze_contextMenudd");//No I18N
	editor.win.focus();
	selectedRange=editor.saveSelection();
	ze_dropdowndiv = document.getElementById("ze_contextMenudd");
	setPositions(ev);

	//event listeners when mouse clicked outside of the menu or key is pressed
	ZE._addEvent(_document,"mousedown", mouse_down);           //No I18N
	ZE._addEvent(_doc,"mousedown", mouse_down);           //No I18N
	ZE._addEvent(_doc,"keydown", mouse_down);           //No I18N


};
ZE.prototype.constructContextMenu = function(options,id,ul_click) {
		var editor = this;
		var mainDivElem, divElem, ulElem, liElem, i, j, optlen = options.length;
		mainDivElem = document.createElement("div");
		mainDivElem.className = "ze_dd shw notrans ze_tbdr";
		mainDivElem.id = id;
		divElem = document.createElement("div");
		//divElem.className = "ze_PUcen";
		ulElem = document.createElement("ul");
		//ulElem.className = "ze_PUhr";
		for ( i = 0; i < optlen; i++) {
			var menu_block = options[i];
			for ( j = 0; j < menu_block.length; j++) {
				liElem = document.createElement("li");
				liElem.innerHTML = menu_block[j].cmd;
				if (menu_block[j].id){
					liElem.id = menu_block[j].id;
				}
				if (menu_block[j]["class"]){      // jshint ignore:line
					liElem.className = menu_block[j]["class"];    // jshint ignore:line
				}
				ulElem.appendChild(liElem);
				liElem.setAttribute("data-value",j);
				if (menu_block[j]["data-i"]){         // jshint ignore:line
					liElem.setAttribute("data-i", menu_block[j]["data-i"]);  // jshint ignore:line
				}
				if(menu_block[j].color){
					liElem.style.color=menu_block[j].color;
				}
				if(menu_block[j].fontWeight){        // jshint ignore:line
					liElem.style.fontWeight =menu_block[j].fontWeight;    // jshint ignore:line
				}
			if (menu_block[j].method){
				liElem.onclick = menu_block[j].method;
			}
			}
			liElem = document.createElement("li");
			liElem.className = "ze_lne";  //NO I18N
			ulElem.appendChild(liElem);
		}
		divElem.appendChild(ulElem);
		mainDivElem.appendChild(divElem);
		document.body.appendChild(mainDivElem);
		if(ul_click)
		{
			ZE._addEvent(ulElem,"click",ul_click);  //No I18N
		}
		mainDivElem.addEventListener("contextmenu",function(ev) {editor._stopEvent(ev);return false; } , false);
	};

ZE.prototype.saveSelection=function()
{
 	var editor=this,
        _document=document,
		_doc=editor.doc;
		editor.win.focus();
 	var sel = editor.win.getSelection ? editor.win.getSelection() : _doc.selection;
 	var range;
	try{
 	if (sel) {
  		if (sel.createRange) {
   			range = sel.createRange();
  		} else if (sel.getRangeAt) {
   			if(sel.rangeCount == 0){
   			
   				editor.focusAtStart(true);
   			}
   			else{
   				range = sel.getRangeAt(0);
   			}

  		} else if (sel.anchorNode && sel.focusNode && _doc.createRange) {

   		range = _doc.createRange();
   		range.setStart(sel.anchorNode, sel.anchorOffset);
   		range.setEnd(sel.focusNode, sel.focusOffset);

   // Handle the case when the selection was selected backwards (from the end to the start in the
   // document)
   		if (range.collapsed !== sel.isCollapsed) {
    		range.setStart(sel.focusNode, sel.focusOffset);
    		range.setEnd(sel.anchorNode, sel.anchorOffset);
   			}
  			}
 		}
 		}
 		catch(e){
 		}
 		return range;
};

ZE.prototype.restoreSelection = function(range)
{
	var editor=this,
        _document=document,
		_doc=editor.doc;
	var sel = editor.win.getSelection ? editor.win.getSelection() : _doc.selection;
 if (sel && range) {
  if (range.select) {
   range.select();
  } else if (sel.removeAllRanges && sel.addRange) {
  
   sel.removeAllRanges();
   sel.addRange(range);
  }
 }
};

ZE.prototype._getSelection = function()
{
	return this.win.getSelection();
};

ZE.prototype._createRange = function(sel)
{
	try
	{
		return sel.getRangeAt(0);
	}
	catch(e)
	{
		return this.doc.createRange();
	}
};

ZE.prototype._getSelectedText = function()
{
	try
	{
		var s = this._getSelection();
		if(s)
		{
			return s.toString();
		}
	}
	catch(e)
	{
		return undefined;
	}
};

ZE.prototype.getParentElement = function()
{
	var editor = this,
	    sel = editor._getSelection(),  //present above  --> returns the selected area
	    range = editor._createRange(sel),  //present above
	    p = range.commonAncestorContainer;  /*returns deepest node that contains both Range.startContainer and Range.endContainer*/
	try
	{
		/*range.collapsed specifies whether the start and end position of the selection are same*/
		/*The Range.startOffset read-only property returns a number representing where in the startContainer the Range starts.
		If the startContainer is a Node of type Text, Comment, or CDATASection, then the offset is the number of characters from the start of the startContainer to the boundary point of the Range. For other Node types, the startOffset is the number of child nodes between the start of the startContainer and the boundary point of the Range.*/
		/*endOffset  = start of the endContainer to the boundary point of the Range. */

		if (!range.collapsed && range.startContainer == range.endContainer && range.startOffset - range.endOffset <= 1 && range.startContainer.hasChildNodes())
		{
			p = range.startContainer.childNodes[range.startOffset];
		}
		while (p.nodeType == 3)   //nodeType 3 is textNode
		{
			p = p.parentNode;     //getting the parent of that textNoe
		}
		return p;
	}
	catch (e)
	{
		return undefined;
	}
};

ZE.prototype.pasteHTML = function(html){
    var sel, range;
    var editor = this;
    var _win=editor.win;

    if (_win.getSelection) {
        // IE9 and non-IE
        sel = _win.getSelection();
        if (sel.getRangeAt && sel.rangeCount) {
            range = sel.getRangeAt(0);
            range.deleteContents();
            // Range.createContextualFragment() would be useful here but is
            // only relatively recently standardized and is not supported in
            // some browsers (IE9, for one)
            var el = editor.doc.createElement("div");
            el.innerHTML = html;
            var frag = editor.doc.createDocumentFragment(), node, lastNode;
            while ( (node = el.firstChild) ) {
                lastNode = frag.appendChild(node);
            }
            range.insertNode(frag);
            // Preserve the selection
            if (lastNode) {
                range = range.cloneRange();
                range.setStartAfter(lastNode);
                range.collapse(true);
                sel.removeAllRanges();
                sel.addRange(range);
            }
        }
    } else if (editor.doc.selection && editor.doc.selection.type != "Control") {          //No I18N
        editor.doc.selection.createRange().pasteHTML(html);
    }
};

ZE.prototype.insertHTML = function(html,saveState)
{
  var isIE = /*@cc_on!@*/false || !!document.documentMode;    
    var selection = window.getSelection();  
    var textNode = ZE_Init.textNode; 
    var newOffset = ZE_Init.newOffset; 
    if(textNode != undefined && textNode!=null)
    {
      try
      {
        selection.collapse(textNode, Math.min(textNode.length, newOffset));
      }
    catch(e)
    {

    }
    }
    ZE_Init.currentEditor.doc.body.focus();
    var editor = this,
            _mode = editor.mode;
		if(_mode && _mode === "plaintext")
        {
                editor.insertText(html);
        }
        else
        {
        	editor.win.focus();
        	var temp_content,
        		new_content,
        	temp_content = editor.getContent();
          html = DOMPurify.sanitize(html,{ADD_ATTR: ['contenteditable']});
        	if(editor.squireInstance){
        		editor.squireInstance.insertHTML(html);
        	}else{
        		editor.pasteHtml(html);
        	}
        	new_content = editor.getContent();
        	if(new_content != temp_content && !saveState){
        		//editor.stack.execute(new editor.EditCommand(editor.doc.body,editor.getContent(),editor.saveCursorPosition(editor.doc.body)));
        		editor.saveCurrentState();
        	}
        	/*
                editor.win.focus();
		try
		{
                	editor.doc.execCommand("insertHTML",false,html);		//No I18N
		}
		catch(e)
		{
       			editor_range = editor.range;
			if(!editor_range) //If cursor  is outside editor.
			{
				editor.win.focus();
		 		sel = editor.doc.selection;
		 		editor_range = sel.createRange();
			}
			else
			{
		  		editor_range.select();
                  		delete editor.range;
			}
                	editor_range.pasteHTML(html);
                	editor_range.collapse(false);
                	editor_range.select();
		}*/
	}
};

/* used for inserting html in the textarea mode*/
ZE.prototype.insertText = function(text)
{       //debugger;
        var editor = this,
            _textarea = editor._textarea,
            _textarea_value = _textarea.value,
            _selectionStart = _textarea.selectionStart,
            _selectionEnd = _textarea.selectionEnd;

        if(_textarea)
        {
                text = ZE.getText(text);
                if(_selectionStart || _selectionStart === 0)
                {
                        _textarea.value = _textarea_value.substring(0,_selectionStart) + text + _textarea_value.substring(_selectionEnd,_textarea_value.length);
                }
                else
                {
                        _textarea.value += text;
                }
                _textarea.focus();
        }
};

/* Returns an array with all the ancestor nodes of the selection. */
ZE.prototype.getAllAncestors = function() {
	var editor = this,
        p = editor.getParentElement(),
        a = [];
	while (p && (p.nodeType == 1) && (p.tagName.toLowerCase() != 'body')) {		//No I18N
		a.push(p);
		p = p.parentNode;
	}
	a.push(editor.doc.body);
	return a;
};
/* global ZE_Init,ZE */
/* This function will create the image dialog and its handling*/
ZE.prototype.createImage = function()
{
	var editor = this,
	    ze_ins_image_div = document.getElementById("ze_ins_image"), //for first time it is undefined
	    _form,//holds the form inside the div
	   I18N=ZE.i18n,
	   imgAction,
	   computer_radio,
	   url_radio,
     file_input,
	   url_input,
     insert_btn,
     cancel_btn,
	   comp_imglink,
	   url_imglink,
     size_info_span,
     errorspan,
     infospan,
     choose_image,
     fileinfospan,
     uploadstate,
	   _img,
	   minus_plus_image,
	   radio_options_div,
	   from_computer_div,
	   from_url_div,
	   advance_options_div,
	   _select_height,
	   _select_width,
	   _small_img_radio,
	   _bestfit_img_radio,
	   _original_img_radio,
	   _imgpreview,
	   _imgoriginal_width,
	   _imgoriginal_height,
	   url_radio_option,
	   computer_radio_option,
	   _small_img_radio_option,
	   _bestfit_img_radio_option,
	   _original_img_radio_option,
	   insert_img_btn,
	   existing_image = editor.getParentElement(),
	   maxUploadSize = editor.initobj.imgMaxUploadSize || ZE_Init.maxImageUploadSize || 3;

	   var sizeToDisplay = maxUploadSize+" MB";		//No I18N
	   if (maxUploadSize < 1) {
	     sizeToDisplay = (maxUploadSize * 1024)+" KB";  //No I18N
	   }

       if (typeof editor.initobj.getImgUploadAction === "function") {
		 imgAction = editor.initobj.getImgUploadAction();
	   }else {
		 imgAction = editor.initobj.imgAction || ZE_Init.imgAction;
	   }

	   var fit_width_span, wrap_text_span, aspect_ratio_span, left_radio_span,
	   right_radio_span,center_radio_span, top_radio_span, bottom_radio_span;

	   if (existing_image &&  existing_image.nodeName !== "IMG") {
			existing_image = undefined;
	   }
	   if (typeof editor.initobj.getImgUploadParameters === "function") {
			 imgAction += editor.initobj.getImgUploadParameters();
	   }else{
		 if (typeof ZE_Init.imgParametersFunction === "function") {
		   ZE_Init.imgParametersFunction();
		 }
		 if (ZE_Init.imgParameters) {
	 	   imgAction += ZE_Init.imgParameters;
	 	 }
	   }

		var hideImagediv = function()
		{
			ze_ins_image_div.parentNode.removeChild(ze_ins_image_div);
			ZE.hideOverlay();
			file_input.disabled=computer_radio.disabled=url_radio.disabled=insert_btn.disabled=false;
			(_form) && (_form.reset());
			editor.win.focus();
			ZE._removeEvent(document,"keydown",esckey);  //No I18N
			ZE._removeEvent(editor.doc,"keydown",esckey);  //No I18N
			comp_imglink.removeAttribute("src");
			url_imglink.removeAttribute("src");
			comp_imglink.style.display = "none";
			url_imglink.style.display = "none";
			if(ZE.activeEditor)
			{
				delete (ZE.activeEditor);
			}
			if(ZE.captchaProcessing)
			{
				delete (ZE.captchaProcessing);
			}
		};
		var esckey = function(ev)
	    {
		var captcha_Div = document.getElementById("ze_captcha");
		if(ev.keyCode == 27)
		{
		  if(captcha_Div && captcha_Div.style.display !=="none")  //Deals with esc key press
		    {
					captcha_Div.style.display = "none";
					return;
		    }
			editor._stopEvent(ev);
			hideImagediv();
		}
	};

		var computerMode = function(){

			ZE.removeClass(computer_radio_option, "zei-unoption");	//No I18N
	  		ZE.addClass(computer_radio_option, "zei-option");	//No I18N

	  		ZE.removeClass(url_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(url_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(_small_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_small_img_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(_bestfit_img_radio_option, "zei-unoption");	//No I18N
	  		ZE.addClass(_bestfit_img_radio_option, "zei-option");	//No I18N

	  		ZE.removeClass(_original_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_original_img_radio_option, "zei-unoption");	//No I18N	  			  		 _

	  		from_computer_div.style.display="";
			from_url_div.style.display="none";

			if(comp_imglink.src) {
				comp_imglink.style.display="";
				_imgpreview.style.display="none";
				fileinfospan.style.display="";
				errorspan.style.display="none";
				infospan.style.display = "none";
			} else {
				_imgpreview.style.display="block";
				comp_imglink.style.display="none";
				if(!uploadstate || uploadstate == "finished"){
					ZE.insertImageMsg((I18N("ads.rteditor.editorpop.file_max_size") + sizeToDisplay),"imginfo");  //No I18N
					ZE.removeClass(errorspan,"ze_popuperrmsg");
					infospan.style.display = "none";
				}
				else if(uploadstate && uploadstate =="loading"){
					infospan.style.display = "";
					errorspan.style.display="none";
				}
			}
			url_imglink.style.display="none";
		};
		var urlMode = function(){
			ZE.removeClass(computer_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(computer_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(url_radio_option, "zei-unoption");	//No I18N
	  		ZE.addClass(url_radio_option, "zei-option");	//No I18N

			ZE.removeClass(_small_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_small_img_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(_bestfit_img_radio_option, "zei-unoption");	//No I18N
	  		ZE.addClass(_bestfit_img_radio_option, "zei-option");	//No I18N

	  		ZE.removeClass(_original_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_original_img_radio_option, "zei-unoption");	//No I18N

			from_computer_div.style.display="none";
			from_url_div.style.display="";

			comp_imglink.style.display="none";
			if(url_imglink.src){
				url_imglink.style.display="";
				_imgpreview.style.display="none";
			}
			else {
				url_imglink.style.display="none";
				_imgpreview.style.display="block";
			}
			url_input.focus();
			fileinfospan.style.display="none";
			errorspan.style.display = "none";
 			infospan.style.display = "none";
		};
		var setFocus = function()
        {
            if(existing_image)
            {
                insert_btn.focus();
            }
            else
            {
                if(url_radio.checked)
                {
                    url_input.focus();
                }
            }
        };
		var initialise = function(){
			/*inputs in the dialog start*/
			var _input = ze_ins_image_div.getElementsByTagName("input");

			file_input = _input[0];
			url_input = _input[1];

			/* spans */
			var _span=ze_ins_image_div.getElementsByTagName("span");

			var _label = ze_ins_image_div.getElementsByTagName("label");
			computer_radio = _span[0];
            url_radio = _span[1];
            choose_image = _label[2];

            errorspan = _span[2];

            infospan = _span[3];
            fileinfospan = _span[4];

            _small_img_radio=_span[5];
            _bestfit_img_radio=_span[6];
            _original_img_radio=_span[7];

            _imgpreview=_span[8];

            insert_btn = _span[9];
            cancel_btn = _span[10];

            _form = document.ze_img_form;
            _form.action = imgAction;

            /*divs */
            var _div = ze_ins_image_div.getElementsByTagName("div");
            from_computer_div = _div[3];
            from_url_div = _div[5];
            insert_img_btn = from_computer_div = _div[4];

            /*tds */
            var _td = ze_ins_image_div.getElementsByTagName("td");
             radio_options_div = _td[0];

            /*i tag */
             _img = ze_ins_image_div.getElementsByTagName("i");
             minus_plus_image = _img[1];

             /*images*/
             comp_imglink = document.getElementById("ze_comp_img");
              url_imglink = document.getElementById("ze_url_img");
              comp_imglink.removeAttribute("src");
			 url_imglink.removeAttribute("src");

			 computer_radio_option=computer_radio.getElementsByTagName("i")[0];
			 url_radio_option=url_radio.getElementsByTagName("i")[0];
			 _small_img_radio_option=_small_img_radio.getElementsByTagName("i")[0];
            _bestfit_img_radio_option=_bestfit_img_radio.getElementsByTagName("i")[0];
            _original_img_radio_option=_original_img_radio.getElementsByTagName("i")[0];

             if(existing_image){
             	urlMode();
             	radio_options_div.style.display = "none";
             	url_imglink.src = existing_image.src;
             	url_imglink.style.display="";
             	url_input.disabled = true;
             	url_input.value = existing_image.src;
             }
             else{
             	computerMode();
             	radio_options_div.style.display = "";
             	url_input.disabled = false;
             }
		};


		ZE.showOverlay();
		editor.win.focus();
		selectedRange=editor.saveSelection();

		/*Header part starts*/
		var tmp = '<div class="zep_PUtt">'+I18N("ads.rteditor.icon.insert_img")+'<i class="zei-close"></i></div>';  //No I18N
		/*Header part ends*/

	 	/*main div*/

   
	 	tmp+='<div class="zep_PUcen"><form id="ze_img_form" name="ze_img_form" method="post" enctype="multipart/form-data" action="'+imgAction+'" target="ze_img_request">';

	 	tmp+='<table class="ze_ptble">';
        tmp+='<tbody>'; //No I18N
        tmp+='<tr>';
	 	tmp+='<td colspan="2" style="padding-bottom:10px;"><span><i class="zei-option"></i>';
	 	tmp+='<label for="ze_img_comp">'+I18N("ads.rteditor.editorpop.upload_disk")+'</label>&nbsp;&nbsp;';     //No I18N
	 	tmp+='</span><span><i class="zei-unoption"></i>';
	 	tmp+='<label for="ze_img_url">'+I18N("ads.rteditor.editorpop.img_url")+'</label>';      //No I18N
	 	tmp+='</span></td>';
	 	tmp+='</tr>';
        tmp+='<tr>';
        tmp+='<td colspan="2" style="padding-bottom:10px;">';
        tmp+='<div>';
        tmp+='<div style="height:0px;width:0px;visibility:hidden;">';
        tmp+='<input type="file" id="UPLOADED_FILE"  name="UPLOADED_FILE">';
        tmp+='</div>';
        tmp+='<div>';
        tmp+='<label for="UPLOADED_FILE" id="ze_choose_image" class="ze_input_text">'+ I18N("ads.rteditor.editorpop.choose_img")+'</label>';//No I18N
        tmp+='</div>';
		    tmp+='<div style="display: none;"><input  class="ze_input_text"  type="text" placeholder = "'+(I18N("ads.rteditor.editorpop.img_url_provide")+" URL")+'"></div>';
        tmp+='</div>';
        tmp+='<p class="ze_iiSnF"><span>'+I18N("ads.rteditor.editorpop.file_max_size" + sizeToDisplay)+'</span></p><span style="display: none;"><img src="'+ZE_Init.imgPath+'/images/loading.gif" align="absmiddle" style="margin-right:3px;"><b style="color:#1daf15;">'+I18N("ads.rteditor.editorpop.img_uploading")+'</b></span><span class="ze_iiSnF" style="display:none;"></span>';
        tmp+='</td>';
        tmp+='</tr>';

        tmp+='<tr>';
        tmp+='<td valign="middle">';
        tmp+='<div class="ze_iiS"><span><i class="zei-unoption"></i>';
        tmp+='<label for="ze_img_comp">'+I18N("ads.rteditor.editorpop.img_small")+'</label>'; //No I18N
        tmp+='</span></div>';
        tmp+='<div class="ze_iiS"><span><i class="zei-unoption"></i>';
        tmp+='<label for="ze_img_comp">'+I18N("ads.rteditor.editorpop.img_best")+'</label>'; //No I18N
        tmp+='</span></div>';
        tmp+='<div class="ze_iiS"><span><i class="zei-option"></i>';
        tmp+='<label for="ze_img_comp">'+I18N("ads.rteditor.editorpop.img_orig")+'</label>';  //No I18N
        tmp+='</span></div></td>';
        tmp+='<td  width="122"><div class="ze_iiI"><span class="ze_iiIP" style="display: block;">'+I18N("ads.rteditor.editorpop.img_prev")+'</span><img id="ze_comp_img" display:="" none;"="" style="display: none;"><img id="ze_url_img" style="width: 120px; height: 120px; display: none;"></div></td>';
        tmp+='</tr>';

        tmp+='</tbody></table><input type="hidden" name="'+ZE.getCSRFParamName()+'" value="'+ZE.getCSRFCookie(editor)+'"/></form>';
	 	tmp+= '</div>';

	 	/*Footer */
        tmp+='<div class="zep_PUbtm"><span class="sel">'+I18N("ads.rteditor.editorpop.insert")+'</span><span data-val="Cancel">'+I18N("ads.rteditor.editorpop.cancel")+'</span></div>';

		var div1 = document.createElement("div");
		div1.className="zep_PU";
		div1.id = "ze_ins_image";
		div1.name = "ze_ins_image";
		div1.innerHTML = tmp;

		document.body.appendChild(div1);
		ze_ins_image_div = div1;

		initialise();
		/*positioning the div*/
		ZE.setPosition(ze_ins_image_div,editor.editordiv);
		setFocus();
		ZE._addEvent(editor.doc,"keydown",esckey);  //No I18N
		ZE._addEvent(document,"keydown", esckey);   //No I18N

		/* event handling for url click start*/
		computer_radio.onclick = function(){

     	 	if(document.getElementById("ze_comp_img")) {
    	  		document.getElementById("ze_comp_img").style.display = "";
      		}
      		if(document.getElementById("ze_url_img")) {
    	  		document.getElementById("ze_url_img").style.display = "none";
      		}
      		computerMode();
      		setFocus();
		};

		url_radio.onclick = function(){
        ZE_Init.jQuery(document).off('focusin.bs.modal');
	  		if(document.getElementById("ze_comp_img")) {
		 		document.getElementById("ze_comp_img").style.display = "none";
	  		}
	  		if(document.getElementById("ze_url_img")) {
		  		document.getElementById("ze_url_img").style.display = "";
	  		}
      		urlMode();
      		setFocus();
		};

		 _small_img_radio.onclick = function(){

		 	ZE.removeClass(_small_img_radio_option, "zei-unoption");	//No I18N
	  		ZE.addClass(_small_img_radio_option, "zei-option");	//No I18N

	  		ZE.removeClass(_bestfit_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_bestfit_img_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(_original_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_original_img_radio_option, "zei-unoption");	//No I18N
		 };

		 _bestfit_img_radio.onclick = function(){
		 	ZE.removeClass(_small_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_small_img_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(_bestfit_img_radio_option, "zei-unoption");	//No I18N
	  		ZE.addClass(_bestfit_img_radio_option, "zei-option");	//No I18N

	  		ZE.removeClass(_original_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_original_img_radio_option, "zei-unoption");	//No I18N
		 };

		 _original_img_radio.onclick = function(){
		 	ZE.removeClass(_small_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_small_img_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(_bestfit_img_radio_option, "zei-option");	//No I18N
	  		ZE.addClass(_bestfit_img_radio_option, "zei-unoption");	//No I18N

	  		ZE.removeClass(_original_img_radio_option, "zei-unoption");	//No I18N
	  		ZE.addClass(_original_img_radio_option, "zei-option");	//No I18N
		 };



		url_img_upload =  function(){
			var tempimgurl = url_input.value;
			if(tempimgurl.length==0){
				return;
			}
			var http = "ht"+"tp://", https = "ht"+"tps://";			//No I18N
			if( !(url_input.value.indexOf(http) === 0) && !(url_input.value.indexOf(https) === 0 )){
				var i18n_msg = (I18N("ads.rteditor.editorpop.invalid_url")+http+I18N("ads.rteditor.editorpop.or")+https+". ");  //No I18N
        		ZE.insertImageMsg(i18n_msg,"error");    //No I18N
        		_imgpreview.style.display="block";
        		url_imglink.style.display = "none";
				url_imglink.removeAttribute("src");
        		return;
      		}
			else if(tempimgurl && url_imglink.src !== tempimgurl)
			{
				_imgpreview.style.display="none";
				url_imglink.src = tempimgurl;
				url_imglink.style.display = "";
				url_imglink.onerror = function(){
					url_imglink.removeAttribute("src");
					url_imglink.style.display = "none";
					var i18n_msg = I18N("ads.rteditor.editorpop.no_img");  //No I18N
        			ZE.insertImageMsg(i18n_msg,"error");  //No I18N
        			_imgpreview.style.display="block";
        			return;
				};
			}
			errorspan.style.display="none";
		};

		url_input.onkeyup = url_input.onblur = url_img_upload;
		url_input.onpaste = url_input.oncut =  function(){
			setTimeout(url_img_upload, 50);
		};

		/* image upload start*/


	fileInputChange =  function(ev){
    var fileNameRegEx = /^[a-zA-Z0-9.\\-_ ]{0,255}$/;
		var contextParam = "";
			if (file_input.files && file_input.files[0]) {
			if(!fileNameRegEx.test(file_input.files[0].name)){
        ZE.insertImageMsg(I18N("ads.rteditor.editorpop.invalid_file_name").replace('{0}', fileNameRegEx), "error");  // No I18N

        file_input.value="";
        if(file_input.value!=""){  //for IE 9 and 10
          var temp_file_input=file_input.cloneNode(true);
          temp_file_input.onchange=file_input.onchange;
          file_input.parentNode.replaceChild(temp_file_input,file_input);
        }

        return;
      }
      if(file_input.files[0].size/(1024*1024) > maxUploadSize){
				ZE.insertImageMsg((I18N("ads.rteditor.editorpop.file_max_size") + sizeToDisplay), "error");  // No I18N

				file_input.value="";
				if(file_input.value!=""){  //for IE 9 and 10
					var temp_file_input=file_input.cloneNode(true);
					temp_file_input.onchange=file_input.onchange;
					file_input.parentNode.replaceChild(temp_file_input,file_input);
				}

				return;
			}
		}
  		if(ZE_Init.context)
		{
			if(ZE_Init.imgParameters)
			{
				_form.action = imgAction+"&context="+ZE_Init.context;
			}
			else
			{
				_form.action = imgAction+"?context="+ZE_Init.context;
			}
			contextParam = "&context="+ZE_Init.context;  //No I18N
  		}
		if(ZE.captchaParam)
		{
			if(ZE_Init.imgParameters || ZE_Init.context) //If service team pass some other parameter
			{
			  _form.action = imgAction+"&"+ZE.captchaParam+contextParam;
			}
			else
			{
			    _form.action = imgAction+"?"+ZE.captchaParam+contextParam;
			}
			delete (ZE.captchaParam);
		}
		else
		{
		   	editor._stopEvent(ev);
		}
    	ZE.captchaProcessing = file_input.onchange;
		var file_input_value = file_input.value;
		if(file_input.value==""){
			return;
		}
		if(!(/(\.(gif|jpg|jpeg|bmp|png))$/i.test(file_input_value)))
		{
      		var temp_i18n = I18N("ads.rteditor.editorpop.img_format");  //No I18N
			_form.reset();
			ZE.insertImageMsg(temp_i18n+" GIF/JPG/PNG","error");//No I18N
			_imgpreview.style.display="block";
			comp_imglink.style.display="none";
			comp_imglink.removeAttribute("src");
			file_input.focus();
			return false;
		}
		ZE.activeEditor=editor;
		comp_imglink.style.visibility="hidden";
		fileinfospan.style.display="none";
		comp_imglink.style.width="";
		comp_imglink.style.height="";
		var file_name;
		uploadstate="loading";	//No I18N
		if(file_input.files){
				file_name=file_input.files[0].name;
		}
		else{
				file_name=file_input.value;
		}
		comp_imglink.onload = function()
		{
			uploadstate="finished";	//No I18N
			comp_imglink.onload = undefined;
			file_input.disabled=computer_radio.disabled=url_radio.disabled=insert_btn.disabled=false;
			infospan.style.display="none";

			if(file_name.length>45){
				var type=file_name.substring(file_name.lastIndexOf('.'),file_name.length);
				var name=file_name.substring(0,40)+"..";
				file_name=name+type;
			}
			fileinfospan.textContent=I18N(file_name);
		    _imgoriginal_width=this.width;
	   		_imgoriginal_height=this.height,

			comp_imglink.style.width="118px";
			comp_imglink.style.height="118px";
			if(ZE.hasClass(url_radio_option,"zei-option")){  // if url radio is selected after uploading file
				comp_imglink.style.display="none";
				fileinfospan.style.display="none";
			}else{
				_imgpreview.style.display="none";
				fileinfospan.style.display="";
				errorspan.style.display="none";
			}
			comp_imglink.style.visibility="";
			choose_image.innerHTML=I18N("Replace Image");	  //No I18N
		};
		file_input.disabled = false;
		_form.submit();
		file_input.disabled=computer_radio.disabled=url_radio.disabled=insert_btn.disabled=true;
		ZE.insertImageMsg(I18N(""),"info");//No I18N
	};

	file_input.onchange = fileInputChange;
	/* event handling start for close*/

	insert_img_btn.onclick=function(ev){
			if(!ZE_Init.is_ie){
				editor._stopEvent(ev);
				file_input.click();
			}
	};


	ze_ins_image_div.getElementsByClassName("zei-close")[0].onclick=cancel_btn.onclick = function(ev){
		editor._stopEvent(ev);
		hideImagediv();
	};
	insert_btn.onclick = function(ev)
    {
            /*This function will update the image object with the values in the popupdialog*/
            var updateStyles = function(img)
            {
            	var max_bestfit_width=400;
            	var bestfit_width=parseInt(editor.editordiv.offsetWidth*(3/4));
            	if (bestfit_width> max_bestfit_width) {
            		bestfit_width=max_bestfit_width;
            	}
            	if (ZE.hasClass(url_radio_option,"zei-option")) {
            		if (img.width) {
            			_imgoriginal_width = img.width;
            			_imgoriginal_height = img.height;
            		}
            		else {
    		        	_imgoriginal_width = img.naturalWidth;
            			_imgoriginal_height = img.naturalHeight;
            		}
            	}
            	img.setAttribute("orig_width", _imgoriginal_width);
            	img.setAttribute("orig_height", _imgoriginal_height);
              img.setAttribute("size_option", "original");

              if(ZE.hasClass(_small_img_radio_option, "zei-option")) {
              	var reduce_ratio = 2.5;
              	if(_imgoriginal_width > bestfit_width){
              		reduce_ratio = _imgoriginal_width/150;
              	}
                img.width = (_imgoriginal_width/reduce_ratio);
                img.height = (_imgoriginal_height/reduce_ratio);
                img.setAttribute("size_option","small");
              } else if(ZE.hasClass(_bestfit_img_radio_option, "zei-option")){
              	var reduce_ratio = 1;
              	if(_imgoriginal_width > bestfit_width){
              		reduce_ratio = _imgoriginal_width/bestfit_width;
              	}
                img.width = (_imgoriginal_width/reduce_ratio);
                img.height = (_imgoriginal_height/reduce_ratio);
                img.setAttribute("size_option","bestfit");
              }
              img.style.display = "";
            };

            /* for existing image start*/
            if(existing_image)
            {
                updateStyles(existing_image);
            }
            else
            {
                var imgurl;
                if(ZE.hasClass(computer_radio_option,"zei-option"))
                {
					imgurl = editor.imgURL;
                    if(!file_input.value || !imgurl)
                    {
                        var i18n_msg = I18N("ads.rteditor.editorpop.img_comp_err");  //No I18N
                        ZE.insertImageMsg(i18n_msg,"error");//No I18N
                        file_input.focus();
                        return false;
                    }
                }
                else if(ZE.hasClass(url_radio_option,"zei-option"))
                {
                    imgurl = url_input.value;
                    if(!imgurl)
                    {
                        var i18n_msg = I18N("ads.rteditor.editorpop.img_url_err");  //No I18N
                        ZE.insertImageMsg(i18n_msg,"error");//No I18N
                        url_input.focus();
                        return false;
                    }
                    if(!url_imglink.src){
                    	return false;
                    }
                }
                if (selectedRange) {
  						editor.restoreSelection(selectedRange);
  				}
                editor.win.focus();
                var newrange;
                var newsel = editor._getSelection();
                try
                {
                	if(!newsel.isCollapsed){
                		sel.deleteFromDocument();
                	}
                	newrange = newsel.getRangeAt(0);
                }
                catch(e)
                {
                	newrange=editor._createRange(newsel);
                }
                var new_img = editor.doc.createElement("img");
                new_img.src = imgurl;
                new_img.style.display="none";
                setTimeout(function(){updateStyles(new_img);editor.saveCurrentState();},500);   //to wait for image height and width values to get loaded                                                     -
                newrange.insertNode(new_img);
               	newrange.selectNode(new_img);
                newrange.collapse(false);
                newsel.removeAllRanges();
                newsel.addRange(newrange);
            }
            editor._stopEvent(ev);
            hideImagediv();
			delete editor.imgURL;
        };

	ZE.prototype.previewImage = function(imgurl){

		var editor = this,
			img,
			imgpopup = document.getElementById("ze_ins_image"),
			newsel,
			newrange;

		if(imgpopup && imgpopup.style.display!="none"){
			img = document.getElementById("ze_comp_img");
			img.src = imgurl;
			editor.imgURL = imgurl;
			img.style.display="";
		}
		else {
			img = document.createElement('img');
			img.src = imgurl;
			newsel = editor._getSelection();
			newrange = editor._createRange(newsel);
			newrange.insertNode(img);
 	   	newrange.selectNode(img);
    	newrange.collapse(false);
    	newsel.removeAllRanges();
    	newsel.addRange(newrange);
		}
};
};
/* This function will handle the image info in the dialog*/
ZE.insertImageMsg = function(msg,msgtype)
{
	var ze_ins_image_div = document.getElementById("ze_ins_image"),
		I18N=ZE.i18n,
		_input,
		_span,
		_label,
		choose_image,
		errorspan,
		infospan,
		fileinfospan,
		_imgpreview,
		computer_radio,
		computer_radio_option,
		file_input,
		comp_imglink;

		if(ze_ins_image_div){

			_input = ze_ins_image_div.getElementsByTagName("input");
			_span = ze_ins_image_div.getElementsByTagName("span");
			_label = ze_ins_image_div.getElementsByTagName("label");

			choose_image = _label[2];
			errorspan = _span[2];
			infospan = _span[3];
			fileinfospan = _span[4];
			_imgpreview=_span[8];
			computer_radio = _span[0];
    		computer_radio_option=computer_radio.getElementsByTagName("i")[0];
			comp_imglink = document.getElementById("ze_comp_img");

			if(msgtype == "info")
			{
				errorspan.innerHTML="";
				errorspan.style.display="none";
				infospan.style.display="";
			}
			else if(msgtype == "error")
			{
				infospan.style.display="none";
				errorspan.innerHTML=msg;
				errorspan.style.display="block";
				ZE.addClass(errorspan, "ze_popuperrmsg");	//No I18N
				file_input = _input[0];
				if(comp_imglink && ZE.hasClass(computer_radio_option,"zei-option")){
    			comp_imglink.removeAttribute("src");
    			_imgpreview.style.display="block";
					comp_imglink.style.display="none";
					file_input.disabled=false;
					file_input.value="";
					if(file_input.value!=""){  //for IE 9 and 10
						var temp_file_input=file_input.cloneNode(true);
						temp_file_input.onchange=file_input.onchange;
						file_input.parentNode.replaceChild(temp_file_input,file_input);
					}
					choose_image.innerHTML=I18N("Click to choose an image"); //No I18N
					fileinfospan.style.display="none";
				}
    		}
    		else if(msgtype == "imginfo"){
    			infospan.style.display="none";
    			errorspan.innerHTML=msg;
    			errorspan.style.display="block";
    		}
    }
};

/* This function will handle the image error from the jsp*/
ZE.insertErrorMsg = function(msg)
{
    var comp_imglink = document.getElementById("ze_comp_img"),
    	I18N=ZE.i18n;
    if(comp_imglink){
			var ze_ins_image_div = document.getElementById("ze_ins_image");
			var _span = ze_ins_image_div.getElementsByTagName("span");
			var computer_radio = _span[0];
            var url_radio = _span[1];
			var _input = ze_ins_image_div.getElementsByTagName("input");
			var comp_imglink = document.getElementById("ze_comp_img");
			var _label = ze_ins_image_div.getElementsByTagName("label");
      var file_input = _input[0],
      	choose_image,
      	_imgpreview,
      	fileinfospan,
      	_imgpreview,
      	errorspan,
      	infospan;

      choose_image = _label[2];
			errorspan = _span[2];
			infospan = _span[3];
			fileinfospan = _span[4];
			_imgpreview=_span[8];

      _input = ze_ins_image_div.getElementsByTagName("input");
			_span = ze_ins_image_div.getElementsByTagName("span");

			file_input.disabled=computer_radio.disabled=false;
			infospan.style.display="none";
			errorspan.innerHTML=msg;
			ZE.addClass(errorspan, "ze_popuperrmsg");
			errorspan.style.display="";
			choose_image.innerHTML=I18N("ads.rteditor.editorpop.choose_img");  //No I18N
			fileinfospan.style.display="none";
			_imgpreview.style.display="block";
			comp_imglink.removeAttribute("src");
			file_input.value="";
			if(file_input.value!=""){  //for IE 9 and 10
					var temp_file_input=file_input.cloneNode(true);
					temp_file_input.onchange=file_input.onchange;
					file_input.parentNode.replaceChild(temp_file_input,file_input);
			}
		}
		else{
			// alert(msg);
		}
 };

 /* globals ZE*/
 ZE.prototype.resizeElement = function (_target, _event) {
   "use strict"; // NO I18N
   var _anchorTarget = _target,
     editor = this,
     _document = document,
     I18N = ZE.i18n,
     imageClicked = false,
     doc = editor.doc,
     image = _target,
     enclosingDiv,
     bestFitValue,
     smallValue,
     origWidth,
     origHeight,
     mainSpan,
     _small,
     _bestfit,
     _original,
     _remove,
     smallDiv,
     value2,
     currentValX,
     currentValY,
     removeDivs;

   var setValues = function () {
     var maxBestFitWidth = 400;
     var bestFitWidth = parseInt(editor.editordiv.offsetWidth * (3 / 4));
     var bestFitReduceRatio = 1,
       smallReduceRatio = 2.5;
     if (bestFitWidth > maxBestFitWidth) {
       bestFitWidth = maxBestFitWidth;
     }
     origWidth = image.getAttribute("orig_width");
     origHeight = image.getAttribute("orig_height");

     if (origWidth > bestFitWidth) {
       bestFitReduceRatio = origWidth / bestFitWidth;
       smallReduceRatio = origWidth / 150;
     }

     bestFitValue = bestFitReduceRatio; // to avoid recalculation
     smallValue = smallReduceRatio;

     if (image.hasAttribute("size_option")) {
       var selectedValue = image.getAttribute("size_option");

       if (selectedValue === "small") {
         _small.className = "ze_sltd";
       } else if (selectedValue === "original") {
         _original.className = "ze_sltd";
       } else if (selectedValue === "bestfit") {
         _bestfit.className = "ze_sltd";
       }
     }
   };

   var getHeight = function (_element) {
     return parseFloat(_element.style.height);
   };
   var getWidth = function (_element) {
     return parseFloat(_element.style.width);
   };
   var getTop = function (_element) {
     return parseFloat(_element.style.top);
   };
   var getLeft = function (_element) {
     return parseFloat(_element.style.left);
   };

   var getImageWidth = function (_element) {
     return (_element.width || parseFloat(_element.style.width));
   };

   var setImageHeight = function (_element, value) {
     _element.height = value;
   };
   var setImageWidth = function (_element, value) {
     _element.width = value;
   };
   var setTop = function (_element, value) {
     _element.style.top = value + "px";
   };
   var setLeft = function (_element, value) {
     _element.style.left = value + "px";
   };

   var minimumWidth = function () { // to check for minimum width
     if (getWidth(enclosingDiv) > 18) {
       return true;
     }
     return false;
   };


   var smallImage = function () {
     setImageWidth(image, origWidth / smallValue);
     setImageHeight(image, origHeight / smallValue);
     image.setAttribute("size_option", "small");
     editor.win.focus();
     removeDivs();
     editor.saveCurrentState();
   };
   var bestfitImage = function () {
     setImageWidth(image, origWidth / bestFitValue);
     setImageHeight(image, origHeight / bestFitValue);
     image.setAttribute("size_option", "bestfit");
     editor.win.focus();
     removeDivs();
     editor.saveCurrentState();
   };
   var removeImage = function () {
     image.parentElement.removeChild(image);
     editor.win.focus();
     removeDivs();
     editor.saveCurrentState();
   };
   var originalImage = function () {
     setImageWidth(image, origWidth);
     setImageHeight(image, origHeight);
     image.setAttribute("size_option", "original");
     removeDivs();
     editor.win.focus();
     editor.saveCurrentState();
   };

     // creating menu for image element
   mainSpan = doc.createElement("span");
   mainSpan.id = "ze_imgBlock";
   mainSpan.className = "ze_spell";
   _small = doc.createElement("span");
   _small.innerHTML = I18N("ads.rteditor.editorpop.img_small"); // No I18N
   _bestfit = doc.createElement("span");
   _bestfit.innerHTML = I18N("ads.rteditor.editorpop.img_best"); // No I18N
   _original = doc.createElement("span");
   _original.innerHTML = I18N("ads.rteditor.editorpop.img_orig"); // No I18N
   _remove = doc.createElement("span");
   _remove.innerHTML = I18N("ads.rteditor.editorpop.remove"); // No I18N

   mainSpan.appendChild(_small);
   mainSpan.appendChild(_bestfit);
   mainSpan.appendChild(_original);
   mainSpan.appendChild(_remove);
   doc.body.appendChild(mainSpan);


   ZE._addEvent(_remove, "click", removeImage); // No I18N
   ZE._addEvent(_original, "click", originalImage); // No I18N
   ZE._addEvent(_small, "click", smallImage); // No I18N
   ZE._addEvent(_bestfit, "click", bestfitImage); // No I18N
     // ------------------------------------------------------------------------------------------------------

   enclosingDiv = doc.createElement("div");
   doc.body.appendChild(enclosingDiv);
   enclosingDiv.className = "enc";

   value2 = image.getBoundingClientRect();
   var posx = value2.left;
   var posy = value2.top;

   if (editor.win.scrollX) {
     enclosingDiv.style.left = (posx + editor.win.scrollX) + "px";
   } else {
     enclosingDiv.style.left = (posx + editor.win.pageXOffset) + "px";
   }


   if (editor.win.scrollY) {
     enclosingDiv.style.top = (value2.top + editor.win.scrollY) + "px";
   } else {
     enclosingDiv.style.top = (value2.top + editor.win.pageYOffset) + "px";
   }
   enclosingDiv.style.height = image.height + "px";
   enclosingDiv.style.width = image.width + "px";

   mainSpan.contentEditable = "false";
   mainSpan.style.left = enclosingDiv.style.left;
   setTop(mainSpan, (getTop(enclosingDiv) + getHeight(enclosingDiv)));
   setValues();

   if (editor.win.scrollY) {
     posy += editor.win.scrollY;
   } else {
     posy += editor.win.pageYOffset;
   }

   if (editor.win.scrollX) {
     posx += editor.win.scrollX;
   } else {
     posx += editor.win.pageXOffset;
   }

   var smallDiv1 = doc.createElement("div");
   smallDiv1.className = "smallDiv";
   doc.body.appendChild(smallDiv1);
   smallDiv1.style.top = posy + "px";
   smallDiv1.style.left = posx + "px";
   smallDiv1.style.cursor = "nw-resize";

   var smallDiv2 = doc.createElement("div");
   smallDiv2.className = "smallDiv";
   doc.body.appendChild(smallDiv2);
   smallDiv2.style.top = posy + "px";
   smallDiv2.style.left = (posx + image.width - 9) + "px";
   smallDiv2.style.cursor = "ne-resize";

   var smallDiv3 = doc.createElement("div");
   smallDiv3.className = "smallDiv";
   doc.body.appendChild(smallDiv3);
   smallDiv3.style.top = (posy + image.height - 9) + "px";
   smallDiv3.style.left = (posx + image.width - 9) + "px";
   smallDiv3.style.cursor = "se-resize";

   var smallDiv4 = doc.createElement("div");
   smallDiv4.className = "smallDiv";
   doc.body.appendChild(smallDiv4);
   smallDiv4.style.top = (posy + image.height - 9) + "px";
   smallDiv4.style.left = posx + "px";
   smallDiv4.style.cursor = "sw-resize";

   var mouseDown = function (ev) { // if user clicks outside the iframe
     var _target1;
     var $zeLink = doc.getElementById("ze_imgBlock");
     if (ev) {
       _target1 = ev.target;
       for (; _target1 !== null; _target1 = _target1.parentNode) {
         if (_target1 === $zeLink || _target1 === smallDiv1 || _target1 === smallDiv2 ||
                     _target1 === smallDiv3 || _target1 === smallDiv4 || _target1 === image) {
           break;
         }
       }
     }
     if (!_target1) {
             // editor._stopEvent(ev);
       removeDivs();
     }
   };

   var keyDown = function (ev) {
     var kCode = ev.keyCode;
     if (kCode === 46) {
       removeImage();
     } else {
       removeDivs();
     }
   };

   var setPosDivs = function () { // setting the positions of handlers based on enclosingDiv
     smallDiv1.style.left = enclosingDiv.style.left;
     smallDiv1.style.top = enclosingDiv.style.top;
     setLeft(smallDiv2, getWidth(enclosingDiv) + getLeft(enclosingDiv) - 9);
     smallDiv2.style.top = enclosingDiv.style.top;
     smallDiv3.style.left = enclosingDiv.style.left;
     setTop(smallDiv3, getHeight(enclosingDiv) + getTop(enclosingDiv) - 9);
     setLeft(smallDiv4, getWidth(enclosingDiv) + getLeft(enclosingDiv) - 9);
     setTop(smallDiv4, getHeight(enclosingDiv) + getTop(enclosingDiv) - 9);
   };

   removeDivs = function () {
     var $zeLink = doc.getElementById("ze_imgBlock");
     if ($zeLink) {
       doc.body.removeChild($zeLink);
     }
     ZE._removeEvent(doc, "mousedown", mouseDown); // No I18N
     ZE._removeEvent(_document, "mousedown", mouseDown); // No I18N
     ZE._removeEvent(doc, "keydown", keyDown); // No I18N

     if (smallDiv1) {
       smallDiv1.parentElement.removeChild(smallDiv1);
       smallDiv2.parentElement.removeChild(smallDiv2);
       smallDiv3.parentElement.removeChild(smallDiv3);
       smallDiv4.parentElement.removeChild(smallDiv4);
       enclosingDiv.parentElement.removeChild(enclosingDiv);
     }
   };

	 var alterImage = function () { // altering size of image based on enclosing div's size

		 image.height = parseFloat(enclosingDiv.style.height);
		 image.width = parseFloat(enclosingDiv.style.width);
		 if (image.style.width) {
			 image.style.width = "";
		 }
		 if (image.style.height) {
			 image.style.height = "";
		 }
	};

   var mouseUp = function () {
     imageClicked = false;
         // editor._stopEvent(e);
     removeEventListenerUp();
     alterImage();

     ZE._removeEvent(smallDiv1, "mousedown", startResize); // No I18N
     ZE._removeEvent(smallDiv2, "mousedown", startResize); // No I18N
     ZE._removeEvent(smallDiv3, "mousedown", startResize); // No I18N
     ZE._removeEvent(smallDiv4, "mousedown", startResize); // No I18N

     smallDiv1.parentElement.removeChild(smallDiv1);
     smallDiv2.parentElement.removeChild(smallDiv2);
     smallDiv3.parentElement.removeChild(smallDiv3);
     smallDiv4.parentElement.removeChild(smallDiv4);
     enclosingDiv.parentElement.removeChild(enclosingDiv);

     var zeLink = doc.getElementById("ze_imgBlock");
     if (zeLink) {
       doc.body.removeChild(zeLink);
     }

     if (getImageWidth(image) === origWidth / bestFitValue) {
       image.setAttribute("size_option", "bestfit");
     } else if (getImageWidth(image) === origWidth / smallValue) {
       image.setAttribute("size_option", "small");
     } else if (getImageWidth(image) === origWidth) {
       image.setAttribute("size_option", "original");
     }
     editor.saveCurrentState();
   };

   var mouseMove = function (_div, e) {
     if (imageClicked) {
       if (e.clientX <= 0 || e.clientY <= 0 || e.clientX > editor.editordiv.offsetWidth) {
         mouseUp(_div);
         return;
       }
             /* values of enclosing Divs*/
       var enX = getLeft(enclosingDiv);
       var enY = getTop(enclosingDiv);
       var enHeight = getHeight(enclosingDiv);
       var enWidth = getWidth(enclosingDiv);

       var rightSide, topHandler, diff, ratio, valueToadd,
         tempValue, valueTosub, divX, divY; // diff for diff in mouse movement

       if (_div === smallDiv2) {
         rightSide = 0;
         topHandler = 0;
       } else if (_div === smallDiv3) {

         rightSide = 0;
         topHandler = 1;
       } else if (_div === smallDiv4) {

         rightSide = 1;
         topHandler = 0;
       } else {

         rightSide = 1;
         topHandler = 1;
       }

       if (e.clientX < currentValX) { // if mouse is moved left side
         diff = currentValX - e.clientX;
         if (rightSide === 0) { // right side handlers
           if (minimumWidth()) {
             ratio = enWidth / (enWidth - diff);
             enWidth /= ratio;
             valueToadd = enHeight - (enHeight / ratio);
             enHeight /= ratio;
             ZE.setCss(enclosingDiv, "height", enHeight + "px");
             ZE.setCss(enclosingDiv, "width", enWidth + "px");
             if (topHandler === 0) {
               setTop(enclosingDiv, getTop(enclosingDiv) + valueToadd);
             }
           }
         } else { // left side handlers
           ratio = (enWidth + diff) / enWidth;
           tempValue = enWidth - (enWidth / ratio);
           enWidth += (enWidth - (enWidth / ratio));

           valueTosub = enHeight - (enHeight / ratio);
           enHeight += (enHeight - (enHeight / ratio));
           ZE.setCss(enclosingDiv, "height", enHeight + "px"); // NO I18N
           ZE.setCss(enclosingDiv, "width", enWidth + "px"); // NO I18N
           divX = getLeft(enclosingDiv);
           divY = getTop(enclosingDiv);
           setLeft(enclosingDiv, divX - tempValue);
           if (topHandler === 1) {
             setTop(enclosingDiv, getTop(enclosingDiv) - valueTosub);
           }
         }
       } else { // if mouse is moved right side
         diff = e.clientX - currentValX;
         if (rightSide === 0) { // right side handlers

           ratio = (enWidth + diff) / enWidth;
           enWidth += (enWidth - (enWidth / ratio));
           valueToadd = enHeight - (enHeight / ratio);
           enHeight += valueToadd;
           ZE.setCss(enclosingDiv, "height", enHeight + "px"); // NO I18N
           ZE.setCss(enclosingDiv, "width", enWidth + "px"); // NO I18N
           if (topHandler === 0) {
             setTop(enclosingDiv, getTop(enclosingDiv) - valueToadd);
           }
         } else { // left side handlers
           if (minimumWidth()) {
             ratio = (enWidth) / (enWidth - diff);
             tempValue = enWidth - (enWidth / ratio);
             enWidth /= ratio;

             valueTosub = enHeight - (enHeight / ratio);
             enHeight /= ratio;
             ZE.setCss(enclosingDiv, "height", enHeight + "px"); // NO I18N
             ZE.setCss(enclosingDiv, "width", enWidth + "px"); // NO I18N

             divX = getLeft(enclosingDiv);
             setLeft(enclosingDiv, divX + tempValue);
             if (topHandler === 1) {
               setTop(enclosingDiv, getTop(enclosingDiv) + valueTosub);
             }
           }
         }
       }
       setPosDivs();
       currentValX = e.clientX; // updating the latest positions
       currentValY = e.clientY;

       if (image.hasAttribute("size_option")) {
         image.removeAttribute("size_option");
       }
     }
   };
   var doMouseMove = function (event) {
     mouseMove(smallDiv, event);
   };

   var doMouseDown = function (event) {
     mouseDown(smallDiv, event);
   };

   var doMouseUp = function (event) {
     editor._stopEvent(event);
     mouseUp(smallDiv, event);
   };

   var removeEventListenerUp = function () {
     ZE._removeEvent(doc, "mousemove", doMouseMove); // No I18N
     ZE._removeEvent(doc, "mouseup", doMouseUp); // No I18N
   };

   var startResize = function (ev) {
     smallDiv = this;

     imageClicked = true;
     editor._stopEvent(ev);

         // initial positions where mouse is clicked
     currentValX = ev.clientX;
     currentValY = ev.clientY;

     ZE._removeEvent(doc, "mousedown", mouseDown); // No I18N
     ZE._removeEvent(_document, "mousedown", mouseDown); // No I18N
         /* on pressing any key , resize handlers should be removed*/
     ZE._removeEvent(doc, "keydown", keyDown); // No I18N
         /* resizing mouse move*/
     ZE._addEvent(doc, "mousemove", doMouseMove); // No I18N
         /* when mouse is released after resizing*/
     ZE._addEvent(doc, "mouseup", doMouseUp); // No I18N
   };

   ZE._addEvent(doc, "mousedown", mouseDown); // No I18N
   ZE._addEvent(_document, "mousedown", mouseDown); // No I18N
   ZE._addEvent(doc, "keydown", keyDown); // No I18N

   ZE._addEvent(smallDiv1, "mousedown", startResize); // No I18N
   ZE._addEvent(smallDiv2, "mousedown", startResize); // No I18N
   ZE._addEvent(smallDiv3, "mousedown", startResize); // No I18N
   ZE._addEvent(smallDiv4, "mousedown", startResize); // No I18N

 };

ZE.prototype.insertImage = function (imgUrl, options, attributes) {
  "use strict"; // No I18N
  var image,
    editor = this,
    origWidth,
    origHeight,
    modifiedDimensions,
    attrObj,
    sizeOption;

  options = options || {};
  sizeOption = options.size || "original"; // No I18N

  if (!imgUrl) {
    return;
  }
  var getDimensionValues = function (width, height, option) {
    var max_bestfit_width = 400,
      bestfit_width = parseInt(editor.editordiv.offsetWidth * (3 / 4)),
      option = option || "original", // No I18N
      modifiedWidth,
      modifiedHeight,
      reduce_ratio;
    if (bestfit_width > max_bestfit_width) {
      bestfit_width = max_bestfit_width;
    }
    if (option === "small") { // No I18N
      reduce_ratio = 2.5;
      if (width > bestfit_width) {
        reduce_ratio = width / 150;
      }
      modifiedWidth = width / reduce_ratio;
      modifiedHeight = height / reduce_ratio;
    } else if (option === "") {
      reduce_ratio = 1;
      if (_imgoriginal_width > bestfit_width) {
        reduce_ratio = _imgoriginal_width / bestfit_width;
      }
      modifiedWidth = (width / reduce_ratio); // No I18N
      modifiedHeight = (height / reduce_ratio); // No I18N
    } else {
      modifiedWidth = width;
      modifiedHeight = height;
    }
    return {
      width: modifiedWidth,
      height: modifiedHeight
    };
  };
  if (typeof Image === "function") { // No I18N
    image = new Image();
  } else {
    image = document.createElement("img"); // No I18N
  }
  image.onload = function () {
    attrObj = attributes || {};
    origWidth = this.width;
    origHeight = this.height;
    attrObj.orig_width = origWidth;
    attrObj.orig_height = origHeight;
    modifiedDimensions = getDimensionValues(origWidth, origHeight, sizeOption);
    attrObj.style = (attrObj.style || "");
    this.width = modifiedDimensions.width;
    this.height = modifiedDimensions.height;
    attrObj.size_option = sizeOption;
    editor.squireInstance.insertImage(imgUrl, attrObj);
  };
  image.onerror = function () {};
  image.src = imgUrl;
};
/* globals ZE,DOMPurify*/
ZE.prototype.showInsertHTMLDialog = function (ev) {
  "use strict";// No I18N
  var editor = this,
    _document = document,
    wrapperDOM = editor.doc.getElementById('ze_ins_insertHtml'), // NO I18N
    I18N = ZE.i18n,
    closeButton,
    buttons,
    textArea,
    _okButton,
    _cancelButton,
    escKeyHandler;
	ZE_Init.jQuery(document).off('focusin.bs.modal');

  var getDOM = function () {
    return [
      '<div class="zep_PUtt">' + I18N('ads.rteditor.editorpop.insert_html') + '<i class="zei-close"></i></div>', // NO I18N
        '<div class="zep_PUcen">', // NO I18N
        '<table class="ze_ptble">', // NO I18N
        '<tbody>', // NO I18N
        '<tr>', // NO I18N
        '<td>', // NO I18N
          '<textarea class="zep_ptxtara" style="width:500px;height:250px;resize:none;">', // NO I18N
          '</textarea>', // NO I18N
        '</td>', // NO I18N
        '</tr>', // NO I18N
        '</tbody>', // NO I18N
        '</table>', // NO I18N
        '</div>', // NO I18N
        '<div class="zep_PUbtm">', // NO I18N
          '<span class="sel">' + I18N('ads.rteditor.editorpop.ok') + '</span>', // NO I18N
          '<span data-val="Cancel">' + I18N('ads.rteditor.editorpop.cancel') + '</span>', // NO I18N
        '</div>' // NO I18N
    ].join('');
  };

  var hideDialog = function () {
    _document.removeEventListener('keydown', escKeyHandler, true); // NO I18N
    wrapperDOM.parentNode.removeChild(wrapperDOM);
    ZE.hideOverlay();
  };

  escKeyHandler = function (event) {
    if (event.keyCode === 27) {
      editor._stopEvent(event);
      hideDialog();
    }
  };

  var onOk = function () {
    var value = textArea.value;
    var hookMethod;
    hideDialog();
    if (DOMPurify) {
      hookMethod = ZE.getHookMethod("ze_insert_html", editor.initobj.hookOnInsertHTML);// No I18N
      ZE.addHook("afterSanitizeElements", hookMethod); // No I18N
      value = DOMPurify.sanitize(value, {
        originator: "ze_insert_html", // No I18N
        ADD_TAGS: editor.initobj.allowTagsInsertHTML || [],
        ADD_ATTR: editor.initobj.allowAttrsInsertHTML || []
      }); // No I18N
      ZE.removeHook("afterSanitizeElements", hookMethod); // No I18N
    }
    editor.insertHTML(value);
  };

  if (wrapperDOM) {
    return;
  }

  ZE.showOverlay();
  wrapperDOM = _document.createElement('div'); // NO I18N
  wrapperDOM.id = 'ze_ins_insertHtml'; // NO I18N
  wrapperDOM.className = 'zep_PU zep_arrb'; // NO I18N
  wrapperDOM.innerHTML = getDOM();
  _document.body.appendChild(wrapperDOM);
  ZE.setPosition(wrapperDOM, editor.editordiv);
  textArea = wrapperDOM.getElementsByTagName('textarea')[0]; // NO I18N
  closeButton = wrapperDOM.getElementsByClassName('zei-close')[0]; // NO I18N
  buttons = wrapperDOM.getElementsByTagName('span'); // NO I18N
  _okButton = buttons[0];
  _cancelButton = buttons[1];
  textArea.focus();
  _cancelButton.onclick = closeButton.onclick = function (event) {
    editor._stopEvent(event);
    hideDialog();
  };

  _okButton.onclick = function (event) {
    editor._stopEvent(event);
    onOk();
  };

  ZE._addEvent(_document, 'keydown', escKeyHandler);	 // NO I18N
};
ZE.getHookMethod = function (originator, fn) {
  "use strict"; // NO I18N
  if (typeof fn === "function") { // NO I18N
    return function (currentNode, data, config) {
      if (config.originator && config.originator === originator) {// No I18N
        fn(currentNode, data);
      }
    };
  }
};

ZE.addHook = function (hookName, fn) {
  "use strict"; // NO I18N
  if (typeof fn === "function") { // NO I18N
    DOMPurify.addHook(hookName, fn);
  }
};

ZE.removeHook = function (hookName, fn) {
  "use strict"; // NO I18N
  if (typeof fn === "function") { // NO I18N
    DOMPurify.removeHook(hookName, fn);
  }
};
/* globals ZE,ZE_Init */
/* This function will create the link dialog and its handling*/

ZE.prototype.createLink = function () {
  "use strict";// No I18N
  var editor = this,
    _document = document,
    $zeLinkDiv = _document.getElementById("ze_link"), // No I18N
    I18N = ZE.i18n,
    selectedText = editor._getSelectedText(),
    _input,
    urlRadio,
    emailRadio,
    textInput,
    urlInput,
    emailInput,
    subjectInput,
    textSpan,
    urlSpan,
    emailSpan,
    subjectSpan,
    isLink,
    existingLink,
    isImage,
    linkhtml,
    buttons,
    closeButton,
    selectedRange,
    keyEventHandler,
    okButton,
    linkErrSpan;
    ZE_Init.jQuery(document).off('focusin.bs.modal');


  /* for first time zeLinkDiv it is undefined*/
  /*  getParentElement() is in zerange.js */


  for (existingLink = editor.getParentElement();
    existingLink !== null && existingLink.nodeName !== "BODY"; // No I18N
    existingLink = existingLink.parentNode) {
    if (existingLink.nodeName === "A") { // No I18N
      isLink = true;
      break;
    } else if (existingLink.nodeName === "IMG") { // No I18N
      isImage = true;
      if (existingLink.parentNode.nodeName === "A") { // No I18N
        isLink = true;
        existingLink = existingLink.parentNode;
      }
      break;
    }
  }

  var hideLinkDiv = function () {
    var _form = $zeLinkDiv.getElementsByTagName("form")[0]; // No I18N
    ZE._removeEvent(_document, "keydown", keyEventHandler); // No I18N
    $zeLinkDiv.parentNode.removeChild($zeLinkDiv);
    ZE.hideOverlay();
    if (_form) {
      _form.reset();
    }
  };

  keyEventHandler = function (ev) {
    if (ev.keyCode === 27) {
      editor._stopEvent(ev);
      hideLinkDiv();
    }
    if (ev.keyCode === 13) {
      editor._stopEvent(ev);
      okButton(ev);
    }
  };

  var urlMode = function () {
    urlRadio.checked = true;
    emailRadio.checked = false;
    ZE.removeClass(urlRadio, "zei-unoption"); //No I18N
    ZE.addClass(urlRadio, "zei-option");  //No I18N
    ZE.removeClass(emailRadio, "zei-option");  //No I18N
    ZE.addClass(emailRadio, "zei-unoption"); //No I18N
    emailSpan.style.display = subjectSpan.style.display = "none"; // No I18N
    urlSpan.style.display = "";
    linkErrSpan.style.display = "none";
    
  };

  var emailMode = function () {
    urlRadio.checked = false;
    emailRadio.checked = true;
    ZE.removeClass(emailRadio, "zei-unoption");  //No I18N
    ZE.addClass(emailRadio, "zei-option"); //No I18N

    ZE.removeClass(urlRadio, "zei-option");  //No I18N
    ZE.addClass(urlRadio, "zei-unoption"); //No I18N


    urlSpan.style.display = "none";// No I18N
    linkErrSpan.style.display = "none";
    emailSpan.style.display = subjectSpan.style.display = "";
  };

  var setFocus = function () {
    if (urlRadio.checked && (isImage || selectedText)) {
      urlInput.focus();
    } else if (emailRadio.checked && (isImage || selectedText)) {
      emailInput.focus();
    } else {
      textInput.focus();
    }
  };

  /* this function will initialise the local variables and the dialog init*/
  var createLinkSelection = function (_urlValue, textValue) {
    // debugger;
    var sel,
      range,
      atag;
    editor.doc.execCommand("createlink", false, _urlValue); // No I18N
    try {
      sel = editor._getSelection();
      sel.collapseToEnd();
      atag = editor.getParentElement();
      if (atag.tagName === "A") {// No I18N
        if (!ZE_Init.preventTargetBlank) {
          atag.target = "_blank";// No I18N
        }
        if (atag.textContent !== textValue && !atag.getElementsByTagName("img")) {// No I18N
          atag.textContent = textValue;
        }
        range = editor._createRange(sel);
        range.selectNode(atag);
        sel.removeAllRanges();
        sel.addRange(range);
        sel.collapseToEnd();
      }
    } catch (e) {
      if (editor.range) {
        editor.range.select();
        delete editor.range;
      }
      editor.doc.execCommand("createlink", false, _urlValue); // No I18N
      atag = editor.getParentElement();
      if (atag.tagName === "A") {// No I18N
        if (!ZE_Init.preventTargetBlank) {
          atag.target = "_blank";// No I18N
        }
        if (atag.innerText !== textValue && !atag.getElementsByTagName("img")) {// No I18N
          atag.innerText = textValue;
        }
        sel = editor._getSelection();
        range = editor._createRange(sel);
        range.moveToElementText(atag);
        range.collapse(false);
        range.select();
      }

    }
    var range1 = editor.doc.createRange();
    range1.setStart(atag, 0);
    range1.setEndAfter(atag);
    range1.selectNode(atag);
    var selection = editor.iframe.contentWindow.getSelection();
    selection.removeAllRanges();
    selection.addRange(range1);
    editor.win.focus();
    editor.iframe.contentWindow.getSelection().collapseToEnd();
    editor.saveCurrentState();
  };

  var initialise = function () {

    var _tr,
      href,
      split1,
      split2;
    /* variable initialisation start*/
    _input = $zeLinkDiv.getElementsByTagName("input");// No I18N
    urlRadio = $zeLinkDiv.getElementsByTagName("span")[0];
    emailRadio = $zeLinkDiv.getElementsByTagName("span")[1];
    textInput = _input[0];
    urlInput = _input[1];
    emailInput = _input[2];
    subjectInput = _input[3];
    // tooltip_input = _input[6];

    buttons = $zeLinkDiv.getElementsByTagName("span");// No I18N
    closeButton = $zeLinkDiv.getElementsByClassName("zei-close")[0]; // No I18N

    _tr = $zeLinkDiv.getElementsByTagName("tr");// No I18N

    textSpan = _tr[1];
    urlSpan = _tr[2];
    emailSpan = _tr[3];
    subjectSpan = _tr[4];
    linkErrSpan = _tr[5];
    /* variable initialisation start*/

    if (isImage) {
      textSpan.style.display = "none";// No I18N
    } else {
      textSpan.style.display = "";
    }

    /* updating the link parameters in the dilog*/
    if (isLink) {
      if (!isImage) {
        textInput.value = existingLink.textContent;
      }

      if (existingLink.protocol === "mailto:") {// No I18N
        emailMode();
        href = existingLink.href;
        split1 = href.split("mailto:");// No I18N
        split2 = split1[1].split("?subject=");// No I18N
        emailInput.value = split2[0] || "";
        subjectInput.value = split2[1] || "";
      } else {
        urlMode();
        urlInput.value = existingLink.href;
      }
      // tooltip_input = existingLink.title || "";
    } else {
      urlMode();
      if (!isImage) {
        textInput.value = selectedText || "";
      }
    }
  };

  var regexEmail = new RegExp("^[\\w]([\\w\-\\.\\+\\']*)@([\\w\\-\\.]*)(\\.[a-zA-Z]{2,22}(\\.[a-zA-Z]{2}){0,2})$");// No I18N
  var regexUrl = new RegExp("^(ht|f)tp(s?)\\:\\/\\/[-.\\w]*(\\/?)([a-zA-Z0-9\\-\\.\\?\\,\\:\\'\\/\\\\\\+=&amp;%\\$#_@]*)?$");// No I18N

  var _selectedText = ZE.trim(selectedText);
  if (regexEmail.test(_selectedText) && !isLink) {
    createLinkSelection("mailto:" + _selectedText, _selectedText);// No I18N
    return;
  } else if (regexUrl.test(_selectedText) && !isLink) {
    createLinkSelection(_selectedText, _selectedText);
    return;
  }
  ZE.showOverlay();
  /* showOverlay is in common.js*/
  editor.win.focus();
  selectedRange = editor.saveSelection();

  linkhtml = '<div class="zep_PUtt">' + I18N("ads.rteditor.editorpop.link_insert") + '<i class="zei-close"></i></div>';// No I18N
  linkhtml += '<div class="zep_PUcen">';// No I18N
  linkhtml += '<form><table class="ze_ptble">';// No I18N
  linkhtml += '<tr><td>' +// No I18N
    '</td><td><span><i id="ze_link_url"></i><label for="ze_link_url">' +// No I18N
    I18N("ads.rteditor.editorpop.url") +// No I18N
    '&nbsp;&nbsp;</label></span><span><i id="ze_link_email"></i><label for="ze_link_email">' +// No I18N
    I18N("ads.rteditor.editorpop.email") +// No I18N
    '</label></span></td>';// No I18N

  linkhtml += '<tr><td>' + I18N("ads.rteditor.editorpop.link_select_text") + '&nbsp;</td><td><input type="text"></td></tr>'; // No I18N
  linkhtml += '<tr><td>' + I18N("ads.rteditor.editorpop.link_addr") + '</td><td><input type="text"></td></tr>'; // No I18N
  linkhtml += '<tr style="display:none;"><td>' +// No I18N
    I18N("ads.rteditor.editorpop.email_addr") +// No I18N
    '</td><td><input type="text"></td></tr>';// No I18N
  linkhtml += '<tr style="display:none;"><td>' + I18N("ads.rteditor.editorpop.subject") + '</td><td><input type="text"></td></tr>';// No I18N
  
  linkhtml += '<tr style="display:none;"><td colspan="2" style="padding-bottom:10px;"><p><span></span></p></td></tr>'; //No I18N

  linkhtml += '</table></form>'+'</div>'; // No I18N
  linkhtml += '<div class="zep_PUbtm"><span class="sel">' +// No I18N
    I18N("OK") +// No I18N
    '</span><span data-val="Cancel">' +// No I18N
    I18N("Cancel") + '</span></div></div>';// No I18N

  var div1 = _document.createElement("div");// No I18N
  div1.className = "zep_PU";// No I18N
  div1.innerHTML = linkhtml;
  div1.id = "ze_link";// No I18N
  document.body.appendChild(div1);
  $zeLinkDiv = div1;
  initialise();

  /* setting the position*/
  ZE.setPosition($zeLinkDiv, editor.editordiv);
  setFocus();

  /* event handling for url click start*/
  urlRadio.onclick = function () {
    urlMode();
    setFocus();
  };

  emailRadio.onclick = function () {
    emailMode();
    setFocus();
  };
    /* event handling for url click end*/

    /* event handling start for close*/
  closeButton.onclick = buttons[4].onclick = function (ev) {
    editor._stopEvent(ev);
    hideLinkDiv();
  };


  /* event handling start for click*/
  okButton = function (ev) {
    var http = "ht" +// No I18N
    "tp://", // No I18N
      https = "ht" +// No I18N
      "tps://"; // No I18N
    editor._stopEvent(ev);

    /* getting the url value to update,remove or creating link*/
    var textValue = textInput.value,
      urlValue,
      subjectValue,
      sel,
      range,
      imglnk,
      anchorElement;

    if (selectedRange) {
      editor.restoreSelection(selectedRange);
    }
    if (urlRadio.checked) {
      urlValue = urlInput.value;
      urlValue = ZE.trim(urlValue);
    } else if (emailRadio.checked) {
      urlValue = emailInput.value;
      urlValue = ZE.trim(urlValue);
    }

    subjectValue = subjectInput.value;
    // tooltip_value = tooltip_input.value;

    /* link exists removal or modification*/
    if (isLink) {
      /* removing link*/
      if (!urlValue) {
        if (true) {
          // confirm("Please confirm that you want to unlink this element." + "\n" + "\n" + "Link points to:" + " " + decodeURI(existingLink.href))
          sel = editor._getSelection();
          range = editor._createRange(sel);
          range.selectNode(existingLink);
          editor.doc.execCommand("unlink", false, null); // No I18N
          hideLinkDiv();
        }
      } else { // modifying link
        if (urlRadio.checked) {
          if ((urlValue.indexOf(http) === 0) ||
          (urlValue.indexOf(https) === 0 ) ||
          (urlValue.indexOf("ftp://") === 0) ||// No I18N
          (urlValue.indexOf("ssh://") === 0)) {// No I18N
          } else {
            urlValue = http + urlValue;
          }
        } else if (emailRadio.checked) {
          urlValue = "mailto:" + urlValue; // No I18N
          if (subjectValue) {
            urlValue += "?subject=" + subjectValue;// No I18N
          }
        }
        existingLink.href = urlValue;
				/* adding target */
        if (!ZE_Init.preventTargetBlank) {
          existingLink.target = "_blank"; // No I18N
        }
        if (!isImage && existingLink.textContent !== textValue) {
          existingLink.textContent = textValue;
        }
        range = editor.doc.createRange();
        range.setStart(existingLink, 0);
        range.setEndAfter(existingLink);
        range.selectNode(existingLink);
        var selection = editor.iframe.contentWindow.getSelection();
        selection.removeAllRanges();
        selection.addRange(range);
        editor.win.focus();
        if (selectedRange) {
          editor.restoreSelection(selectedRange);
        }
        editor.saveCurrentState();
      }
    } else { // creating new link for text or image
      textValue = ZE.trim(textValue);
      if (!textValue && !isImage) {
        // alert(I18N("You must Select or ENTER Some text to create link")); // No I18N
        ZE.insertLinkErrMsg("ads.rteditor.editorerr.enter_text");


        textInput.focus();
        return false;
      }

      if (urlRadio.checked) {
        if (!urlValue) {
          // alert(I18N("Please enter URL to make a link")); // No I18N
          ZE.insertLinkErrMsg("ads.rteditor.editorerr.enter_url");
          urlInput.focus();
          return false;
        }
        if ((urlValue.indexOf(http) === 0) ||
        (urlValue.indexOf(https) === 0) ||
        (urlValue.indexOf("ftp://") === 0) ||// No I18N
        (urlValue.indexOf("ssh://") === 0)) {// No I18N
        } else {
          urlValue = http + urlValue;
        }
      } else if (emailRadio.checked) {
        if (!urlValue) {
          // alert(I18N("Please enter Email to make a link")); // No I18N
          ZE.insertLinkErrMsg("ads.rteditor.editorerr.enter_email");
          emailInput.focus();
          return false;
        }
        urlValue = "mailto:" + urlValue; // No I18N
        if (subjectValue) {
          urlValue += "?subject=" + subjectValue; // No I18N
        }
      }

      if (isImage) {
        // debugger;
        editor.doc.execCommand("createlink", false, urlValue); // No I18N
        sel = editor._getSelection();
        sel.collapseToEnd();
        imglnk = editor.getParentElement();
        if (imglnk && imglnk.tagName.toLowerCase() === "a") {// No I18N
          /* adding target */
          if (!ZE_Init.preventTargetBlank) {
            imglnk.target = "_blank"; // No I18N
          }
        }
        var atag = imglnk.parentElement;
        range = editor._createRange(sel);
        range.selectNode(atag);
        sel.removeAllRanges();
        sel.addRange(range);
        sel.collapseToEnd();
      } else if (selectedText && selectedText.length !== 0) {
        createLinkSelection(urlValue, textValue);
      } else {
        var tmp = "<a id='an_link'"; // No I18N
        if (!ZE_Init.preventTargetBlank) {
          tmp += "target='_blank'"; // No I18N
        }
        tmp += "></a>"; // No I18N
        editor.win.focus();
        editor.pasteHTML(tmp);
        anchorElement = editor.doc.getElementById("an_link");// No I18N
        /* To deal with relative link issue,while inserting link of same domain,when no selection is there*/
        if (anchorElement) {
          anchorElement.appendChild(editor.doc.createTextNode(textValue));
          anchorElement.setAttribute("href", urlValue);// No I18N
          anchorElement.removeAttribute("id");// No I18N
        }
        editor.saveCurrentState();
      }
    }
    hideLinkDiv();
    return false;
  };
  buttons[3].onclick = okButton;
  ZE._addEvent(_document, "keydown", keyEventHandler);// No I18N
};

/* called when link is clicked*/
ZE.prototype.showAnchorTag = function (_target) {
  "use strict"; // No I18N
  var _anchorTarget = _target,
    editor = this,
    _document = document,
    I18N = ZE.i18n,
    mouseDownHandler,
    $zeLink,
    removeEventListeners,
    keyDownHandler,
    saveAndRestoreFocus,
    removeAnchor,
    setPositions,
    anchorEle,
    mainSpan;
    // editor.win.focus();

  var selectedRange = editor.saveSelection();

  mouseDownHandler = function (ev) { // if user clicks outside the iframe
    $zeLink = document.getElementById("ze_linkBlock");// No I18N
    if (ev) {
      _target = ev.target;
      for (; _target !== null; _target = _target.parentNode) {
        if (_target === $zeLink) {
          break;
        }
      }
    }
    if (!_target) {
      removeEventListeners();
    }
  };
  keyDownHandler = function () {
    removeEventListeners();
  };
  removeEventListeners = function () {
    $zeLink = document.getElementById("ze_linkBlock");// No I18N
    if ($zeLink) {
      document.body.removeChild($zeLink);
      ZE._removeEvent(_document, "mousedown", mouseDownHandler); // No I18N
      ZE._removeEvent(editor.doc, "mousedown", mouseDownHandler); // No I18N
      ZE._removeEvent(editor.doc, "keydown", keyDownHandler); // No I18N"
    }
  };
  saveAndRestoreFocus = function () {
    var range = editor.doc.createRange();
    range.setStart(_anchorTarget, 0);
    range.setEndAfter(_anchorTarget);
    range.selectNode(_anchorTarget);
    var selection = editor.iframe.contentWindow.getSelection();
    selection.removeAllRanges();
    selection.addRange(range);
    editor.win.focus();
    if (selectedRange) {
      editor.restoreSelection(selectedRange);
    }
  };

  removeAnchor = function () {
    var range = editor.doc.createRange();
    range.setStart(_anchorTarget, 0);
    range.setEndAfter(_anchorTarget);
    range.selectNode(_anchorTarget);
    var selection = editor.iframe.contentWindow.getSelection();
    selection.removeAllRanges();
    selection.addRange(range);
    editor.win.focus();
    editor.doc.execCommand("unlink", false, null); // No I18N
    editor.iframe.contentWindow.getSelection().collapseToStart();
    removeEventListeners();
    editor.saveCurrentState();
  };
  setPositions = function () {
    var $zeLinkDom = document.getElementById("ze_linkBlock");// No I18N
    var editorPos = ZE.getPos(editor.editordiv),
      _style = $zeLinkDom.style,
      $document = document,
      $body = document.body,
      $documentElement = $document.documentElement;
        // setting position
    var posx = 0;
    var posy = 0;
    var value1 = editor.iframe.getBoundingClientRect();
    var value2 = _anchorTarget.getBoundingClientRect();
    var _docWidth = document.body.getBoundingClientRect().width;
    var blockWidth;
    posx = value1.left + value2.left;
    posy = value1.top + value2.top + _anchorTarget.offsetHeight + (Math.max($body.scrollTop, $documentElement.scrollTop) || 0);
    if (posx < _docWidth / 2) {
      _style.left = parseInt(posx) + "px"; // No I18N
      _style.top = parseInt(posy) + "px"; // No I18N
      _style.right = "auto"; // No I18N
      blockWidth = (posx + $zeLinkDom.offsetWidth);
    } else {
      _style.left = "auto"; // No I18N
      _style.top = parseInt(posy) + "px"; // No I18N
      posx = window.innerWidth - posx - _anchorTarget.offsetWidth;
      _style.right = parseInt(posx) + "px"; // No I18N
      blockWidth = (posx + $zeLinkDom.offsetWidth);
    }
    _style.zIndex="9002";

    
    if (blockWidth >= ZE_Init.jQuery("#ze_id").width()) {
      var tempRef = anchorEle.innerHTML;
      if (tempRef.length > 55) {
        tempRef = tempRef.substring(0, 54) + "..."; // No I18N
      }
      anchorEle.innerHTML = tempRef;
    }
    if (posy + $zeLinkDom.offsetHeight > editor.editordiv.offsetHeight + editorPos.offsetTop) {
            // var tempTop = posy - _offsetheight;
      _style.top = "auto"; // No I18N
      posy = window.innerHeight - posy + _anchorTarget.offsetHeight;
      _style.bottom = parseInt(posy) + "px"; // No I18N
    }
  };
    // creating menu for anchor element


  $zeLink = document.getElementById("ze_linkBlock");// No I18N
  if ($zeLink) {
    removeEventListeners();
  }
  mainSpan = document.createElement("span");// No I18N
  mainSpan.id = "ze_linkBlock";// No I18N
  mainSpan.className = "ze_spell";// No I18N

  anchorEle = document.createElement("a");// No I18N
  if (_anchorTarget.href.indexOf("mailto") === 0) {// No I18N
    anchorEle.appendChild(editor.doc.createTextNode(_anchorTarget.href));
  } else {
    anchorEle.setAttribute("href", _anchorTarget.href);// No I18N
    mainSpan.appendChild(editor.doc.createTextNode((I18N("ads.rteditor.editorpop.link_goto")+": ")));// No I18N
    anchorEle.appendChild(editor.doc.createTextNode(_anchorTarget.href)); // No I18N
    anchorEle.target = "_blank";// No I18N
    anchorEle.style.marginLeft = "-5px";// No I18N
  }
  mainSpan.appendChild(anchorEle);
  var changeAnchor = document.createElement("span");// No I18N
  changeAnchor.innerHTML = I18N("ads.rteditor.editorpop.change"); // No I18N
  var _removeAnchor = document.createElement("span");// No I18N
  _removeAnchor.innerHTML = I18N("ads.rteditor.editorpop.remove"); // No I18N
  var close = document.createElement("i");// No I18N
  close.className = "zei-close";// No I18N

  mainSpan.appendChild(anchorEle);
  mainSpan.appendChild(changeAnchor);
  mainSpan.appendChild(_removeAnchor);
  mainSpan.appendChild(close);
  document.body.appendChild(mainSpan);
  setPositions();

    // event listeners for li elements
  ZE._addEvent(close, "click", function () { // No I18N
    removeEventListeners();
    saveAndRestoreFocus();
  });
  ZE._addEvent(_removeAnchor, "click", removeAnchor); // No I18N
  ZE._addEvent(changeAnchor, "click", function () { // No I18N
    if (selectedRange) {
      editor.restoreSelection(selectedRange);
    }
    editor.win.focus();
    editor.createLink(_anchorTarget);
    removeEventListeners();
  });

  editor.updateToolbar();
    // event listeners when clicked outside menu
  ZE._addEvent(_document, "mousedown", mouseDownHandler); // No I18N
  ZE._addEvent(editor.doc, "mousedown", mouseDownHandler); // No I18N
  ZE._addEvent(editor.doc, "keydown", keyDownHandler); // No I18N
};

/* This function will spellcheck/removespellcheck the document in both modes
 *
 * plaintext,richtext
 *
 * */
/* globals ZE */

ZE.prototype.spellcheck = function () {
    // return;
  var editor = this,
    _toolbar = editor.toolbarobject,
    _spellcheck_tbobj = _toolbar.spellcheck;

  var spellcheckoptions_toolbarobject = _toolbar.spellcheckoptions,
  spellchecklang = "locale", // No I18N
    _document = document,
    I18N = ZE.i18n,
    contextValue = ZE.getContextValue();
    ZE.activeEditor = editor;
    if(spellcheckoptions_toolbarobject.hasAttribute("data-lang"))
    {
      spellchecklang = spellcheckoptions_toolbarobject.getAttribute("data-lang");
    }
    else if(ZE_Init.useProxy){
    	spellchecklang = navigator.language;
    }
    else{
    	spellchecklang = "locale";  //No I18N
    }


  var ze_spellcheck_iframe = _document.getElementById("ze_spellcheck");
  var srcValue = contextValue + "/ze/spellcheck?spellchecklang=" + spellchecklang + "&domainname=" + ZE_Init.domain; // No I18N
  if (ZE_Init.useProxy && ZE_Init.spellcheckProxyUrl) {
    srcValue += "&spellcheckurl=" + ZE_Init.spellcheckProxyUrl + "&useProxy=" + ZE_Init.useProxy; // No I18N
  } else {
    srcValue += "&spellcheckurl=" + ZE_Init.spellcheckURL; // No I18N
  }

  if (ZE_Init.useSameDomain) {
    srcValue += "&useSameDomain=true"; // No I18N
  }

    // for first time it is undefined
  if (ze_spellcheck_iframe) {
    ze_spellcheck_iframe.src = srcValue;
  } else {
    var _iframe = _document.createElement("iframe");
    _iframe.name = _iframe.id = "ze_spellcheck";
    _iframe.src = srcValue;
    var _style = _iframe.style,
      _editorIframe = editor.iframe;

    _style.width = "500px";
    _style.left = "-1000px";
    _style.height = "50px";
    _style.top = ZE.getPos(_editorIframe).offsetTop + "px";

    _style.position = "absolute";
    _document.body.appendChild(_iframe);
  }

  if (editor.scspan) {
  /* spellcheck options in the toolbar modification start*/
    var spellcheck_log = editor.sclog;
    spellcheck_log.style.display = "";
    spellcheck_log.innerHTML = I18N("Checking..."); // No I18N
    editor.screcheck.style.display = "none";
    editor.sccancel.style.display = "";
    editor.scclose.style.display = "none";
        /* spellcheck options in the toolbar modification start*/

    editor.scspan.style.display = "";
  } else /* for each editor spellcheck options will be created*/ {
    var fragment = _document.createDocumentFragment();

        /* creating spellcheck options outer span start*/
    var outer_span = _document.createElement("span");
    outer_span.className = "ze_spell";
    var toolbarRect = editor.toolbardiv.getBoundingClientRect();
    fragment.appendChild(outer_span);
    editor.scspan = outer_span;
        /* creating spellcheck options outer span end*/

        /* creating inner span start*/
    var inner_span = _document.createElement("span");
    inner_span.appendChild(_document.createTextNode(I18N("Checking") + "...")); // No I18N
    outer_span.appendChild(inner_span);
    editor.sclog = inner_span;
        /* creating inner span end*/

        /* Recheck anchor start*/
    var recheck_a = _document.createElement("a"),
      recheck_i18n = I18N("Recheck"); // No I18N
    recheck_a.style.display = "none";
    recheck_a.title = recheck_a.href = recheck_i18n;
    recheck_a.appendChild(_document.createTextNode(recheck_i18n));
    recheck_a.onclick = function () {
      editor.removeSpellcheckspans();
            // first time it will remove the spellcheck
      editor.spellcheck();
            // second time it will do the spellcheck again
      return false;
    };
    outer_span.appendChild(recheck_a);
    editor.screcheck = recheck_a;
        /* Recheck anchor end*/

        /* cancel anchor start*/
    var cancel_a = _document.createElement("a"),
      cancel_i18n = I18N("Cancel"); // No I18N
    cancel_a.title = cancel_a.href = cancel_i18n;
    cancel_a.appendChild(_document.createTextNode(cancel_i18n));
    cancel_a.onclick = function () {
      editor.cancelSpellcheck();
      editor.scspan.style.display = "none";
      return false;
    };
    outer_span.appendChild(cancel_a);
    editor.sccancel = cancel_a;
        /* cancel anchor end*/

        /* close anchor start*/
    var close_a = _document.createElement("a"),
      close_i18n = I18N("Close"); // No I18N
    close_a.title = close_a.href = close_i18n;
    close_a.style.display = "none";
    close_a.appendChild(_document.createTextNode(close_i18n));
    close_a.onclick = function () {
      editor.removeSpellcheckspans();
      editor.scspan.style.display = "none";
      return false;
    };
    outer_span.appendChild(close_a);
    editor.scclose = close_a;
        /* close anchor end*/

    editor.toolbardiv.appendChild(fragment);
  }
};

ZE.prototype.cancelSpellcheck = function () {
  var editor = this;
  document.getElementById("ze_spellcheck").src = ZE_Init.jsPath + "/html/blank.html";

    /* spellcheck toolbar class removed*/
    //	editor.toolbarobject["spellcheck"].className = editor.toolbarobject["spellcheck"].className.replace("ze_dummy","");

  if (editor.spellcheckContentSet) {
    editor.removeSpellcheckspans();
    delete editor.spellcheckContentSet;
  }
  return false;
};

ZE.prototype.getSpellcheckRemovedContent = function (mode) {
  "use strict"; // No I18N
  var editor = this,
    spellcheckdiv = editor.spellcheckdiv,
    cloneNode,
    docFrag,
    spans,
    spanEle,
    i;

  if (mode === "plaintext") {
    cloneNode = spellcheckdiv.cloneNode(true);
    docFrag = cloneNode;
    spans = docFrag.getElementsByTagName('span');
  } else if (mode === "richtext") { // No I18N
    cloneNode = editor.doc.body.cloneNode(true);
    docFrag = cloneNode;
    spans = docFrag.getElementsByTagName('span');
  }
  if (!spans) {
    return;
  }

  for (i = spans.length - 1; i >= 0; i--) {
    spanEle = spans[i];
    if (spanEle.hasAttribute("data-s") || spanEle.getAttribute("data-s")) {
      spanEle.style.backgroundColor = "";
      if (spanEle.style.length > 0) {
        spanEle.removeAttribute("data-s");
      } else if (spanEle.hasChildNodes()) {
        var children = spanEle.childNodes,
          parentNode = spanEle.parentNode;
        for (var k = 0; k < children.length; k++) {
          parentNode.insertBefore(children[k].cloneNode(true), spanEle);
        }
        parentNode.removeChild(spanEle);
      }
    }
  }
  return docFrag.innerHTML;
};

/* removing the spellcheck spans depending upon the mode and placing the content either inside the textarea or the editor*/
ZE.prototype.removeSpellcheckspans = function () {
  var editor = this,
    _mode = editor.mode,
    spans, // span array of editor or spellcheckdiv content
    spellcheckdiv = editor.spellcheckdiv;

    /* spellcheck toolbar class removed*/
    // editor.toolbarobject.spellcheck.removeAttribute("class");

    /* removing ZE.activeeditor*/
  if (ZE.activeEditor) {
    delete (ZE.activeEditor);
  }

  if (_mode === "plaintext") {
    if (spellcheckdiv) {
      spans = spellcheckdiv.getElementsByTagName("span");
      if (editor.spellCheckDivEvent) {
        ZE._removeEvent(spellcheckdiv, "mouseup", editor.spellCheckDivEvent); // No I18N
      }
    }
  } else {
    spans = editor.doc.getElementsByTagName("span");
        /* editor spellcheck menu event removal*/
    if (editor.spellCheckEvent) {
      ZE._removeEvent(editor.doc, "mouseup", editor.spellCheckEvent); // No I18N
            // editor.doc.removeEventListener("mouseup", editor.spellCheckEvent, true);
    }
  }

  if (!spans) {
    return;
  }
  for (var i = spans.length - 1; i >= 0; i--) {
    var spanEle = spans[i];
    if (spanEle.hasAttribute("data-s") || spanEle.getAttribute("data-s")) {
      spanEle.style.backgroundColor = "";
      if (spanEle.style.length > 0) {
        spanEle.removeAttribute("data-s");
      } else if (spanEle.hasChildNodes()) {
        var children = spanEle.childNodes,
          parentNode = spanEle.parentNode;
        for (var k = 0; k < children.length; k++) {
          parentNode.insertBefore(children[k].cloneNode(true), spanEle);
        }
        parentNode.removeChild(spanEle);
      }
    }
  }

  if (_mode === "plaintext") {
        // editor.plainText();
    if (spellcheckdiv) {
      var _textarea = editor._textarea;

            /* setting textarea value as the innerHTML of spellcheck div*/
      _textarea.value = ZE.getText(spellcheckdiv.innerHTML);
      _textarea.style.display = "";

            /* removing spellcheck div */
      spellcheckdiv.parentNode.removeChild(spellcheckdiv);
      delete editor.spellcheckdiv;
    }
  }
};

/* response sent from the lt.zoho.com server*/
ZE.prototype.setSpellcheckContent = function (html) {
  var editor = this;

  editor.spellcheckContentSet = true;

  if (editor.mode === "plaintext") {
    var _div = document.createElement("div"),
      _textarea = editor._textarea;

    _div.className = _textarea.className;
    _div.style.cssText = _textarea.style.cssText;
    _div.style.overflow = "auto";
    _div.style.clear = "both"; // No I18N
    _div.innerHTML = html;

    editor.spellCheckDivEvent = function (ev) {
      return editor.spellCheckEventDiv(ev);
    };
    ZE._addEvent(_div, "mouseup", editor.spellCheckDivEvent); // No I18N
        // _div.addEventListener("mouseup", editor.spellCheckDivEvent, true);
    editor.editordiv.appendChild(_div);

        /* making text area hide*/
    _textarea.style.display = "none";

        /* making rich text span display none */
        // editor.span.style.display = "none";

    editor.spellcheckdiv = _div;
        // New div assigned as property of editor object
  } else {
    var doc = editor.doc;
    doc.body.innerHTML = html;
    if (!editor.spellCheckEvent) {
      editor.spellCheckEvent = function (ev) {
        return editor.spellCheckMenu(ev);
      };
    }
    ZE._addEvent(doc, "mouseup", editor.spellCheckEvent); // No I18N
        // doc.addEventListener("mouseup", editor.spellCheckEvent, true);
    editor.win.focus();
  }

    /* spellcheck options in the toolbar modification start*/
  editor.sclog.style.display = "none";
  editor.screcheck.style.display = "";
  editor.sccancel.style.display = "none";
  editor.scclose.style.display = "";
    /* spellcheck options in the toolbar modification start*/
};

/* for plaintext mode spellchecked content is placed inside
 *
 * the div and event handling is done by the below method
 * */
ZE.prototype.spellCheckEventDiv = function (ev) {
  if (ev.button !== 0) // other than left click
    {
    return false;
  }
  var editor = this,
    _target = ev.target;

  for (var temptarget = _target; temptarget && temptarget.nodeName !== "BODY" && temptarget.nodeName !== "HTML"; temptarget = temptarget.parentNode) {
    if (temptarget.hasAttribute("data-s")) {
      _target = temptarget;
      break;
    }
  }

  if (_target.hasAttribute("data-s")) {
    editor._stopEvent(ev);
  } else {
    return false;
  }

    /* creating the spellcheck suggestions start*/
  var _document = document,
    ze_spellcheckmenu_div;

    /* hiding the spellcheck suggestions div*/
  var hideSpellcheckMenuDiv = function (ev) {
    if (ev) {
      editor._stopEvent(ev);
    }

    ZE._removeEvent(_document, "keydown", hideSpellcheckMenuDiv); // No I18N
    ZE._removeEvent(_document, "mousedown", _mousedown); // No I18N
        /*
        _document.removeEventListener("keydown", hideSpellcheckMenuDiv, true);
        _document.removeEventListener("mousedown", _mousedown, true);
        */
    ze_spellcheckmenu_div.parentNode.removeChild(ze_spellcheckmenu_div);
  };

    /* tracking the mouse down outside the spellcheck suggestions div*/
  var _mousedown = function (ev) {
    editor._stopEvent(ev);
    var _target = ev.target;
    for (; _target !== null && _target !== ze_spellcheckmenu_div; _target = _target.parentNode);
    if (_target === null) {
      hideSpellcheckMenuDiv();
    }

  };

  var ul_click = function (ev) {
    editor._stopEvent(ev);
    var target = ev.target;
        // holds the a element
    if (target.nodeName === "UL") {
      return false;
    }
    if (target.nodeName === "LI") {
      value = target.getAttribute("data-i");
      if (value === "No Suggestions") {
        return;
      }
      if (value === "Ignore All") {
        editor.leaveSimilarErrorWords(_target.getAttribute("replaceword"));
      } else if (value === "Dictionary") { // No I18N
        editor.addToDictionary(_target.getAttribute("replaceword"));
      } else if (value === "Custom Dictionary") { // No I18N
        editor.customDictionary();
      } else {
        var replaceword, span_element = _target, // which is present in the editor
          span_element_parent = span_element.parentNode,
          span_element_style = span_element.style;

                /* Ignore case will come in if loop*/
        if (value === "Ignore") {
          replaceword = span_element.textContent;
        } else {
          replaceword = target.textContent;
                    // from the popupmenu
        }

                /* here we are checking the styles attributes and if its length greater than one we are just removing the attributes and not the span*/
        if (span_element_style && span_element_style.length > 1) {
          span_element_style.backgroundColor = "";
          span_element.removeAttribute("data-s");
          span_element.textContent = span_element.textContent.replace(span_element.getAttribute("replaceword"), replaceword);
          span_element.removeAttribute("replaceword");
        } else // trying to remove the span element
                {
          if (span_element.textContent === span_element.getAttribute("replaceword")) {
            span_element_parent.insertBefore(_document.createTextNode(replaceword), span_element);
          } else {
            span_element.textContent = span_element.textContent.replace(span_element.getAttribute("replaceword"), replaceword);
            var childNode = span_element.firstChild;
            while (childNode) {
              var nodeCopy = childNode.cloneNode(true);
              span_element_parent.insertBefore(nodeCopy, span_element);
              childNode = childNode.nextSibling;
            }
          }
          span_element_parent.removeChild(span_element);
        }
      }
    }
    hideSpellcheckMenuDiv();
    return false;

  };

    /* creating the spellcheck suggestions start*/
  var fragment = _document.createDocumentFragment();
    // ze_spellcheckmenu_div = _document.createElement("ul");



  var contextMenu = {
    "spellcheck": [] // No I18N
  }; // No I18N

  var suggestions = _target.getAttribute("data-s");
  suggestions = suggestions.split(",");
  contextMenu.spellcheck[0] = [];
  for (var i = 0, temp;
        (temp = suggestions[i]) && i < 5; i++) {
    var _li = _document.createElement("li");
    _li.innerHTML = temp;
    contextMenu.spellcheck[0][i] = {};
    contextMenu.spellcheck[0][i].cmd = temp;
    if (i === 0 && temp === "No Suggestions") {
      contextMenu.spellcheck[0][i]["data-i"] = "No Suggestions"; // jshint ignore:line
      contextMenu.spellcheck[0][i].color = "#bcb9af"; // jshint ignore:line
      contextMenu.spellcheck[0][i].fontWeight = "Normal"; // jshint ignore:line
    }
  }

    /* Add to Dictionary option start*/
  contextMenu.spellcheck[1] = [];
  contextMenu.spellcheck[1][0] = {};
  contextMenu.spellcheck[1][0].cmd = "Add to Dictionary";
  contextMenu.spellcheck[1][0]["data-i"] = "Dictionary"; // jshint ignore:line
    /* Add to Dictionary option end*/
    /* Ignore option*/
  contextMenu.spellcheck[1][1] = {};
  contextMenu.spellcheck[1][1].cmd = "Ignore";
  contextMenu.spellcheck[1][1]["data-i"] = "Ignore"; // jshint ignore:line
    /* Ignore All option start*/

  contextMenu.spellcheck[1][2] = {};
  contextMenu.spellcheck[1][2].cmd = "Ignore All";
  contextMenu.spellcheck[1][2]["data-i"] = "Ignore All"; // jshint ignore:line
    /* Ignore All option end*/

    /* Custom Dictionary start*/

  contextMenu.spellcheck[2] = [];
  contextMenu.spellcheck[2][0] = {};
  contextMenu.spellcheck[2][0].cmd = "Custom Dictionary";
  contextMenu.spellcheck[2][0]["data-i"] = "Custom Dictionary"; // jshint ignore:line

    /* Custom Dictionary end*/
  editor.constructContextMenu(contextMenu.spellcheck, "ze_spellcheckmenu_div", ul_click); // No I18N
  ze_spellcheckmenu_div = document.getElementById("ze_spellcheckmenu_div");
    /* registering events*/
  ZE._addEvent(_document, "mousedown", _mousedown); // No I18N
  ZE._addEvent(_document, "mousedown", _mousedown); // No I18N
  ZE._addEvent(_document, "keydown", hideSpellcheckMenuDiv); // No I18N
    /*
    _document.addEventListener("mousedown", _mousedown, true);

    _document.addEventListener("mousedown", _mousedown, true);
    _document.addEventListener("keydown", hideSpellcheckMenuDiv, true);
    */
    /* setting the position*/
  var editor_pos = ZE.getPos(editor.editordiv),
    _style = ze_spellcheckmenu_div.style;

  posx = 0;
  posy = 0;
  var value1 = editor.iframe.getBoundingClientRect();
  var value2 = _target.getBoundingClientRect();



    /*
    posx=value2.left+(ev.clientX-_anchorElement1.offsetLeft);
    		posy=posy+(ev.clientY-_anchorElement1.offsetTop);
    		}
    		else if (ev.clientX || ev.clientY) {
    			posx = ev.clientX + window.pageXOffset;
    			posy = ev.clientY + window.pageYOffset;
    		}
    */
  if (ev.pageX || ev.pageY) {
    posx = value1.left + value2.left + (ev.pageX - value2.left);
    if (editor.win.scrollY) {
      posy = value1.top + value2.top + (ev.pageY - value2.top) - editor.win.scrollY;
    } else {
      posy = value1.top + value2.top + (ev.pageY - value2.top) - editor.win.pageYOffset;
    }
  } else {
    posx = value1.left + value2.left + (ev.clientX - value2.left);
    if (editor.win.scrollY) {
      posy = value1.top + value2.top + (ev.clientY - value2.top) - editor.win.scrollY;
    } else {
      posy = value1.top + value2.top + (ev.clientY - value2.top) - editor.win.pageYOffset;
    }
  }
  _style.left = parseInt(posx) + "px";
  _style.top = parseInt(posy) + "px";
  var spellcheck_offsetheight = ze_spellcheckmenu_div.offsetHeight;
  if (posy + spellcheck_offsetheight > (window.innerHeight - 20)) {
    var tempTop = posy - spellcheck_offsetheight;
    if (tempTop < 41) {
      _style.top = "40px";
    } else {
      _style.top = parseInt(tempTop) + "px";
    }
  }

};

ZE.prototype.spellCheckMenu = function (ev) {
  if (ev.button !== 0) {
    return false;
  }

  var editor = this,
    _target = ev.target;

  for (var temptarget = _target; temptarget && temptarget.nodeName !== "BODY" && temptarget.nodeName !== "HTML"; temptarget = temptarget.parentNode) {
    if (temptarget.hasAttribute("data-s")) {
      _target = temptarget;
      break;
    }
  }

  if (_target.hasAttribute("data-s")) {
    editor._stopEvent(ev);
  } else {
    return false;
  }

  var _doc = editor.doc,
    _document = document,
    ze_spellcheckmenu_div;
    /* hiding the spellcheck suggestions div*/
  var hideSpellcheckMenuDiv = function (ev) {
    if (ev && ev.type !== "keydown") {
      editor._stopEvent(ev);
    }
    ZE._removeEvent(_document, "mousedown", _mousedown); // No I18N
    ZE._removeEvent(_doc, "mousedown", hideSpellcheckMenuDiv); // No I18N
    ZE._removeEvent(_doc, "keydown", hideSpellcheckMenuDiv); // No I18N

        /*
		_document.removeEventListener("mousedown", _mousedown, true);
		_doc.removeEventListener("mousedown", hideSpellcheckMenuDiv, true);
		_doc.removeEventListener("keydown", hideSpellcheckMenuDiv, true);
		*/
    ze_spellcheckmenu_div.parentNode.removeChild(ze_spellcheckmenu_div);
  };

    /* tracking the mouse down outside the spellcheck suggestions div*/
  var _mousedown = function (ev) {
    editor._stopEvent(ev);
    var _target = ev.target;
    for (; _target !== null && _target !== ze_spellcheckmenu_div; _target = _target.parentNode);
    if (_target === null) {
      hideSpellcheckMenuDiv();
    }
  };

  var ul_click = function (ev) {
    editor._stopEvent(ev);
    var target = ev.target;
    var value;
        // holds the a element
        
    if (target.nodeName === "UL") {
      return false;
    }
    if (target.nodeName === "LI") {
      value = target.getAttribute("data-i");
      if (value === "No Suggestions") {
        return;
      }
      if (value === "Ignore All") {
        editor.leaveSimilarErrorWords(_target.getAttribute("replaceword"));
      } else if (value === "Dictionary") { // No I18N
        editor.addToDictionary(_target.getAttribute("replaceword"));
      } else if (value === "Custom Dictionary") { // No I18N
        editor.customDictionary();
      } else {
        var replaceword, span_element = _target, // which is present in the editor
          span_element_parent = span_element.parentNode,
          span_element_style = span_element.style;

                /* Ignore case will come in if loop*/
        if (value === "Ignore") {
          replaceword = span_element.textContent;
        } else {
          replaceword = target.textContent;
                    // from the popupmenu
        }

                /* here we are checking the styles attributes and if its length greater than one we are just removing the attributes and not the span*/
        if (span_element_style && span_element_style.length > 1) {
          span_element_style.backgroundColor = "";
          span_element.removeAttribute("data-s");
          span_element.textContent = span_element.textContent.replace(span_element.getAttribute("replaceword"), replaceword);
          span_element.removeAttribute("replaceword");
        } else // trying to remove the span element
                {
          if (span_element.textContent === span_element.getAttribute("replaceword")) {
            span_element_parent.insertBefore(_doc.createTextNode(replaceword), span_element);
          } else {
            span_element.textContent = span_element.textContent.replace(span_element.getAttribute("replaceword"), replaceword);
            var childNode = span_element.firstChild;
            while (childNode) {
              var nodeCopy = childNode.cloneNode(true);
              span_element_parent.insertBefore(nodeCopy, span_element);
              childNode = childNode.nextSibling;
            }
          }
          span_element_parent.removeChild(span_element);
        }
      }
    }
    hideSpellcheckMenuDiv();
    return false;
  };

    /* creating the spellcheck suggestions start*/
  var fragment = _document.createDocumentFragment();
  var contextMenu = {
    "spellcheck": [] // No I18N
  }; // No I18N

  var suggestions = _target.getAttribute("data-s");
  suggestions = suggestions.split(",");
  contextMenu.spellcheck[0] = [];
  for (var i = 0, temp;
        (temp = suggestions[i]) && i < 5; i++) {
    var _li = _document.createElement("li");
    _li.innerHTML = temp;
    contextMenu.spellcheck[0][i] = {};
    contextMenu.spellcheck[0][i].cmd = temp;
    if (i === 0 && temp === "No Suggestions") {
      contextMenu.spellcheck[0][i]["data-i"] = "No Suggestions"; // jshint ignore:line
      contextMenu.spellcheck[0][i].color = "#bcb9af";
      contextMenu.spellcheck[0][i].fontWeight = "Normal";
    }
  }

    /* Add to Dictionary option start*/
  contextMenu.spellcheck[1] = [];
  contextMenu.spellcheck[1][0] = {};
  contextMenu.spellcheck[1][0].cmd = "Add to Dictionary";
  contextMenu.spellcheck[1][0]["data-i"] = "Dictionary"; // jshint ignore:line
    /* Add to Dictionary option end*/
    /* Ignore option*/
  contextMenu.spellcheck[1][1] = {};
  contextMenu.spellcheck[1][1].cmd = "Ignore";
  contextMenu.spellcheck[1][1]["data-i"] = "Ignore"; // jshint ignore:line
    /* Ignore All option start*/

  contextMenu.spellcheck[1][2] = {};
  contextMenu.spellcheck[1][2].cmd = "Ignore All";
  contextMenu.spellcheck[1][2]["data-i"] = "Ignore All"; // jshint ignore:line
    /* Ignore All option end*/

    /* Custom Dictionary start*/

  contextMenu.spellcheck[2] = [];
  contextMenu.spellcheck[2][0] = {};
  contextMenu.spellcheck[2][0].cmd = "Custom Dictionary";
  contextMenu.spellcheck[2][0]["data-i"] = "Custom Dictionary"; // jshint ignore:line

    /* Custom Dictionary end*/
  editor.constructContextMenu(contextMenu.spellcheck, "ze_spellcheckmenu_div", ul_click); // No I18N
  ze_spellcheckmenu_div = document.getElementById("ze_spellcheckmenu_div");
    /* registering events*/

  ZE._addEvent(_document, "mousedown", _mousedown); // No I18N
  ZE._addEvent(_doc, "mousedown", hideSpellcheckMenuDiv); // No I18N
  ZE._addEvent(_doc, "keydown", hideSpellcheckMenuDiv); // No I18N
    /*
    _document.addEventListener("mousedown", _mousedown, true);
    _doc.addEventListener("mousedown", hideSpellcheckMenuDiv, true);
    _doc.addEventListener("keydown", hideSpellcheckMenuDiv, true);
    */
    /* setting the position*/
  var editor_pos = ZE.getPos(editor.editordiv),
    _style = ze_spellcheckmenu_div.style,
    ypos = ev.clientY + editor_pos.offsetTop + editor.toolbardiv.offsetHeight,
    xpos = ev.clientX + editor_pos.offsetLeft;

  posx = 0;
  posy = 0;
  var value1 = editor.iframe.getBoundingClientRect();
  var value2 = _target.getBoundingClientRect();

  if (ev.pageX || ev.pageY) {
    posx = value1.left + value2.left + (ev.pageX - value2.left);
    if (editor.win.scrollY) {
      posy = value1.top + value2.top + (ev.pageY - value2.top) - editor.win.scrollY;
    } else {
      posy = value1.top + value2.top + (ev.pageY - value2.top) - editor.win.pageYOffset;
    }
  } else {
    posx = value1.left + value2.left + (ev.clientX - value2.left);
    if (editor.win.scrollY) {
      posy = value1.top + value2.top + (ev.clientY - value2.top) - editor.win.scrollY;
    } else {
      posy = value1.top + value2.top + (ev.clientY - value2.top) - editor.win.pageYOffset;
    }
  }
  _style.left = parseInt(posx) + "px";
  _style.top = parseInt(posy) + "px";

  var spellcheck_offsetheight = ze_spellcheckmenu_div.offsetHeight;

  if (posy + spellcheck_offsetheight > (window.innerHeight - 20)) {

    var tempTop = posy - spellcheck_offsetheight;
    if (tempTop < 41) {
      _style.top = "40px";
    } else {
      _style.top = parseInt(tempTop) + "px";
    }
  }
};

/* for editable mode*/
ZE.prototype.removeSpellcheckEvent = function (res) {
  var editor = this;

    /* spellcheck toolbar class removed*/
    // editor.toolbarobject.spellcheck.removeAttribute("class");

    /* editor spellcheck menu event removal*/
  if (editor.spellCheckEvent) {
    ZE._removeEvent(editor.doc, "mouseup", editor.spellCheckEvent); // No I18N
        /*
        editor.doc.removeEventListener("mouseup", editor.spellCheckEvent, true);
        */
  }

  if (ZE.activeEditor) {
    delete (ZE.activeEditor);
  }

  var spellcheck_log = editor.sclog;
  spellcheck_log.style.display = "";
  if (res === "success") {
    spellcheck_log.innerHTML = ZE.i18n("No errors"); // No I18N
  } else {
    spellcheck_log.innerHTML = ZE.i18n("Try Again"); // No I18N
  }
  setTimeout(function () {
    editor.sclog.style.display = "none";
    editor.screcheck.style.display = "";
  }, 2500);
  editor.screcheck.style.display = "none";
  editor.sccancel.style.display = "none";
  editor.scclose.style.display = "";
    /* spellcheck options in the toolbar modification start*/
  editor.scspan.style.display = "";
};

/* This will be called for the action of Ignore All depending upon the mode*/
ZE.prototype.leaveSimilarErrorWords = function (wordToBeIgnored) {
  var editor = this,
    _mode = editor.mode,
    spans, // span array of editor or spellcheckdiv content
    spellcheckdiv = editor.spellcheckdiv;

  wordToBeIgnored = wordToBeIgnored.toLowerCase();

  if (_mode === "plaintext") {
    if (spellcheckdiv) {
      spans = spellcheckdiv.getElementsByTagName("span");
    }
  } else {
    spans = editor.doc.getElementsByTagName("span");
  }

  if (!spans) {
    return;
  }
  for (var i = spans.length - 1; i >= 0; i--) {
    var spanEle = spans[i];
    if (spanEle.hasAttribute("replaceword")) {
      if (wordToBeIgnored === spanEle.getAttribute("replaceword").toLowerCase()) {
        spanEle.style.backgroundColor = "";
        if (spanEle.style.length > 0) {
          spanEle.removeAttribute("data-s");
          spanEle.removeAttribute("replaceword");
        } else if (spanEle.hasChildNodes()) {
          var children = spanEle.childNodes,
            parentNode = spanEle.parentNode;
          for (var k = 0; k < children.length; k++) {
            parentNode.insertBefore(children[k].cloneNode(true), spanEle);
          }
          parentNode.removeChild(spanEle);
        }
      }
    }
  }
};

/* spellcheck options drop down*/
ZE.prototype.spellcheckOptions = function (ev) {
  var editor = this,
    _anchorelement = ev.currentTarget, // holds the anchor element;
    _document = document,
    ze_spellcheck_options = _document.getElementById("ze_spellcheck_options"), // for first time it is undefined
    _doc = editor.doc;
    spellcheckobject = editor.toolbarobject["spellcheckoptions"];
    editor.popupdiv = _document.createElement("div");
  var hidespellcheck_options = function (ev) {
    if (ev && ev.type !== "keydown") {
      editor._stopEvent(ev);
    }
    ze_spellcheck_options.style.display = "none";
    ZE.removeClass(spellcheckobject, "ze_dn");

    ZE._removeEvent(ze_spellcheck_options, "click", ul_click); // No I18N
    ZE._removeEvent(_document.body, "click", _mousedown); // No I18N
    ZE._removeEvent(_doc, "mousedown", hidespellcheck_options); // No I18N
    ZE._removeEvent(_doc, "keydown", hidespellcheck_options); // No I18N


        ze_spellcheck_options.removeEventListener("click", ul_click, true);
        _document.body.removeEventListener("click", _mousedown, true);
        _doc.removeEventListener("mousedown", hidespellcheck_options, true);
        _doc.removeEventListener("keydown", hidespellcheck_options, true);

  };

  var ul_click = function (ev) {
    editor._stopEvent(ev);
    var _target = ev.target, // holds the a element
      _nodeName = _target.nodeName;

    if (_nodeName === "LI") {
      var temp_var = _nodeName; // to avoid empty block check
            //	_target = _target.firstChild;
    } else {
      if (_target.nodeName === "IMG") {
        _target = _target.parentNode;
      }
      if (_target.nodeName === "SPAN") {
        _target = _target.parentNode;
      }
    }
    if (_target.hasAttribute("data-cd") && _target.getAttribute("data-cd") === "customdictionary") {
      editor.customDictionary();
    } else {
      // debugger;
      _target.firstChild.className = "ze_tick";
      // ze_spellcheck_options.getElementsByTagName("li")[ze_spellcheck_options.getAttribute("data-index")].firstChild.removeAttribute("class");
      ze_spellcheck_options.setAttribute("data-index", _target.getAttribute("data-index"));
      _anchorelement.setAttribute("data-lang", _target.getAttribute("data-lang"));
    }
    hidespellcheck_options();
  };

  var getSpellCheckDivHeight = function () {
    var _ulheight = (window.innerHeight - editor.iframe.getBoundingClientRect().top) * .6;
    if (_ulheight < 150) {
      _ulheight = 150;
    } else if (_ulheight > 300) {
      _ulheight = 300;
    }
    return _ulheight;
  };

  var _mousedown = function (ev) {
    var _target = ev.target;
    if (_target === ze_spellcheck_options || _target.nodeName === "UL") {
      return false;
    }
    editor._stopEvent(ev);
    for (; _target !== null && _target !== ze_spellcheck_options && _target !== spellcheckobject; _target = _target.parentNode);
    if (_target === null) {
      hidespellcheck_options();
    }
  };

  var _className = _anchorelement.className;
  if (_className && _className.search("ze_dn") > 0) {
    hidespellcheck_options();
    return false;
  }

  if (ze_spellcheck_options) {
    ze_spellcheck_options.style.display = "";
    ze_spellcheck_options.firstChild.style.height = getSpellCheckDivHeight() + "px";
    ZE.addClass(spellcheckobject, "ze_dn");
    if (ZE_Init.needEditorStats) {
      editor.updateCount("spo"); // No I18N
    }
  } else {
    var fragment = _document.createDocumentFragment(),
      imgPath = ZE_Init.imgPath,
      I18N = ZE.i18n;

    var _div = _document.createElement("div");
    _div.className = "ze_dd shw";
    _div.id = "ze_spellcheck_options";
    ze_spellcheck_options = _div;
    fragment.appendChild(_div);

        /* Custom Dictionary start*/
        //                var _p = _document.createElement("p");
        //                _p.className = "ze_cd";
        //
        //                var _image = _document.createElement("img");
        //                _image.className = "ze_tabmenuicon ze_cdimg";
        //                _image.align = "absmiddle";
        //                _image.src = imgPath+"/images/spacer.gif";
        //                _p.appendChild(_image);
        //
        //                var i18n_custom_dictionary = I18N("Custom Dictionary");
        //                _p.appendChild(_document.createTextNode(i18n_custom_dictionary));
        //                _p.title = i18n_custom_dictionary;
        //
        //                _div.appendChild(_p);
        /* Custom Dictionary end*/

    var _ul = _document.createElement("ul");
    _ul.className = "ze_temp";
    _ul.style.height = getSpellCheckDivHeight() + "px";
    _ul.style.overflow = "hidden";
    _ul.style.overflowY = "scroll"; // No I18N
    _div.appendChild(_ul);

    var spellcheckarray = ZE_Init.spellCheckOptions;
    if (!spellcheckarray) {
          spellcheckarray = [
                ['locale', 'Auto'], // No I18N
                ['af-ZA', 'Afrikaans'], // No I18N
                ['am', 'Amharic'], // No I18N
                ['ar', '\u0627\u0644\u0639\u0631\u0628\u064a\u0629'], // Arabic		//No I18N
                ['hy_AM', '\u0540\u0561\u0575\u0565\u0580\u0565\u0576'], // Armenian		//No I18N
                ['az', 'Azeri'], // No I18N
                ['bg_BG', '\u0411\u044a\u043b\u0433\u0430\u0440\u0441\u043a\u0438'], // Bulgarian		//No I18N
                ['bn_BN', 'Bengali'], // No I18N
                ['ca', 'Catal\u00e0'], // Catalan		//No I18N
                ['cs_CZ', '\u010cesk\u00fd'], // Czech		//No I18N
                ['da', 'Danske'], // Danish		//No I18N
                ['nl_NL', 'Nederlands'], // Dutch		//No I18N
                ['en-AU', 'English(AU)'], // No I18N
                ['en-CA', 'English(CA)'], // No I18N
                ['en-NZ', 'English(NZ)'], // No I18N
                ['en-GB', 'English(UK)'], // No I18N
                ['en-US', 'English(US)'], // No I18N
                ['en_ZA', 'English(ZA)'], // No I18N
                ['eo_l3', 'Esperanto'], // No I18N
                ['et_EE', 'Eesti'], // Estonian		//No I18N
                ['fo_FO', 'Faroese'], // No I18N
                ['fa', 'Farsi'], // No I18N
                ['fj_FJ', 'Fijian'], // No I18N
                ['fr-FR', 'Fran\u00e7ais'], // French		//No I18N
                ['fy_NL', 'Frisian'], // No I18N
                ['gl', 'Galego'], // Galician		//No I18N
                ['de-AT', 'Deutsch(AT)'], // German(AT)		//No I18N
                ['de-CH', 'Deutsch(CH)'], // German(CH)		//No I18N
                ['de-DE', 'Deutsch(DE)'], // German(DE)		//No I18N
                ['el_GR', '\u0395\u03bb\u03bb\u03b7\u03bd\u03b9\u03ba\u03ac'], // Greek		//No I18N
                ['he-IL', '\u05e2\u05d1\u05e8\u05d9\u05ea'], // Hebrew		//No I18N
                ['hi_IN', '\u0939\u093f\u0928\u094d\u0926\u0940'], // Hindi		//No I18N
                ['hu', 'Magyar'], // Hungarian		//No I18N
                ['id_ID', 'Indonesia'], // Indonesian		//No I18N
                ['ia', 'Interlingua'], // No I18N
                ['ga_IE', 'Gaeilge'], // Irish		//No I18N
                ['is', '\u00cdslenska'], // Icelandic		//No I18N
                ['it', 'Italiano'], // Italian		//No I18N
                ['ko', 'Korean'], // No I18N
                ['la', 'Latin'], // No I18N
                ['lv-LV', 'Latvijas'], // Latvian		//No I18N
                ['lt', 'Lietuvos'], // Lithuanian		//No I18N
                ['mi', 'Maori'], // No I18N
                ['ms_MY', 'Melayu'], // Malay		//No I18N
                ['mr_IN', 'Marathi'], // No I18N
                ['mn_MN', 'Mongolian(MN)'], // No I18N
                ['ne_NP', 'Nepali'], // No I18N
                ['nb_NO', 'Norsk bokm\u00e5l'], // Norwegian Bokmal		//No I18N
                ['nn', 'Norsk Nynorsk'], // Norwegian Nynorsk		//No I18N
                ['ns_ZA', 'Northern Sotho'], // Northern Sotho		//No I18N
                ['oc_FR', 'Occitan'], // No I18N
                ['or_OR', 'Oriya'], // No I18N
                ['PL', 'Polski'], // Polish		//No I18N
                ['pt_PT', 'Portugu\u00eas(PT)'], // Portuguese		//No I18N
                ['pt-BR', 'Portugu\u00eas(BR)'], // Portuguese		//No I18N
                ['qu_BO', 'Quechua'], // No I18N
                ['rw_RW', 'Rheato-Romanic'], // No I18N
                ['ro', 'Rom\u00e2n\u0103'], // Romanian		//No I18N
                ['ru', '\u0420\u0443\u0441\u0441\u043a\u0438\u0439'], // Russian		//No I18N
                ['gd_GB', 'Scots gaelic'], // No I18N
                ['sr', '\u0421\u0440\u043f\u0441\u043a\u0438'], // Serbian		//No I18N
                ['sk', 'Slovensk\u00fd'], // Slovak		//No I18N
                ['sl', 'Slovenski'], // Slovenian		//No I18N
                ['es_CL', 'Espa\u00f1ol(CL)'], // Spanish		//No I18N
                ['es_CO', 'Espa\u00f1ol(CO)'], // Spanish		//No I18N
                ['es_EC', 'Espa\u00f1ol(EC)'], // Spanish		//No I18N
                ['es-ES', 'Espa\u00f1ol(ES)'], // Spanish		//No I18N
                ['es-MX', 'Espa\u00f1ol(MX)'], // Spanish		//No I18N
                ['es_NI', 'Espa\u00f1ol(NI)'], // Spanish		//No I18N
                ['es_PE', 'Espa\u00f1ol(PE)'], // Spanish		//No I18N
                ['es_PR', 'Espa\u00f1ol(PR)'], // Spanish		//No I18N
                ['es_UY', 'Espa\u00f1ol(UY)'], // Spanish		//No I18N
                ['sv_SE', 'Svenska'], // Swedish		//No I18N
                ['sw_KE', 'Swahili'], // No I18N
                ['ta_TA', '\u0ba4\u0bae\u0bbf\u0bb4\u0bcd'], // Tamil		//No I18N
                ['tn_ZA', 'Tswana'], // No I18N
                ['ts_ZA', 'Tsonga'], // No I18N
                ['uz_UZ', 'Uzbek'], // No I18N
                ['ve_ZA', 'Venda'], // No I18N
                ['vi_VI', 'Vietnamese'], // No I18N
                ['xh_ZA', 'Xhosa'], // No I18N
                ['zu-ZA', 'Zulu'] // No I18N
      ];
          //  holds the possible spellcheck languages

    }

    for (var i = 0, lang; lang = spellcheckarray[i]; i++) {
      var key = lang[0],
        value = lang[1];
            // this has to be i18ned

      var _li = _document.createElement("li");

      _li.title = _li.href = value;
      _li.setAttribute("data-index", i);
      _li.setAttribute("data-lang", key);

      var _img = _document.createElement("img");
      if (i === 0) {
        _img.className = "ze_tick";
        _anchorelement.setAttribute("data-lang", key);
        ze_spellcheck_options.setAttribute("data-index", 0);
      }
      _img.src = imgPath + "/images/spacer.gif";
      _img.align = "absmiddle";
            //	_li.appendChild(_img);

      var _span = _document.createElement("span");
      _li.appendChild(_document.createTextNode(value));
            //	_li.appendChild(_span);

      _ul.appendChild(_li);
    }



        /* new custom dictionary start*/
    var _second_ul = _document.createElement("ul");
    _second_ul.className = "ze_temp1";
    _div.appendChild(_second_ul);

    var _second_li = _document.createElement("li");
    _second_ul.appendChild(_second_li);

    _second_li.setAttribute("data-cd", "customdictionary");
    _second_li.title = _second_li.href = "Custom Dictionary";

    var _second_span = _document.createElement("span");
        // _second_li.appendChild(_second_span);

    var _second_img = _document.createElement("img");
    _second_img.src = imgPath + "/images/spacer.gif";
    _second_img.className = "ze_cdimg";
        // _second_span.appendChild(_second_img);

    _second_li.appendChild(_document.createTextNode(I18N("Custom Dictionary"))); // No I18N

        /* new custom dictionary end*/
    ZE.addClass(spellcheckobject, "ze_dn");
    editor.popupdiv.appendChild(fragment);
    _document.body.appendChild(editor.popupdiv);
    if (ZE_Init.needEditorStats) {
      editor.updateCount("spo"); // No I18N
    }
  }
    /* registering events*/
  ZE._addEvent(ze_spellcheck_options, "click", ul_click); // No I18N
  ZE._addEvent(_document, "mousedown", _mousedown); // No I18N
  ZE._addEvent(_doc, "mousedown", hidespellcheck_options); // No I18N
  ZE._addEvent(_doc, "keydown", hidespellcheck_options); // No I18N

    ze_spellcheck_options.addEventListener("click", ul_click, true);
    _document.body.addEventListener("mousedown", _mousedown, true);
    _doc.addEventListener("mousedown", hidespellcheck_options, true);
    _doc.addEventListener("keydown", hidespellcheck_options, true);

    /* setting the position of the div*/


  var offsets = ZE.getPos(_anchorelement),
    _style = ze_spellcheck_options.style,
    tempOffLeft = offsets.offsetLeft,
    tempLeft = tempOffLeft - ze_spellcheck_options.offsetWidth + _anchorelement.offsetWidth;
  if (tempLeft < editor.editordiv.getBoundingClientRect().left) {
    _style.left = tempOffLeft + "px";
  } else {
    _style.left = tempLeft + "px";
  }

  _style.top = offsets.offsetTop + _anchorelement.offsetHeight + "px";
};

/* This function will add the word to the custome dictionary of the particular user*/
ZE.prototype.addToDictionary = function (wordtobeadded) {
  var editor = this,
    _location = location,
    _form, spellchecklang = "locale", // No I18N
//    editor.popupdiv = _document.createElement("div");
    _popupdiv = editor.popupdiv,
    _document = document;
    // spellcheckoptions_toolbarobject = editor.toolbarobject.spellcheckoptions;

    /* leaving similar error words in the editor*/
  editor.leaveSimilarErrorWords(wordtobeadded);

    /* if(spellcheckoptions_toolbarobject.hasAttribute("data-lang"))
     {
     spellchecklang = spellcheckoptions_toolbarobject.getAttribute("data-lang");
     }*/

  _form = document.createElement("form");
  _form.method = 'POST'; // No I18N
  if (ZE_Init.useProxy) {
    _form.action = ZE_Init.spellcheckProxyUrl + "/lt/customdictionary.lt?operation=add&word=" + wordtobeadded + "&servicename=" + _location.hostname.split(".")[0] + "&language=" + spellchecklang;
  } else {
    _form.action = _location.protocol + "//" + ZE_Init.spellcheckURL + "/lt/customdictionary.lt?operation=add&word=" + wordtobeadded + "&servicename=" + _location.hostname.split(".")[0] + "&language=" + spellchecklang;
  }
  _form.target = "ze_spellcheck";
  _document.body.appendChild(_form);
  _form.submit();
  _document.body.removeChild(_form);
};

/* This function will list the custom dictionary for the particular user where he can add/remove it
 *
 * served from lt.zoho.com
 *
 * */
ZE.prototype.customDictionary = function () {
  var editor = this,
    _document = document,
    ze_custom_dictionary_div = _document.getElementById("ze_cstm_dict"), // for first time it is undefined
    I18N = ZE.i18n,
    spellchecklang = "locale"; // No I18N
    spellcheckoptions_toolbarobject = editor.toolbarobject.spellcheckoptions;



    if(spellcheckoptions_toolbarobject && spellcheckoptions_toolbarobject.hasAttribute("data-lang")) {
     spellchecklang = spellcheckoptions_toolbarobject.getAttribute("data-lang");
     }

  var hideCustomDictionaryDiv = function () {
    ZE._removeEvent(_document, "keydown", esckey); // No I18N
        // _document.removeEventListener("keydown", esckey, true);
    ze_custom_dictionary_div.parentNode.removeChild(ze_custom_dictionary_div);
    ZE.hideOverlay();
    editor.win.focus();
  };

  var esckey = function (ev) {
    if (ev.keyCode == 27) {
      editor._stopEvent(ev);
      hideCustomDictionaryDiv();
    }
  };
  ZE.showOverlay();
  if (ze_custom_dictionary_div) {
    ze_custom_dictionary_div.style.display = "";
    ze_custom_dictionary_div.getElementsByTagName("iframe")[0].src = location.protocol + "//" + ZE_Init.spellcheckURL + "/lt/customdictionary2g.lt?CD_LANGUAGE=" + spellchecklang;
  } else {
        /* Header part starts*/
    var tmp = "<div class='zep_PUtt' onmousedown='ZE.drag(event,\"ze_cstm_dict\");return false;'>";

    tmp += I18N("Custom Dictionary"); // No I18N
    tmp += "<i class='zei-close'></i></div>";
        /* Header part ends*/

    tmp += "<div class='zep_PUcen' style='margin:10px 0px 10px 0px;'>";
    tmp += "<iframe frameborder='0' style='border: medium none; width: 420px; height: 260px;' src=" + location.protocol + "//" + ZE_Init.spellcheckURL + "/lt/customdictionary2g.lt?CD_LANGUAGE=" + spellchecklang + "></iframe>";
    tmp += "</div>";

    var div1 = _document.createElement("div");
    div1.className = "zep_PU";
    div1.innerHTML = tmp;
    div1.id = "ze_cstm_dict";
    document.body.appendChild(div1);
    ze_custom_dictionary_div = div1;
  }
    /* positioning the div*/
  ZE.setPosition(ze_custom_dictionary_div, editor.editordiv);

    /* event handling start for close*/
  ze_custom_dictionary_div.getElementsByClassName("zei-close")[0].onclick = function (ev) {
    editor._stopEvent(ev);
    hideCustomDictionaryDiv();
  };

    /* setting focus start*/
  ze_custom_dictionary_div.focus();
  ZE._addEvent(_document, "keydown", esckey); // No I18N
    // _document.addEventListener("keydown", esckey, true);
};

ZE.prototype.createTable = function(_object)
{
// debugger;
	var editor = this,
            _document = document,
	    ze_ins_table_div = _document.getElementById("ze_ins_table"), //for first time it is undefined
	    I18N=ZE.i18n,
            hideTableDiv,
            esckey,
            tblhtml,
            div1,
            _input,
            row_input,
            buttons,
            close_button,
            selectedRange,
            title,
            _errorspan;

	hideTableDiv = function(){
		var _form = ze_ins_table_div.getElementsByTagName("form")[0];
		_document.removeEventListener("keydown",esckey,true);
		ze_ins_table_div.parentNode.removeChild(ze_ins_table_div);
		ZE.hideOverlay();
		(_form) && (_form.reset());
		editor.win.focus();
		 if(editor.range)
		{
			editor.range.select();
			delete (editor.range);
		}
	};
	initialize = function(){
		var row_value,
        	column_input,
        	column_value,
        	width_input,
        	width_value,
        	border_input,
        	border_value,
        	table_width,
        	element,
        	cellPadding_input,
        	cellSpacing_input;

      		 row_input.value=_object.rows.length;
      		 row_input.disabled=true;

      		 column_input = _input[1];
      		 column_input.value=_object.rows[0].cells.length;
      		 column_input.disabled=true;

      		 width_input = _input[2];
      		 table_width = _object.style.width || _object.width;
      		 element = ze_ins_table_div.getElementsByTagName("select")[0];
      		 if(table_width.indexOf('%')!=-1){
      		 	element.selectedIndex="0";
      		 }else{
      		 	element.selectedIndex="1";
      		 }
      		 if(table_width){
      		 	width_input.value=parseInt(table_width);
      		 }
      		 width_input.focus();



			cellPadding_input = _input[3];
			if(_object.cellPadding){
				cellPadding_input.value=_object.cellPadding;
			}
			else{
				cellPadding_input.value="0";
			}


			cellSpacing_input = _input[4];
			if(_object.cellSpacing){
				cellSpacing_input.value=_object.cellSpacing;
			}
			else{
				cellSpacing_input.value="0";
			}

			border_input = _input[5];
			border_value=_object.style.border || _object.border;
			if(border_value){
				border_input.value=parseInt(border_value);
			}
			else{
				border_input.value="0";
			}

	};

	esckey = function(ev){
		if(ev.keyCode === 27)
		{
			editor._stopEvent(ev);
			hideTableDiv();
		}
		if(ev.keyCode === 13)
		{
			editor._stopEvent(ev);
			okButton(ev);
		}
	};


	if(_object){
		title="Edit Table";  //No I18N
	}
	else{
		title="Insert Table";	//No I18N
	}
	tblhtml  = '<div class="zep_PUtt">'+I18N(title)+'<i class="zei-close"></i></div>';
	tblhtml += '<div class="zep_PUcen">';
	tblhtml += '<form><table class="ze_ptble"><tr><td>'+I18N("Rows")+'</td><td><input type="text" class="ze_m20" value="2" maxlength="2" size="2"></td><td>'+I18N("Columns")+'</td><td><input type="text" value="2" maxlength="2" size="2"></td></tr>';
	tblhtml += '<tr><td>'+I18N("Width")+'</td><td><input type="text" value="100" maxlength="4" size="2"/></td><td colspan="2"><div class="ze_select"><select class="select"><option value="%">%</option><option value="px">'+I18N("px")+'</option></select></div></td></tr>';	// No I18N
	if(_object){
		tblhtml+='<tr><td>'+I18N("Cell Padding")+'</td><td><input type="text" maxlength="2" size="2"/></td><td>'+I18N("Cell Spacing")+'</td><td><input type="text" maxlength="2" size="2"/></td></tr>';	// No I18N
	}
	tblhtml += '<tr><td>'+I18N("Border")+'</td><td><input type="text" value="1" maxlength="2" size="2"/></td></tr>';	// No I18N
	tblhtml+='<tr><td></td></tr><tr><td colspan="4"><p class="ze_iiSnF"><span class="ze_popuperrmsg"style="display:none;">this is temp text</span></p></td></tr></table></form></div>';   //No I18N
	tblhtml += '<div class="zep_PUbtm"><span class="sel">'+I18N("ads.rteditor.editorpop.ok")+'</span><span data-val="Cancel">'+I18N("ads.rteditor.editorpop.cancel")+'</span></div>';


	ZE.showOverlay();
	editor.win.focus();
	selectedRange=editor.saveSelection();
	div1 = _document.createElement("div");
	div1.setAttribute("class","zep_PU zep_arrb");
	div1.innerHTML =tblhtml;
	div1.id = "ze_ins_table";

	ze_ins_table_div = div1;
	document.body.appendChild(div1);

	/*setting the position*/
	ZE.setPosition(ze_ins_table_div,editor.editordiv);

	/* variables caching for components inside div*/
	_input = ze_ins_table_div.getElementsByTagName("input");
	row_input = _input[0];
	buttons = ze_ins_table_div.getElementsByTagName("span");
	_errorspan = buttons[0];
	close_button = ze_ins_table_div.getElementsByClassName("zei-close")[0];

	if(_object){
		initialize();
	}else{
		row_input.focus();
	}
	/* focus start*/


	/* event handling start for close*/
	close_button.onclick=buttons[2].onclick = function(ev){
		editor._stopEvent(ev);
		hideTableDiv();
	};

	var insertTableErrorMsg = function(msg){
		_errorspan=ze_ins_table_div.getElementsByTagName("span");
		_errorspan[0].style.display="";
		_errorspan[0].innerHTML=msg;
	};

	/* event handling for ok*/
	buttons[1].onclick=okButton;
	function okButton(ev){

		editor._stopEvent(ev);
        var row_value,
            column_input,
            column_value,
            width_input,
            width_value,
            border_input,
            border_value,
            _doc,
		    element,
            fragment,
		    _table,
		    _tbody,
		    i,
		    j,
            row,
            cell,
            sel,
            range,
		    _initobj = editor.initobj,
		    outGoingFontFamily = ZE_Init.outGoingFontFamily,
		    tableStyle,
		    cellPadding_input,
        	cellSpacing_input,
        	cellPadding_value,
        	cellSpacing_value;

		if (selectedRange) {
  			editor.restoreSelection(selectedRange);
  		}
		row_value = row_input.value;
		if( !(row_value > 0 && row_value < 100) ){
			//alert(I18N('Please Enter a valid number for Rows'));//No I18N
			insertTableErrorMsg(I18N('Specify valid number for Rows')); //No I18N
			row_input.focus();
			row_input.select();
			return false;
		}

		column_input = _input[1];
		column_value = column_input.value;
		if( !(column_value > 0 && column_value < 100) ){
			//alert(I18N('Please Enter a valid number for Columns'));//No I18N
			insertTableErrorMsg(I18N('Specify valid number for Columns'));//No I18N
			column_input.focus();
			column_input.select();
			return false;
		}

		width_input = _input[2];
		width_value = width_input.value;
		if( !(width_value > 1 && width_value < 10000) ){
			//alert(I18N('Please Enter a valid number for Width'));//No I18N
			insertTableErrorMsg(I18N('Specify valid number for Width'));//No I18N
			width_input.focus();
			width_input.select();
			return false;
		}
		border_input = _input[3];
		if(_object){
			cellPadding_input = _input[3];
			cellPadding_value = cellPadding_input.value;
			if(cellPadding_value == "" || !(cellPadding_value >= 0 && cellPadding_value < 100) ){
				//alert(I18N('Please Enter a valid number for Cell Padding'));//No I18N
				insertTableErrorMsg(I18N('Specify valid number for Cell Padding'));//No I18N
				cellPadding_input.focus();
				cellPadding_input.select();
				return false;
			}

			cellSpacing_input = _input[4];
			cellSpacing_value = cellSpacing_input.value;
			if(cellSpacing_value == "" || !(cellSpacing_value >= 0 && cellSpacing_value < 100) ){
				//alert(I18N('Please Enter a valid number for Cell Spacing'));//No I18N
				insertTableErrorMsg(I18N('Specify valid number for Cell Spacing'));  //No I18N
				cellSpacing_input.focus();
				cellSpacing_input.select();
				return false;
			}
			border_input = _input[5];
		}

		border_value = border_input.value;
		if(border_value == "" || !(border_value >= 0 && border_value < 100) ){
				//alert(I18N('Please Enter a valid number for Border'));//No I18N
				insertTableErrorMsg(I18N('Specify valid number for Border'));//No I18N
				border_input.focus();
				border_input.select();
				return false;
		}

		_doc = editor.doc;
		element = ze_ins_table_div.getElementsByTagName("select")[0];

		if(_object){
			tableStyle=_object.style;
			if(_object.width){
				_object.width="";
			}
			tableStyle.width=width_value+element.options[element.selectedIndex].value;
			if(_object.style.border){
				_object.style.border="";
			}
			_object.border = border_value;
			_object.cellPadding=cellPadding_value;
			_object.cellSpacing=cellSpacing_value;
			editor.win.focus();
		}
		else{

		fragment = _doc.createDocumentFragment();
		fragment.appendChild(_doc.createElement("br"));

		_table = _doc.createElement("table");
	    tableStyle = _table.style;
	    tableStyle.width=width_value+element.options[element.selectedIndex].value;
		tableStyle.fontSize = _initobj.defaultfontsize || ZE_Init.defaultFontSize || "";
		tableStyle.fontFamily = _initobj.defaultfontfamily || ZE_Init.defaultFontFamily || "";
		_table.cellPadding="2";
		_table.cellSpacing="2";
		_table.border = border_value;

		changeColor = function(){
			// debugger;
			// alert("from changeColor");
				}
		_tbody = _doc.createElement("tbody");
		for (i = 0; i < row_value; i++)
		{
			// debugger;
			row = _doc.createElement("tr");
			var div = _doc.createElement("div");
			div.mouseover = changeColor;
			div.id = "resizableDiv";
			row.appendChild(div);
			for (j = 0; j < column_value; j++)
			{
				cell = _doc.createElement("td");
				var newDiv = _doc.createElement("div");
				newDiv.appendChild(_doc.createElement("br"))
				cell.appendChild(newDiv);
				row.appendChild(cell);
			}
			_tbody.appendChild(row);
		}

		_table.appendChild(_tbody);
		fragment.appendChild(_table);
		fragment.appendChild(_doc.createElement("br"));
		editor.win.focus();
		sel=editor._getSelection();
		range;
		try	{

			if(!sel.isCollapsed){
				sel.deleteFromDocument();
			}
			range = sel.getRangeAt(0);
		}
		catch(e){
			range=editor._createRange(sel);
		}
		try	{
			range.insertNode(fragment);  //to insert the position where cursor is availabale=
			sel.removeAllRanges();
			//ZE._addEvent(_table,"contextmenu",function(ev) {  editor._stopEvent(ev); editor.showContextMenu(ev,"table",_table);  return false; });	// No I18N

		}
		catch(e1){
			insertTableErrorMsg(I18N('Exception in inserting table')); //No I18N
			//alert("Exception in inserting table");//No I18N
		}
		}

		hideTableDiv();
		editor.saveCurrentState();
		return false;
	};
	ZE._addEvent(_document,"keydown",esckey);	// No I18N
};

ZE.prototype.insertObj = function()
{
	var editor = this,
            _document = document,
	    ze_ins_obj_div = _document.getElementById("ze_ins_obj"), //for first time it is undefined
	    _textArea,
	    I18N=ZE.i18n,
            hideObjdiv,
            esckey,
            tmp,
            div1,
            _input1;

	//editor.freeze();
	ZE.showOverlay();

	hideObjdiv = function()
	{
		ze_ins_obj_div.style.display = "none";
		_textArea.value="";
		//editor.hideFreeze();
		ZE.hideOverlay();
		editor.win.focus();
		_document.removeEventListener("keydown",esckey,true);
	};

	esckey = function(ev)
	{
		if(ev.keyCode === 27)
		{
			editor._stopEvent(ev);
			hideObjdiv();
		}
	};

	if(ze_ins_obj_div)
	{
		ze_ins_obj_div.style.display="";
	}
	else
	{
		tmp = "<div class='ze_pop_header' onmousedown='ZE.drag(event,\"ze_ins_obj\");return false;'><img class='ze_closeimg' src='"+ZE_Init.imgPath+"/images/spacer.gif'/>";
		tmp += "<h4>"+I18N("ads.rteditor.editorpop.insert_html")+"</h4></div>";//No I18N

		tmp += '<div class="ze_subpart ze_objsub"><span class="ze_clr"><textarea class="ze_objecttxt"></textarea></span></div>';

		tmp += '<div class="ze_botpart"><input type="submit" class="ze_btn" value='+I18N("Insert")+' /><input type="submit" class="ze_btn" value='+I18N("Cancel")+' /></div>';

		div1 = _document.createElement("div");
		div1.className="ze_objpop";
		div1.innerHTML =tmp;
		div1.id = "ze_ins_obj";
		document.body.appendChild(div1);
		ze_ins_obj_div = div1;
	}
	/* setting the position*/
	ZE.setPosition(ze_ins_obj_div,editor.editordiv);

	_textArea = ze_ins_obj_div.getElementsByTagName("textarea")[0];

	/* setting the focus*/
	_textArea.focus();

	_input1 = ze_ins_obj_div.getElementsByTagName("input");
	/* event handling start for close*/
	ze_ins_obj_div.getElementsByTagName("img")[0].onclick=_input1[1].onclick = function(ev)
	{
		editor._stopEvent(ev);
		hideObjdiv();
	};

	/* event handling for insert button*/
	_input1[0].onclick = function(ev)
	{
		editor._stopEvent(ev);
		var val = _textArea.value;
		val = ZE.trim(val);

		if(val.length === 0)
		{
			// alert(I18N("ads.rteditor.editorpop.enter_html"));  //No I18N
			_textArea.focus();
			return false;
		}
		editor.win.focus();
		editor.doc.execCommand("inserthtml",false,val);//No I18N
		hideObjdiv();
	};
	_document.addEventListener("keydown",esckey,true);
};

ZE.prototype.insertCode = function()
{
	var editor = this,
            sel,
            startnode,
            class_set,
            range,
            _parent,
            ols,
            ols_length,
            i;

	editor.doc.execCommand("insertorderedlist",false," ");						//No I18N

	sel = editor.win.getSelection();
	startnode = sel.anchorNode;

	if(startnode.nodeName === "OL")
	{
		startnode.className="code";
		return;
	}

	class_set = false;

	for(; startnode !== null && startnode.nodeName !== "BODY"; startnode = startnode.parentNode)
	{
		if(startnode.nodeName === "OL")
		{
			startnode.className="code";
			class_set = true;
			break;
		}
	}

	if(!class_set)
	{
		range = sel.getRangeAt(0);
		_parent = range.commonAncestorContainer;

		if(_parent.nodeType !== 1)
		{
			for(;_parent !== null && _parent.nodeName !== "BODY"; _parent = _parent.parentNode)
			{
				if(_parent.nodeType === 1)
				{
					break;
				}
			}
		}
		if(_parent.nodeType === 1)
		{
			ols = _parent.getElementsByTagName("ol");
			ols_length = ols.length;
			for(i=0; i<ols_length; i++)
			{
				if(sel.containsNode(ols[i],true))
				{
					ols[i].className="code";
					break;
				}
			}
		}
	}
};

ZE.prototype.insertQuote = function()
{
        var editor = this,
            doc = editor.doc,
            sel,
            range,
            fragment,
            _block,
            _div,
            _empty,
            temp_html,
            _anchorElement;

		temp_html=editor.getContent();
        editor.win.focus();

        _anchorElement=editor.win.getSelection().anchorNode.parentNode;
        while(_anchorElement !== null) {
							if(_anchorElement.nodeName==="BLOCKQUOTE"){
								return true;
							}
							else{
								_anchorElement = _anchorElement.parentNode;
							}
		}
        sel = editor._getSelection();
        range = editor._createRange(sel);
        fragment = doc.createDocumentFragment();

        /*br before blockquote tag*/
		var _tempDiv = doc.createElement("div");
		_tempDiv.appendChild(doc.createElement("br"));
		fragment.appendChild(_tempDiv);

        /* creating blockquote start*/
        _block = doc.createElement("blockquote");
        fragment.appendChild(_block);
        /* creating blockquote end*/

        /* creating blockquote for div start*/
        _div = doc.createElement("div");
        _block.appendChild(_div);
        /* creating blockquote for div end*/

        /*br after blockquote tag*/
        fragment.appendChild(doc.createElement("br"));

        if(ZE_Init.inlineQuotes)
        {
//                _block.style.borderLeft = "2px solid #CCCCCC";
//                _block.style.paddingLeft = "10px";
                _block.style.border = "1px solid #CCCCCC";
                _block.style.padding =  "7px";
                _block.style.backgroundColor = "#F5F5F5";
        }
        else
        {
                _block.className = "block_quote";
        }
        if(sel.isCollapsed)
        {
                _div.appendChild(doc.createElement("br"));		//No I18N
                range.insertNode(fragment);
                range.selectNodeContents(_div);
                range.collapse(true);
                sel.removeAllRanges();
                sel.addRange(range);
        }
        else
        {
            _div.appendChild(range.cloneContents());
			var wrapperDiv = doc.createElement("div");
			wrapperDiv.appendChild(fragment);
			fragment.appendChild(doc.createElement("br"));
            editor.insertHTML(wrapperDiv.innerHTML,true);
            //var _selection = editor.win.getSelection();
            //var range = editor._createRange(_selection);
            //range.insertNode(fragment);
            //range.selectNode(_block);
            //range.collapse(false);
            /*
            _range.selectNode(_divElement);
                        _selection.removeAllRanges();
                                            _selection.addRange(_range);
                                            _selection.collapseToStart();*/

               /*
                if(!range.nextSibling)
                               {
                                       _empty = doc.createTextNode(" ");
                                       range.insertNode(_empty);
                                       range.selectNodeContents(_empty);
                                       range.collapse(false);
                                       sel.removeAllRanges();
                                       sel.addRange(range);
                               }*/
        }
        //editor.stack.execute(new editor.EditCommand(editor.doc.body, editor.getContent(),editor.saveCursorPosition(editor.doc.body)));			//No I18N
        editor.saveCurrentState();
};

/* global ZE */
ZE.prototype.htmlView = function () {
	"use strict";
	var editor = this,
            _document = document,
	    ze_htmlview_div = _document.getElementById("ze_htmlview"), //for first time it is undefined
	    _textarea,
	    _iframe,
	    firstspan,
	    secondspan,
 	    html = editor.getContent(),
	    _input,
            hideHtmlViewDiv,
            esckey,
            initialise,
            load,
            xmlhttp;

	//editor.freeze();
    ZE.showOverlay();
	hideHtmlViewDiv = function()
	{
		ze_htmlview_div.style.display="none";
		//editor.hideFreeze();
		ZE.hideOverlay();
		editor.win.focus();
		_document.removeEventListener("keydown",esckey,true);
	};

	esckey = function(ev)
	{
		if(ev.keyCode === 27)
		{
			editor._stopEvent(ev);
			hideHtmlViewDiv();
		}
	};

	/* this function will initialise the local variables*/
	initialise = function()
	{
		_textarea = ze_htmlview_div.getElementsByTagName("textarea")[0];
		_iframe = ze_htmlview_div.getElementsByTagName("iframe")[0];
		_input = ze_htmlview_div.getElementsByTagName("input");
		var _span = ze_htmlview_div.getElementsByTagName("span");
		firstspan = _span[0];
		secondspan = _span[1];
	};

	load = function()
	{
		firstspan.className="ze_edit_sel";
		secondspan.className="ze_edit";
		_iframe.style.display="none";
		_textarea.style.display="";
	};

	if(ze_htmlview_div)
	{
		initialise();
		_textarea.value=html;
		load();
		ze_htmlview_div.style.display="";
	}
	else
	{
                (function()
                {
                        var I18N = ZE.i18n,
                            tmp,
                            div;

                        tmp = "<div class='ze_pop_header' onmousedown='ZE.drag(event,\"ze_htmlview\");return false;'><img class='ze_closeimg' src='"+ZE_Init.imgPath+"/images/spacer.gif'/>";
                        tmp += "<h4>"+I18N("Edit HTML")+"</h4></div>";  //No I18N

                        tmp += "<div class='ze_menu_tab'><span class='ze_edit_sel'>"+I18N("HTML")+"</span>";
                        tmp += "<span class='ze_edit'>"+I18N("Preview")+"</span></div>";

                        tmp += "<textarea class='ze_ed_txtarea'>"+html+"</textarea>";
                        tmp += "<iframe class='ze_ed_ifr' style='display:none;'></iframe>";

                        tmp += "<div class='ze_botpart'><input type='submit' class='ze_btn' value='"+I18N("Insert")+"'/>";
                        tmp += "<input type='submit' class='ze_btn' value='"+I18N("Cancel")+"'/>";

                        div = _document.createElement("div");
                        div.className="ze_htmlpop";
                        div.innerHTML =tmp;
                        div.id = "ze_htmlview";
                        document.body.appendChild(div);
                        ze_htmlview_div = div;
                        initialise();
                }());
	}

	/* positioning the div*/
	ZE.setPosition(ze_htmlview_div,editor.editordiv);

	/* setting the focus*/
	_textarea.focus();

	try
	{
		xmlhttp = new XMLHttpRequest();
		xmlhttp.open("POST","/ze/formatTag", true);
		xmlhttp.onreadystatechange = function()
		{
			if (xmlhttp.readyState === 4)
			{
				if(xmlhttp.status === 200)
				{
					var response = xmlhttp.responseText;
					if(response)
					{
						response=eval("("+response+")");
						_textarea.value=response.content||html;
					}
				}
			}
		};
		xmlhttp.setRequestHeader("Content-Type","application/x-www-form-urlencoded;charset=UTF-8");
		xmlhttp.send(encodeURI("&content="+encodeURIComponent(html)+"&zereqid="+ZE.getCSRFCookie(editor)));  //No I18N
	}
	catch(e)
	{
	}

	firstspan.onmousedown = function()
	{
		load();
		_textarea.focus();
		return false;
	};

	secondspan.onmousedown = function()
	{
		firstspan.className="ze_edit";
		secondspan.className="ze_edit_sel";
		_textarea.style.display="none";

		var _iframedoc = _iframe.contentWindow.document,
                    css,
                    _head,
                    _iframedoc_body;

                _iframedoc.open();
                _iframedoc.write(_textarea.value);
                _iframedoc.close();

                /* adding the css for first time*/
		if(ZE_Init.editorCSS && _iframedoc.styleSheets.length < 1)
		{
                        css = _iframedoc.createElement("link");
                        css.type = 'text/css';
                        css.rel = 'stylesheet';
                        css.href = ZE_Init.cssPath+'/css/zeditor.min.css';
                        _head = _iframedoc.getElementsByTagName("head")[0];
                        //mac safari 3.2 will not have head tag
                        if(!_head)
                        {
                                _iframedoc_body = _iframedoc.body;
                                _iframedoc_body.parentNode.insertBefore(_iframedoc.createElement("head"),_iframedoc_body);
                                _head = _iframedoc.getElementsByTagName("head")[0];
                        }
                        _head.appendChild(css);
		}

		_iframe.style.display="";
		_iframe.contentWindow.focus();
		return false;
	};

	/* event handling start for close*/
	ze_htmlview_div.getElementsByTagName("img")[0].onclick=_input[1].onclick = function(ev)
	{
		editor._stopEvent(ev);
		hideHtmlViewDiv();
	};

	/* event handling for insert*/
	_input[0].onclick = function(ev)
	{
		editor._stopEvent(ev);
		editor.setContent(_textarea.value);
		hideHtmlViewDiv();
	};

	_document.addEventListener("keydown",esckey,true);
};

ZE.show_CaptchaImage = function(hipurl,editor1)
{
	var _img,
	    tmp,
	    _doc = document,
	    captcha_Div = _doc.getElementById("ze_captcha"),    //No I18N
	    I18N=ZE.i18n,
	    captcha_text,
	    go_btn,
	    cancel_btn,
	    refresh_btn,
	    form_captcha,
	    editor;
	    if(editor1){
	    	editor=editor1;
	    }else{
	    	editor=ZE.activeEditor;
	    }

	var initialise = function(){
		var _span = captcha_Div.getElementsByTagName("span"); //No I18N

		refresh_btn=_span[0];
		go_btn=_span[1];
		cancel_btn=_span[2];

	};
	if(captcha_Div) // for other time generation of captcha(except the first time),we set the display and dynamically update the captcha image url
	{
		captcha_Div.style.display = "";
	}
	else  //for first time captcha div is generated.
	{
		/* Header part starts*/
		tmp = "<div class='zep_PUtt' onmousedown='ZE.drag(event,\"ze_captcha\");return false;'>"+I18N("Word Verification")+"<i class='zei-close'></i></div>";  //No I18N
		/* Header part ends*/

		/* Main Div start*/
		tmp += "<div class='zep_PUcen'>";   //No I18N

		tmp += "<div ><table width='100%' cellspacing='0' cellpadding='5' border='0' align='center' class='ze_bordersizemain'> <tbody><tr><th align='right'>"+I18N("Image Text")+"</th><td>"+I18N("Enter the text you see in below image")+"</td></tr>";   //No I18N

		tmp +=  "<tr><td>&nbsp;</td><td>"+I18N("Letters are not case sensitive")+"</td></tr>";   //No I18N

		tmp += "<tr><td>&nbsp;</td><td><input type='text' id ='ze_captcha_text' class='.ze_textbox' style='width: 202px;'></td></tr>";						//No I18N

		tmp +=  "<tr><td>&nbsp;</td><td><div  class='ze_captcha'><img align='absmiddle' height ='72px' class='ze_hip' alt="+I18N("HIPImage")+" title="+I18N("Image Verification")+" name='ze_hipImg'></div><span id ='ze_refresh_hip' title ="+I18N("Refresh image")+" class='ze_change-captcha-icon'></span></td></tr>"; //No I18N
		tmp += "</tbody></table></div></div>";    //No I18N
		//Footer part
		tmp+="<div class='zep_PUbtm'><span>"+I18N("Go")+"</span><span>"+I18N("Cancel")+"</span></div>";

		captcha_Div = _doc.createElement("div");
		captcha_Div.className="zep_PU";
		captcha_Div.innerHTML =tmp;
		captcha_Div.id = "ze_captcha";
		document.body.appendChild(captcha_Div);

	}
	initialise();
	captcha_text = _doc.getElementById('ze_captcha_text'); //No I18N
	captcha_text.value = "";
	captcha_text.focus();
	ZE.setPosition(captcha_Div,editor.editordiv);
	_img = captcha_Div.getElementsByTagName("img");  //No I18N
	_img[0].src = "/showcaptcha?digest="+hipurl;

	go_btn.onclick=refresh_btn.onclick = function(ev)
	{
		var captcha_text_value = captcha_text.value,
		    target  = ev ? ev.target : window.event.srcElement;

		ZE.captchaParam = hipurl+"="+captcha_text_value;
		if(target.id === "ze_refresh_hip")  //If correct image text is entered and refresh button is clicked,generates new captcha image.
		{
			
			ZE.captchaParam = " ";
		}

		if(ZE.captchaProcessing)
		{
			ZE.captchaProcessing();
		}

		if(target.id === "ze_refresh_hip")  //To avoid jerking of captcha div ,when refresh is clicked.
		{
			
			return false;
		}
		captcha_Div.parentNode.removeChild(captcha_Div);
		return false;
	};

	captcha_Div.getElementsByClassName("zei-close")[0].onclick = cancel_btn.onclick = function()  //Handles events for close icon and button.
	{
		//captcha_Div.style.display = "none";
		captcha_Div.parentNode.removeChild(captcha_Div);
		var i18n_msg = I18N("Unable to insert image. Retry after sometime");  //No I18N
		ZE.insertImageMsg(i18n_msg,"error");	  //No I18N
		if(editor.inlineImagesToBe && editor.inlineImagesToBe.length>0){
			editor.inlineImagesToBe.splice(0,editor.inlineImagesToBe.length);
		}
		return false;
	};
};


ZE.insertLinkErrMsg = function(msg)
{
  
  var ze_ins_link_div = document.getElementById("ze_link"), //No I18N
     I18N=ZE.i18n,
    _span,
    errorspan,
    linkErrSpan;
    if(ze_ins_link_div){
      _span = ze_ins_link_div.getElementsByTagName("span"); //No I18N
      _tr = ze_ins_link_div.getElementsByTagName("tr"); //No I18N
        errorspan = _span[2];
        linkErrSpan = _tr[5];
        errorspan.innerHTML=I18N(msg);
        linkErrSpan.style.display=""; //No I18N
        ZE.addClass(errorspan, "ze_popuperrmsg"); //No I18N
    }
        
};
ZE.insertMacro = function(macro)
{
  ZE_Init.currentEditor.doc.body.focus();
  ZE_Init.currentEditor.insertHTML(macro,false);
  ZE_Init.newOffset = ZE_Init.newOffset+macro.length;
};
//ignorei18n_end
