// $Id: EditorHandler.js,v 1.7.6.1 2018/12/03 17:58:46 ganesh.venkatraman Exp $
//ignorei18n_start
/* global ZE,ZE_Init */
function ZE(initobj) {
    "use strict"; // No I18N
    this.state = "loading"; // No I18N
    this.mode = "richtext"; // No I18N
    this.afterload = []; // array containing functions to be called after the onload

    if (initobj && initobj.mode === "plaintext") {
        this.mode = "plaintext"; // No I18N
    }

    this.initobj = initobj || {}; // initialising the object coming from the other services
    /* holds the outer element where the editor is going to appended to be done by the required team*/
    this.outerdiv = document.getElementById(initobj.id);

    this.editordiv = undefined; // holds the editordiv containing toolbar,editor,textarea(if there)
    this.toolbardiv = undefined; // this will be the toolbar div
    this.toolbarobject = undefined; // this will hold the toolbar object
    this.popupid = "ze_popups"; // popup div id//No I18N
    this.popupdiv = undefined; // this will be the popup div
    this.createToolbar();
    this.createEditor();
    //  editor.initobj.triggerSpe()
    // this.spell = ini. || "loca"
    if (ZE_Init.needEditorStats) {
        this.clickCount = {};
    }

    if (ZE_Init.needplaintext && !this.initobj.avoidPlainText) {
        var avoidFocus = !ZE_Init.needEditorFocus;
        if (this.mode === "plaintext") {
            this.plainText(initobj.content, {
                avoidFocus: avoidFocus,
                plainTextData: ZE_Init.plainTextDataDef
            });
        }
    }

    ZE.sendInitRequest();
}

/* first time this function will be called for loading the js and afterwards method in common1.js will be called*/
ZE.create = function(initobj) {
    "use strict"; // No I18N
    if (ZE_Init.loading) {
        /* secondary css and js loading */
        var load = function() {
            // ZE_Init.loadURL(ZE_Init.jsPath + "/utils/zep1.min.js", "js"); // No I18N
        };
        setTimeout(load, 0);
        delete ZE_Init.loading;
    }
    return new ZE(initobj);
};

/* function to be executed after generating the editor*/
ZE.prototype.afterEditorLoad = function(tempfunction) {
    "use strict"; // No I18N
    var editor = this;
    if (editor.state) {
        editor.afterload.push(tempfunction);
    } else {
        tempfunction();
    }
};

ZE.prototype.setContent = function(html, avoidNewState) {
    "use strict"; // No I18N
    var editor = this,
        tempfunction,
        _mode = editor.mode,
        optionsObj = {};

    if (typeof html === "undefined") { // No I18N
        return;
    }

    if (editor.state) {
        tempfunction = (function(htmlToSet) {
            return function() {
                editor.setContent(htmlToSet);
            };
        }(html));

        editor.afterload.push(tempfunction); // if current state is loading then push the work to afterload
    } else if (_mode && _mode === "plaintext") { // No I18N
        editor._textarea.value = html;
    } else {
        if (editor.initobj.handlePasteImages) {
            optionsObj.oldState = avoidNewState;
        }

        editor.squireInstance.setHTML(html, optionsObj);
        editor.win.focus();
        if (!avoidNewState) {
            editor.saveCurrentState();
        }
        try {
            editor.updateToolbar();
        } catch (e) {
            // Empty block must avoid
        }
    }
};

ZE.setProcessedContent = function(html) {
    "use strict"; // No I18N
    var editor = this,
        _mode = editor.mode;
    if (_mode && _mode === "plaintext") {
        html = html.replace(/\n/gi, '<br/>');
    } else {
        html = html.replace(/<br.*?>/gi, '\n');
    }
};

ZE.i18n = function(key) {
    "use strict"; // No I18N

    if (ZE_Init.I18N_DATA_MODEL[key] == null) {
        return key;
    } else {
        return ZE_Init.I18N_DATA_MODEL[key];
    }

};

ZE.prototype.focusAtStart = function(avoidTimeOut) {
    "use strict"; // No I18N
    var editor = this,
        win = editor.win,
        doc = editor.doc,
        selection = win.getSelection() || doc.selection;

    if (selection) {
        var range = editor._createRange(selection);
        if (doc.body.firstChild) {
            range.setStart(doc.body.firstChild, 0);
            range.setEnd(doc.body.firstChild, 0);
            selection.removeAllRanges();
            selection.addRange(range);
        } else {
            selection.collapse(doc.body, 0);
        }
    }
    if (avoidTimeOut) {
        win.focus();
    } else {
        setTimeout(function() {
            win.focus();
        }, 300);
    }
};

ZE.prototype.getRawContent = function() {
    "use strict"; // No I18N
    var editor = this;
    if (editor.scspan && editor.scspan.style.display !== "none") {
        editor.removeSpellcheckspans();
        editor.scspan.style.display = "none"; // No I18N
    }
    return editor.getContent();
};
/* This function will get the body content inside the editor or textarea depending on its mode
 *
 * If there is spellcheck it will be removed and the original content is update in the editor/textarea
 *
 * and then the content is returned
 *
 * */
ZE.prototype.getContent = function() { // Important,donot Change this Function
    "use strict"; // No I18N
    var editor = this,
        _mode = editor.mode,
        _textarea,
        textAreaValue,
        _doc,
        docValue;

    if (_mode && _mode === 'plaintext') {
        _textarea = editor._textarea;
        if (_textarea) {
            textAreaValue = _textarea.value;
            if (editor.scspan && editor.scspan.style.display !== 'none') {
                textAreaValue = editor.getSpellcheckRemovedContent('plaintext'); // No I18N
                textAreaValue = ZE.getText(textAreaValue);
            }
            if (textAreaValue) {
                if (ZE_Init.setContentProcessed) {
                    textAreaValue = textAreaValue.replace(/\r+/gi, '');
                    textAreaValue = textAreaValue.replace(/\n/gi, '<br />');
                }
                return textAreaValue;
            }
        }
    } else {
        _doc = editor.doc;
        if (_doc) {
            if (editor.scspan && editor.scspan.style.display !== 'none') {
                docValue = editor.getSpellcheckRemovedContent('richtext'); // No I18N
            } else {
                docValue = _doc.body.innerHTML;
            }
            return docValue;
        }
    }
    return '';
};

ZE.prototype.confirmPlainText = function(content) {
    "use strict"; // No I18N
    var editor = this,
        I18N = ZE.i18n;
    if (confirm(I18N("When you switch to plain text mode, you will loose the formatting and images. Continue ?"))) {
        editor.plainText(content);
        if (ZE_Init.modeChange) { // mode change notification to zohomail for storing in the db
            ZE_Init.modeChange(editor.mode);
        }
    }
};

ZE.prototype.plainText = function(content, options,zeObject) {
    "use strict"; // No I18N
    var editor = (zeObject ? zeObject :this),
        uls = editor.toolbardiv.getElementsByTagName("ul"),
        fontArr = editor.toolbardiv.getElementsByTagName("font"),
        _textarea = editor._textarea,
        ulsLen = uls.length;
    options = options || {};

    editor.mode = "plaintext"; // No I18N
    ZE_Init.currentEditor = editor;
    /* making display none of all toolbar items*/
    for (var i = 0; i < ulsLen; i++) {
        uls[i].style.display = "none"; // No I18N
        if (fontArr[i]) {
            fontArr[i].style.display = "none";
        }
    }

    /* Enable spellcheck and attachment icon alone in toolbar*/
    var _spellcheck = editor.toolbarobject.otheroptions;
    var _att = editor.toolbarobject.attach;
    if (_spellcheck) {
        _spellcheck.parentNode.parentNode.style.display = "";
    }
    if (_att) {
        _att.parentNode.parentNode.style.display = "";
    }
    if (!_textarea) {
        _textarea = document.createElement("textarea");
        _textarea.className = "ze_area";
        editor._textarea = _textarea;
        editor.editordiv.appendChild(_textarea);
        _textarea.onbeforedeactivate = function() {
            var sel = document.selection;
            if (sel) {
                editor.textrange = sel.createRange();
            }
        };

        ZE._addEvent(_textarea, "focus", function(ev) // No I18N
        {
            ZE_Init.currentEditor = editor;
        });

        ZE._addEvent(_textarea, 'keyup', function() {
            var currentVal = this.value;
            if (editor.initobj.contentChanged && typeof editor.initobj.contentChanged === "function") {
                if (currentVal !== editor._textareaValue) {
                    editor._textareaValue = currentVal;
                    editor.initobj.contentChanged();
                }
            }
            editor.saveCurrentState();
        });

        if (!ZE_Init.avoidDropDragHandle) {
            ZE._addEvent(_textarea, 'dragover', function(evt) { // No I18N
                var dt = evt.dataTransfer,
                    I18N = ZE.i18n,
                    effectAllowed;
                if ((dt.types !== null || (dt.files && dt.files.length > 0))) {
                    if ((dt.files && dt.files.length > 0) ||
                        (dt.types.indexOf ? dt.types.indexOf('Files') > -1 : dt.types.contains('application/x-moz-file')) || // No I18N
                        dt.types[0] === "Files") {
                        var mask,
                            innerMask;
                        mask = document.getElementById("mask_editor");
                        effectAllowed = dt.effectAllowed;
                        dt.dropEffect = (effectAllowed === 'move' || effectAllowed === 'linkMove') ? 'move' : 'copy'; // No I18N
                        if (!mask) {
                            mask = document.createElement('div');
                            mask.contentEditable = "false";
                            mask.id = "mask_editor"; // No I18N
                            document.body.appendChild(mask);

                            ZE._addEvent(mask, "dragover", function(ev) { // No I18N
                                clearTimeout(editor.dragTimer);
                                var _effectAllowed = ev.dataTransfer.effectAllowed;
                                ev.dataTransfer.dropEffect = (_effectAllowed === 'move' || _effectAllowed === 'linkMove') ? 'move' : 'copy'; // No I18N
                                editor._stopEvent(ev);
                            });

                            ZE._addEvent(mask, "dragleave", function(ev) { // No I18N
                                editor.dragTimer = setTimeout(function() {
                                    var newMask = document.getElementById("mask_editor");
                                    if (newMask) {
                                        newMask.parentElement.removeChild(newMask);
                                    }
                                }, 250);
                                editor._stopEvent(ev);
                            });

                            ZE._addEvent(mask, "drop", function(ev) { // No I18N
                                editor._stopEvent(ev);
                                if (mask) {
                                    mask.parentElement.removeChild(mask);
                                }
                                var files = ev.dataTransfer.files;
                                if ((!files || files.length === 0)) { // no file api support or no files are chosen
                                    return;
                                }
                                ZE_Init.fileUpload(editor, files, ev);
                            });

                            var _textareaValues = editor._textarea.getBoundingClientRect();
                            mask.style.left = _textareaValues.left + "px"; // No I18N
                            mask.style.width = _textareaValues.right + "px"; // No I18N
                            mask.style.height = _textareaValues.height + "px"; // No I18N
                            mask.style.width = _textareaValues.width + "px"; // No I18N
                            mask.style.top = _textareaValues.top + "px"; // No I18N
                            mask.style.position = "absolute"; // No I18N
                            innerMask = document.createElement('div');
                            innerMask.className = "ze_drag"; // No I18N
                            innerMask.contentEditable = "false";
                            var _span = document.createElement('span'); // No I18N
                            innerMask.appendChild(_span);
                            _span.innerHTML = I18N("Drop Files to Attach"); // No I18N
                            mask.appendChild(innerMask);
                        }
                        editor._stopEvent(evt);
                    }
                }

            });
        }
    }
    if (content) {
        _textarea.value = options.plainTextData ? content : ZE.getText(content);
    }
    editor._textareaValue = _textarea.value;
    editor.iframe.style.display = "none";
    _textarea.style.height = editor.iframe.style.height;
    _textarea.style.display = "";
    try {
        if (!options.avoidFocus) {
            _textarea.focus();
            if (_textarea.setSelectionRange) {
                _textarea.setSelectionRange(0, 0); // In plain text, moves the cursor at the top left of editor.
            }
        }
    } catch (e) {
        // TODO empty block need to remove
    }

};

ZE.prototype.richText = function(content,zeObject) {
    "use strict"; // No I18N
    var editor = (zeObject ? zeObject : this),
        uls = editor.toolbardiv.getElementsByTagName("ul"),
        _textarea = editor._textarea,
        ulsLen = uls.length,
        fontArr = editor.toolbardiv.getElementsByTagName("font");

    /* making toolbar items display none removed*/
    for (var i = 0; i < ulsLen; i++) {
        uls[i].style.display = "";
        if (fontArr[i]) {
            fontArr[i].style.display = "";
        }
    }

    editor.mode = "richtext"; // No I18N

    _textarea.style.display = "none";
    if (content) {
        editor.squireInstance.setHTML(ZE.getFormattedContent(content));
    } else {
        editor.squireInstance.setHTML('');
    }
    if (ZE_Init.modeChange) { // mode change notification to zohomail for storing in the db
        ZE_Init.modeChange(editor.mode);
    }
    if (editor.stack && editor.stack.commands.length > 0) {
        editor.stack.clearStack();
        editor.saveCurrentState({
            cursorPosition: {
                start: 0,
                end: 0
            }
        });
    }
    editor.iframe.style.height = _textarea.style.height;
    editor.iframe.style.display = "";
    setTimeout(function() {
        editor.focusAtStart(true);
        editor.squireInstance.focus();
        editor.updateToolbar();
    }, 0);
};

ZE.getFormattedContent = function(html) {
    "use strict"; // No I18N
    return html.replace(/ /gi, ' ').replace(/</gi, '&lt;').replace(/>/gi, '&gt;').replace(/\n/gi, '<br>');
};
ZE._setAttribute = function(node, propName, value) {
    "use strict";
    node.setAttribute(propName, value);
};
ZE._appendChildren = function(node, childNodes) {
    "use strict";
    var len = childNodes.length;
    for (var i = 0; i < len; i++) {
        node.appendChild(childNodes[i]);
    }
};
ZE._setStyle = function(node, properties, value) {
    "use strict";
    if (typeof(properties) === 'object') {
        var _prop = Object.keys(properties);
        var len = _prop.length;
        for (var i = 0; i < len; i++) {
            node.style[_prop[i]] = properties[_prop[i]];
        }
    } else if (typeof(properties) === 'string') {
        node.style[properties] = value;
    }
};
ZE.setCss = function(node, propName, value) {
    "use strict";
    node.style[propName] = value;
};

ZE.getText = function(html) {
    "use strict"; // No I18N
    if (html) {
        var htmlToText = function(resultHTML) {
            resultHTML = resultHTML.replace(/\n+/gi, '');
            resultHTML = resultHTML.replace(/\r+/gi, '');
            resultHTML = resultHTML.replace(/<!--.*?-->/gi, '');
            resultHTML = resultHTML.replace(/<head>.*?<\/head>/gi, '');

            resultHTML = resultHTML.replace(/<br.*?>/gi, '\n');
            resultHTML = resultHTML.replace(/<hr.*?>/gi, '\n');
            resultHTML = resultHTML.replace(/<\/p>/gi, '\n');

            // html=html.replace(/<\/div>/gi,'\n');//replace end div tag with \n character
            resultHTML = resultHTML.replace(/<\/h[1-6]>/gi, '\n');
            resultHTML = resultHTML.replace(/<\/tr>/gi, '\n');
            resultHTML = resultHTML.replace(/<\/li>/gi, '\n');

            resultHTML = resultHTML.replace(/<\/td>/gi, ' ');
            resultHTML = resultHTML.replace(/<\/th>/gi, ' ');

            /* html entities start*/
            resultHTML = resultHTML.replace(/<.*?>/gi, '');
            resultHTML = resultHTML.replace(/&nbsp;/gi, ' ');
            resultHTML = resultHTML.replace(/&lt;/gi, '<');
            resultHTML = resultHTML.replace(/&gt;/gi, '>');
            resultHTML = resultHTML.replace(/&quot;/gi, '"');
            resultHTML = resultHTML.replace(/&amp;/gi, '&');
            /* html entities end*/
            return resultHTML;
        };

        /* converting reply blockquote to > start*/
        var isBlockQuote = html.search(/<blockquote/gi);
        if (isBlockQuote !== -1) {
            var firstIndex = html.search(/<blockquote/gi);
            var lastIndex = (html.toLowerCase()).lastIndexOf("</blockquote>");
            var blockquotehtml = html.substring(firstIndex, lastIndex + 13);
            html = html.replace(blockquotehtml, "##===###===##"); // replacing blockquotehtml by this symbol
            blockquotehtml = htmlToText(blockquotehtml);
            blockquotehtml = blockquotehtml.replace(/\n/gi, '\n > ');
            blockquotehtml = " > " + blockquotehtml;
            html = htmlToText(html);
            if (html.search(/##===###===##/gi) !== -1) {
                html = html.replace("##===###===##", blockquotehtml);
            }
            return html;
        } /* converting reply blockquote to > end*/
        var tempDiv=document.createElement("div");
        var content=ZE_Init.jQuery(tempDiv).html(html)[0];
        var tds=content.getElementsByTagName("td");
        for(var i=0;i<tds.length;i++)
        {
            var brs=tds[i].getElementsByTagName("br");
            for(var j=0;j<brs.length;j++)
            {
                brs[j].parentNode.removeChild(brs[j]);
            }
        }
        html=ZE_Init.jQuery(content).html();
        return htmlToText(html);
    }
    return "";
};

ZE.prototype.setMode = function(mode,content,zeobject) {
    "use strict"; // No I18N
    var editor = (zeobject ? zeobject : this),
        _mode = editor.mode;

    if (mode === "plaintext") { // No I18N
      editor.plainText(content,{},zeobject);
    } else if (_mode !== "richtext") { // No I18N
        editor.richText(content,zeobject);
    }
};

ZE.getCSRFCookie = function(editor) {
    "use strict"; // No I18N
    var name = "ZE_CSRF_TOKEN"; // No I18N
    var init = document.cookie.indexOf(name);
    if (init > -1) {
        var userlen = name.length;
        var beginIndex = ((editor.doc.cookie).indexOf(name) + userlen);
        var endIndex = (editor.doc.cookie).indexOf(";", beginIndex);
        if (endIndex > -1) {
            endIndex = (editor.doc.cookie).length;
        }
        var cVal = (editor.doc.cookie).substring(beginIndex + 1, endIndex);
        return cVal;
    }
    return null;
};

ZE.getContextValue = function() {
    "use strict"; // No I18N
    if (ZE_Init.contextVal) {
        return "/" + ZE_Init.contextVal; // No I18N
    }
    return ""; // No I18N
};

ZE.sendInitRequest = function(resend) {
    "use strict"; // No I18N
    var reqImgFrame = document.getElementById("ze_img_request"),
        contextVal = ZE.getContextValue();

    if (!reqImgFrame) {
        reqImgFrame = document.createElement("iframe");
        reqImgFrame.name = "ze_img_request";
        reqImgFrame.id = "ze_img_request";
        reqImgFrame.style.width = "0px";
        reqImgFrame.style.height = "0px";
        reqImgFrame.style.border = "0px";
        // reqImgFrame.src = contextVal + "/ze/blank?t=" + (new Date()).getTime();
        document.body.appendChild(reqImgFrame);
    }
    if (resend === "true") {
        reqImgFrame.src = contextVal + "/ze/blank?t=" + (new Date()).getTime();
    }
};

ZE.getCSRFParamName = function() {
    "use strict"; // No I18N
    return ZE_Init.csrfParamVal || "zereqid"; // No I18N
};

ZE.getCSRFCookie = function(editor) {
    "use strict"; // No I18N

    if (ZE_Init.csrfCookieVal && ZE_Init.csrfParamVal) {
        return ZE_Init.csrfCookieVal;
    }

    var name = ZE_Init.csrfCookieName || "ZE_CSRF_TOKEN"; // No I18N
    var init = document.cookie.indexOf(name);
    if (init > -1) {
        var userlen = name.length;
        var beginIndex = ((editor.doc.cookie).indexOf(name) + userlen);
        var endIndex = (editor.doc.cookie).indexOf(";", beginIndex);
        if (endIndex > -1) {
            endIndex = (editor.doc.cookie).length;
        }
        var cVal = (editor.doc.cookie).substring(beginIndex + 1, endIndex);
        return cVal;
    }
    return null;
};

ZE.addClass = function(element, newClass) {
    "use strict"; // No I18N
    if (element.className.indexOf(newClass) == -1) {
        if (!element.className) {
            element.className = newClass;
        } else {
            element.className += ' ' + newClass;
        }
    }
};

ZE.removeClass = function(element, remClass) {
    "use strict"; // No I18N
    element.className = element.className.replace(remClass, "");
    element.className = ZE.trim(element.className);
};

ZE._addEvent = function(el, evname, func) {
    "use strict"; // No I18N
    if (el) {
        if (document.addEventListener) {
            el.addEventListener(evname, func, true);
        } else {
            el.attachEvent("on" + evname, func);
        }
    }
};

ZE._removeEvent = function(el, evname, func) {
    "use strict"; // No I18N
    if (el) {
        if (document.removeEventListener) {
            el.removeEventListener(evname, func, true);
        } else {
            el.detachEvent("on" + evname, func);
        }
    }
};

ZE.hasClass = function(element, className) {
    "use strict"; // No I18N
    if (element.className.indexOf(className) > -1) {
        return true;
    }
    return false;
};

ZE.showOverlay = function() {
    "use strict"; // No I18N
    var overlayDiv;

    if (document.getElementById("ze_orly")) {
        return;
    }
    overlayDiv = document.createElement("div");
    overlayDiv.id = "ze_overlay";
    overlayDiv.className = "ze_orly";
    document.body.appendChild(overlayDiv);
};

ZE.hideOverlay = function() {
    "use strict"; // No I18N
    var overlayDiv = document.getElementById("ze_overlay");
    overlayDiv.parentNode.removeChild(overlayDiv);
};

ZE.trim = function(val) {
    "use strict"; // No I18N
    val = val.replace(/^\s*(.*)/, "$1");
    val = val.replace(/(.*?)\s*$/, "$1");
    return val;
};

ZE.prototype.getFormattingValues = function(_className) {
    "use strict"; // No I18N
    var editor = this;
    var selection;
    if (editor.win.getSelection) {
        selection = editor.win.getSelection();
    } else if (editor.doc.selection && editor.doc.selection.type !== "Control") { // No I18N
        selection = editor.doc.selection;
    }
    var _anchorElement = selection.anchorNode;
    var value;
    while (_anchorElement != null) {
        if (_anchorElement.className && _anchorElement.className === _className) {
            switch (_className) {
                case "size": // No I18N
                    value = _anchorElement.style.fontSize;
                    break;
                case "highlight": // No I18N
                    value = _anchorElement.style.backgroundColor;
                    break;
            }
            break;
        } else {
            _anchorElement = _anchorElement.parentNode;
        }
    }
    return value;
};


ZE.prototype.extend = function(target, ref) {
    "use strict"; // No I18N
    var name, value;
    for (name in ref) {
        value = ref[name];
        if (value !== undefined) {
            target[name] = value;
        }
    }
    return target;
};


ZE.prototype.saveCursorPosition = function(containerEl) {
    "use strict"; // No I18N
    var editor = this,
        win = editor.win,
        _doc = editor.doc,
        start;
    if (win.getSelection && _doc.createRange) {
        var selection = editor.win.getSelection();
        if (selection && selection.rangeCount > 0) {
            var range = editor.win.getSelection().getRangeAt(0);
            var preSelectionRange = range.cloneRange();
            preSelectionRange.selectNodeContents(containerEl); // selecting all node contents
            preSelectionRange.setEnd(range.startContainer, range.startOffset); // setting end as range.start container
            start = preSelectionRange.toString().length;
            return {
                start: start,
                end: start + range.toString().length
            };
        }
        return {
            start: 0,
            end: 0
        };
    } else if (_doc.selection) {
        var selectedTextRange = _doc.selection.createRange();
        var preSelectionTextRange = _doc.body.createTextRange();
        preSelectionTextRange.moveToElementText(containerEl);
        preSelectionTextRange.setEndPoint("EndToStart", selectedTextRange); // No I18N
        start = preSelectionTextRange.text.length;
        return {
            start: start,
            end: start + selectedTextRange.text.length
        };
    }
};

/* element(body) and the selection to be restored*/
ZE.prototype.restoreCursorPosition = function(containerEl, savedSel) {
    "use strict"; // No I18N
    var editor = this,
        win = editor.win,
        _doc = editor.doc,
        focusAtStart = false;

    if (win.getSelection && _doc.createRange) {
        var charIndex = 0,
            range = editor.doc.createRange();
        range.setStart(containerEl, 0); // initially setting the start at start of the body
        range.collapse(true);
        /* if both are 0,then place the cursor at the start */
        if (savedSel.start == 0 && savedSel.end == 0) {
            focusAtStart = true;
        }
        var nodeStack = [containerEl],
            node,
            foundStart = false,
            stop = false;

        if (!focusAtStart) {
            while (!stop && (node = nodeStack.pop())) {
                if (node.nodeType === 3) {
                    var nextCharIndex = charIndex + node.length; // checking length of the node
                    if (!foundStart && savedSel.start >= charIndex && savedSel.start <= nextCharIndex) {
                        range.setStart(node, savedSel.start - charIndex);
                        foundStart = true; // start point of the selection found
                    }
                    if (foundStart && savedSel.end >= charIndex && savedSel.end <= nextCharIndex) {
                        range.setEnd(node, savedSel.end - charIndex);
                        stop = true; // end point of the selection found
                    }
                    charIndex = nextCharIndex;
                } else {
                    var i = node.childNodes.length;
                    while (i--) {
                        nodeStack.push(node.childNodes[i]);
                    }
                }
            }
        }


        var sel = editor.win.getSelection();
        sel.removeAllRanges();
        sel.addRange(range);
    } else if (_doc.selection) {
        var textRange = _doc.body.createTextRange();
        textRange.moveToElementText(containerEl);
        textRange.collapse(true);
        textRange.moveEnd("character", savedSel.end); // No I18N
        textRange.moveStart("character", savedSel.start); // No I18N
        textRange.select();
    }
};

ZE.prototype.saveCurrentState = function(data) {
    "use strict"; // No I18N
    var editor = this,
        doc = editor.doc,
        cursorPosition;
    data = data || {};
    cursorPosition = data.cursorPosition;
    if (editor.stack) {
        if (!cursorPosition) {
            editor.stack.execute(new editor.EditorState(doc.body, editor.getContent(), editor.saveCursorPosition(doc.body)));
        } else { // if cursor position is explicitly specified
            editor.stack.execute(new editor.EditorState(doc.body, editor.getContent(), cursorPosition));
        }
        // triggering the app using the editor to specify that editor content is changed
        if (editor.initobj.contentChanged && typeof editor.initobj.contentChanged === "function" &&
            !data.suppressContentChange) {
            editor.initobj.contentChanged();
        }
    }
    ZE_Init.jQuery('#'+ZE_Init.currentEditor.outerdiv.id).trigger('contentchanged');
};

ZE.prototype.getPosFromCursor = function(nodename, skipcount) {
    "use strict"; // No I18N
    var editor = this;
    var path = editor.squireInstance.getPath();
    var pathArr = [];
    var tempcount = (skipcount) ? skipcount : 0;
    if (path.length > 0) {
        pathArr = path.split(">");
    }

    var i,
        temp = -1;
    for (i = pathArr.length - 1; i >= 0; i--) {
        if (pathArr[i] === nodename) {
            if (tempcount === 0) {
                temp = i;
                break;
            }
            tempcount = tempcount - 1;
        }
    }
    return temp;
};
ZE.prototype.fontsizeConversion = function(conversion, val) {

    "use strict"; // No I18N
    var ptToPx = {
        "8": "10",
        "10": "13",
        "12": "16",
        "14": "18",
        "18": "24",
        "24": "32",
        "36": "48"
    };
    var pxToPt = Math.round(val * 0.75);
    /* {
      "10": "8",
      "13": "10",
      "16": "12",
      "18": "14",
      "24": "18",
      "32": "24",
      "48": "36"
    }; */
    var fontvalToPt = {
        "1": "8",
        "2": "10",
        "3": "12",
        "4": "14",
        "5": "18",
        "6": "24",
        "7": "36"
    };
    var fontvalToPx = {
        "1": "10",
        "2": "13",
        "3": "16",
        "4": "18",
        "5": "24",
        "6": "32",
        "7": "48"
    };

    if (conversion === "pttopx") { // No I18N
        return ptToPx[val];
    } else if (conversion === "pxtopt") { // No I18N
        return pxToPt;
    } else if (conversion === "fontvaltopt") { // No I18N
        return fontvalToPt[val];
    } else if (conversion === "fontvaltopx") { // No I18N
        return fontvalToPx[val];
    }
};

ZE.tabHandler = function(event, _window, _document) {
    "use strict"; // No I18N
    if (ZE_Init.tabKeyHandling) {
        event.preventDefault();
        if (!(_document.queryCommandState("insertOrderedList") || _document.queryCommandState("insertUnOrderedList"))) {
            _window.getSelection().collapseToStart();
            _document.execCommand("insertHTML", false, "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"); // No I18N
        }
    }
};

ZE.fsDisp = {
    "1": "8", // No I18N
    "2": "10", // No I18N
    "3": "12", // No I18N
    "4": "14", // No I18N
    "5": "18", // No I18N
    "6": "24", // No I18N
    "7": "36" // No I18N
};

ZE.ffDisp = {
    "arial": "Arial", // No I18N
    "comic sans ms": "Comic Sans MS", // No I18N
    "verdana": "Verdana", // No I18N
    "georgia": "Georgia", // No I18N
    "tahoma": "Tahoma", // No I18N
    "calibri": "Calibri", // No I18N
    "courier new": "Courier New", // No I18N
    "serif": "Serif", // No I18N
    "arial narrow": "Narrow", // No I18N
    "arial black": "Wide", // No I18N
    "times new roman": "Times New Roman", // No I18N
    "garamond": "Garamond", // No I18N
    "batang": "Serif", // No I18N
    "trebuchet ms": "Trebuchet" // No I18N
};
var ze_Undo = (function() {

    // ze_Undo=this.ze_Undo={};
    var UndoObj = {
        Stack: function() {
            this.commands = [];
            this.stackPosition = -1;
            this.lastSavedState = "";

            this.execute = function(command) {
                if (this.lastSavedState == command.newValue) {
                    return; // same state so do nothing
                } else {
                    this.lastSavedState = command.newValue; // update last saved state
                }
                this.clearRedo(); // clear Redo since new state is going to be storeds
                if (this.stackPosition + 1 > 100) { // if stack exceeds 100
                    this.commands.splice(0, 1);
                    this.stackPosition -= 1;
                }
                this.commands.push(command);
                this.stackPosition++;

            };

            this.clearStack = function() { // clearing the state
                this.stackPosition = -1;
                this.commands.splice(0, this.commands.length);
                this.lastSavedState = "";
            };

            this.undo = function() {
                if (this.stackPosition > 0) {
                    this.stackPosition--;
                    this.commands[this.stackPosition].undo();
                    this.commands[this.stackPosition].setFocus();
                    this.lastSavedState = this.commands[this.stackPosition].newValue;
                }

            };
            this.canUndo = function() {
                return this.stackPosition > 0;
            };
            this.redo = function() {
                this.stackPosition++;
                this.commands[this.stackPosition].redo();
                this.lastSavedState = this.commands[this.stackPosition].newValue;
                this.commands[this.stackPosition].setFocus();

            };
            this.canRedo = function() {
                return this.stackPosition < this.commands.length - 1;
            };
            this.clearRedo = function() {
                // TODO there's probably a more efficient way for this
                this.commands = this.commands.slice(0, this.stackPosition + 1);
            };
        }
    };
    return UndoObj;
})(); /* Copyright © 2011-2015 by Neil Jenkins. MIT Licensed. */

(function(doc, undefined) {
    "use strict";

    var DOCUMENT_POSITION_PRECEDING = 2; // Node.DOCUMENT_POSITION_PRECEDING
    var ELEMENT_NODE = 1; // Node.ELEMENT_NODE;
    var TEXT_NODE = 3; // Node.TEXT_NODE;
    var DOCUMENT_NODE = 9; // Node.DOCUMENT_NODE;
    var DOCUMENT_FRAGMENT_NODE = 11; // Node.DOCUMENT_FRAGMENT_NODE;
    var SHOW_ELEMENT = 1; // NodeFilter.SHOW_ELEMENT;
    var SHOW_TEXT = 4; // NodeFilter.SHOW_TEXT;

    var START_TO_START = 0; // Range.START_TO_START
    var START_TO_END = 1; // Range.START_TO_END
    var END_TO_END = 2; // Range.END_TO_END
    var END_TO_START = 3; // Range.END_TO_START

    var HIGHLIGHT_CLASS = 'highlight';
    var COLOUR_CLASS = 'colour';
    var FONT_FAMILY_CLASS = 'font';
    var FONT_SIZE_CLASS = 'size';



    var ZWS = '\u200B';

    var win = 'defaultView' in doc?doc.defaultView:doc.parentWindow;

    var ua = navigator.userAgent;

    var isIOS = /iP(?:ad|hone|od)/.test(ua);
    var isMac = /Mac OS X/.test(ua);

    var isAndroid = /Android/.test(ua);

    var isGecko = /Gecko\//.test(ua);
    var isIElt11 = /Trident\/[456]\./.test(ua);
    var isPresto = !!win.opera;
    var isEdge = /Edge\//.test(ua);
    var isWebKit = !isEdge && /WebKit\//.test(ua);
    var isIE = /Trident\/[4567]\./.test(ua);

    var ctrlKey = isMac ? 'meta-' : 'ctrl-';

    var useTextFixer = isIElt11 || isPresto;
    var cantFocusEmptyTextNodes = isIElt11 || isWebKit;
    var losesSelectionOnBlur = isIElt11;

    var canObserveMutations = typeof MutationObserver !== 'undefined';

    // Use [^ \t\r\n] instead of \S so that nbsp does not count as white-space
    var notWS = /[^ \t\r\n]/;

    var indexOf = Array.prototype.indexOf;

    // Polyfill for FF3.5
    if (!Object.create) {
        Object.create = function(proto) {
            var F = function() {};
            F.prototype = proto;
            return new F();
        };
    }

    /*
        Native TreeWalker is buggy in IE and Opera:
        * IE9/10 sometimes throw errors when calling TreeWalker#nextNode or
          TreeWalker#previousNode. No way to feature detect this.
        * Some versions of Opera have a bug in TreeWalker#previousNode which makes
          it skip to the wrong node.

        Rather than risk further bugs, it's easiest just to implement our own
        (subset) of the spec in all browsers.
    */

    var typeToBitArray = {
        // ELEMENT_NODE
        1: 1,
        // ATTRIBUTE_NODE
        2: 2,
        // TEXT_NODE
        3: 4,
        // COMMENT_NODE
        8: 128,
        // DOCUMENT_NODE
        9: 256,
        // DOCUMENT_FRAGMENT_NODE
        11: 1024
    };

    function TreeWalker(root, nodeType, filter) {
        this.root = this.currentNode = root;
        this.nodeType = nodeType;
        this.filter = filter;
    }

    TreeWalker.prototype.nextNode = function() {
        var current = this.currentNode,
            root = this.root,
            nodeType = this.nodeType,
            filter = this.filter,
            node;
        while (true) {
            node = current.firstChild;
            while (!node && current) {
                if (current === root) {
                    break;
                }
                node = current.nextSibling;
                if (!node) {
                    current = current.parentNode;
                }
            }
            if (!node) {
                return null;
            }
            if ((typeToBitArray[node.nodeType] & nodeType) &&
                filter(node)) {
                this.currentNode = node;
                return node;
            }
            current = node;
        }
    };

    TreeWalker.prototype.previousNode = function() {
        var current = this.currentNode,
            root = this.root,
            nodeType = this.nodeType,
            filter = this.filter,
            node;
        while (true) {
            if (current === root) {
                return null;
            }
            node = current.previousSibling;
            if (node) {
                while (current = node.lastChild) {
                    node = current;
                }
            } else {
                node = current.parentNode;
            }
            if (!node) {
                return null;
            }
            if ((typeToBitArray[node.nodeType] & nodeType) &&
                filter(node)) {
                this.currentNode = node;
                return node;
            }
            current = node;
        }
    };

    // Previous node in post-order.
    TreeWalker.prototype.previousPONode = function() {
        var current = this.currentNode,
            root = this.root,
            nodeType = this.nodeType,
            filter = this.filter,
            node;
        while (true) {
            node = current.lastChild;
            while (!node && current) {
                if (current === root) {
                    break;
                }
                node = current.previousSibling;
                if (!node) {
                    current = current.parentNode;
                }
            }
            if (!node) {
                return null;
            }
            if ((typeToBitArray[node.nodeType] & nodeType) &&
                filter(node)) {
                this.currentNode = node;
                return node;
            }
            current = node;
        }
    };

    var inlineNodeNames = /^(?:#text|A(?:BBR|CRONYM)?|B(?:R|D[IO])?|C(?:ITE|ODE)|D(?:ATA|EL|FN)|EM|FONT|HR|I(?:FRAME|MG|NPUT|NS)?|KBD|Q|R(?:P|T|UBY)|S(?:AMP|MALL|PAN|TR(?:IKE|ONG)|U[BP])?|U|VAR|WBR)$/;

    var leafNodeNames = {
        BR: 1,
        HR: 1,
        IFRAME: 1,
        IMG: 1,
        INPUT: 1
    };

    function every(nodeList, fn) {
        var l = nodeList.length;
        while (l--) {
            if (!fn(nodeList[l])) {
                return false;
            }
        }
        return true;
    }

    // ---

    function isLeaf(node) {
        return node.nodeType === ELEMENT_NODE &&
            !!leafNodeNames[node.nodeName];
    }

    function isInline(node) {
        return inlineNodeNames.test(node.nodeName);
    }

    function isBlock(node) {
        var type = node.nodeType;
        return (type === ELEMENT_NODE || type === DOCUMENT_FRAGMENT_NODE) &&
            !isInline(node) && every(node.childNodes, isInline);
    }

    function isContainer(node) {
        var type = node.nodeType;
        return (type === ELEMENT_NODE || type === DOCUMENT_FRAGMENT_NODE) &&
            !isInline(node) && !isBlock(node);
    }

    function getBlockWalker(node, root) {
        var walker = new TreeWalker(root, SHOW_ELEMENT, isBlock);
        walker.currentNode = node;
        return walker;
    }

    function getPreviousBlock(node, root) {
        node = getBlockWalker(node, root).previousNode();
        return node !== root ? node : null;
    }

    function getNextBlock(node, root) {
        node = getBlockWalker(node, root).nextNode();
        return node !== root ? node : null;
    }

    function areAlike(node, node2) {
        return !isLeaf(node) && (
            node.nodeType === node2.nodeType &&
            node.nodeName === node2.nodeName &&
            node.nodeName !== 'A' &&
            node.className === node2.className &&
            ((!node.style && !node2.style) ||
                node.style.cssText === node2.style.cssText)
        );
    }

    function hasTagAttributes(node, tag, attributes) {
        if (node.nodeName !== tag) {
            return false;
        }
        for (var attr in attributes) {
            if (node.getAttribute(attr) !== attributes[attr]) {
                return false;
            }
        }
        return true;
    }

    function getNearest(node, root, tag, attributes) {
        while (node && node !== root) {
            if (hasTagAttributes(node, tag, attributes)) {
                return node;
            }
            node = node.parentNode;
        }
        return null;
    }

    function isOrContains(parent, node) {
        while (node) {
            if (node === parent) {
                return true;
            }
            node = node.parentNode;
        }
        return false;
    }

    function getPath(node, root) {
        var path = '';
        var id, className, classNames, dir;
        if (node && node !== root) {
            path = getPath(node.parentNode, root);
            if (node.nodeType === ELEMENT_NODE) {
                path += (path ? '>' : '') + node.nodeName;
                if (id = node.id) {
                    path += '#' + id;
                }
                if (className = node.className.trim()) {
                    classNames = className.split(/\s\s*/);
                    classNames.sort();
                    path += '.';
                    path += classNames.join('.');
                }
                if (dir = node.dir) {
                    path += '[dir=' + dir + ']';
                }
                if (classNames) {
                    if (indexOf.call(classNames, HIGHLIGHT_CLASS) > -1) {
                        path += '[backgroundColor=' +
                            node.style.backgroundColor.replace(/ /g, '') + ']';
                    }
                    if (indexOf.call(classNames, COLOUR_CLASS) > -1) {
                        path += '[color=' +
                            node.style.color.replace(/ /g, '') + ']';
                    }
                    if (indexOf.call(classNames, FONT_FAMILY_CLASS) > -1) {
                        path += '[fontFamily=' +
                            node.style.fontFamily.replace(/ /g, '') + ']';
                    }
                    if (indexOf.call(classNames, FONT_SIZE_CLASS) > -1) {
                        path += '[fontSize=' + node.style.fontSize + ']';
                    }
                }
            }
        }
        return path;
    }

    function getLength(node) {
        var nodeType = node.nodeType;
        return nodeType === ELEMENT_NODE ?
            node.childNodes.length : node.length || 0;
    }

    function detach(node) {
        var parent = node.parentNode;
        if (parent) {
            parent.removeChild(node);
        }
        return node;
    }

    function replaceWith(node, node2) {
        var parent = node.parentNode;
        if (parent) {
            parent.replaceChild(node2, node);
        }
    }

    function empty(node) {
        var frag = node.ownerDocument.createDocumentFragment(),
            childNodes = node.childNodes,
            l = childNodes ? childNodes.length : 0;
        while (l--) {
            frag.appendChild(node.firstChild);
        }
        return frag;
    }

    function createElement(doc, tag, props, children) {
        var el = doc.createElement(tag),
            attr, value, i, l;
        if (props instanceof Array) {
            children = props;
            props = null;
        }
        if (props) {
            for (attr in props) {
                value = props[attr];
                if (value !== undefined) {
                    el.setAttribute(attr, props[attr]);
                }
            }
        }
        if (children) {
            for (i = 0, l = children.length; i < l; i += 1) {
                el.appendChild(children[i]);
            }
        }
        return el;
    }

    function fixCursor(node, root) {
        // In Webkit and Gecko, block level elements are collapsed and
        // unfocussable if they have no content. To remedy this, a <BR> must be
        // inserted. In Opera and IE, we just need a textnode in order for the
        // cursor to appear.
        var doc = node.ownerDocument,
            originalNode = node,
            fixer, child;

        if (node === root) {
            if (!(child = node.firstChild) || child.nodeName === 'BR') {
                fixer = getSquireInstance(doc).createDefaultBlock();
                if (child) {
                    node.replaceChild(fixer, child);
                } else {
                    node.appendChild(fixer);
                }
                node = fixer;
                fixer = null;
            }
        }

        if (node.nodeType === TEXT_NODE) {
            return originalNode;
        }

        if (isInline(node)) {
            child = node.firstChild;
            while (cantFocusEmptyTextNodes && child &&
                child.nodeType === TEXT_NODE && !child.data) {
                node.removeChild(child);
                child = node.firstChild;
            }
            if (!child) {
                if (cantFocusEmptyTextNodes) {
                    fixer = doc.createTextNode(ZWS);
                    getSquireInstance(doc)._didAddZWS();
                } else {
                    fixer = doc.createTextNode('');
                }
            }
        } else {
            if (useTextFixer) {
                while (node.nodeType !== TEXT_NODE && !isLeaf(node)) {
                    child = node.firstChild;
                    if (!child) {
                        fixer = doc.createTextNode('');
                        break;
                    }
                    node = child;
                }
                if (node.nodeType === TEXT_NODE) {
                    // Opera will collapse the block element if it contains
                    // just spaces (but not if it contains no data at all).
                    if (/^ +$/.test(node.data)) {
                        node.data = '';
                    }
                } else if (isLeaf(node)) {
                    node.parentNode.insertBefore(doc.createTextNode(''), node);
                }
            } else if (!node.querySelector('BR')) {
                fixer = createElement(doc, 'BR');
                while ((child = node.lastElementChild) && !isInline(child)) {
                    node = child;
                }
            }
        }
        if (fixer) {
            try {
                node.appendChild(fixer);
            } catch (error) {
                getSquireInstance(doc).didError({
                    name: 'Squire: fixCursor – ' + error,
                    message: 'Parent: ' + node.nodeName + '/' + node.innerHTML +
                        ' appendChild: ' + fixer.nodeName
                });
            }
        }

        return originalNode;
    }

    // Recursively examine container nodes and wrap any inline children.
    function fixContainer(container, root) {
        var children = container.childNodes,
            doc = container.ownerDocument,
            wrapper = null,
            i, l, child, isBR,
            config = getSquireInstance(doc)._config;
        for (i = 0, l = children.length; i < l; i += 1) {
            child = children[i];
            isBR = child.nodeName === 'BR';
            if (!isBR && isInline(child)) {
                if (!wrapper) {
                    wrapper = createElement(doc,
                        config.blockTag, config.blockAttributes);
                }
                wrapper.appendChild(child);
                i -= 1;
                l -= 1;
            } else if (isBR || wrapper) {
                if (!wrapper) {
                    wrapper = createElement(doc,
                        config.blockTag, config.blockAttributes);
                }
                fixCursor(wrapper, root);
                if (isBR) {
                    container.replaceChild(wrapper, child);
                } else {
                    container.insertBefore(wrapper, child);
                    i += 1;
                    l += 1;
                }
                wrapper = null;
            }
            if (isContainer(child)) {
                fixContainer(child, root);
            }
        }
        if (wrapper) {
            container.appendChild(fixCursor(wrapper, root));
        }
        return container;
    }

    function split(node, offset, stopNode, root) {
        var nodeType = node.nodeType,
            parent, clone, next;
        if (nodeType === TEXT_NODE && node !== stopNode) {
            return split(
                node.parentNode, node.splitText(offset), stopNode, root);
        }
        if (nodeType === ELEMENT_NODE) {
            if (typeof(offset) === 'number') {
                offset = offset < node.childNodes.length ?
                    node.childNodes[offset] : null;
            }
            if (node === stopNode) {
                return offset;
            }

            // Clone node without children
            parent = node.parentNode;
            clone = node.cloneNode(false);

            // Add right-hand siblings to the clone
            while (offset) {
                next = offset.nextSibling;
                clone.appendChild(offset);
                offset = next;
            }

            // Maintain li numbering if inside a quote.
            if (node.nodeName === 'OL' &&
                getNearest(node, root, 'BLOCKQUOTE')) {
                clone.start = (+node.start || 1) + node.childNodes.length - 1;
            }

            // DO NOT NORMALISE. This may undo the fixCursor() call
            // of a node lower down the tree!

            // We need something in the element in order for the cursor to appear.
            fixCursor(node, root);
            fixCursor(clone, root);

            // Inject clone after original node
            if (next = node.nextSibling) {
                parent.insertBefore(clone, next);
            } else {
                parent.appendChild(clone);
            }

            // Keep on splitting up the tree
            return split(parent, clone, stopNode, root);
        }
        return offset;
    }

    function _mergeInlines(node, fakeRange) {
        var children = node.childNodes,
            l = children.length,
            frags = [],
            child, prev, len;
        while (l--) {
            child = children[l];
            prev = l && children[l - 1];
            if (l && isInline(child) && areAlike(child, prev) &&
                !leafNodeNames[child.nodeName]) {
                if (fakeRange.startContainer === child) {
                    fakeRange.startContainer = prev;
                    fakeRange.startOffset += getLength(prev);
                }
                if (fakeRange.endContainer === child) {
                    fakeRange.endContainer = prev;
                    fakeRange.endOffset += getLength(prev);
                }
                if (fakeRange.startContainer === node) {
                    if (fakeRange.startOffset > l) {
                        fakeRange.startOffset -= 1;
                    } else if (fakeRange.startOffset === l) {
                        fakeRange.startContainer = prev;
                        fakeRange.startOffset = getLength(prev);
                    }
                }
                if (fakeRange.endContainer === node) {
                    if (fakeRange.endOffset > l) {
                        fakeRange.endOffset -= 1;
                    } else if (fakeRange.endOffset === l) {
                        fakeRange.endContainer = prev;
                        fakeRange.endOffset = getLength(prev);
                    }
                }
                detach(child);
                if (child.nodeType === TEXT_NODE) {
                    prev.appendData(child.data);
                } else {
                    frags.push(empty(child));
                }
            } else if (child.nodeType === ELEMENT_NODE) {
                len = frags.length;
                while (len--) {
                    child.appendChild(frags.pop());
                }
                _mergeInlines(child, fakeRange);
            }
        }
    }

    function mergeInlines(node, range) {
        if (node.nodeType === TEXT_NODE) {
            node = node.parentNode;
        }
        if (node.nodeType === ELEMENT_NODE) {
            var fakeRange = {
                startContainer: range.startContainer,
                startOffset: range.startOffset,
                endContainer: range.endContainer,
                endOffset: range.endOffset
            };
            _mergeInlines(node, fakeRange);
            range.setStart(fakeRange.startContainer, fakeRange.startOffset);
            range.setEnd(fakeRange.endContainer, fakeRange.endOffset);
        }
    }

    function mergeWithBlock(block, next, range) {
        var container = next,
            last, offset;
        while (container.parentNode.childNodes.length === 1) {
            container = container.parentNode;
        }
        if (container.nodeName == "TD") {
            return;
        }
        detach(container);

        offset = block.childNodes.length;

        // Remove extra <BR> fixer if present.
        last = block.lastChild;
        if (last && last.nodeName === 'BR') {
            block.removeChild(last);
            offset -= 1;
        }

        block.appendChild(empty(next));

        range.setStart(block, offset);
        range.collapse(true);
        mergeInlines(block, range);

        // Opera inserts a BR if you delete the last piece of text
        // in a block-level element. Unfortunately, it then gets
        // confused when setting the selection subsequently and
        // refuses to accept the range that finishes just before the
        // BR. Removing the BR fixes the bug.
        // Steps to reproduce bug: Type "a-b-c" (where - is return)
        // then backspace twice. The cursor goes to the top instead
        // of after "b".
        if (isPresto && (last = block.lastChild) && last.nodeName === 'BR') {
            block.removeChild(last);
        }
    }

    function mergeContainers(node, root) {
        var prev = node.previousSibling,
            first = node.firstChild,
            doc = node.ownerDocument,
            isListItem = (node.nodeName === 'LI'),
            needsFix, block;

        // Do not merge LIs, unless it only contains a UL
        if (isListItem && (!first || !/^[OU]L$/.test(first.nodeName))) {
            return;
        }

        if (prev && areAlike(prev, node)) {
            if (!isContainer(prev)) {
                if (isListItem) {
                    block = createElement(doc, 'DIV');
                    block.appendChild(empty(prev));
                    prev.appendChild(block);
                } else {
                    return;
                }
            }
            detach(node);
            needsFix = !isContainer(node);
            prev.appendChild(empty(node));
            if (needsFix) {
                fixContainer(prev, root);
            }
            if (first) {
                mergeContainers(first, root);
            }
        } else if (isListItem) {
            prev = createElement(doc, 'DIV');
            node.insertBefore(prev, first);
            fixCursor(prev, root);
        }
    }

    var getNodeBefore = function(node, offset) {
        var children = node.childNodes;
        while (offset && node.nodeType === ELEMENT_NODE) {
            node = children[offset - 1];
            children = node.childNodes;
            offset = children.length;
        }
        return node;
    };

    var getNodeAfter = function(node, offset) {
        if (node.nodeType === ELEMENT_NODE) {
            var children = node.childNodes;
            if (offset < children.length) {
                node = children[offset];
            } else {
                while (node && !node.nextSibling) {
                    node = node.parentNode;
                }
                if (node) {
                    node = node.nextSibling;
                }
            }
        }
        return node;
    };

    // ---

    var insertNodeInRange = function(range, node) {
        // Insert at start.
        var startContainer = range.startContainer,
            startOffset = range.startOffset,
            endContainer = range.endContainer,
            endOffset = range.endOffset,
            parent, children, childCount, afterSplit;

        // If part way through a text node, split it.
        if (startContainer.nodeType === TEXT_NODE) {
            parent = startContainer.parentNode;
            children = parent.childNodes;
            if (startOffset === startContainer.length) {
                startOffset = indexOf.call(children, startContainer) + 1;
                if (range.collapsed) {
                    endContainer = parent;
                    endOffset = startOffset;
                }
            } else {
                if (startOffset) {
                    afterSplit = startContainer.splitText(startOffset);
                    if (endContainer === startContainer) {
                        endOffset -= startOffset;
                        endContainer = afterSplit;
                    } else if (endContainer === parent) {
                        endOffset += 1;
                    }
                    startContainer = afterSplit;
                }
                startOffset = indexOf.call(children, startContainer);
            }
            startContainer = parent;
        } else {
            children = startContainer.childNodes;
        }

        childCount = children.length;

        if (startOffset === childCount) {
            startContainer.appendChild(node);
        } else {
            startContainer.insertBefore(node, children[startOffset]);
        }

        if (startContainer === endContainer) {
            endOffset += children.length - childCount;
        }

        range.setStart(startContainer, startOffset);
        range.setEnd(endContainer, endOffset);
    };

    var extractContentsOfRange = function(range, common, root) {
        var startContainer = range.startContainer,
            startOffset = range.startOffset,
            endContainer = range.endContainer,
            endOffset = range.endOffset;

        if (!common) {
            common = range.commonAncestorContainer;
        }

        if (common.nodeType === TEXT_NODE) {
            common = common.parentNode;
        }

        var endNode = split(endContainer, endOffset, common, root),
            startNode = split(startContainer, startOffset, common, root),
            frag = common.ownerDocument.createDocumentFragment(),
            next, before, after;

        // End node will be null if at end of child nodes list.
        while (startNode !== endNode) {
            next = startNode.nextSibling;
            frag.appendChild(startNode);
            startNode = next;
        }

        startContainer = common;
        startOffset = endNode ?
            indexOf.call(common.childNodes, endNode) :
            common.childNodes.length;

        // Merge text nodes if adjacent. IE10 in particular will not focus
        // between two text nodes
        after = common.childNodes[startOffset];
        before = after && after.previousSibling;
        if (before &&
            before.nodeType === TEXT_NODE &&
            after.nodeType === TEXT_NODE) {
            startContainer = before;
            startOffset = before.length;
            before.appendData(after.data);
            detach(after);
        }

        range.setStart(startContainer, startOffset);
        range.collapse(true);

        fixCursor(common, root);

        return frag;
    };

    var deleteContentsOfRange = function(range, root) {
        // Move boundaries up as much as possible to reduce need to split.
        // But we need to check whether we've moved the boundary outside of a
        // block. If so, the entire block will be removed, so we shouldn't merge
        // later.
        moveRangeBoundariesUpTree(range);

        var startBlock = range.startContainer,
            endBlock = range.endContainer,
            needsMerge = (isInline(startBlock) || isBlock(startBlock)) &&
            (isInline(endBlock) || isBlock(endBlock));

        // Remove selected range
        var frag = extractContentsOfRange(range, null, root);

        // Move boundaries back down tree so that they are inside the blocks.
        // If we don't do this, the range may be collapsed to a point between
        // two blocks, so get(Start|End)BlockOfRange will return null.
        moveRangeBoundariesDownTree(range);

        // If we split into two different blocks, merge the blocks.
        startBlock = getStartBlockOfRange(range, root);
        if (needsMerge) {
            endBlock = getEndBlockOfRange(range, root);
            if (startBlock && endBlock && startBlock !== endBlock) {
                mergeWithBlock(startBlock, endBlock, range);
            }
        }

        // Ensure block has necessary children
        if (startBlock) {
            fixCursor(startBlock, root);
        }

        // Ensure root has a block-level element in it.
        var child = root.firstChild;
        if (!child || child.nodeName === 'BR') {
            fixCursor(root, root);
            range.selectNodeContents(root.firstChild);
        } else {
            range.collapse(false);
        }
        return frag;
    };

    // ---

    var insertTreeFragmentIntoRange = function(range, frag, root) {
        // Check if it's all inline content
        var allInline = true,
            children = frag.childNodes,
            l = children.length;
        while (l--) {
            if (!isInline(children[l])) {
                allInline = false;
                break;
            }
        }

        // Delete any selected content
        if (!range.collapsed) {
            deleteContentsOfRange(range, root);
        }

        // Move range down into text nodes
        moveRangeBoundariesDownTree(range);

        if (allInline) {
            // If inline, just insert at the current position.
            insertNodeInRange(range, frag);
            if (range.startContainer !== range.endContainer) {
                mergeInlines(range.endContainer, range);
            }
            mergeInlines(range.startContainer, range);
            range.collapse(false);
        } else {
            // Otherwise...
            // 1. Split up to blockquote (if a parent) or root
            var splitPoint = range.startContainer,
                nodeAfterSplit = split(splitPoint, range.startOffset,
                    getNearest(splitPoint.parentNode, root, 'BLOCKQUOTE') || getNearest(splitPoint.parentNode, root, 'TD') || root,
                    root
                ),
                nodeBeforeSplit = nodeAfterSplit.previousSibling,
                startContainer = nodeBeforeSplit,
                startOffset = startContainer.childNodes.length,
                endContainer = nodeAfterSplit,
                endOffset = 0,
                parent = nodeAfterSplit.parentNode,
                child, node, prev, next, startAnchor;

            // 2. Move down into edge either side of split and insert any inline
            // nodes at the beginning/end of the fragment
            while ((child = startContainer.lastChild) &&
                child.nodeType === ELEMENT_NODE) {
                if (child.nodeName === 'BR') {
                    startOffset -= 1;
                    break;
                }
                startContainer = child;
                startOffset = startContainer.childNodes.length;
            }
            while ((child = endContainer.firstChild) &&
                child.nodeType === ELEMENT_NODE &&
                child.nodeName !== 'BR') {
                endContainer = child;
            }
            startAnchor = startContainer.childNodes[startOffset] || null;
            while ((child = frag.firstChild) && isInline(child)) {
                startContainer.insertBefore(child, startAnchor);
            }
            while ((child = frag.lastChild) && isInline(child)) {
                endContainer.insertBefore(child, endContainer.firstChild);
                endOffset += 1;
            }

            // 3. Fix cursor then insert block(s) in the fragment
            node = frag;
            while (node = getNextBlock(node, root)) {
                fixCursor(node, root);
            }
            parent.insertBefore(frag, nodeAfterSplit);

            // 4. Remove empty nodes created either side of split, then
            // merge containers at the edges.
            next = nodeBeforeSplit.nextSibling;
            node = getPreviousBlock(next, root);
            if (node && !/\S/.test(node.textContent) &&!every(node,isInline)) {
                do {
                    parent = node.parentNode;
                    parent.removeChild(node);
                    node = parent;
                } while (node && !node.lastChild && node !== root && node.nodeName !== "IMG");
            }
            if (!nodeBeforeSplit.parentNode) {
                nodeBeforeSplit = next.previousSibling;
            }
            if (!startContainer.parentNode) {
                startContainer = nodeBeforeSplit || next.parentNode;
                startOffset = nodeBeforeSplit ?
                    nodeBeforeSplit.childNodes.length : 0;
            }
            // Merge inserted containers with edges of split
            if (isContainer(next)) {
                mergeContainers(next, root);
            }

            prev = nodeAfterSplit.previousSibling;
            node = isBlock(nodeAfterSplit) ?
                nodeAfterSplit : getNextBlock(nodeAfterSplit, root);

            if (node && !/\S/.test(node.textContent) &&!every(node,isInline)) {
                do {
                    parent = node.parentNode;
                    parent.removeChild(node);
                    node = parent;
                } while (node && !node.lastChild && node !== root );
            }
            if (!nodeAfterSplit.parentNode) {
                nodeAfterSplit = prev.nextSibling;
            }
            if (!endOffset) {
                endContainer = prev;
                endOffset = prev.childNodes.length;
            }
            // Merge inserted containers with edges of split
            if (nodeAfterSplit && isContainer(nodeAfterSplit)) {
                mergeContainers(nodeAfterSplit, root);
            }

            range.setStart(startContainer, startOffset);
            range.setEnd(endContainer, endOffset);
            moveRangeBoundariesDownTree(range);
        }
    };

    // ---

    var isNodeContainedInRange = function(range, node, partial) {
        var nodeRange = node.ownerDocument.createRange();

        nodeRange.selectNode(node);

        if (partial) {
            // Node must not finish before range starts or start after range
            // finishes.
            var nodeEndBeforeStart = (range.compareBoundaryPoints(
                    END_TO_START, nodeRange) > -1),
                nodeStartAfterEnd = (range.compareBoundaryPoints(
                    START_TO_END, nodeRange) < 1);
            return (!nodeEndBeforeStart && !nodeStartAfterEnd);
        } else {
            // Node must start after range starts and finish before range
            // finishes
            var nodeStartAfterStart = (range.compareBoundaryPoints(
                    START_TO_START, nodeRange) < 1),
                nodeEndBeforeEnd = (range.compareBoundaryPoints(
                    END_TO_END, nodeRange) > -1);
            return (nodeStartAfterStart && nodeEndBeforeEnd);
        }
    };

    var moveRangeBoundariesDownTree = function(range) {
        var startContainer = range.startContainer,
            startOffset = range.startOffset,
            endContainer = range.endContainer,
            endOffset = range.endOffset,
            child;

        while (startContainer.nodeType !== TEXT_NODE) {
            child = startContainer.childNodes[startOffset];
            if (!child || isLeaf(child)) {
                break;
            }
            startContainer = child;
            startOffset = 0;
        }
        if (endOffset) {
            while (endContainer.nodeType !== TEXT_NODE) {
                child = endContainer.childNodes[endOffset - 1];
                if (!child || isLeaf(child)) {
                    break;
                }
                endContainer = child;
                endOffset = getLength(endContainer);
            }
        } else {
            while (endContainer.nodeType !== TEXT_NODE) {
                child = endContainer.firstChild;
                if (!child || isLeaf(child)) {
                    break;
                }
                endContainer = child;
            }
        }

        // If collapsed, this algorithm finds the nearest text node positions
        // *outside* the range rather than inside, but also it flips which is
        // assigned to which.
        if (range.collapsed) {
            range.setStart(endContainer, endOffset);
            range.setEnd(startContainer, startOffset);
        } else {
            range.setStart(startContainer, startOffset);
            range.setEnd(endContainer, endOffset);
        }
    };

    var moveRangeBoundariesUpTree = function(range, common) {
        var startContainer = range.startContainer,
            startOffset = range.startOffset,
            endContainer = range.endContainer,
            endOffset = range.endOffset,
            parent;

        if (!common) {
            common = range.commonAncestorContainer;
        }

        while (startContainer !== common && !startOffset) {
            parent = startContainer.parentNode;
            startOffset = indexOf.call(parent.childNodes, startContainer);
            startContainer = parent;
        }

        while (endContainer !== common &&
            endOffset === getLength(endContainer)) {
            parent = endContainer.parentNode;
            endOffset = indexOf.call(parent.childNodes, endContainer) + 1;
            endContainer = parent;
        }

        range.setStart(startContainer, startOffset);
        range.setEnd(endContainer, endOffset);
    };

    // Returns the first block at least partially contained by the range,
    // or null if no block is contained by the range.
    var getStartBlockOfRange = function(range, root) {
        var container = range.startContainer,
            block;

        // If inline, get the containing block.
        if (isInline(container)) {
            block = getPreviousBlock(container, root);
        } else if (container !== root && isBlock(container)) {
            block = container;
        } else {
            block = getNodeBefore(container, range.startOffset);
            block = getNextBlock(block, root);
        }
        // Check the block actually intersects the range
        return block && isNodeContainedInRange(range, block, true) ? block : null;
    };

    // Returns the last block at least partially contained by the range,
    // or null if no block is contained by the range.
    var getEndBlockOfRange = function(range, root) {
        var container = range.endContainer,
            block, child;

        // If inline, get the containing block.
        if (isInline(container)) {
            block = getPreviousBlock(container, root);
        } else if (container !== root && isBlock(container)) {
            block = container;
        } else {
            block = getNodeAfter(container, range.endOffset);
            if (!block || !isOrContains(root, block)) {
                block = root;
                while (child = block.lastChild) {
                    block = child;
                }
            }
            block = getPreviousBlock(block, root);
        }
        // Check the block actually intersects the range
        return block && isNodeContainedInRange(range, block, true) ? block : null;
    };

    var contentWalker = new TreeWalker(null,
        SHOW_TEXT | SHOW_ELEMENT,
        function(node) {
            return node.nodeType === TEXT_NODE ?
                notWS.test(node.data) :
                (node.nodeName === 'IMG' || node.nodeName === 'INPUT');
        }
    );

    var rangeDoesStartAtBlockBoundary = function(range, root) {
        var startContainer = range.startContainer;
        var startOffset = range.startOffset;
        var nodeAfterCursor;

        // If in the middle or end of a text node, we're not at the boundary.
        contentWalker.root = null;
        if (startContainer.nodeType === TEXT_NODE) {
            if (startOffset) {
                return false;
            }
            nodeAfterCursor = startContainer;
        } else {
            nodeAfterCursor = getNodeAfter(startContainer, startOffset);
            if (nodeAfterCursor && !isOrContains(root, nodeAfterCursor)) {
                nodeAfterCursor = null;
            }
            // The cursor was right at the end of the document
            if (!nodeAfterCursor) {
                nodeAfterCursor = getNodeBefore(startContainer, startOffset);
                if (nodeAfterCursor.nodeType === TEXT_NODE &&
                    nodeAfterCursor.length) {
                    return false;
                }
            }
        }

        // Otherwise, look for any previous content in the same block.
        contentWalker.currentNode = nodeAfterCursor;
        contentWalker.root = getStartBlockOfRange(range, root);

        return !contentWalker.previousNode();
    };

    var rangeDoesEndAtBlockBoundary = function(range, root) {
        var endContainer = range.endContainer,
            endOffset = range.endOffset,
            length;

        // If in a text node with content, and not at the end, we're not
        // at the boundary
        contentWalker.root = null;
        if (endContainer.nodeType === TEXT_NODE) {
            length = endContainer.data.length;
            if (length && endOffset < length) {
                return false;
            }
            contentWalker.currentNode = endContainer;
        } else {
            contentWalker.currentNode = getNodeBefore(endContainer, endOffset);
        }

        // Otherwise, look for any further content in the same block.
        contentWalker.root = getEndBlockOfRange(range, root);

        return !contentWalker.nextNode();
    };

    var expandRangeToBlockBoundaries = function(range, root) {
        var start = getStartBlockOfRange(range, root),
            end = getEndBlockOfRange(range, root),
            parent;

        if (start && end) {
            parent = start.parentNode;
            range.setStart(parent, indexOf.call(parent.childNodes, start));
            parent = end.parentNode;
            range.setEnd(parent, indexOf.call(parent.childNodes, end) + 1);
        }
    };

    var keys = {
        8: 'backspace',
        9: 'tab',
        13: 'enter',
        32: 'space',
        33: 'pageup',
        34: 'pagedown',
        37: 'left',
        39: 'right',
        46: 'delete',
        219: '[',
        221: ']'
    };

    // Ref: http://unixpapa.com/js/key.html
    var onKey = function(event) {
        var code = event.keyCode,
            key = keys[code],
            modifiers = '',
            range = this.getSelection();

        ZE_Init.keyPressed = code;

        if (event.defaultPrevented) {
            return;
        }

        if (!key) {
            key = String.fromCharCode(code).toLowerCase();
            // Only reliable for letters and numbers
            if (!/^[A-Za-z0-9]$/.test(key)) {
                key = '';
            }
        }

        // On keypress, delete and '.' both have event.keyCode 46
        // Must check event.which to differentiate.
        if (isPresto && event.which === 46) {
            key = '.';
        }

        // Function keys
        if (111 < code && code < 124) {
            key = 'f' + (code - 111);
        }

        // We need to apply the backspace/delete handlers regardless of
        // control key modifiers.
        if (key !== 'backspace' && key !== 'delete') {
            if (event.altKey) {
                modifiers += 'alt-';
            }
            if (event.ctrlKey) {
                modifiers += 'ctrl-';
            }
            if (event.metaKey) {
                modifiers += 'meta-';
            }
        }
        // However, on Windows, shift-delete is apparently "cut" (WTF right?), so
        // we want to let the browser handle shift-delete.
        if (event.shiftKey) {
            modifiers += 'shift-';
        }

        key = modifiers + key;

        if (this._keyHandlers[key]) {
            this._keyHandlers[key](this, event, range);
        } else if (key.length === 1 && !range.collapsed) {
            // Record undo checkpoint.
            this.saveUndoState(range);
            // Delete the selection
            deleteContentsOfRange(range, this._root);
            this._ensureBottomLine();
            this.setSelection(range);
            this._updatePath(range, true);
        }
    };

    var mapKeyTo = function(method) {
        return function(self, event) {
            event.preventDefault();
            self[method]();
        };
    };

    var mapKeyToFormat = function(tag, remove) {
        remove = remove || null;
        return function(self, event) {
            event.preventDefault();
            var range = self.getSelection();
            if (self.hasFormat(tag, null, range)) {
                self.changeFormat(null, {
                    tag: tag
                }, range);
            } else {
                self.changeFormat({
                    tag: tag
                }, remove, range);
            }
        };
    };

    // If you delete the content inside a span with a font styling, Webkit will
    // replace it with a <font> tag (!). If you delete all the text inside a
    // link in Opera, it won't delete the link. Let's make things consistent. If
    // you delete all text inside an inline tag, remove the inline tag.
    var afterDelete = function(self, range) {
        try {
            if (!range) {
                range = self.getSelection();
            }
            var node = range.startContainer,
                parent;
            // Climb the tree from the focus point while we are inside an empty
            // inline element
            if (node.nodeType === TEXT_NODE) {
                node = node.parentNode;
            }
            parent = node;
            while (isInline(parent) &&
                (!parent.textContent || parent.textContent === ZWS) && parent.getElementsByTagName("img").length == 0) {
                node = parent;
                parent = node.parentNode;
            }
            // If focused in empty inline element
            if (node !== parent) {
                // Move focus to just before empty inline(s)
                range.setStart(parent,
                    indexOf.call(parent.childNodes, node));
                range.collapse(true);
                // Remove empty inline(s)
                parent.removeChild(node);
                // Fix cursor in block
                if (!isBlock(parent)) {
                    parent = getPreviousBlock(parent, self._root);
                }
                fixCursor(parent, self._root);
                // Move cursor into text node
                moveRangeBoundariesDownTree(range);
            }
            // If you delete the last character in the sole <div> in Chrome,
            // it removes the div and replaces it with just a <br> inside the
            // root. Detach the <br>; the _ensureBottomLine call will insert a new
            // block.
            if (node === self._root &&
                (node = node.firstChild) && node.nodeName === 'BR') {
                detach(node);
            }
            self._ensureBottomLine();
            self.setSelection(range);
            self._updatePath(range, true);
        } catch (error) {
            self.didError(error);
        }
    };

    var keyHandlers = {
        enter: function(self, event, range) {
            var root = self._root;
            var block, parent, nodeAfterSplit, tempElem;

            // We handle this ourselves
            event.preventDefault();
            //FIXME This is used in @mention in zohomail editor. Need to handle it properly
            tempElem = document.getElementById("ze_autofill");
            if (tempElem && tempElem.getElementsByClassName("sel").length) {
                return true;
            }
            // Save undo checkpoint and add any links in the preceding section.
            // Remove any zws so we don't think there's content in an empty
            // block.
            self._recordUndoState(range);
            addLinks(range.startContainer, root, self);
            self._removeZWS();
            self._getRangeAndRemoveBookmark(range);

            // Selected text is overwritten, therefore delete the contents
            // to collapse selection.
            if (!range.collapsed) {
                deleteContentsOfRange(range, root);
            }

            block = getStartBlockOfRange(range, root);

            // If this is a malformed bit of document or in a table;
            // just play it safe and insert a <br>.
            if (!block || /^T[HD]$/.test(block.nodeName)) {
                insertNodeInRange(range, self.createElement('BR'));
                range.collapse(false);
                self.setSelection(range);
                self._updatePath(range, true);
                return;
            }

            // If in a list, we'll split the LI instead.
            if (parent = getNearest(block, root, 'LI')) {
                block = parent;
            }

            if (!block.textContent) {
                // Break list
                if (getNearest(block, root, 'UL') ||
                    getNearest(block, root, 'OL')) {
                    return self.modifyBlocks(decreaseListLevel, range);
                }
                // Break blockquote
                else if (getNearest(block, root, 'BLOCKQUOTE')) {
                    return self.modifyBlocks(removeBlockQuote, range);
                }
            }

            // Otherwise, split at cursor point.
            nodeAfterSplit = splitBlock(self, block,
                range.startContainer, range.startOffset);

            // Clean up any empty inlines if we hit enter at the beginning of the
            // block
            removeZWS(block);
            removeEmptyInlines(block);
            fixCursor(block, root);

            // Focus cursor
            // If there's a <b>/<i> etc. at the beginning of the split
            // make sure we focus inside it.
            while (nodeAfterSplit.nodeType === ELEMENT_NODE) {
                var child = nodeAfterSplit.firstChild,
                    next;

                // Don't continue links over a block break; unlikely to be the
                // desired outcome.
                if (nodeAfterSplit.nodeName === 'A' &&
                    (!nodeAfterSplit.textContent ||
                        nodeAfterSplit.textContent === ZWS) && nodeAfterSplit.getElementsByTagName("img").length == 0) {
                    child = self._doc.createTextNode('');
                    replaceWith(nodeAfterSplit, child);
                    nodeAfterSplit = child;
                    break;
                }

                while (child && child.nodeType === TEXT_NODE && !child.data) {
                    next = child.nextSibling;
                    if (!next || next.nodeName === 'BR') {
                        break;
                    }
                    detach(child);
                    child = next;
                }

                // 'BR's essentially don't count; they're a browser hack.
                // If you try to select the contents of a 'BR', FF will not let
                // you type anything!
                if (!child || child.nodeName === 'BR' ||
                    (child.nodeType === TEXT_NODE && !isPresto)) {
                    break;
                }
                nodeAfterSplit = child;
            }
            range = self._createRange(nodeAfterSplit, 0);
            self.setSelection(range);
            self._updatePath(range, true);

            // Scroll into view
            if (nodeAfterSplit.nodeType === TEXT_NODE) {
                nodeAfterSplit = nodeAfterSplit.parentNode;
            }
            // 16 ~ one standard line height in px.
            if (nodeAfterSplit.getBoundingClientRect().top + 16 >
                self._doc.documentElement.clientHeight) {
                nodeAfterSplit.scrollIntoView(true);
            }
        },
        backspace: function(self, event, range) {
            var root = self._root;
            self._removeZWS();
            // Record undo checkpoint.
            self.saveUndoState(range);
            // If not collapsed, delete contents
            if (!range.collapsed) {
                event.preventDefault();
                deleteContentsOfRange(range, root);
                afterDelete(self, range);
            }
            // If at beginning of block, merge with previous
            else if (rangeDoesStartAtBlockBoundary(range, root)) {
                event.preventDefault();
                var current = getStartBlockOfRange(range, root);
                var previous;
                if (!current) {
                    return;
                }
                // In case inline data has somehow got between blocks.
                fixContainer(current.parentNode, root);
                // Now get previous block
                previous = getPreviousBlock(current, root);
                var tableNode = previous && getNearest(previous, root, 'TABLE', {
                    contenteditable: "false"
                });
                if (tableNode) {
                    previous = tableNode;
                }
                // Must not be at the very beginning of the text area.
                if (previous) {
                    // If not editable, just delete whole block.
                    if (!previous.isContentEditable) {
                        detach(previous);
                        return;
                    }
                    // Otherwise merge.
                    mergeWithBlock(previous, current, range);
                    // If deleted line between containers, merge newly adjacent
                    // containers.
                    current = previous.parentNode;
                    while (current !== root && !current.nextSibling) {
                        current = current.parentNode;
                    }
                    /*In order to avoid td gettings merged - retain default behaviour of tables*/
                    if (current !== root && current.nodeName != "TD" && current.nodeName != "TR" && (current = current.nextSibling)) {
                        mergeContainers(current, root);
                    }
                    self.setSelection(range);
                }
                // If at very beginning of text area, allow backspace
                // to break lists/blockquote.
                else if (current) {
                    // Break list
                    if (getNearest(current, root, 'UL') ||
                        getNearest(current, root, 'OL')) {
                        return self.modifyBlocks(decreaseListLevel, range);
                    }
                    // Break blockquote
                    else if (getNearest(current, root, 'BLOCKQUOTE')) {
                        return self.modifyBlocks(decreaseBlockQuoteLevel, range);
                    }
                    self.setSelection(range);
                    self._updatePath(range, true);
                }
            }
            // Otherwise, leave to browser but check afterwards whether it has
            // left behind an empty inline tag.
            else {
                self.setSelection(range);
                setTimeout(function() {
                    afterDelete(self);
                }, 0);
            }
        },
        'delete': function(self, event, range) {
            var root = self._root;
            var current, next, originalRange,
                cursorContainer, cursorOffset, nodeAfterCursor;
            self._removeZWS();
            // Record undo checkpoint.
            self.saveUndoState(range);
            // If not collapsed, delete contents
            if (!range.collapsed) {
                event.preventDefault();
                deleteContentsOfRange(range, root);
                afterDelete(self, range);
            }
            // If at end of block, merge next into this block
            else if (rangeDoesEndAtBlockBoundary(range, root)) {
                event.preventDefault();
                current = getStartBlockOfRange(range, root);
                if (!current) {
                    return;
                }
                // In case inline data has somehow got between blocks.
                fixContainer(current.parentNode, root);
                // Now get next block
                next = getNextBlock(current, root);
                // Must not be at the very end of the text area.
                if (next) {
                    // If not editable, just delete whole block.
                    if (!next.isContentEditable) {
                        if (!next.hasAttribute("resizeDiv")) {
                            return;
                        } else {
                            detach(next);
                            return;
                        }
                    }
                    // Otherwise merge.
                    mergeWithBlock(current, next, range);
                    // If deleted line between containers, merge newly adjacent
                    // containers.
                    next = current.parentNode;
                    while (next !== root && !next.nextSibling) {
                        next = next.parentNode;
                    }
                    if (next !== root && (next = next.nextSibling)) {
                        mergeContainers(next, root);
                    }
                    self.setSelection(range);
                    self._updatePath(range, true);
                }
            }
            // Otherwise, leave to browser but check afterwards whether it has
            // left behind an empty inline tag.
            else {
                // But first check if the cursor is just before an IMG tag. If so,
                // delete it ourselves, because the browser won't if it is not
                // inline.
                originalRange = range.cloneRange();
                moveRangeBoundariesUpTree(range, self._root);
                cursorContainer = range.endContainer;
                cursorOffset = range.endOffset;
                if (cursorContainer.nodeType === ELEMENT_NODE) {
                    nodeAfterCursor = cursorContainer.childNodes[cursorOffset];
                    if (nodeAfterCursor && nodeAfterCursor.nodeName === 'IMG') {
                        event.preventDefault();
                        detach(nodeAfterCursor);
                        moveRangeBoundariesDownTree(range);
                        afterDelete(self, range);
                        return;
                    }
                }
                self.setSelection(originalRange);
                setTimeout(function() {
                    afterDelete(self);
                }, 0);
            }
        },
        tab: function(self, event, range) {
            var root = self._root;
            var node, parent;
            self._removeZWS();
            var flag = false;
            // If no selection and at start of block
            if (range.collapsed && rangeDoesStartAtBlockBoundary(range, root)) {
                node = getStartBlockOfRange(range, root);
                // Iterate through the block's parents
                while (parent = node.parentNode) {
                    // If we find a UL or OL (so are in a list, node must be an LI)
                    if (parent.nodeName === 'UL' || parent.nodeName === 'OL') {
                        // AND the LI is not the first in the list
                        if (node.previousSibling) {
                            // Then increase the list level
                            event.preventDefault();
                            self.modifyBlocks(increaseListLevel, range);
                        }
                        flag = true;
                        break;
                    }
                    node = parent;
                }
            }
            if (!flag && window.ZE && ZE.tabHandler) {
                ZE.tabHandler(event, self._win, self._doc);
            }
        },
        'shift-tab': function(self, event, range) {
            var root = self._root;
            var node;
            self._removeZWS();
            // If no selection and at start of block
            if (range.collapsed && rangeDoesStartAtBlockBoundary(range, root)) {
                // Break list
                node = range.startContainer;
                if (getNearest(node, root, 'UL') ||
                    getNearest(node, root, 'OL')) {
                    event.preventDefault();
                    self.modifyBlocks(decreaseListLevel, range);
                }
            }
        },
        space: function(self, _, range) {
            var node, parent;
            self._recordUndoState(range);
            addLinks(range.startContainer, self._root, self);
            self._getRangeAndRemoveBookmark(range);

            // If the cursor is at the end of a link (<a>foo|</a>) then move it
            // outside of the link (<a>foo</a>|) so that the space is not part of
            // the link text.
            node = range.endContainer;
            parent = node.parentNode;
            if (range.collapsed && parent.nodeName === 'A' &&
                !node.nextSibling && range.endOffset === getLength(node)) {
                range.setStartAfter(parent);
            }
            // Delete the selection if not collapsed
            else if (!range.collapsed) {
                deleteContentsOfRange(range, self._root);
                self._ensureBottomLine();
                self.setSelection(range);
                self._updatePath(range, true);
            }

            self.setSelection(range);
        },
        left: function(self) {
            self._removeZWS();
        },
        right: function(self) {
            self._removeZWS();
        }
    };

    // Firefox pre v29 incorrectly handles Cmd-left/Cmd-right on Mac:
    // it goes back/forward in history! Override to do the right
    // thing.
    // https://bugzilla.mozilla.org/show_bug.cgi?id=289384
    if (isMac && isGecko) {
        keyHandlers['meta-left'] = function(self, event) {
            event.preventDefault();
            var sel = getWindowSelection(self);
            if (sel && sel.modify) {
                sel.modify('move', 'backward', 'lineboundary');
            }
        };
        keyHandlers['meta-right'] = function(self, event) {
            event.preventDefault();
            var sel = getWindowSelection(self);
            if (sel && sel.modify) {
                sel.modify('move', 'forward', 'lineboundary');
            }
        };
    }

    // System standard for page up/down on Mac is to just scroll, not move the
    // cursor. On Linux/Windows, it should move the cursor, but some browsers don't
    // implement this natively. Override to support it.
    if (!isMac) {
        keyHandlers.pageup = function(self) {
            self.moveCursorToStart();
        };
        keyHandlers.pagedown = function(self) {
            self.moveCursorToEnd();
        };
    }
    /*
    keyHandlers[ ctrlKey + 'b' ] = mapKeyToFormat( 'B' );
    keyHandlers[ ctrlKey + 'i' ] = mapKeyToFormat( 'I' );
    keyHandlers[ ctrlKey + 'u' ] = mapKeyToFormat( 'U' );
    keyHandlers[ ctrlKey + 'shift-7' ] = mapKeyToFormat( 'S' );
    keyHandlers[ ctrlKey + 'shift-5' ] = mapKeyToFormat( 'SUB', { tag: 'SUP' } );
    keyHandlers[ ctrlKey + 'shift-6' ] = mapKeyToFormat( 'SUP', { tag: 'SUB' } );
    keyHandlers[ ctrlKey + 'shift-8' ] = mapKeyTo( 'makeUnorderedList' );
    keyHandlers[ ctrlKey + 'shift-9' ] = mapKeyTo( 'makeOrderedList' );
    keyHandlers[ ctrlKey + '[' ] = mapKeyTo( 'decreaseQuoteLevel' );
    keyHandlers[ ctrlKey + ']' ] = mapKeyTo( 'increaseQuoteLevel' );
    keyHandlers[ ctrlKey + 'y' ] = mapKeyTo( 'redo' );
    keyHandlers[ ctrlKey + 'z' ] = mapKeyTo( 'undo' );
    keyHandlers[ ctrlKey + 'shift-z' ] = mapKeyTo( 'redo' );
    */
    var fontSizes = {
        1: 10,
        2: 13,
        3: 16,
        4: 18,
        5: 24,
        6: 32,
        7: 48
    };

    var styleToSemantic = {
        backgroundColor: {
            regexp: notWS,
            replace: function(doc, colour) {
                return createElement(doc, 'SPAN', {
                    'class': HIGHLIGHT_CLASS,
                    style: 'background-color:' + colour
                });
            }
        },
        color: {
            regexp: notWS,
            replace: function(doc, colour) {
                return createElement(doc, 'SPAN', {
                    'class': COLOUR_CLASS,
                    style: 'color:' + colour
                });
            }
        },
        fontWeight: {
            regexp: /^bold/i,
            replace: function(doc) {
                return createElement(doc, 'B');
            }
        },
        fontStyle: {
            regexp: /^italic/i,
            replace: function(doc) {
                return createElement(doc, 'I');
            }
        },
        fontFamily: {
            regexp: notWS,
            replace: function(doc, family) {
                return createElement(doc, 'SPAN', {
                    'class': FONT_FAMILY_CLASS,
                    style: 'font-family:' + family
                });
            }
        },
        fontSize: {
            regexp: notWS,
            replace: function(doc, size) {
                return createElement(doc, 'SPAN', {
                    'class': FONT_SIZE_CLASS,
                    style: 'font-size:' + size
                });
            }
        },
        textDecoration: {
            regexp: /^underline/i,
            replace: function(doc) {
                return createElement(doc, 'U');
            }
        }
    };

    var replaceWithTag = function(tag) {
        return function(node, parent) {
            var el = createElement(node.ownerDocument, tag);
            parent.replaceChild(el, node);
            el.appendChild(empty(node));
            return el;
        };
    };

    var replaceStyles = function(node, parent) {
        var style = node.style;
        var doc = node.ownerDocument;
        var attr, converter, css, newTreeBottom, newTreeTop, el;

        for (attr in styleToSemantic) {
            converter = styleToSemantic[attr];
            css = style[attr];
            if (css && converter.regexp.test(css)) {
                el = converter.replace(doc, css);
                if (!newTreeTop) {
                    newTreeTop = el;
                }
                if (newTreeBottom) {
                    newTreeBottom.appendChild(el);
                }
                newTreeBottom = el;
                node.style[attr] = '';
            }
        }

        if (newTreeTop) {
            newTreeBottom.appendChild(empty(node));
            if (node.nodeName === 'SPAN') {
                parent.replaceChild(newTreeTop, node);
            } else {
                node.appendChild(newTreeTop);
            }
        }

        return newTreeBottom || node;
    };

    var stylesRewriters = {
        P: replaceStyles,
        SPAN: replaceStyles,
        STRONG: replaceWithTag('B'),
        EM: replaceWithTag('I'),
        INS: replaceWithTag('U'),
        STRIKE: replaceWithTag('S'),
        FONT: function(node, parent) {
            var face = node.face || node.style.fontFamily,
                size = node.size,
                colour = node.color || node.style.color,
                doc = node.ownerDocument,
                fontSpan, sizeSpan, colourSpan,
                newTreeBottom, newTreeTop;
            if (face) {
                fontSpan = createElement(doc, 'SPAN', {
                    'class': 'font',
                    style: 'font-family:' + face
                });
                newTreeTop = fontSpan;
                newTreeBottom = fontSpan;
            }
            if (size) {
                sizeSpan = createElement(doc, 'SPAN', {
                    'class': 'size',
                    style: 'font-size:' + fontSizes[size] + 'px'
                });
                if (!newTreeTop) {
                    newTreeTop = sizeSpan;
                }
                if (newTreeBottom) {
                    newTreeBottom.appendChild(sizeSpan);
                }
                newTreeBottom = sizeSpan;
            }
            if (colour) {
                if (/^#?([\dA-F]{3}){1,2}$/i.test(colour)) {
                    if (colour.charAt(0) !== '#') {
                        colour = '#' + colour;
                    }
                    colourSpan = createElement(doc, 'SPAN', {
                        'class': 'colour',
                        style: 'color:' + colour
                    });
                    if (!newTreeTop) {
                        newTreeTop = colourSpan;
                    }
                    if (newTreeBottom) {
                        newTreeBottom.appendChild(colourSpan);
                    }
                    newTreeBottom = colourSpan;
                } else if (colour.indexOf("rgb") > -1) {
                    colour = colour.replace(/rgb\(|\)/g, "").split(",");
                    var collen = colour.length;
                    for (var i = 0; i < collen; i++) {
                        colour[i] = parseInt(colour[i], 10).toString(16);
                        colour[i] = (colour[i].length == 1) ? '0' + colour[i] : colour[i];
                    }
                    colour = '#' + colour.join("");
                    colourSpan = createElement(doc, 'SPAN', {
                        'class': 'colour',
                        style: 'color:' + colour
                    });
                    if (!newTreeTop) {
                        newTreeTop = colourSpan;
                    }
                    if (newTreeBottom) {
                        newTreeBottom.appendChild(colourSpan);
                    }
                    newTreeBottom = colourSpan;
                }
            }
            if (!newTreeTop) {
                newTreeTop = newTreeBottom = createElement(doc, 'SPAN');
            }
            parent.replaceChild(newTreeTop, node);
            newTreeBottom.appendChild(empty(node));
            return newTreeBottom;
        },
        TT: function(node, parent) {
            var el = createElement(node.ownerDocument, 'SPAN', {
                'class': 'font',
                style: 'font-family:menlo,consolas,"courier new",monospace'
            });
            parent.replaceChild(el, node);
            el.appendChild(empty(node));
            return el;
        }
    };

    var allowedBlock = /^(?:A(?:DDRESS|RTICLE|SIDE|UDIO)|BLOCKQUOTE|CAPTION|D(?:[DLT]|IV)|F(?:IGURE|IGCAPTION|OOTER)|H[1-6]|HEADER|L(?:ABEL|EGEND|I)|O(?:L|UTPUT)|P(?:RE)?|SECTION|T(?:ABLE|BODY|D|FOOT|H|HEAD|R)|UL)$/;

    var blacklist = /^(?:HEAD|META|STYLE)/;

    var walker = new TreeWalker(null, SHOW_TEXT | SHOW_ELEMENT, function() {
        return true;
    });

    /*
        Two purposes:

        1. Remove nodes we don't want, such as weird <o:p> tags, comment nodes
           and whitespace nodes.
        2. Convert inline tags into our preferred format.
    */
    var cleanTree = function cleanTree(node, preserveWS, options) {

        var children = node.childNodes,
            nonInlineParent, i, l, child, nodeName, nodeType, rewriter, childLength,
            startsWithWS, endsWithWS, data, sibling, editorInstance, setZEEditorImageStyle;


        /* custom block start */
        options = options || {};
        setZEEditorImageStyle = function() {
            var img = this;
            img.setAttribute("orig_width", img.width);
            img.setAttribute("orig_height", img.height);
            if (typeof ZE !== "undefined") {
                ZE.setImageSizeOptions(img, "bestfit", editorInstance.editordiv.offsetWidth);
            }
            img.removeAttribute("data-zeLoad");
        };
        /* custom block ends */

        nonInlineParent = node;
        while (isInline(nonInlineParent)) {
            nonInlineParent = nonInlineParent.parentNode;
        }
        walker.root = nonInlineParent;

        for (i = 0, l = children.length; i < l; i += 1) {
            child = children[i];
            nodeName = child.nodeName;
            nodeType = child.nodeType;
            rewriter = stylesRewriters[nodeName];
            if (nodeType === ELEMENT_NODE) {
                childLength = child.childNodes.length;
                if (rewriter) {
                    child = rewriter(child, node);
                } else if (blacklist.test(nodeName)) {
                    node.removeChild(child);
                    i -= 1;
                    l -= 1;
                    continue;
                } else if (!allowedBlock.test(nodeName) && !isInline(child)) {
                    i -= 1;
                    l += childLength - 1;
                    node.replaceChild(empty(child), child);
                    continue;
                }
                if (nodeName === "IMG" && options.handleWaitingImages) {
                    if (child.className.indexOf("ze_img_upload") > -1) {
                        var nodeId = child.getAttribute("id");
                        editorInstance = options.editorRef();
                        if (nodeId && editorInstance._unusedImagesList[nodeId]) {
                            child.setAttribute("data-zeload", true);
                            child.onload = setZEEditorImageStyle;
                            child.src = editorInstance._unusedImagesList[nodeId];
                            child.removeAttribute("id");
                            child.removeAttribute("class");
                            delete editorInstance._unusedImagesList[nodeId];
                        } else if (nodeId && !editorInstance._pendingImagesList[nodeId]) {
                            node.removeChild(child);
                            i -= 1;
                            l -= 1;
                            continue;
                        }
                    } else if (child.hasAttribute("data-zeload")) {
                        editorInstance = options.editorRef();
                        child.onload = setZEEditorImageStyle;
                    }
                }

                if (childLength) {
                    cleanTree(child, preserveWS || (nodeName === 'PRE'), options);
                }
            } else {
                if (nodeType === TEXT_NODE) {
                    data = child.data;
                    startsWithWS = !notWS.test(data.charAt(0));
                    endsWithWS = !notWS.test(data.charAt(data.length - 1));
                    if (preserveWS || (!startsWithWS && !endsWithWS)) {
                        continue;
                    }
                    // Iterate through the nodes; if we hit some other content
                    // before the start of a new block we don't trim
                    if (startsWithWS) {
                        walker.currentNode = child;
                        while (sibling = walker.previousPONode()) {
                            nodeName = sibling.nodeName;
                            if (nodeName === 'IMG' ||
                                (nodeName === '#text' &&
                                    /\S/.test(sibling.data))) {
                                break;
                            }
                            if (!isInline(sibling)) {
                                sibling = null;
                                break;
                            }
                        }
                        data = data.replace(/^\s+/g, sibling ? ' ' : '');
                    }
                    if (endsWithWS) {
                        walker.currentNode = child;
                        while (sibling = walker.nextNode()) {
                            if (nodeName === 'IMG' ||
                                (nodeName === '#text' &&
                                    /\S/.test(sibling.data))) {
                                break;
                            }
                            if (!isInline(sibling)) {
                                sibling = null;
                                break;
                            }
                        }
                        data = data.replace(/\s+$/g, sibling ? ' ' : '');
                    }
                    if (data) {
                        child.data = data;
                        continue;
                    }
                }
                node.removeChild(child);
                i -= 1;
                l -= 1;
            }
        }
        return node;
    };

    // ---

    var removeEmptyInlines = function removeEmptyInlines(node) {
        var children = node.childNodes,
            l = children.length,
            child;
        while (l--) {
            child = children[l];
            if (child.nodeType === ELEMENT_NODE && !isLeaf(child)) {
                removeEmptyInlines(child);
                if (isInline(child) && !child.firstChild) {
                    node.removeChild(child);
                }
            } else if (child.nodeType === TEXT_NODE && !child.data) {
                node.removeChild(child);
            }
        }
    };

    // ---

    var notWSTextNode = function(node) {
        return node.nodeType === ELEMENT_NODE ?
            node.nodeName === 'BR' :
            notWS.test(node.data);
    };
    var isLineBreak = function(br) {
        var block = br.parentNode,
            walker;
        while (isInline(block)) {
            block = block.parentNode;
        }
        walker = new TreeWalker(
            block, SHOW_ELEMENT | SHOW_TEXT, notWSTextNode);
        walker.currentNode = br;
        return !!walker.nextNode();
    };

    // <br> elements are treated specially, and differently depending on the
    // browser, when in rich text editor mode. When adding HTML from external
    // sources, we must remove them, replacing the ones that actually affect
    // line breaks by wrapping the inline text in a <div>. Browsers that want <br>
    // elements at the end of each block will then have them added back in a later
    // fixCursor method call.
    var cleanupBRs = function(node, root) {
        var brs = node.querySelectorAll('BR'),
            brBreaksLine = [],
            l = brs.length,
            i, br, parent;

        // Must calculate whether the <br> breaks a line first, because if we
        // have two <br>s next to each other, after the first one is converted
        // to a block split, the second will be at the end of a block and
        // therefore seem to not be a line break. But in its original context it
        // was, so we should also convert it to a block split.
        for (i = 0; i < l; i += 1) {
            brBreaksLine[i] = isLineBreak(brs[i]);
        }
        while (l--) {
            br = brs[l];
            // Cleanup may have removed it
            parent = br.parentNode;
            if (!parent) {
                continue;
            }
            // If it doesn't break a line, just remove it; it's not doing
            // anything useful. We'll add it back later if required by the
            // browser. If it breaks a line, wrap the content in div tags
            // and replace the brs.
            if (!brBreaksLine[l]) {
                detach(br);
            } else if (!isInline(parent)) {
                fixContainer(parent, root);
            }
        }
    };

    var onCut = function(event) {
        var clipboardData = event.clipboardData;
        var range = this.getSelection();
        var node = this.createElement('div');
        var root = this._root;
        var self = this;

        // Save undo checkpoint
        this.saveUndoState(range);

        // Edge only seems to support setting plain text as of 2016-03-11.
        // Mobile Safari flat out doesn't work:
        // https://bugs.webkit.org/show_bug.cgi?id=143776
        if (!isEdge && !isIOS && clipboardData) {
            moveRangeBoundariesUpTree(range, root);
            node.appendChild(deleteContentsOfRange(range, root));
            clipboardData.setData('text/html', node.innerHTML);
            clipboardData.setData('text/plain',
                node.innerText || node.textContent);
            event.preventDefault();
        } else {
            setTimeout(function() {
                try {
                    // If all content removed, ensure div at start of root.
                    self._ensureBottomLine();
                } catch (error) {
                    self.didError(error);
                }
            }, 0);
        }

        this.setSelection(range);
    };

    var onCopy = function(event) {
        var clipboardData = event.clipboardData;
        var range = this.getSelection();
        var node = this.createElement('div');
        var root = this._root;
        var contents, parent, newContents;

        // Edge only seems to support setting plain text as of 2016-03-11.
        // Mobile Safari flat out doesn't work:
        // https://bugs.webkit.org/show_bug.cgi?id=143776
        if (!isEdge && !isIOS && clipboardData) {
            range = range.cloneRange();
            if (getStartBlockOfRange(range, root) ===
                getEndBlockOfRange(range, root)) {
                moveRangeBoundariesDownTree(range);
                contents = range.cloneContents();
            } else {
                moveRangeBoundariesUpTree(range, root);
                contents = range.cloneContents();
                parent = range.commonAncestorContainer;
                while (parent && parent !== root) {
                    newContents = parent.cloneNode(false);
                    newContents.appendChild(contents);
                    contents = newContents;
                    parent = parent.parentNode;
                }
            }
            node.appendChild(contents);
            clipboardData.setData('text/html', node.innerHTML);
            clipboardData.setData('text/plain',
                node.innerText || node.textContent);
            event.preventDefault();
        }
    };

    //Need to monitor for shift key like this, as event.shiftKey is not available
    //in paste event.
    function monitorShiftKey(event) {
        this.isShiftDown = event.shiftKey;
    }


    var onPaste = function(event) {
        // debugger;
        var clipboardData = event.clipboardData;
        var items = clipboardData && clipboardData.items;
        var choosePlain = this.isShiftDown;
        var fireDrop = false;
        var hasImage = false;
        var plainItem = null;
        var self = this;
        var l, item, type, types, data;
        // Current HTML5 Clipboard interface
        // ---------------------------------
        // https://html.spec.whatwg.org/multipage/interaction.html
        // Edge only provides access to plain text as of 2016-03-11.
        // this._editorRef().pasteContent(items);
        if (!isEdge && items) {
            event.preventDefault();
            l = items.length;
            while (l--) {
                item = items[l];
                type = item.type;
                if (!choosePlain && type === 'text/html') {
                    /*jshint loopfunc: true */

                    item.getAsString(function(html) {
                        // self._editorRef().pasteContent(html);
                        self.insertHTML(html, true);
                    });
                    /*jshint loopfunc: false */
                    return;
                }
                if (type === 'text/plain') {
                    plainItem = item;
                }
                if (/^image\/.*/.test(type)) {
                    hasImage = true;
                }
            }
            // Treat image paste as a drop of an image file.
            if (hasImage) {
                this.fireEvent('dragover', {
                    dataTransfer: clipboardData,
                    /*jshint loopfunc: true */
                    preventDefault: function() {
                        fireDrop = true;
                    }
                    /*jshint loopfunc: false */
                });
                if (fireDrop) {
                    this.fireEvent('drop', {
                        dataTransfer: clipboardData,
                        editorCustomPaste: true
                    });
                }
            } else if (plainItem) {

                item.getAsString(function(text) {
                    // self._editorRef().pasteContent(text);
                    self.insertPlainText(text, true);
                });
            }
            return;
        }
        // Old interface
        // -------------

        // Safari (and indeed many other OS X apps) copies stuff as text/rtf
        // rather than text/html; even from a webpage in Safari. The only way
        // to get an HTML version is to fallback to letting the browser insert
        // the content. Same for getting image data. *Sigh*.
        //
        // Firefox is even worse: it doesn't even let you know that there might be
        // an RTF version on the clipboard, but it will also convert to HTML if you
        // let the browser insert the content. I've filed
        // https://bugzilla.mozilla.org/show_bug.cgi?id=1254028

        // Firefox doesnt detect whether paste is triggered via CMD+Shift+V or CMD+V
        types = clipboardData && clipboardData.types;
        if (!isEdge && types && (
                indexOf.call(types, 'text/html') > -1 || (!isGecko &&
                    indexOf.call(types, 'text/plain') > -1 &&
                    indexOf.call(types, 'text/rtf') < 0)
            )) {
            event.preventDefault();
            // Abiword on Linux copies a plain text and html version, but the HTML
            // version is the empty string! So always try to get HTML, but if none,
            // insert plain text instead. On iOS, Facebook (and possibly other
            // apps?) copy links as type text/uri-list, but also insert a **blank**
            // text/plain item onto the clipboard. Why? Who knows.
            if (!choosePlain && (data = clipboardData.getData('text/html'))) {
                this.insertHTML(data, true);
            } else if (
                (data = clipboardData.getData('text/plain')) ||
                (data = clipboardData.getData('text/uri-list'))) {
                this.insertPlainText(data, true);
            }
            return;
        }

        // No interface. Includes all versions of IE :(
        // --------------------------------------------

        this._awaitingPaste = true;

        var body = this._doc.body,
            range = this.getSelection(),
            startContainer = range.startContainer,
            startOffset = range.startOffset,
            endContainer = range.endContainer,
            endOffset = range.endOffset;

        // We need to position the pasteArea in the visible portion of the screen
        // to stop the browser auto-scrolling.
        var pasteArea = this.createElement('DIV', {
            contenteditable: 'true',
            style: 'position:fixed; overflow:hidden; top:0; right:100%; width:1px; height:1px;'
        });
        body.appendChild(pasteArea);
        range.selectNodeContents(pasteArea);
        this.setSelection(range);

        // A setTimeout of 0 means this is added to the back of the
        // single javascript thread, so it will be executed after the
        // paste event.
        setTimeout(function() {
            try {
                // IE sometimes fires the beforepaste event twice; make sure it is
                // not run again before our after paste function is called.
                self._awaitingPaste = false;

                // Get the pasted content and clean
                var html = '',
                    next = pasteArea,
                    first, range;

                // #88: Chrome can apparently split the paste area if certain
                // content is inserted; gather them all up.
                while (pasteArea = next) {
                    next = pasteArea.nextSibling;
                    detach(pasteArea);
                    // Safari and IE like putting extra divs around things.
                    first = pasteArea.firstChild;
                    if (first && first === pasteArea.lastChild &&
                        first.nodeName === 'DIV') {
                        pasteArea = first;
                    }
                    html += pasteArea.innerHTML;
                }

                range = self._createRange(
                    startContainer, startOffset, endContainer, endOffset);
                self.setSelection(range);

                if (html) {
                    self.insertHTML(html, true);
                }
            } catch (error) {
                self.didError(error);
            }
        }, 0);
    };

    // On Windows you can drag an drop text. We can't handle this ourselves, because
    // as far as I can see, there's no way to get the drop insertion point. So just
    // save an undo state and hope for the best.
    var onDrop = function(event) {
        var types = event.dataTransfer.types;
        var l = types.length;
        var hasPlain = false;
        var hasHTML = false;
        while (l--) {
            switch (types[l]) {
                case 'text/plain':
                    hasPlain = true;
                    break;
                case 'text/html':
                    hasHTML = true;
                    break;
                default:
                    return;
            }
        }
        if (hasHTML || hasPlain) {
            this.saveUndoState();
        }
    };

    var instances = [];

    function getSquireInstance(doc) {
        var l = instances.length,
            instance;
        while (l--) {
            instance = instances[l];
            if (instance._doc === doc) {
                return instance;
            }
        }
        return null;
    }

    function mergeObjects(base, extras, mayOverride) {
        var prop, value;
        if (!base) {
            base = {};
        }
        if (extras) {
            for (prop in extras) {
                if (mayOverride || !(prop in base)) {
                    value = extras[prop];
                    base[prop] = (value && value.constructor === Object) ?
                        mergeObjects(base[prop], value, mayOverride) :
                        value;
                }
            }
        }
        return base;
    }

    function Squire(root, options) {
        if (root.nodeType === DOCUMENT_NODE) {
            root = root.body;
        }
        var doc = root.ownerDocument;
        var win = doc.defaultView;
        var mutation;

        this._win = win;
        this._doc = doc;
        this._root = root;

        this._events = {};
        if (options && options.getEditorInstance) {
            this._editorRef = options.getEditorInstance;
        }
        this._isFocused = false;
        this._lastSelection = null;

        this.addEventListener('click', this._mouseDblMacro);
        this.addEventListener('mousedown', this._mousedownMacro);
        this.addEventListener('mouseup', this._mouseupMacro);

        // IE loses selection state of iframe on blur, so make sure we
        // cache it just before it loses focus.
        if (losesSelectionOnBlur) {
            this.addEventListener('beforedeactivate', this.getSelection);
        }

        this._hasZWS = false;

        this._lastAnchorNode = null;
        this._lastFocusNode = null;
        this._path = '';
        this._willUpdatePath = false;

        if ('onselectionchange' in doc) {
            this.addEventListener('selectionchange', this._updatePathOnEvent);
        } else {
            this.addEventListener('keyup', this._updatePathOnEvent);
            this.addEventListener('mouseup', this._updatePathOnEvent);
        }

        this._undoIndex = -1;
        this._undoStack = [];
        this._undoStackLength = 0;
        this._isInUndoState = false;
        this._ignoreChange = false;
        this._ignoreAllChanges = false;

        if (canObserveMutations) {
            mutation = new MutationObserver(this._docWasChanged.bind(this));
            mutation.observe(root, {
                childList: true,
                attributes: true,
                characterData: true,
                subtree: true
            });
            this._mutation = mutation;
        } else {
            this.addEventListener('keyup', this._keyUpDetectChange);
        }

        // On blur, restore focus except if the user taps or clicks to focus a
        // specific point. Can't actually use click event because focus happens
        // before click, so use mousedown/touchstart
        this._restoreSelection = false;
        this.addEventListener('blur', enableRestoreSelection);
        this.addEventListener('mousedown', disableRestoreSelection);
        this.addEventListener('touchstart', disableRestoreSelection);
        this.addEventListener('focus', restoreSelection);

        // IE sometimes fires the beforepaste event twice; make sure it is not run
        // again before our after paste function is called.
        this._awaitingPaste = false;
        this.addEventListener(isIElt11 ? 'beforecut' : 'cut', onCut);
        this.addEventListener('copy', onCopy);
        this.addEventListener('keydown', monitorShiftKey);
        this.addEventListener('keyup', monitorShiftKey);
        this.addEventListener(isIElt11 ? 'beforepaste' : 'paste', onPaste);
        this.addEventListener('drop', onDrop);

        // Opera does not fire keydown repeatedly.
        this.addEventListener(isPresto ? 'keypress' : 'keydown', onKey);

        // Add key handlers
        this._keyHandlers = Object.create(keyHandlers);

        // Override default properties
        this.setConfig(options && options.config);

        // Fix IE<10's buggy implementation of Text#splitText.
        // If the split is at the end of the node, it doesn't insert the newly split
        // node into the document, and sets its value to undefined rather than ''.
        // And even if the split is not at the end, the original node is removed
        // from the document and replaced by another, rather than just having its
        // data shortened.
        // We used to feature test for this, but then found the feature test would
        // sometimes pass, but later on the buggy behaviour would still appear.
        // I think IE10 does not have the same bug, but it doesn't hurt to replace
        // its native fn too and then we don't need yet another UA category.
        if (isIElt11) {
            win.Text.prototype.splitText = function(offset) {
                var afterSplit = this.ownerDocument.createTextNode(
                        this.data.slice(offset)),
                    next = this.nextSibling,
                    parent = this.parentNode,
                    toDelete = this.length - offset;
                if (next) {
                    parent.insertBefore(afterSplit, next);
                } else {
                    parent.appendChild(afterSplit);
                }
                if (toDelete) {
                    this.deleteData(offset, toDelete);
                }
                return afterSplit;
            };
        }

        root.setAttribute('contenteditable', 'true');

        // Remove Firefox's built-in controls
        try {
            doc.execCommand('enableObjectResizing', false, 'false');
            doc.execCommand('enableInlineTableEditing', false, 'false');
        } catch (error) {}

        instances.push(this);

        // Need to register instance before calling setHTML, so that the fixCursor
        // function can lookup any default block tag options set.
        //this.setHTML( '' );
    }

    var proto = Squire.prototype;

    proto.setConfig = function(config) {
        config = mergeObjects({
            blockTag: 'DIV',
            blockAttributes: null,
            tagAttributes: {
                blockquote: null,
                ul: null,
                ol: null,
                li: null,
                a: null
            },
            leafNodeNames: leafNodeNames,
            undo: {
                documentSizeThreshold: -1, // -1 means no threshold
                undoLimit: -1 // -1 means no limit
            }
        }, config, true);

        // Users may specify block tag in lower case
        config.blockTag = config.blockTag.toUpperCase();

        this._config = config;

        return this;
    };

    proto.createElement = function(tag, props, children) {
        return createElement(this._doc, tag, props, children);
    };

    proto.createDefaultBlock = function(children) {
        var config = this._config;
        return fixCursor(
            this.createElement(config.blockTag, config.blockAttributes, children),
            this._root
        );
    };

    proto.didError = function(error) {

    };

    proto.getDocument = function() {
        return this._doc;
    };
    proto.getRoot = function() {
        return this._root;
    };

    proto.modifyDocument = function(modificationCallback) {
        this._ignoreAllChanges = true;
        if (this._mutation) {
            this._mutation.disconnect();
        }

        modificationCallback();

        this._ignoreAllChanges = false;
        if (this._mutation) {
            this._mutation.observe(this._root, {
                childList: true,
                attributes: true,
                characterData: true,
                subtree: true
            });
        }
    };

    // --- Events ---

    // Subscribing to these events won't automatically add a listener to the
    // document node, since these events are fired in a custom manner by the
    // editor code.
    var customEvents = {
        pathChange: 1,
        select: 1,
        input: 1,
        undoStateChange: 1
    };

    proto.fireEvent = function(type, event) {
        var handlers = this._events[type];
        var isFocused, l, obj;
        // UI code, especially modal views, may be monitoring for focus events and
        // immediately removing focus. In certain conditions, this can cause the
        // focus event to fire after the blur event, which can cause an infinite
        // loop. So we detect whether we're actually focused/blurred before firing.
        if (/^(?:focus|blur)/.test(type)) {
            isFocused = isOrContains(this._root, this._doc.activeElement);
            if (type === 'focus') {
                if (!isFocused || this._isFocused) {
                    return this;
                }
                this._isFocused = true;
            } else {
                if (isFocused || !this._isFocused) {
                    return this;
                }
                this._isFocused = false;
            }
        }
        if (handlers) {
            if (!event) {
                event = {};
            }
            if (event.type !== type) {
                event.type = type;
            }
            // Clone handlers array, so any handlers added/removed do not affect it.
            handlers = handlers.slice();
            l = handlers.length;
            while (l--) {
                obj = handlers[l];
                try {
                    if (obj.handleEvent) {
                        obj.handleEvent(event);
                    } else {
                        obj.call(this, event);
                    }
                } catch (error) {
                    error.details = 'Squire: fireEvent error. Event type: ' + type;
                    this.didError(error);
                }
            }
        }
        return this;
    };

    proto.destroy = function() {
        var l = instances.length;
        var events = this._events;
        var type;

        for (type in events) {
            this.removeEventListener(type);
        }
        if (this._mutation) {
            this._mutation.disconnect();
        }
        while (l--) {
            if (instances[l] === this) {
                instances.splice(l, 1);
            }
        }

        // Destroy undo stack
        this._undoIndex = -1;
        this._undoStack = [];
        this._undoStackLength = 0;
    };

    proto.handleEvent = function(event) {
        this.fireEvent(event.type, event);
    };

    proto.addEventListener = function(type, fn) {
        var handlers = this._events[type];
        var target = this._root;
        if (!fn) {
            this.didError({
                name: 'Squire: addEventListener with null or undefined fn',
                message: 'Event type: ' + type
            });
            return this;
        }
        if (!handlers) {
            handlers = this._events[type] = [];
            if (!customEvents[type]) {
                if (type === 'selectionchange') {
                    target = this._doc;
                }
                target.addEventListener(type, this, true);
            }
        }
        handlers.push(fn);
        return this;
    };

    proto.removeEventListener = function(type, fn) {
        var handlers = this._events[type];
        var target = this._root;
        var l;
        if (handlers) {
            if (fn) {
                l = handlers.length;
                while (l--) {
                    if (handlers[l] === fn) {
                        handlers.splice(l, 1);
                    }
                }
            } else {
                handlers.length = 0;
            }
            if (!handlers.length) {
                delete this._events[type];
                if (!customEvents[type]) {
                    if (type === 'selectionchange') {
                        target = this._doc;
                    }
                    target.removeEventListener(type, this, true);
                }
            }
        }
        return this;
    };

    // --- Selection and Path ---

    proto._createRange =
        function(range, startOffset, endContainer, endOffset) {
            if (range instanceof this._win.Range) {
                return range.cloneRange();
            }
            var domRange = this._doc.createRange();
            domRange.setStart(range, startOffset);
            if (endContainer) {
                domRange.setEnd(endContainer, endOffset);
            } else {
                domRange.setEnd(range, startOffset);
            }
            return domRange;
        };

    proto.getCursorPosition = function(range) {
        if ((!range && !(range = this.getSelection())) ||
            !range.getBoundingClientRect) {
            return null;
        }
        // Get the bounding rect
        var rect = range.getBoundingClientRect();
        var node, parent;
        if (rect && !rect.top) {
            this._ignoreChange = true;
            node = this._doc.createElement('SPAN');
            node.textContent = ZWS;
            insertNodeInRange(range, node);
            rect = node.getBoundingClientRect();
            parent = node.parentNode;
            parent.removeChild(node);
            mergeInlines(parent, range);
        }
        return rect;
    };

    proto._moveCursorTo = function(toStart) {
        var root = this._root,
            range = this._createRange(root, toStart ? 0 : root.childNodes.length);
        moveRangeBoundariesDownTree(range);
        this.setSelection(range);
        return this;
    };
    proto.moveCursorToStart = function() {
        return this._moveCursorTo(true);
    };
    proto.moveCursorToEnd = function() {
        return this._moveCursorTo(false);
    };

    var getWindowSelection = function(self) {
        return self._win.getSelection() || null;
    };

    proto.setSelection = function(range) {
        if (range) {
            this._lastSelection = range;
            // If we're setting selection, that automatically, and synchronously, // triggers a focus event. So just store the selection and mark it as
            // needing restore on focus.
            if (!this._isFocused) {
                enableRestoreSelection.call(this);
            } else if (isAndroid && !this._restoreSelection) {
                // Android closes the keyboard on removeAllRanges() and doesn't
                // open it again when addRange() is called, sigh.
                // Since Android doesn't trigger a focus event in setSelection(),
                // use a blur/focus dance to work around this by letting the
                // selection be restored on focus.
                // Need to check for !this._restoreSelection to avoid infinite loop
                enableRestoreSelection.call(this);
                this.blur();
                this.focus();
            } else {
                // iOS bug: if you don't focus the iframe before setting the
                // selection, you can end up in a state where you type but the input
                // doesn't get directed into the contenteditable area but is instead
                // lost in a black hole. Very strange.
                if (isIOS) {
                    this._win.focus();
                }
                var sel = getWindowSelection(this);
                if (sel) {
                    sel.removeAllRanges();
                    sel.addRange(range);
                }
            }
        }
        return this;
    };

    proto.getSelection = function(isForce) {
        var sel = getWindowSelection(this);
        var root = this._root;
        var selection, startContainer, endContainer;
        if (sel && sel.rangeCount) {
            selection = sel.getRangeAt(0).cloneRange();
            startContainer = selection.startContainer;
            endContainer = selection.endContainer;
            // FF can return the selection as being inside an <img>. WTF?
            if (startContainer && isLeaf(startContainer)) {
                selection.setStartBefore(startContainer);
            }
            if (endContainer && isLeaf(endContainer)) {
                selection.setEndBefore(endContainer);
            }
        }
        if (selection &&
            isOrContains(root, selection.commonAncestorContainer)) {
            this._lastSelection = selection;
        } else {
            selection = this._lastSelection;
        }
        if (!selection) {
            selection = this._createRange(root.firstChild, 0);
        }
        var isIE = /*@cc_on!@*/false || !!document.documentMode;    
        var isEdge = !isIE && !!window.StyleMedia;
        try
        {
            var position = sel.anchorNode.compareDocumentPosition(sel.focusNode),
            backward = false;
            if (!position && sel.anchorOffset > sel.focusOffset || position === Node.DOCUMENT_POSITION_PRECEDING) {
                backward = true;
            }
        }
        catch(e)
        {

        }
        var tempSelection = selection;
        selection = ZE.checkMacro(sel, selection,isIE||isEdge,backward);
        if(isIE||isEdge)
        {

        if(((selection.startOffset != tempSelection.startOffset || selection.endOffset != tempSelection.endOffset) && (ZE_Init.isMouseUp)) || (ZE_Init.isMouseUp && isForce))
            {
                if(backward)
                {

                    var endRange = selection.cloneRange();
                     sel.removeAllRanges();
                     sel.addRange(endRange);
                    try
                    {
                         this.setSelection(selection);
                    }
                    catch(e)
                    {

                    }   

                }
                else
                {
                    this.setSelection(selection);
                    this._updatePath(selection, true);
                }
            }
        }
    
        return selection;
    };

    function enableRestoreSelection() {
        this._restoreSelection = true;
    }

    function disableRestoreSelection() {
        this._restoreSelection = false;
    }

    function restoreSelection() {
        if (this._restoreSelection) {
            this.setSelection(this._lastSelection);
        }
    }

    
    proto._mousedownMacro = function() {
        var self = this;
        ZE_Init.isMouseUp = false;
        
    };
    proto._mouseupMacro = function() {
        var self = this;
        ZE_Init.isMouseUp = true;
        var sel = this.getSelection(false);
        if(!sel.collapsed){
        sel = this.getSelection(true);}
    };

    proto.getSelectedText = function() {
        var range = this.getSelection(),
            walker = new TreeWalker(
                range.commonAncestorContainer,
                SHOW_TEXT | SHOW_ELEMENT,
                function(node) {
                    return isNodeContainedInRange(range, node, true);
                }
            ),
            startContainer = range.startContainer,
            endContainer = range.endContainer,
            node = walker.currentNode = startContainer,
            textContent = '',
            addedTextInBlock = false,
            value;

        if (!walker.filter(node)) {
            node = walker.nextNode();
        }

        while (node) {
            if (node.nodeType === TEXT_NODE) {
                value = node.data;
                if (value && (/\S/.test(value))) {
                    if (node === endContainer) {
                        value = value.slice(0, range.endOffset);
                    }
                    if (node === startContainer) {
                        value = value.slice(range.startOffset);
                    }
                    textContent += value;
                    addedTextInBlock = true;
                }
            } else if (node.nodeName === 'BR' ||
                addedTextInBlock && !isInline(node)) {
                textContent += '\n';
                addedTextInBlock = false;
            }
            node = walker.nextNode();
        }

        return textContent;
    };

    proto.getPath = function() {
        return this._path;
    };

    // --- Workaround for browsers that can't focus empty text nodes ---

    // WebKit bug: https://bugs.webkit.org/show_bug.cgi?id=15256

    // Walk down the tree starting at the root and remove any ZWS. If the node only
    // contained ZWS space then remove it too. We may want to keep one ZWS node at
    // the bottom of the tree so the block can be selected. Define that node as the
    // keepNode.
    var removeZWS = function(root, keepNode) {
        var walker = new TreeWalker(root, SHOW_TEXT, function() {
                return true;
            }, false),
            parent, node, index;
        while (node = walker.nextNode()) {
            while ((index = node.data.indexOf(ZWS)) > -1 &&
                (!keepNode || node.parentNode !== keepNode)) {
                if (node.length === 1) {
                    do {
                        parent = node.parentNode;
                        parent.removeChild(node);
                        node = parent;
                        walker.currentNode = parent;
                    } while (isInline(node) && !getLength(node));
                    break;
                } else {
                    node.deleteData(index, 1);
                }
            }
        }
    };

    proto._didAddZWS = function() {
        this._hasZWS = true;
    };
    proto._removeZWS = function() {
        if (!this._hasZWS) {
            return;
        }
        removeZWS(this._root);
        this._hasZWS = false;
    };

    // --- Path change events ---

    proto._updatePath = function(range, force) {
        var anchor = range.startContainer.nodeName=="#text"?range.startContainer.parentNode:range.startContainer,
            focus = range.endContainer.nodeName=="#text"?range.endContainer.parentNode:range.endContainer,
            newPath;
        if (force || anchor !== this._lastAnchorNode ||
            focus !== this._lastFocusNode) {
            this._lastAnchorNode = anchor;
            this._lastFocusNode = focus;
            newPath = (anchor && focus) ? getPath(focus, this._root) : '';
            if (this._path !== newPath) {
                this._path = newPath;
                this.fireEvent('pathChange', {
                    path: newPath
                });
            }
        }
        if (!range.collapsed) {
            this.fireEvent('select');
        }
    };

    // selectionchange is fired synchronously in IE when removing current selection
    // and when setting new selection; keyup/mouseup may have processing we want
    // to do first. Either way, send to next event loop.
    proto._updatePathOnEvent = function() {
        var self = this;
        if (!self._willUpdatePath) {
            self._willUpdatePath = true;
            setTimeout(function() {
                self._willUpdatePath = false;
                self._updatePath(self.getSelection());
            }, 0);
        }
    };

    // --- Focus ---

    proto.focus = function() {
        this._root.focus();

        if (isIE) {
            this.fireEvent('focus');
        }

        return this;
    };

    proto.blur = function() {
        this._root.blur();

        if (isIE) {
            this.fireEvent('blur');
        }

        return this;
    };

    // --- Bookmarking ---

    var startSelectionId = 'squire-selection-start';
    var endSelectionId = 'squire-selection-end';

    proto._saveRangeToBookmark = function(range) {
        var startNode = this.createElement('INPUT', {
                id: startSelectionId,
                type: 'hidden'
            }),
            endNode = this.createElement('INPUT', {
                id: endSelectionId,
                type: 'hidden'
            }),
            temp;

        insertNodeInRange(range, startNode);
        range.collapse(false);
        insertNodeInRange(range, endNode);

        // In a collapsed range, the start is sometimes inserted after the end!
        if (startNode.compareDocumentPosition(endNode) &
            DOCUMENT_POSITION_PRECEDING) {
            startNode.id = endSelectionId;
            endNode.id = startSelectionId;
            temp = startNode;
            startNode = endNode;
            endNode = temp;
        }

        range.setStartAfter(startNode);
        range.setEndBefore(endNode);
    };

    proto._getRangeAndRemoveBookmark = function(range) {
        var root = this._root,
            start = root.querySelector('#' + startSelectionId),
            end = root.querySelector('#' + endSelectionId);

        if (start && end) {
            var startContainer = start.parentNode,
                endContainer = end.parentNode,
                startOffset = indexOf.call(startContainer.childNodes, start),
                endOffset = indexOf.call(endContainer.childNodes, end);

            if (startContainer === endContainer) {
                endOffset -= 1;
            }

            detach(start);
            detach(end);

            if (!range) {
                range = this._doc.createRange();
            }
            range.setStart(startContainer, startOffset);
            range.setEnd(endContainer, endOffset);

            // Merge any text nodes we split
            mergeInlines(startContainer, range);
            if (startContainer !== endContainer) {
                mergeInlines(endContainer, range);
            }

            // If we didn't split a text node, we should move into any adjacent
            // text node to current selection point
            if (range.collapsed) {
                startContainer = range.startContainer;
                if (startContainer.nodeType === TEXT_NODE) {
                    endContainer = startContainer.childNodes[range.startOffset];
                    if (!endContainer || endContainer.nodeType !== TEXT_NODE) {
                        endContainer =
                            startContainer.childNodes[range.startOffset - 1];
                    }
                    if (endContainer && endContainer.nodeType === TEXT_NODE) {
                        range.setStart(endContainer, 0);
                        range.collapse(true);
                    }
                }
            }
        }
        return range || null;
    };

    // --- Undo ---

    proto._keyUpDetectChange = function(event) {
        var code = event.keyCode;
        // Presume document was changed if:
        // 1. A modifier key (other than shift) wasn't held down
        // 2. The key pressed is not in range 16<=x<=20 (control keys)
        // 3. The key pressed is not in range 33<=x<=45 (navigation keys)
        if (!event.ctrlKey && !event.metaKey && !event.altKey &&
            (code < 16 || code > 20) &&
            (code < 33 || code > 45)) {
            this._docWasChanged();
        }
    };

    proto._docWasChanged = function() {
        if (this._ignoreAllChanges) {
            return;
        }

        if (canObserveMutations && this._ignoreChange) {
            this._ignoreChange = false;
            return;
        }
        if (this._isInUndoState) {
            this._isInUndoState = false;
            this.fireEvent('undoStateChange', {
                canUndo: true,
                canRedo: false
            });
        }
        this.fireEvent('input');
    };

    // Leaves bookmark
    proto._recordUndoState = function(range) {
        // Don't record if we're already in an undo state
        if (!this._isInUndoState) {
            // Advance pointer to new position
            var undoIndex = this._undoIndex += 1;
            var undoStack = this._undoStack;
            var undoConfig = this._config.undo;
            var undoThreshold = undoConfig.documentSizeThreshold;
            var undoLimit = undoConfig.undoLimit;
            var html;

            // Truncate stack if longer (i.e. if has been previously undone)
            if (undoIndex < this._undoStackLength) {
                undoStack.length = this._undoStackLength = undoIndex;
            }

            // Get data
            if (range) {
                this._saveRangeToBookmark(range);
            }
            html = this._getHTML();

            // If this document is above the configured size threshold,
            // limit the number of saved undo states.
            // Threshold is in bytes, JS uses 2 bytes per character
            if (undoThreshold > -1 && html.length * 2 > undoThreshold) {
                if (undoLimit > -1 && undoIndex > undoLimit) {
                    undoStack.splice(0, undoIndex - undoLimit);
                    undoIndex = this._undoIndex = undoLimit;
                    this._undoStackLength = undoLimit;
                }
            }

            // Save data
            undoStack[undoIndex] = html;
            this._undoStackLength += 1;
            this._isInUndoState = true;
        }
    };

    proto.saveUndoState = function(range) {
        if (range === undefined) {
            range = this.getSelection();
        }
        if (!this._isInUndoState) {
            this._recordUndoState(range);
            this._getRangeAndRemoveBookmark(range);
        }
        return this;
    };

    proto.undo = function() {
        // Sanity check: must not be at beginning of the history stack
        if (this._undoIndex !== 0 || !this._isInUndoState) {
            // Make sure any changes since last checkpoint are saved.
            this._recordUndoState(this.getSelection());

            this._undoIndex -= 1;
            this._setHTML(this._undoStack[this._undoIndex]);
            var range = this._getRangeAndRemoveBookmark();
            if (range) {
                this.setSelection(range);
            }
            this._isInUndoState = true;
            this.fireEvent('undoStateChange', {
                canUndo: this._undoIndex !== 0,
                canRedo: true
            });
            this.fireEvent('input');
        }
        return this;
    };

    proto.redo = function() {
        // Sanity check: must not be at end of stack and must be in an undo
        // state.
        var undoIndex = this._undoIndex,
            undoStackLength = this._undoStackLength;
        if (undoIndex + 1 < undoStackLength && this._isInUndoState) {
            this._undoIndex += 1;
            this._setHTML(this._undoStack[this._undoIndex]);
            var range = this._getRangeAndRemoveBookmark();
            if (range) {
                this.setSelection(range);
            }
            this.fireEvent('undoStateChange', {
                canUndo: true,
                canRedo: undoIndex + 2 < undoStackLength
            });
            this.fireEvent('input');
        }
        return this;
    };

    // --- Inline formatting ---

    // Looks for matching tag and attributes, so won't work
    // if <strong> instead of <b> etc.
    proto.hasFormat = function(tag, attributes, range) {
        // 1. Normalise the arguments and get selection
        tag = tag.toUpperCase();
        if (!attributes) {
            attributes = {};
        }
        if (!range && !(range = this.getSelection())) {
            return false;
        }

        // Sanitize range to prevent weird IE artifacts
        if (!range.collapsed &&
            range.startContainer.nodeType === TEXT_NODE &&
            range.startOffset === range.startContainer.length &&
            range.startContainer.nextSibling) {
            range.setStartBefore(range.startContainer.nextSibling);
        }
        if (!range.collapsed &&
            range.endContainer.nodeType === TEXT_NODE &&
            range.endOffset === 0 &&
            range.endContainer.previousSibling) {
            range.setEndAfter(range.endContainer.previousSibling);
        }

        // If the common ancestor is inside the tag we require, we definitely
        // have the format.
        var root = this._root;
        var common = range.commonAncestorContainer;
        var walker, node;
        if (getNearest(common, root, tag, attributes)) {
            return true;
        }

        // If common ancestor is a text node and doesn't have the format, we
        // definitely don't have it.
        if (common.nodeType === TEXT_NODE) {
            return false;
        }

        // Otherwise, check each text node at least partially contained within
        // the selection and make sure all of them have the format we want.
        walker = new TreeWalker(common, SHOW_TEXT, function(node) {
            return isNodeContainedInRange(range, node, true);
        }, false);

        var seenNode = false;
        while (node = walker.nextNode()) {
            if (!getNearest(node, root, tag, attributes)) {
                return false;
            }
            seenNode = true;
        }

        return seenNode;
    };

    // Extracts the font-family and font-size (if any) of the element
    // holding the cursor. If there's a selection, returns an empty object.
    proto.getFontInfo = function(range) {
        var fontInfo = {
            color: undefined,
            backgroundColor: undefined,
            family: undefined,
            size: undefined
        };
        var seenAttributes = 0;
        var element, style, attr;

        if (!range && !(range = this.getSelection())) {
            return fontInfo;
        }

        element = range.commonAncestorContainer;
        if (range.collapsed || element.nodeType === TEXT_NODE) {
            if (element.nodeType === TEXT_NODE) {
                element = element.parentNode;
            }
            while (seenAttributes < 4 && element) {
                if (style = element.style) {
                    if (!fontInfo.color && (attr = style.color)) {
                        fontInfo.color = attr;
                        seenAttributes += 1;
                    }
                    if (!fontInfo.backgroundColor &&
                        (attr = style.backgroundColor)) {
                        fontInfo.backgroundColor = attr;
                        seenAttributes += 1;
                    }
                    if (!fontInfo.family && (attr = style.fontFamily)) {
                        fontInfo.family = attr;
                        seenAttributes += 1;
                    }
                    if (!fontInfo.size && (attr = style.fontSize)) {
                        fontInfo.size = attr;
                        seenAttributes += 1;
                    }
                }
                element = element.parentNode;
            }
        }
        return fontInfo;
    };

    proto._addFormat = function(tag, attributes, range) {
        // If the range is collapsed we simply insert the node by wrapping
        // it round the range and focus it.
        var root = this._root;
        var el, walker, startContainer, endContainer, startOffset, endOffset,
            node, needsFormat, block;

        if (range.collapsed) {
            el = fixCursor(this.createElement(tag, attributes), root);
            insertNodeInRange(range, el);
            range.setStart(el.firstChild, el.firstChild.length);
            range.collapse(true);

            // Clean up any previous formats that may have been set on this block
            // that are unused.
            block = el;
            while (isInline(block)) {
                block = block.parentNode;
            }
            removeZWS(block, el);
        }
        // Otherwise we find all the textnodes in the range (splitting
        // partially selected nodes) and if they're not already formatted
        // correctly we wrap them in the appropriate tag.
        else {
            // Create an iterator to walk over all the text nodes under this
            // ancestor which are in the range and not already formatted
            // correctly.
            //
            // In Blink/WebKit, empty blocks may have no text nodes, just a <br>.
            // Therefore we wrap this in the tag as well, as this will then cause it
            // to apply when the user types something in the block, which is
            // presumably what was intended.
            //
            // IMG tags are included because we may want to create a link around
            // them, and adding other styles is harmless.
            walker = new TreeWalker(
                range.commonAncestorContainer,
                SHOW_TEXT | SHOW_ELEMENT,
                function(node) {
                    return (node.nodeType === TEXT_NODE ||
                        node.nodeName === 'BR' ||
                        node.nodeName === 'IMG'
                    ) && isNodeContainedInRange(range, node, true);
                },
                false
            );

            // Start at the beginning node of the range and iterate through
            // all the nodes in the range that need formatting.
            startContainer = range.startContainer;
            startOffset = range.startOffset;
            endContainer = range.endContainer;
            endOffset = range.endOffset;

            // Make sure we start with a valid node.
            walker.currentNode = startContainer;
            if (!walker.filter(startContainer)) {
                startContainer = walker.nextNode();
                startOffset = 0;
            }

            // If there are no interesting nodes in the selection, abort
            if (!startContainer) {
                return range;
            }

            do {
                node = walker.currentNode;
                needsFormat = !getNearest(node, root, tag, attributes);
                if (needsFormat) {
                    // <br> can never be a container node, so must have a text node
                    // if node == (end|start)Container
                    if (node === endContainer && node.length > endOffset) {
                        node.splitText(endOffset);
                    }
                    if (node === startContainer && startOffset) {
                        node = node.splitText(startOffset);
                        if (endContainer === startContainer) {
                            endContainer = node;
                            endOffset -= startOffset;
                        }
                        startContainer = node;
                        startOffset = 0;
                    }
                    el = this.createElement(tag, attributes);
                    replaceWith(node, el);
                    el.appendChild(node);
                }
            } while (walker.nextNode());

            // If we don't finish inside a text node, offset may have changed.
            if (endContainer.nodeType !== TEXT_NODE) {
                if (node.nodeType === TEXT_NODE) {
                    endContainer = node;
                    endOffset = node.length;
                } else {
                    // If <br>, we must have just wrapped it, so it must have only
                    // one child
                    endContainer = node.parentNode;
                    endOffset = 1;
                }
            }

            // Now set the selection to as it was before
            range = this._createRange(
                startContainer, startOffset, endContainer, endOffset);
        }
        return range;
    };

    proto._removeFormat = function(tag, attributes, range, partial) {
        // Add bookmark
        this._saveRangeToBookmark(range);

        // We need a node in the selection to break the surrounding
        // formatted text.
        var doc = this._doc,
            fixer;
        if (range.collapsed) {
            if (cantFocusEmptyTextNodes) {
                fixer = doc.createTextNode(ZWS);
                this._didAddZWS();
            } else {
                fixer = doc.createTextNode('');
            }
            insertNodeInRange(range, fixer);
        }

        // Find block-level ancestor of selection
        var root = range.commonAncestorContainer;
        while (isInline(root)) {
            root = root.parentNode;
        }

        // Find text nodes inside formatTags that are not in selection and
        // add an extra tag with the same formatting.
        var startContainer = range.startContainer,
            startOffset = range.startOffset,
            endContainer = range.endContainer,
            endOffset = range.endOffset,
            toWrap = [],
            examineNode = function(node, exemplar) {
                // If the node is completely contained by the range then
                // we're going to remove all formatting so ignore it.
                if (isNodeContainedInRange(range, node, false)) {
                    return;
                }

                var isText = (node.nodeType === TEXT_NODE),
                    child, next;

                // If not at least partially contained, wrap entire contents
                // in a clone of the tag we're removing and we're done.
                if (!isNodeContainedInRange(range, node, true)) {
                    // Ignore bookmarks and empty text nodes
                    if (node.nodeName !== 'INPUT' &&
                        (!isText || node.data)) {
                        toWrap.push([exemplar, node]);
                    }
                    return;
                }

                // Split any partially selected text nodes.
                if (isText) {
                    if (node === endContainer && endOffset !== node.length) {
                        toWrap.push([exemplar, node.splitText(endOffset)]);
                    }
                    if (node === startContainer && startOffset) {
                        node.splitText(startOffset);
                        toWrap.push([exemplar, node]);
                    }
                }
                // If not a text node, recurse onto all children.
                // Beware, the tree may be rewritten with each call
                // to examineNode, hence find the next sibling first.
                else {
                    for (child = node.firstChild; child; child = next) {
                        next = child.nextSibling;
                        examineNode(child, exemplar);
                    }
                }
            },
            formatTags = Array.prototype.filter.call(
                root.getElementsByTagName(tag),
                function(el) {
                    return isNodeContainedInRange(range, el, true) &&
                        hasTagAttributes(el, tag, attributes);
                }
            );

        if (!partial) {
            formatTags.forEach(function(node) {
                examineNode(node, node);
            });
        }

        // Now wrap unselected nodes in the tag
        toWrap.forEach(function(item) {
            // [ exemplar, node ] tuple
            var el = item[0].cloneNode(false),
                node = item[1];
            replaceWith(node, el);
            el.appendChild(node);
        });
        // and remove old formatting tags.
        formatTags.forEach(function(el) {
            replaceWith(el, empty(el));
        });

        // Merge adjacent inlines:
        this._getRangeAndRemoveBookmark(range);
        if (fixer) {
            range.collapse(false);
        }
        mergeInlines(root, range);

        return range;
    };

    proto.changeFormat = function(add, remove, range, partial) {
        // Normalise the arguments and get selection
        if (!range && !(range = this.getSelection())) {
            return this;
        }

        // Save undo checkpoint
        this.saveUndoState(range);

        if (remove) {
            range = this._removeFormat(remove.tag.toUpperCase(),
                remove.attributes || {}, range, partial);
        }
        if (add) {
            range = this._addFormat(add.tag.toUpperCase(),
                add.attributes || {}, range);
        }

        this.setSelection(range);
        this._updatePath(range, true);

        // We're not still in an undo state
        if (!canObserveMutations) {
            this._docWasChanged();
        }

        return this;
    };

    // --- Block formatting ---

    var tagAfterSplit = {
        DT: 'DD',
        DD: 'DT',
        LI: 'LI'
    };

    var splitBlock = function(self, block, node, offset) {
        var splitTag = tagAfterSplit[block.nodeName],
            splitProperties = null,
            nodeAfterSplit = split(node, offset, block.parentNode, self._root),
            config = self._config;

        if (!splitTag) {
            splitTag = config.blockTag;
            splitProperties = config.blockAttributes;
        }

        // Make sure the new node is the correct type.
        if (!hasTagAttributes(nodeAfterSplit, splitTag, splitProperties)) {
            block = createElement(nodeAfterSplit.ownerDocument,
                splitTag, splitProperties);
            if (nodeAfterSplit.dir) {
                block.dir = nodeAfterSplit.dir;
            }
            replaceWith(nodeAfterSplit, block);
            block.appendChild(empty(nodeAfterSplit));
            nodeAfterSplit = block;
        }
        return nodeAfterSplit;
    };

    proto.forEachBlock = function(fn, mutates, range) {
        if (!range && !(range = this.getSelection())) {
            return this;
        }

        // Save undo checkpoint
        if (mutates) {
            this.saveUndoState(range);
        }

        var root = this._root;
        var start = getStartBlockOfRange(range, root);
        var end = getEndBlockOfRange(range, root);
        if (start && end) {
            do {
                if (fn(start) || start === end) {
                    break;
                }
            } while (start = getNextBlock(start, root));
        }

        if (mutates) {
            this.setSelection(range);

            // Path may have changed
            this._updatePath(range, true);

            // We're not still in an undo state
            if (!canObserveMutations) {
                this._docWasChanged();
            }
        }
        return this;
    };

    proto.modifyBlocks = function(modify, range) {
        if (!range && !(range = this.getSelection())) {
            return this;
        }

        // 1. Save undo checkpoint and bookmark selection
        if (this._isInUndoState) {
            this._saveRangeToBookmark(range);
        } else {
            this._recordUndoState(range);
        }

        var root = this._root;
        var frag;

        // 2. Expand range to block boundaries
        expandRangeToBlockBoundaries(range, root);

        // 3. Remove range.
        moveRangeBoundariesUpTree(range, root);
        frag = extractContentsOfRange(range, root, root);

        // 4. Modify tree of fragment and reinsert.
        insertNodeInRange(range, modify.call(this, frag));

        // 5. Merge containers at edges
        if (range.endOffset < range.endContainer.childNodes.length) {
            mergeContainers(range.endContainer.childNodes[range.endOffset], root);
        }
        mergeContainers(range.startContainer.childNodes[range.startOffset], root);

        // 6. Restore selection
        this._getRangeAndRemoveBookmark(range);
        this.setSelection(range);
        this._updatePath(range, true);

        // 7. We're not still in an undo state
        if (!canObserveMutations) {
            this._docWasChanged();
        }

        return this;
    };

    var increaseBlockQuoteLevel = function(frag) {
        return this.createElement('BLOCKQUOTE',
            this._config.tagAttributes.blockquote, [
                frag
            ]);
    };

    var decreaseBlockQuoteLevel = function(frag) {
        var root = this._root;
        var blockquotes = frag.querySelectorAll('blockquote');
        Array.prototype.filter.call(blockquotes, function(el) {
            return !getNearest(el.parentNode, root, 'BLOCKQUOTE');
        }).forEach(function(el) {
            replaceWith(el, empty(el));
        });
        return frag;
    };

    var removeBlockQuote = function( /* frag */ ) {
        return this.createDefaultBlock([
            this.createElement('INPUT', {
                id: startSelectionId,
                type: 'hidden'
            }),
            this.createElement('INPUT', {
                id: endSelectionId,
                type: 'hidden'
            })
        ]);
    };

    var makeList = function(self, frag, type) {
        var walker = getBlockWalker(frag, self._root),
            node, tag, prev, newLi,
            tagAttributes = self._config.tagAttributes,
            listAttrs = tagAttributes[type.toLowerCase()],
            listItemAttrs = tagAttributes.li;

        while (node = walker.nextNode()) {
            tag = node.parentNode.nodeName;
            if (tag !== 'LI') {
                newLi = self.createElement('LI', listItemAttrs);
                if (node.dir) {
                    newLi.dir = node.dir;
                }

                // Have we replaced the previous block with a new <ul>/<ol>?
                if ((prev = node.previousSibling) &&
                    prev.nodeName === type) {
                    prev.appendChild(newLi);
                }
                // Otherwise, replace this block with the <ul>/<ol>
                else {
                    replaceWith(
                        node,
                        self.createElement(type, listAttrs, [
                            newLi
                        ])
                    );
                }
                newLi.appendChild(node);
            } else {
                node = node.parentNode.parentNode;
                tag = node.nodeName;
                if (tag !== type && (/^[OU]L$/.test(tag))) {
                    replaceWith(node,
                        self.createElement(type, listAttrs, [empty(node)])
                    );
                }
            }
        }
    };

    var makeUnorderedList = function(frag) {
        makeList(this, frag, 'UL');
        return frag;
    };

    var makeOrderedList = function(frag) {
        makeList(this, frag, 'OL');
        return frag;
    };

    var removeList = function(frag) {
        var lists = frag.querySelectorAll('UL, OL'),
            i, l, ll, list, listFrag, children, child;
        for (i = 0, l = lists.length; i < l; i += 1) {
            list = lists[i];
            listFrag = empty(list);
            children = listFrag.childNodes;
            ll = children.length;
            while (ll--) {
                child = children[ll];
                replaceWith(child, empty(child));
            }
            fixContainer(listFrag, this._root);
            replaceWith(list, listFrag);
        }
        return frag;
    };

    var increaseListLevel = function(frag) {
        var items = frag.querySelectorAll('LI'),
            i, l, item,
            type, newParent,
            tagAttributes = this._config.tagAttributes,
            listItemAttrs = tagAttributes.li,
            listAttrs;
        for (i = 0, l = items.length; i < l; i += 1) {
            item = items[i];
            if (!isContainer(item.firstChild)) {
                // type => 'UL' or 'OL'
                type = item.parentNode.nodeName;
                newParent = item.previousSibling;
                if (!newParent || !(newParent = newParent.lastChild) ||
                    newParent.nodeName !== type) {
                    listAttrs = tagAttributes[type.toLowerCase()];
                    replaceWith(
                        item,
                        this.createElement('LI', listItemAttrs, [
                            newParent = this.createElement(type, listAttrs)
                        ])
                    );
                }
                newParent.appendChild(item);
            }
        }
        return frag;
    };

    var decreaseListLevel = function(frag) {
        var root = this._root;
        var items = frag.querySelectorAll('LI');
        Array.prototype.filter.call(items, function(el) {
            return !isContainer(el.firstChild);
        }).forEach(function(item) {
            var parent = item.parentNode,
                newParent = parent.parentNode,
                first = item.firstChild,
                node = first,
                next;
            if (item.previousSibling) {
                parent = split(parent, item, newParent, root);
            }
            while (node) {
                next = node.nextSibling;
                if (isContainer(node)) {
                    break;
                }
                newParent.insertBefore(node, parent);
                node = next;
            }
            if (newParent.nodeName === 'LI' && first.previousSibling) {
                split(newParent, first, newParent.parentNode, root);
            }
            while (item !== frag && !item.childNodes.length) {
                parent = item.parentNode;
                parent.removeChild(item);
                item = parent;
            }
        }, this);
        fixContainer(frag, root);
        return frag;
    };

    proto._ensureBottomLine = function() {
        var root = this._root;
        var last = root.lastElementChild;
        if (!last ||
            last.nodeName !== this._config.blockTag || !isBlock(last)) {
            if (last && last.nodeName == "BR") {
                root.removeChild(last);
            }
            root.appendChild(this.createDefaultBlock());
        }
    };

    // --- Keyboard interaction ---

    proto.setKeyHandler = function(key, fn) {
        this._keyHandlers[key] = fn;
        return this;
    };

    // --- Get/Set data ---

    proto._getHTML = function() {
        return this._root.innerHTML;
    };

    proto._setHTML = function(html) {
        var root = this._root;
        var node = root;
        node.innerHTML = html;
        do {
            fixCursor(node, root);
        } while (node = getNextBlock(node, root));
        this._ignoreChange = true;
    };

    proto.getHTML = function(withBookMark) {
        var brs = [],
            root, node, fixer, html, l, range;
        if (withBookMark && (range = this.getSelection())) {
            this._saveRangeToBookmark(range);
        }
        if (useTextFixer) {
            root = this._root;
            node = root;
            while (node = getNextBlock(node, root)) {
                if (!node.textContent && !node.querySelector('BR')) {
                    fixer = this.createElement('BR');
                    node.appendChild(fixer);
                    brs.push(fixer);
                }
            }
        }
        html = this._getHTML().replace(/\u200B/g, '');
        if (useTextFixer) {
            l = brs.length;
            while (l--) {
                detach(brs[l]);
            }
        }
        if (range) {
            this._getRangeAndRemoveBookmark(range);
        }
        return html;
    };

    proto.setHTML = function(html, options) {
        var frag = this._doc.createDocumentFragment();
        var div = this.createElement('DIV');
        var root = this._root;
        var child;
        /* custom block start */
        options = options || {};
        var editorInstance;
        /* custom block end */

        // Parse HTML into DOM tree
        div.innerHTML = html;
        frag.appendChild(empty(div));

        cleanTree(frag, false, {
            editorRef: this._editorRef,
            handleWaitingImages: options.oldState
        });
        cleanupBRs(frag, root);

        fixContainer(frag, root);

        // Fix cursor
        var node = frag;
        while (node = getNextBlock(node, root)) {
            fixCursor(node, root);
        }

        // Don't fire an input event
        this._ignoreChange = true;

        // Remove existing root children
        while (child = root.lastChild) {
            root.removeChild(child);
        }

        // And insert new content
        root.appendChild(frag);
        fixCursor(root, root);

        /*If an old stack state has been edited, update that in respective stack area*/
        if (options.oldState) {
            editorInstance = this._editorRef();
            editorInstance.updateStateHTML(editorInstance.stack.stackPosition, root.innerHTML);
        }

        // Reset the undo stack
        this._undoIndex = -1;
        this._undoStack.length = 0;
        this._undoStackLength = 0;
        this._isInUndoState = false;

        // Record undo state
        var range = this._getRangeAndRemoveBookmark() ||
            this._createRange(root.firstChild, 0);
        this.saveUndoState(range);
        // IE will also set focus when selecting text so don't use
        // setSelection. Instead, just store it in lastSelection, so if
        // anything calls getSelection before first focus, we have a range
        // to return.
        this._lastSelection = range;
        enableRestoreSelection.call(this);
        this._updatePath(range, true);

        return this;
    };

    proto.insertElement = function(el, range) {
        if (!range) {
            range = this.getSelection();
        }
        range.collapse(true);
        if (isInline(el)) {
            insertNodeInRange(range, el);
            range.setStartAfter(el);
        } else {
            // Get containing block node.
            var root = this._root;
            var splitNode = getStartBlockOfRange(range, root) || root;
            var parent, nodeAfterSplit;
            // While at end of container node, move up DOM tree.
            while (splitNode !== root && !splitNode.nextSibling) {
                splitNode = splitNode.parentNode;
            }
            // If in the middle of a container node, split up to root.
            if (splitNode !== root) {
                parent = splitNode.parentNode;
                nodeAfterSplit = split(parent, splitNode.nextSibling, root, root);
            }
            if (nodeAfterSplit) {
                root.insertBefore(el, nodeAfterSplit);
            } else {
                root.appendChild(el);
                // Insert blank line below block.
                nodeAfterSplit = this.createDefaultBlock();
                root.appendChild(nodeAfterSplit);
            }
            range.setStart(nodeAfterSplit, 0);
            range.setEnd(nodeAfterSplit, 0);
            moveRangeBoundariesDownTree(range);
        }
        this.focus();
        this.setSelection(range);
        this._updatePath(range);

        if (!canObserveMutations) {
            this._docWasChanged();
        }

        return this;
    };

    proto.insertImage = function(src, attributes) {
        var img = this.createElement('IMG', mergeObjects({
            src: src
        }, attributes, true));
        this.insertElement(img);
        return img;
    };

    var linkRegExp = /\b((?:(?:ht|f)tps?:\/\/|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,}\/)(?:[^\s()<>]+|\([^\s()<>]+\))+(?:\((?:[^\s()<>]+|(?:\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'".,<>?«»“”‘’]))|([\w\-.%+]+@(?:[\w\-]+\.)+[A-Z]{2,}\b)/i;

    var addLinks = function(frag, root, self) {
        var doc = frag.ownerDocument,
            walker = new TreeWalker(frag, SHOW_TEXT,
                function(node) {
                    return !getNearest(node, root, 'A');
                }, false),
            defaultAttributes = self._config.tagAttributes.a,
            node, data, parent, match, index, endIndex, child;
        while (node = walker.nextNode()) {
            data = node.data;
            parent = node.parentNode;
            while (match = linkRegExp.exec(data)) {
                index = match.index;
                endIndex = index + match[0].length;
                if (index) {
                    child = doc.createTextNode(data.slice(0, index));
                    parent.insertBefore(child, node);
                }
                child = self.createElement('A', mergeObjects({
                    href: match[1] ?
                        /^(?:ht|f)tps?:/.test(match[1]) ?
                        match[1] :
                        'http://' + match[1] : 'mailto:' + match[2]
                }, defaultAttributes, false));
                child.textContent = data.slice(index, endIndex);
                parent.insertBefore(child, node);
                node.data = data = data.slice(endIndex);
            }
        }
    };
    var parseExcelContent = function(html, _doc) {
        html = html.replace("border=0", "border=1");

        var endFragmentIndex = html.lastIndexOf('<!--EndFragment-->');
        html = html.slice(0, endFragmentIndex);

        /* get style tags and body tags contents*/
        var styleText = /<style([.\s\S])*>([.\s\S])*<\/style>/i.exec(html)[0];
        var bodyContent = html.slice(html.search("<body"));

        /* get all style tags such as .xl.. */
        var classRegx = /\.x([a-z][0-9]+)[\n]?(\s)*{([""#a-zA-Z0-9\n\s.:,;-]*)/g;
        var styleContent = styleText ? styleText.match(classRegx) : [];
        var styleContentLength = styleContent ? styleContent.length : 0;

        var classNames = [],
            _style = [],
            limit,
            classNamesLength,
            i, j, k;

        /* Append the body content in a fragment */
        var fragment = _doc.createDocumentFragment();
        var _div = _doc.createElement("div");
        _div.innerHTML = bodyContent;
        fragment.appendChild(_div);

        if (styleContentLength) {
            for (var m = 0; m < styleContentLength; m++) {
                limit = styleContent[m].search("{");
                classNames[m] = styleContent[m].slice(0, limit).trim();
                _style[m] = styleContent[m].slice(limit + 1, styleContent[m].length);
            }

            classNamesLength = classNames.length;
            var regs = /([""\.a-zA-Z0-9-\n\s#:,])*/g;

            for (i = 0; i < classNamesLength; i++) {
                var propName,
                    propArr,
                    propArrLength,
                    p,
                    styleMapObj = {};

                var _tr = _div.firstElementChild.querySelectorAll(classNames[i]);
                var _trLength = _tr.length;
                var inline = _style[i].match(regs);
                var _inlineLength = inline.length;

                /*
                Create a map of the style properties and the values
                */
                for (k = 0; k < _inlineLength; k++) {
                    inline[k] = inline[k].trim();
                    if (inline[k].length > 0) {
                        propName = inline[k].slice(0, inline[k].search(":"));
                        styleMapObj[propName] = inline[k].slice(inline[k].search(":") + 1, inline[k].length);
                    }
                }

                /*
                Apply the style properties of those classes for the respective nodes
                */
                propArr = Object.keys(styleMapObj);
                propArrLength = propArr.length;
                for (j = 0; j < _trLength; j++) {
                    // propArr.forEach (function (value) {
                    //   if (value === "font-size") {
                    //     styleMapObj[value] += "px";
                    //   }
                    for (p = 0; p < propArrLength; p++) {
                        // if (propArr[p] === "font-size") {
                        //   styleMapObj[propArr[p]] += "px";
                        // }
                        _tr[j].style[propArr[p]] = styleMapObj[propArr[p]];
                    }
                }

            }
        }
        return _div.innerHTML;
    };

    // Insert HTML at the cursor location. If the selection is not collapsed
    // insertTreeFragmentIntoRange will delete the selection so that it is replaced
    // by the html being inserted.
    proto.insertHTML = function(html, isPaste) {
        var range = this.getSelection();
        var doc = this._doc;
        var startFragmentIndex, endFragmentIndex;
        var div, frag, root, node, event;
        var isExcelContent;
        var _this = this;
        var selection = window.getSelection();  
        var textNode = ZE_Init.textNode; 
        var newOffset = ZE_Init.newOffset; 
        if(textNode != undefined && textNode!=null)
        {
            try{
            selection.collapse(textNode, Math.min(textNode.length, newOffset));
            }
            catch(e)
            {

            }
        }
        ZE_Init.currentEditor.doc.body.focus();

        // Edge doesn't just copy the fragment, but includes the surrounding guff
        // including the full <head> of the page. Need to strip this out. If
        // available use DOMPurify to parse and sanitise.

        if (isPaste) {
            /*
             * If the pasted header contains this meta tag ,
             * then we can assume its from excel sheet, lets process it before sending in
             */
            //
            isExcelContent = html.search(/<meta .* content=Excel\.Sheet>/g);
            if (isExcelContent > 0) {
                html = parseExcelContent(html, doc);
            } else {
                startFragmentIndex = html.indexOf('<!--StartFragment-->');
                endFragmentIndex = html.lastIndexOf('<!--EndFragment-->');
                if (startFragmentIndex > -1 && endFragmentIndex > -1) {
                    html = html.slice(startFragmentIndex + 20, endFragmentIndex);
                }
            }
        }
        // Parse HTML into DOM tree
        // this._editorRef().pasteContent(html);

        div = this.createElement('DIV');
        div.innerHTML = html;
        frag = doc.createDocumentFragment();
        frag.appendChild(empty(div));
        this._editorRef().pasteContent(html);
        if (isPaste && this._editorRef().initobj.handlePasteImages) {
            if (frag.firstChild.nodeName === "IMG") {
                if (frag.firstChild.src.substr(0, 5) === 'data:') {
                    this._editorRef()._uploadInlineImages({
                        dataURI: frag.firstChild.src
                    });
                    this.focus();
                    return;
                } else if (frag.firstChild.src.substr(0, 11) === 'webkit-fake') { // No I18N
                    this.focus();
                    return;
                }
            }
        }

        // Record undo checkpoint
        this.saveUndoState(range);

        try {
            root = this._root;
            node = frag;
            event = {
                fragment: frag,
                preventDefault: function() {
                    this.defaultPrevented = true;
                },
                defaultPrevented: false
            };

            //addLinks( frag , frag, this);
            cleanTree(frag);
            cleanupBRs(frag, null);
            removeEmptyInlines(frag);
            frag.normalize();
            //this._editorRef().pasteContent()
            while (node = getNextBlock(node, frag)) {
                fixCursor(node, null);
            }

            if (isPaste) {
                this.fireEvent('willPaste', event);
            }

            if (!event.defaultPrevented) {
                insertTreeFragmentIntoRange(range, event.fragment, root);
                if (!canObserveMutations) {
                    this._docWasChanged();
                }
                range.collapse(false);
                this._ensureBottomLine();
            }

            this.setSelection(range);
            this._updatePath(range, true);
            // Safari sometimes loses focus after paste. Weird.
            if (isPaste) {
                this.focus();
            }
        } catch (error) {
            this.didError(error);
        }
        return this;
    };

    var escapeHTMLFragement = function(text) {
        return text.split('&').join('&amp;')
            .split('<').join('&lt;')
            .split('>').join('&gt;')
            .split('"').join('&quot;');
    };

    proto.insertPlainText = function(plainText, isPaste) {
        var lines = plainText.split('\n');
        var config = this._config;
        var tag = config.blockTag;
        var attributes = config.blockAttributes;
        var closeBlock = '</' + tag + '>';
        var openBlock = '<' + tag;
        var attr, i, l, line;

        for (attr in attributes) {
            openBlock += ' ' + attr + '="' +
                escapeHTMLFragement(attributes[attr]) +
                '"';
        }
        openBlock += '>';

        for (i = 0, l = lines.length; i < l; i += 1) {
            line = lines[i];
            line = escapeHTMLFragement(line).replace(/ (?= )/g, '&nbsp;');
            // Wrap all but first/last lines in <div></div>
            if (i && i + 1 < l) {
                line = openBlock + (line || '<BR>') + closeBlock;
            }
            lines[i] = line;
        }
        return this.insertHTML(lines.join(''), isPaste);
    };

    // --- Formatting ---

    var command = function(method, arg, arg2) {
        return function() {
            this[method](arg, arg2);
            return this.focus();
        };
    };

    proto.addStyles = function(styles) {
        if (styles) {
            var head = this._doc.documentElement.firstChild,
                style = this.createElement('STYLE', {
                    type: 'text/css'
                });
            style.appendChild(this._doc.createTextNode(styles));
            head.appendChild(style);
        }
        return this;
    };
    proto.bold = command('changeFormat', {
        tag: 'B'
    });
    proto.italic = command('changeFormat', {
        tag: 'I'
    });
    proto.underline = command('changeFormat', {
        tag: 'U'
    });
    proto.strikethrough = command('changeFormat', {
        tag: 'S'
    });
    proto.subscript = command('changeFormat', {
        tag: 'SUB'
    }, {
        tag: 'SUP'
    });
    proto.superscript = command('changeFormat', {
        tag: 'SUP'
    }, {
        tag: 'SUB'
    });

    proto.removeBold = command('changeFormat', null, {
        tag: 'B'
    });
    proto.removeItalic = command('changeFormat', null, {
        tag: 'I'
    });
    proto.removeUnderline = command('changeFormat', null, {
        tag: 'U'
    });
    proto.removeStrikethrough = command('changeFormat', null, {
        tag: 'S'
    });
    proto.removeSubscript = command('changeFormat', null, {
        tag: 'SUB'
    });
    proto.removeSuperscript = command('changeFormat', null, {
        tag: 'SUP'
    });

    proto.makeLink = function(url, attributes) {
        var range = this.getSelection();
        if (range.collapsed) {
            var protocolEnd = url.indexOf(':') + 1;
            if (protocolEnd) {
                while (url[protocolEnd] === '/') {
                    protocolEnd += 1;
                }
            }
            insertNodeInRange(
                range,
                this._doc.createTextNode(url.slice(protocolEnd))
            );
        }
        attributes = mergeObjects(
            mergeObjects({
                href: url
            }, attributes, true),
            this._config.tagAttributes.a,
            false
        );

        this.changeFormat({
            tag: 'A',
            attributes: attributes
        }, {
            tag: 'A'
        }, range);
        return this.focus();
    };
    proto.removeLink = function() {
        this.changeFormat(null, {
            tag: 'A'
        }, this.getSelection(), true);
        return this.focus();
    };

    proto.setFontFace = function(name) {
        this.changeFormat(name ? {
            tag: 'SPAN',
            attributes: {
                'class': 'font',
                style: 'font-family: ' + name + ', sans-serif;'
            }
        } : null, {
            tag: 'SPAN',
            attributes: {
                'class': 'font'
            }
        });
        return this.focus();
    };
    proto.setFontSize = function(size) {
        this.changeFormat(size ? {
            tag: 'SPAN',
            attributes: {
                'class': 'size',
                style: 'font-size: ' +
                    (typeof size === 'number' ? size + 'px' : size)
            }
        } : null, {
            tag: 'SPAN',
            attributes: {
                'class': 'size'
            }
        });
        return this.focus();
    };

    proto.setTextColour = function(colour) {
        this.changeFormat(colour ? {
            tag: 'SPAN',
            attributes: {
                'class': 'colour',
                style: 'color:' + colour
            }
        } : null, {
            tag: 'SPAN',
            attributes: {
                'class': 'colour'
            }
        });
        return this.focus();
    };

    proto.setHighlightColour = function(colour) {
        this.changeFormat(colour ? {
            tag: 'SPAN',
            attributes: {
                'class': 'highlight',
                style: 'background-color:' + colour
            }
        } : colour, {
            tag: 'SPAN',
            attributes: {
                'class': 'highlight'
            }
        });
        return this.focus();
    };

    proto.setTextAlignment = function(alignment) {
        this.forEachBlock(function(block) {
            block.className = (block.className
                .split(/\s+/)
                .filter(function(klass) {
                    return !(/align/.test(klass));
                })
                .join(' ') +
                ' align-' + alignment).trim();
            block.style.textAlign = alignment;
        }, true);
        return this.focus();
    };

    proto.setTextDirection = function(direction) {
        this.forEachBlock(function(block) {
            block.dir = direction;
        }, true);
        return this.focus();
    };

    function removeFormatting(self, root, clean) {
        var node, next;
        for (node = root.firstChild; node; node = next) {
            next = node.nextSibling;
            if (isInline(node)) {
                if (node.nodeType === TEXT_NODE || node.nodeName === 'BR' || node.nodeName === 'IMG') {
                    clean.appendChild(node);
                    continue;
                }
            } else if (isBlock(node)) {
                clean.appendChild(self.createDefaultBlock([
                    removeFormatting(
                        self, node, self._doc.createDocumentFragment())
                ]));
                continue;
            }
            removeFormatting(self, node, clean);
        }
        return clean;
    }

    proto.removeAllFormatting = function(range) {
        if (!range && !(range = this.getSelection()) || range.collapsed) {
            return this;
        }

        var root = this._root;
        var stopNode = range.commonAncestorContainer;
        while (stopNode && !isBlock(stopNode)) {
            stopNode = stopNode.parentNode;
        }
        if (!stopNode) {
            expandRangeToBlockBoundaries(range, root);
            stopNode = root;
        }
        if (stopNode.nodeType === TEXT_NODE) {
            return this;
        }

        // Record undo point
        this.saveUndoState(range);

        // Avoid splitting where we're already at edges.
        moveRangeBoundariesUpTree(range, stopNode);

        // Split the selection up to the block, or if whole selection in same
        // block, expand range boundaries to ends of block and split up to root.
        var doc = stopNode.ownerDocument;
        var startContainer = range.startContainer;
        var startOffset = range.startOffset;
        var endContainer = range.endContainer;
        var endOffset = range.endOffset;

        // Split end point first to avoid problems when end and start
        // in same container.
        var formattedNodes = doc.createDocumentFragment();
        var cleanNodes = doc.createDocumentFragment();
        var nodeAfterSplit = split(endContainer, endOffset, stopNode, root);
        var nodeInSplit = split(startContainer, startOffset, stopNode, root);
        var nextNode, childNodes;

        // Then replace contents in split with a cleaned version of the same:
        // blocks become default blocks, text and leaf nodes survive, everything
        // else is obliterated.
        while (nodeInSplit !== nodeAfterSplit) {
            nextNode = nodeInSplit.nextSibling;
            formattedNodes.appendChild(nodeInSplit);
            nodeInSplit = nextNode;
        }
        removeFormatting(this, formattedNodes, cleanNodes);
        cleanNodes.normalize();
        nodeInSplit = cleanNodes.firstChild;
        nextNode = cleanNodes.lastChild;

        // Restore selection
        childNodes = stopNode.childNodes;
        if (nodeInSplit) {
            stopNode.insertBefore(cleanNodes, nodeAfterSplit);
            startOffset = indexOf.call(childNodes, nodeInSplit);
            endOffset = indexOf.call(childNodes, nextNode) + 1;
        } else {
            startOffset = indexOf.call(childNodes, nodeAfterSplit);
            endOffset = startOffset;
        }

        // Merge text nodes at edges, if possible
        range.setStart(stopNode, startOffset);
        range.setEnd(stopNode, endOffset);
        mergeInlines(stopNode, range);

        // And move back down the tree
        moveRangeBoundariesDownTree(range);

        this.setSelection(range);
        this._updatePath(range, true);

        return this.focus();
    };

    proto.increaseQuoteLevel = command('modifyBlocks', increaseBlockQuoteLevel);
    proto.decreaseQuoteLevel = command('modifyBlocks', decreaseBlockQuoteLevel);

    proto.makeUnorderedList = command('modifyBlocks', makeUnorderedList);
    proto.makeOrderedList = command('modifyBlocks', makeOrderedList);
    proto.removeList = command('modifyBlocks', removeList);

    proto.increaseListLevel = command('modifyBlocks', increaseListLevel);
    proto.decreaseListLevel = command('modifyBlocks', decreaseListLevel);

    if (typeof exports === 'object') {
        module.exports = Squire;
    } else if (typeof define === 'function' && define.amd) {
        define(function() {
            return Squire;
        });
    } else {
        win.Squire = Squire;

        if (top !== win &&
            doc.documentElement.getAttribute('data-squireinit') === 'true') {
            win.editor = new Squire(doc);
            if (win.onEditorLoad) {
                win.onEditorLoad(win.editor);
                win.onEditorLoad = null;
            }
        }
    }

}(document));;
(function(factory) {
    'use strict';
    /* global window: false, define: false, module: false */
    var root = typeof window === 'undefined' ? null : window;

    if (typeof define === 'function' && define.amd) {
        define(function() {
            return factory(root);
        });
    } else if (typeof module !== 'undefined') {
        module.exports = factory(root);
    } else {
        root.DOMPurify = factory(root);
    }
}(function factory(window) {
    'use strict';

    var DOMPurify = function(window) {
        return factory(window);
    };

    /**
     * Version label, exposed for easier checks
     * if DOMPurify is up to date or not
     */
    DOMPurify.version = '0.7.3';

    if (!window || !window.document || window.document.nodeType !== 9) {
        // not running in a browser, provide a factory function
        // so that you can pass your own Window
        DOMPurify.isSupported = false;
        return DOMPurify;
    }

    var document = window.document;
    var originalDocument = document;
    var DocumentFragment = window.DocumentFragment;
    var HTMLTemplateElement = window.HTMLTemplateElement;
    var NodeFilter = window.NodeFilter;
    var NamedNodeMap = window.NamedNodeMap || window.MozNamedAttrMap;
    var Text = window.Text;
    var Comment = window.Comment;
    var DOMParser = window.DOMParser;

    // As per issue #47, the web-components registry is inherited by a
    // new document created via createHTMLDocument. As per the spec
    // (http://w3c.github.io/webcomponents/spec/custom/#creating-and-passing-registries)
    // a new empty registry is used when creating a template contents owner
    // document, so we use that as our parent document to ensure nothing
    // is inherited.
    if (typeof HTMLTemplateElement === 'function') {
        document = document.createElement('template').content.ownerDocument;
    }
    var implementation = document.implementation;
    var createNodeIterator = document.createNodeIterator;
    var getElementsByTagName = document.getElementsByTagName;
    var createDocumentFragment = document.createDocumentFragment;
    var importNode = originalDocument.importNode;

    var hooks = {};

    /**
     * Expose whether this browser supports running the full DOMPurify.
     */
    DOMPurify.isSupported =
        typeof implementation.createHTMLDocument !== 'undefined' &&
        document.documentMode !== 9;

    /* Add properties to a lookup table */
    var _addToSet = function(set, array) {
        var l = array.length;
        while (l--) {
            set[array[l]] = true;
        }
        return set;
    };

    /* Shallow clone an object */
    var _cloneObj = function(object) {
        var newObject = {};
        var property;
        for (property in object) {
            if (object.hasOwnProperty(property)) {
                newObject[property] = object[property];
            }
        }
        return newObject;
    };

    /**
     * We consider the elements and attributes below to be safe. Ideally
     * don't add any new ones but feel free to remove unwanted ones.
     */

    /* allowed element names */
    var ALLOWED_TAGS = null;
    var DEFAULT_ALLOWED_TAGS = _addToSet({}, [

        // HTML
        'a', 'abbr', 'acronym', 'address', 'area', 'article', 'aside', 'audio', 'b',
        'bdi', 'bdo', 'big', 'blink', 'blockquote', 'body', 'br', 'button', 'canvas',
        'caption', 'center', 'cite', 'code', 'col', 'colgroup', 'content', 'data',
        'datalist', 'dd', 'decorator', 'del', 'details', 'dfn', 'dir', 'div', 'dl', 'dt',
        'element', 'em', 'fieldset', 'figcaption', 'figure', 'font', 'footer', 'form',
        'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'head', 'header', 'hgroup', 'hr', 'html', 'i',
        'img', 'input', 'ins', 'kbd', 'label', 'legend', 'li', 'main', 'map', 'mark',
        'marquee', 'menu', 'menuitem', 'meter', 'nav', 'nobr', 'ol', 'optgroup',
        'option', 'output', 'p', 'pre', 'progress', 'q', 'rp', 'rt', 'ruby', 's', 'samp',
        'section', 'select', 'shadow', 'small', 'source', 'spacer', 'span', 'strike',
        'strong', 'style', 'sub', 'summary', 'sup', 'table', 'tbody', 'td', 'template',
        'textarea', 'tfoot', 'th', 'thead', 'time', 'tr', 'track', 'tt', 'u', 'ul', 'var',
        'video', 'wbr',

        // SVG
        'svg', 'altglyph', 'altglyphdef', 'altglyphitem', 'animatecolor',
        'animatemotion', 'animatetransform', 'circle', 'clippath', 'defs', 'desc',
        'ellipse', 'font', 'g', 'glyph', 'glyphref', 'hkern', 'image', 'line',
        'lineargradient', 'marker', 'mask', 'metadata', 'mpath', 'path', 'pattern',
        'polygon', 'polyline', 'radialgradient', 'rect', 'stop', 'switch', 'symbol',
        'text', 'textpath', 'title', 'tref', 'tspan', 'view', 'vkern',

        // SVG Filters
        'feBlend', 'feColorMatrix', 'feComponentTransfer', 'feComposite',
        'feConvolveMatrix', 'feDiffuseLighting', 'feDisplacementMap',
        'feFlood', 'feFuncA', 'feFuncB', 'feFuncG', 'feFuncR', 'feGaussianBlur',
        'feImage', 'feMerge', 'feMergeNode', 'feMorphology', 'feOffset',
        'feSpecularLighting', 'feTile', 'feTurbulence',

        //MathML
        'math', 'menclose', 'merror', 'mfenced', 'mfrac', 'mglyph', 'mi', 'mlabeledtr',
        'mmuliscripts', 'mn', 'mo', 'mover', 'mpadded', 'mphantom', 'mroot', 'mrow',
        'ms', 'mpspace', 'msqrt', 'mystyle', 'msub', 'msup', 'msubsup', 'mtable', 'mtd',
        'mtext', 'mtr', 'munder', 'munderover',

        //Text
        '#text'
    ]);

    /* Allowed attribute names */
    var ALLOWED_ATTR = null;
    var DEFAULT_ALLOWED_ATTR = _addToSet({}, [

        // HTML
        'accept', 'action', 'align', 'alt', 'autocomplete', 'background', 'bgcolor',
        'border', 'cellpadding', 'cellspacing', 'checked', 'cite', 'class', 'clear', 'color',
        'cols', 'colspan', 'coords', 'datetime', 'default', 'dir', 'disabled',
        'download', 'enctype', 'face', 'for', 'headers', 'height', 'hidden', 'high', 'href',
        'hreflang', 'id', 'ismap', 'label', 'lang', 'list', 'loop', 'low', 'max',
        'maxlength', 'media', 'method', 'min', 'multiple', 'name', 'noshade', 'novalidate',
        'nowrap', 'open', 'optimum', 'pattern', 'placeholder', 'poster', 'preload', 'pubdate',
        'radiogroup', 'readonly', 'rel', 'required', 'rev', 'reversed', 'rows',
        'rowspan', 'spellcheck', 'scope', 'selected', 'shape', 'size', 'span',
        'srclang', 'start', 'src', 'step', 'style', 'summary', 'tabindex', 'title',
        'type', 'usemap', 'valign', 'value', 'width', 'xmlns',

        // SVG
        'accent-height', 'accumulate', 'additivive', 'alignment-baseline',
        'ascent', 'attributename', 'attributetype', 'azimuth', 'basefrequency',
        'baseline-shift', 'begin', 'bias', 'by', 'clip', 'clip-path', 'clip-rule',
        'color', 'color-interpolation', 'color-interpolation-filters', 'color-profile',
        'color-rendering', 'cx', 'cy', 'd', 'dx', 'dy', 'diffuseconstant', 'direction',
        'display', 'divisor', 'dur', 'edgemode', 'elevation', 'end', 'fill', 'fill-opacity',
        'fill-rule', 'filter', 'flood-color', 'flood-opacity', 'font-family', 'font-size',
        'font-size-adjust', 'font-stretch', 'font-style', 'font-variant', 'font-weight',
        'fx', 'fy', 'g1', 'g2', 'glyph-name', 'glyphref', 'gradientunits', 'gradienttransform',
        'image-rendering', 'in', 'in2', 'k', 'k1', 'k2', 'k3', 'k4', 'kerning', 'keypoints',
        'keysplines', 'keytimes', 'lengthadjust', 'letter-spacing', 'kernelmatrix',
        'kernelunitlength', 'lighting-color', 'local', 'marker-end', 'marker-mid',
        'marker-start', 'markerheight', 'markerunits', 'markerwidth', 'maskcontentunits',
        'maskunits', 'max', 'mask', 'mode', 'min', 'numoctaves', 'offset', 'operator',
        'opacity', 'order', 'orient', 'orientation', 'origin', 'overflow', 'paint-order',
        'path', 'pathlength', 'patterncontentunits', 'patterntransform', 'patternunits',
        'points', 'preservealpha', 'r', 'rx', 'ry', 'radius', 'refx', 'refy', 'repeatcount',
        'repeatdur', 'restart', 'rotate', 'scale', 'seed', 'shape-rendering', 'specularconstant',
        'specularexponent', 'spreadmethod', 'stddeviation', 'stitchtiles', 'stop-color',
        'stop-opacity', 'stroke-dasharray', 'stroke-dashoffset', 'stroke-linecap',
        'stroke-linejoin', 'stroke-miterlimit', 'stroke-opacity', 'stroke', 'stroke-width',
        'surfacescale', 'targetx', 'targety', 'transform', 'text-anchor', 'text-decoration',
        'text-rendering', 'textlength', 'u1', 'u2', 'unicode', 'values', 'viewbox',
        'visibility', 'vert-adv-y', 'vert-origin-x', 'vert-origin-y', 'word-spacing',
        'wrap', 'writing-mode', 'xchannelselector', 'ychannelselector', 'x', 'x1', 'x2',
        'y', 'y1', 'y2', 'z', 'zoomandpan',

        // MathML
        'accent', 'accentunder', 'bevelled', 'close', 'columnsalign', 'columnlines',
        'columnspan', 'denomalign', 'depth', 'display', 'displaystyle', 'fence',
        'frame', 'largeop', 'length', 'linethickness', 'lspace', 'lquote',
        'mathbackground', 'mathcolor', 'mathsize', 'mathvariant', 'maxsize',
        'minsize', 'movablelimits', 'notation', 'numalign', 'open', 'rowalign',
        'rowlines', 'rowspacing', 'rowspan', 'rspace', 'rquote', 'scriptlevel',
        'scriptminsize', 'scriptsizemultiplier', 'selection', 'separator',
        'separators', 'stretchy', 'subscriptshift', 'supscriptshift', 'symmetric',
        'voffset',

        // XML
        'xlink:href', 'xml:id', 'xlink:title', 'xml:space', 'xmlns:xlink'
    ]);

    /* Explicitly forbidden tags (overrides ALLOWED_TAGS/ADD_TAGS) */
    var FORBID_TAGS = null;

    /* Explicitly forbidden attributes (overrides ALLOWED_ATTR/ADD_ATTR) */
    var FORBID_ATTR = null;

    /* Decide if custom data attributes are okay */
    var ALLOW_DATA_ATTR = true;

    /* Output should be safe for jQuery's $() factory? */
    var SAFE_FOR_JQUERY = false;

    /* Output should be safe for common template engines.
     * This means, DOMPurify removes data attributes, mustaches and ERB
     */
    var SAFE_FOR_TEMPLATES = false;

    /* Decide if document with <html>... should be returned */
    var WHOLE_DOCUMENT = false;

    /* Decide if a DOM `HTMLBodyElement` should be returned, instead of a html string.
     * If `WHOLE_DOCUMENT` is enabled a `HTMLHtmlElement` will be returned instead
     */
    var RETURN_DOM = false;

    /* Decide if a DOM `DocumentFragment` should be returned, instead of a html string */
    var RETURN_DOM_FRAGMENT = false;

    /* If `RETURN_DOM` or `RETURN_DOM_FRAGMENT` is enabled, decide if the returned DOM
     * `Node` is imported into the current `Document`. If this flag is not enabled the
     * `Node` will belong (its ownerDocument) to a fresh `HTMLDocument`, created by
     * DOMPurify. */
    var RETURN_DOM_IMPORT = false;

    /* Output should be free from DOM clobbering attacks? */
    var SANITIZE_DOM = true;

    /* Keep element content when removing element? */
    var KEEP_CONTENT = true;

    /* Tags to ignore content of when KEEP_CONTENT is true */
    var FORBID_CONTENTS = _addToSet({}, [
        'audio', 'head', 'math', 'script', 'style', 'svg', 'video'
    ]);

    /* Keep a reference to config to pass to hooks */
    var CONFIG = null;

    /* Ideally, do not touch anything below this line */
    /* ______________________________________________ */

    var formElement = document.createElement('form');

    /**
     * _parseConfig
     *
     * @param  optional config literal
     */
    var _parseConfig = function(cfg) {
        /* Shield configuration object from tampering */
        if (typeof cfg !== 'object') {
            cfg = {};
        }

        /* Set configuration parameters */
        ALLOWED_TAGS = 'ALLOWED_TAGS' in cfg ?
            _addToSet({}, cfg.ALLOWED_TAGS) : DEFAULT_ALLOWED_TAGS;
        ALLOWED_ATTR = 'ALLOWED_ATTR' in cfg ?
            _addToSet({}, cfg.ALLOWED_ATTR) : DEFAULT_ALLOWED_ATTR;
        FORBID_TAGS = 'FORBID_TAGS' in cfg ?
            _addToSet({}, cfg.FORBID_TAGS) : {};
        FORBID_ATTR = 'FORBID_ATTR' in cfg ?
            _addToSet({}, cfg.FORBID_ATTR) : {};
        ALLOW_DATA_ATTR = cfg.ALLOW_DATA_ATTR !== false; // Default true
        SAFE_FOR_JQUERY = cfg.SAFE_FOR_JQUERY || false; // Default false
        SAFE_FOR_TEMPLATES = cfg.SAFE_FOR_TEMPLATES || false; // Default false
        WHOLE_DOCUMENT = cfg.WHOLE_DOCUMENT || false; // Default false
        RETURN_DOM = cfg.RETURN_DOM || false; // Default false
        RETURN_DOM_FRAGMENT = cfg.RETURN_DOM_FRAGMENT || false; // Default false
        RETURN_DOM_IMPORT = cfg.RETURN_DOM_IMPORT || false; // Default false
        SANITIZE_DOM = cfg.SANITIZE_DOM !== false; // Default true
        KEEP_CONTENT = cfg.KEEP_CONTENT !== false; // Default true

        if (RETURN_DOM_FRAGMENT) {
            RETURN_DOM = true;
        }

        /* Merge configuration parameters */
        if (cfg.ADD_TAGS) {
            if (ALLOWED_TAGS === DEFAULT_ALLOWED_TAGS) {
                ALLOWED_TAGS = _cloneObj(ALLOWED_TAGS);
            }
            _addToSet(ALLOWED_TAGS, cfg.ADD_TAGS);
        }
        if (cfg.ADD_ATTR) {
            if (ALLOWED_ATTR === DEFAULT_ALLOWED_ATTR) {
                ALLOWED_ATTR = _cloneObj(ALLOWED_ATTR);
            }
            _addToSet(ALLOWED_ATTR, cfg.ADD_ATTR);
        }

        /* Add #text in case KEEP_CONTENT is set to true */
        if (KEEP_CONTENT) {
            ALLOWED_TAGS['#text'] = true;
        }

        // Prevent further manipulation of configuration.
        // Not available in IE8, Safari 5, etc.
        if (Object && 'freeze' in Object) {
            Object.freeze(cfg);
        }

        CONFIG = cfg;
    };

    /**
     * _forceRemove
     *
     * @param  a DOM node
     */
    var _forceRemove = function(node) {
        try {
            node.parentNode.removeChild(node);
        } catch (e) {
            node.outerHTML = '';
        }
    };

    /**
     * _initDocument
     *
     * @param  a string of dirty markup
     * @return a DOM, filled with the dirty markup
     */
    var _initDocument = function(dirty) {
        /* Create a HTML document using DOMParser */
        var doc, body;
        try {
            doc = new DOMParser().parseFromString(dirty, 'text/html');
        } catch (e) {}

        /* Some browsers throw, some browsers return null for the code above
           DOMParser with text/html support is only in very recent browsers. */
        if (!doc) {
            doc = implementation.createHTMLDocument('');
            body = doc.body;
            body.parentNode.removeChild(body.parentNode.firstElementChild);
            body.outerHTML = dirty;
        }

        /* Work on whole document or just its body */
        if (typeof doc.getElementsByTagName === 'function') {
            return doc.getElementsByTagName(
                WHOLE_DOCUMENT ? 'html' : 'body')[0];
        } else {
            return getElementsByTagName.call(doc,
                WHOLE_DOCUMENT ? 'html' : 'body')[0];
        }
    };

    /**
     * _createIterator
     *
     * @param  document/fragment to create iterator for
     * @return iterator instance
     */
    var _createIterator = function(root) {
        return createNodeIterator.call(root.ownerDocument || root,
            root,
            NodeFilter.SHOW_ELEMENT |
            NodeFilter.SHOW_COMMENT |
            NodeFilter.SHOW_TEXT,
            function() {
                return NodeFilter.FILTER_ACCEPT;
            },
            false
        );
    };

    /**
     * _isClobbered
     *
     * @param  element to check for clobbering attacks
     * @return true if clobbered, false if safe
     */
    var _isClobbered = function(elm) {
        if (elm instanceof Text || elm instanceof Comment) {
            return false;
        }
        if (typeof elm.nodeName !== 'string' ||
            typeof elm.textContent !== 'string' ||
            typeof elm.removeChild !== 'function' ||
            !(elm.attributes instanceof NamedNodeMap) ||
            typeof elm.removeAttribute !== 'function' ||
            typeof elm.setAttribute !== 'function'
        ) {
            return true;
        }
        return false;
    };

    var MUSTACHE_EXPR = /\{\{.*|.*\}\}/gm;
    var ERB_EXPR = /<%.*|.*%>/gm;

    /**
     * _sanitizeElements
     *
     * @protect nodeName
     * @protect textContent
     * @protect removeChild
     *
     * @param   node to check for permission to exist
     * @return  true if node was killed, false if left alive
     */
    var _sanitizeElements = function(currentNode) {
        /* Execute a hook if present */
        _executeHook('beforeSanitizeElements', currentNode, null);

        /* Check if element is clobbered or can clobber */
        if (_isClobbered(currentNode)) {
            _forceRemove(currentNode);
            return true;
        }

        /* Now let's check the element's type and name */
        var tagName = currentNode.nodeName.toLowerCase();

        /* Execute a hook if present */
        _executeHook('uponSanitizeElement', currentNode, {
            tagName: tagName
        });

        /* Remove element if anything forbids its presence */
        if (!ALLOWED_TAGS[tagName] || FORBID_TAGS[tagName]) {
            /* Keep content except for black-listed elements */
            if (KEEP_CONTENT && !FORBID_CONTENTS[tagName] &&
                typeof currentNode.insertAdjacentHTML === 'function') {
                try {
                    currentNode.insertAdjacentHTML('AfterEnd', currentNode.innerHTML);
                } catch (e) {}
            }
            _forceRemove(currentNode);
            return true;
        }

        /* Convert markup to cover jQuery behavior */
        if (SAFE_FOR_JQUERY && !currentNode.firstElementChild &&
            (!currentNode.content || !currentNode.content.firstElementChild)) {
            currentNode.innerHTML = currentNode.textContent.replace(/</g, '&lt;');
        }

        /* Sanitize element content to be template-safe */
        if (SAFE_FOR_TEMPLATES && currentNode.nodeType === 3) {
            /* Get the element's text content */
            var content = currentNode.textContent;
            content = content.replace(MUSTACHE_EXPR, ' ');
            content = content.replace(ERB_EXPR, ' ');
            currentNode.textContent = content;
        }

        /* Execute a hook if present */
        _executeHook('afterSanitizeElements', currentNode, null);

        return false;
    };

    var DATA_ATTR = /^data-[\w.\u00B7-\uFFFF-]/;
    var IS_SCRIPT_OR_DATA = /^(?:\w+script|data):/i;
    /* This needs to be extensive thanks to Webkit/Blink's behavior */
    var ATTR_WHITESPACE = /[\x00-\x20\xA0\u1680\u180E\u2000-\u2029\u205f\u3000]/g;

    /**
     * _sanitizeAttributes
     *
     * @protect attributes
     * @protect nodeName
     * @protect removeAttribute
     * @protect setAttribute
     *
     * @param   node to sanitize
     * @return  void
     */
    var _sanitizeAttributes = function(currentNode) {
        /* Execute a hook if present */
        _executeHook('beforeSanitizeAttributes', currentNode, null);

        var attributes = currentNode.attributes;

        /* Check if we have attributes; if not we might have a text node */
        if (!attributes) {
            return;
        }

        var hookEvent = {
            attrName: '',
            attrValue: '',
            keepAttr: true
        };
        var l = attributes.length;
        var attr, name, value, lcName, idAttr;

        /* Go backwards over all attributes; safely remove bad ones */
        while (l--) {
            attr = attributes[l];
            name = attr.name;
            value = attr.value;
            lcName = name.toLowerCase();

            /* Execute a hook if present */
            hookEvent.attrName = lcName;
            hookEvent.attrValue = value;
            hookEvent.keepAttr = true;
            _executeHook('uponSanitizeAttribute', currentNode, hookEvent);
            value = hookEvent.attrValue;

            /* Remove attribute */
            // Safari (iOS + Mac), last tested v8.0.5, crashes if you try to
            // remove a "name" attribute from an <img> tag that has an "id"
            // attribute at the time.
            if (lcName === 'name' &&
                currentNode.nodeName === 'IMG' && attributes.id) {
                idAttr = attributes.id;
                attributes = Array.prototype.slice.apply(attributes);
                currentNode.removeAttribute('id');
                currentNode.removeAttribute(name);
                if (attributes.indexOf(idAttr) > l) {
                    currentNode.setAttribute('id', idAttr.value);
                }
            } else {
                // This avoids a crash in Safari v9.0 with double-ids.
                // The trick is to first set the id to be empty and then to
                // remove the attriubute
                if (name === 'id') {
                    currentNode.setAttribute(name, '');
                }
                currentNode.removeAttribute(name);
            }

            /* Did the hooks approve of the attribute? */
            if (!hookEvent.keepAttr) {
                continue;
            }

            /* Make sure attribute cannot clobber */
            if (SANITIZE_DOM &&
                (lcName === 'id' || lcName === 'name') &&
                (value in window || value in document || value in formElement)) {
                continue;
            }

            if (
                /* Check the name is permitted */
                (
                    (ALLOWED_ATTR[lcName] && !FORBID_ATTR[lcName]) ||
                    /* Allow potentially valid data-* attributes
                     * At least one character after "-" (https://html.spec.whatwg.org/multipage/dom.html#embedding-custom-non-visible-data-with-the-data-*-attributes)
                     * XML-compatible (https://html.spec.whatwg.org/multipage/infrastructure.html#xml-compatible and http://www.w3.org/TR/xml/#d0e804) */
                    (!SAFE_FOR_TEMPLATES && ALLOW_DATA_ATTR && DATA_ATTR.test(lcName))
                ) &&
                /* Get rid of script and data URIs */
                (!IS_SCRIPT_OR_DATA.test(value.replace(ATTR_WHITESPACE, '')) ||
                    /* Keep image data URIs alive if src is allowed */
                    (lcName === 'src' && value.indexOf('data:') === 0 &&
                        currentNode.nodeName === 'IMG')
                )
            ) {
                /* Handle invalid data-* attribute set by try-catching it */
                try {
                    /* Sanitize attribute content to be template-safe */
                    if (SAFE_FOR_TEMPLATES) {
                        value = value.replace(MUSTACHE_EXPR, ' ');
                        value = value.replace(ERB_EXPR, ' ');
                    }

                    currentNode.setAttribute(name, value);
                } catch (e) {}
            }
        }

        /* Execute a hook if present */
        _executeHook('afterSanitizeAttributes', currentNode, null);

        if (currentNode.nodeName.toLowerCase() === "a" && currentNode.href) {
            currentNode.setAttribute("href", currentNode.href);
        }
    };

    /**
     * _sanitizeShadowDOM
     *
     * @param  fragment to iterate over recursively
     * @return void
     */
    var _sanitizeShadowDOM = function(fragment) {
        var shadowNode;
        var shadowIterator = _createIterator(fragment);

        /* Execute a hook if present */
        _executeHook('beforeSanitizeShadowDOM', fragment, null);

        while ((shadowNode = shadowIterator.nextNode())) {
            /* Execute a hook if present */
            _executeHook('uponSanitizeShadowNode', shadowNode, null);

            /* Sanitize tags and elements */
            if (_sanitizeElements(shadowNode)) {
                continue;
            }

            /* Deep shadow DOM detected */
            if (shadowNode.content instanceof DocumentFragment) {
                _sanitizeShadowDOM(shadowNode.content);
            }

            /* Check attributes, sanitize if necessary */
            _sanitizeAttributes(shadowNode);
        }

        /* Execute a hook if present */
        _executeHook('afterSanitizeShadowDOM', fragment, null);
    };

    /**
     * _executeHook
     * Execute user configurable hooks
     *
     * @param  {String} entryPoint  Name of the hook's entry point
     * @param  {Node} currentNode
     */
    var _executeHook = function(entryPoint, currentNode, data) {
        if (!hooks[entryPoint]) {
            return;
        }

        hooks[entryPoint].forEach(function(hook) {
            hook.call(DOMPurify, currentNode, data, CONFIG);
        });
    };

    /**
     * sanitize
     * Public method providing core sanitation functionality
     *
     * @param {String} dirty string
     * @param {Object} configuration object
     */
    DOMPurify.sanitize = function(dirty, cfg) {
        /* Make sure we have a string to sanitize.
           DO NOT return early, as this will return the wrong type if
           the user has requested a DOM object rather than a string */
        if (!dirty) {
            dirty = '';
        }

        /* Stringify, in case dirty is an array or other object */
        if (typeof dirty !== 'string') {
            dirty = dirty.toString();
        }

        /* Check we can run. Otherwise fall back or ignore */
        if (!DOMPurify.isSupported) {
            if (typeof window.toStaticHTML === 'object' ||
                typeof window.toStaticHTML === 'function') {
                return window.toStaticHTML(dirty);
            }
            return dirty;
        }

        /* Assign config vars */
        _parseConfig(cfg);

        /* Exit directly if we have nothing to do */
        if (!RETURN_DOM && !WHOLE_DOCUMENT && dirty.indexOf('<') === -1) {
            return dirty;
        }

        /* Initialize the document to work on */
        var body = _initDocument(dirty);

        /* Check we have a DOM node from the data */
        if (!body) {
            return RETURN_DOM ? null : '';
        }

        /* Get node iterator */
        var currentNode;
        var oldNode;
        var nodeIterator = _createIterator(body);

        /* Now start iterating over the created document */
        while ((currentNode = nodeIterator.nextNode())) {

            /* Fix IE's strange behavior with manipulated textNodes #89 */
            if (currentNode.nodeType === 3 && currentNode === oldNode) {
                continue;
            }

            /* Sanitize tags and elements */
            if (_sanitizeElements(currentNode)) {
                continue;
            }

            /* Shadow DOM detected, sanitize it */
            if (currentNode.content instanceof DocumentFragment) {
                _sanitizeShadowDOM(currentNode.content);
            }

            /* Check attributes, sanitize if necessary */
            _sanitizeAttributes(currentNode);

            oldNode = currentNode;
        }

        /* Return sanitized string or DOM */
        var returnNode;
        if (RETURN_DOM) {

            if (RETURN_DOM_FRAGMENT) {
                returnNode = createDocumentFragment.call(body.ownerDocument);

                while (body.firstChild) {
                    returnNode.appendChild(body.firstChild);
                }
            } else {
                returnNode = body;
            }

            if (RETURN_DOM_IMPORT) {
                /* adoptNode() is not used because internal state is not reset
                   (e.g. the past names map of a HTMLFormElement), this is safe
                   in theory but we would rather not risk another attack vector.
                   The state that is cloned by importNode() is explicitly defined
                   by the specs. */
                returnNode = importNode.call(originalDocument, returnNode, true);
            }

            return returnNode;
        }

        return WHOLE_DOCUMENT ? body.outerHTML : body.innerHTML;
    };

    /**
     * addHook
     * Public method to add DOMPurify hooks
     *
     * @param {String} entryPoint
     * @param {Function} hookFunction
     */
    DOMPurify.addHook = function(entryPoint, hookFunction) {
        if (typeof hookFunction !== 'function') {
            return;
        }
        hooks[entryPoint] = hooks[entryPoint] || [];
        hooks[entryPoint].push(hookFunction);
    };

    /**
     * removeHook
     * Public method to remove a DOMPurify hook at a given entryPoint
     * (pops it from the stack of hooks if more are present)
     *
     * @param {String} entryPoint
     * @return void
     */
    DOMPurify.removeHook = function(entryPoint) {
        if (hooks[entryPoint]) {
            hooks[entryPoint].pop();
        }
    };

    /**
     * removeHooks
     * Public method to remove all DOMPurify hooks at a given entryPoint
     *
     * @param  {String} entryPoint
     * @return void
     */
    DOMPurify.removeHooks = function(entryPoint) {
        if (hooks[entryPoint]) {
            hooks[entryPoint] = [];
        }
    };

    /**
     * removeAllHooks
     * Public method to remove all DOMPurify hooks
     *
     * @return void
     */
    DOMPurify.removeAllHooks = function() {
        hooks = [];
    };

    return DOMPurify;
}));

/**
 * Rangy, a cross-browser JavaScript range and selection library
 * https://github.com/timdown/rangy
 *
 * Copyright 2015, Tim Down
 * Licensed under the MIT license.
 * Version: 1.3.1-dev
 * Build date: 20 May 2015
 */

(function(factory, root) {
    if (typeof define == "function" && define.amd) {
        // AMD. Register as an anonymous module.
        define(factory);
    } else if (typeof module != "undefined" && typeof exports == "object") {
        // Node/CommonJS style
        module.exports = factory();
    } else {
        // No AMD or CommonJS support so we place Rangy in (probably) the global variable
        root.rangy = factory();
    }
})(function() {

    var OBJECT = "object",
        FUNCTION = "function",
        UNDEFINED = "undefined";

    // Minimal set of properties required for DOM Level 2 Range compliance. Comparison constants such as START_TO_START
    // are omitted because ranges in KHTML do not have them but otherwise work perfectly well. See issue 113.
    var domRangeProperties = ["startContainer", "startOffset", "endContainer", "endOffset", "collapsed",
        "commonAncestorContainer"
    ];

    // Minimal set of methods required for DOM Level 2 Range compliance
    var domRangeMethods = ["setStart", "setStartBefore", "setStartAfter", "setEnd", "setEndBefore",
        "setEndAfter", "collapse", "selectNode", "selectNodeContents", "compareBoundaryPoints", "deleteContents",
        "extractContents", "cloneContents", "insertNode", "surroundContents", "cloneRange", "toString", "detach"
    ];

    var textRangeProperties = ["boundingHeight", "boundingLeft", "boundingTop", "boundingWidth", "htmlText", "text"];

    // Subset of TextRange's full set of methods that we're interested in
    var textRangeMethods = ["collapse", "compareEndPoints", "duplicate", "moveToElementText", "parentElement", "select",
        "setEndPoint", "getBoundingClientRect"
    ];

    /*----------------------------------------------------------------------------------------------------------------*/

    // Trio of functions taken from Peter Michaux's article:
    // http://peter.michaux.ca/articles/feature-detection-state-of-the-art-browser-scripting
    function isHostMethod(o, p) {
        var t = typeof o[p];
        return t == FUNCTION || (!!(t == OBJECT && o[p])) || t == "unknown";
    }

    function isHostObject(o, p) {
        return !!(typeof o[p] == OBJECT && o[p]);
    }

    function isHostProperty(o, p) {
        return typeof o[p] != UNDEFINED;
    }

    // Creates a convenience function to save verbose repeated calls to tests functions
    function createMultiplePropertyTest(testFunc) {
        return function(o, props) {
            var i = props.length;
            while (i--) {
                if (!testFunc(o, props[i])) {
                    return false;
                }
            }
            return true;
        };
    }

    // Next trio of functions are a convenience to save verbose repeated calls to previous two functions
    var areHostMethods = createMultiplePropertyTest(isHostMethod);
    var areHostObjects = createMultiplePropertyTest(isHostObject);
    var areHostProperties = createMultiplePropertyTest(isHostProperty);

    function isTextRange(range) {
        return range && areHostMethods(range, textRangeMethods) && areHostProperties(range, textRangeProperties);
    }

    function getBody(doc) {
        return isHostObject(doc, "body") ? doc.body : doc.getElementsByTagName("body")[0];
    }

    var forEach = [].forEach ?
        function(arr, func) {
            arr.forEach(func);
        } :
        function(arr, func) {
            for (var i = 0, len = arr.length; i < len; ++i) {
                func(arr[i], i);
            }
        };

    var modules = {};

    var isBrowser = (typeof window != UNDEFINED && typeof document != UNDEFINED);

    var util = {
        isHostMethod: isHostMethod,
        isHostObject: isHostObject,
        isHostProperty: isHostProperty,
        areHostMethods: areHostMethods,
        areHostObjects: areHostObjects,
        areHostProperties: areHostProperties,
        isTextRange: isTextRange,
        getBody: getBody,
        forEach: forEach
    };

    var api = {
        version: "1.3.1-dev",
        initialized: false,
        isBrowser: isBrowser,
        supported: true,
        util: util,
        features: {},
        modules: modules,
        config: {
            alertOnFail: false,
            alertOnWarn: false,
            preferTextRange: false,
            autoInitialize: (typeof rangyAutoInitialize == UNDEFINED) ? true : rangyAutoInitialize
        }
    };

    function consoleLog(msg) {
        if (typeof console != UNDEFINED && isHostMethod(console, "log")) {

        }
    }

    function alertOrLog(msg, shouldAlert) {
        if (isBrowser && shouldAlert) {
            // alert(msg);
        } else {
            consoleLog(msg);
        }
    }

    function fail(reason) {
        api.initialized = true;
        api.supported = false;
        // alertOrLog("Rangy is not supported in this environment. Reason: " + reason, api.config.alertOnFail);
    }

    api.fail = fail;

    function warn(msg) {
        alertOrLog("Rangy warning: " + msg, api.config.alertOnWarn);
    }

    api.warn = warn;

    // Add utility extend() method
    var extend;
    if ({}.hasOwnProperty) {
        util.extend = extend = function(obj, props, deep) {
            var o, p;
            for (var i in props) {
                if (props.hasOwnProperty(i)) {
                    o = obj[i];
                    p = props[i];
                    if (deep && o !== null && typeof o == "object" && p !== null && typeof p == "object") {
                        extend(o, p, true);
                    }
                    obj[i] = p;
                }
            }
            // Special case for toString, which does not show up in for...in loops in IE <= 8
            if (props.hasOwnProperty("toString")) {
                obj.toString = props.toString;
            }
            return obj;
        };

        util.createOptions = function(optionsParam, defaults) {
            var options = {};
            extend(options, defaults);
            if (optionsParam) {
                extend(options, optionsParam);
            }
            return options;
        };
    } else {
        fail("hasOwnProperty not supported");
    }

    // Test whether we're in a browser and bail out if not
    if (!isBrowser) {
        fail("Rangy can only run in a browser");
    }

    // Test whether Array.prototype.slice can be relied on for NodeLists and use an alternative toArray() if not
    (function() {
        var toArray;

        if (isBrowser) {
            var el = document.createElement("div");
            el.appendChild(document.createElement("span"));
            var slice = [].slice;
            try {
                if (slice.call(el.childNodes, 0)[0].nodeType == 1) {
                    toArray = function(arrayLike) {
                        return slice.call(arrayLike, 0);
                    };
                }
            } catch (e) {}
        }

        if (!toArray) {
            toArray = function(arrayLike) {
                var arr = [];
                for (var i = 0, len = arrayLike.length; i < len; ++i) {
                    arr[i] = arrayLike[i];
                }
                return arr;
            };
        }

        util.toArray = toArray;
    })();

    // Very simple event handler wrapper function that doesn't attempt to solve issues such as "this" handling or
    // normalization of event properties
    var addListener;
    if (isBrowser) {
        if (isHostMethod(document, "addEventListener")) {
            addListener = function(obj, eventType, listener) {
                obj.addEventListener(eventType, listener, false);
            };
        } else if (isHostMethod(document, "attachEvent")) {
            addListener = function(obj, eventType, listener) {
                obj.attachEvent("on" + eventType, listener);
            };
        } else {
            fail("Document does not have required addEventListener or attachEvent method");
        }

        util.addListener = addListener;
    }

    var initListeners = [];

    function getErrorDesc(ex) {
        return ex.message || ex.description || String(ex);
    }

    // Initialization
    function init() {
        if (!isBrowser || api.initialized) {
            return;
        }
        var testRange;
        var implementsDomRange = false,
            implementsTextRange = false;

        // First, perform basic feature tests

        if (isHostMethod(document, "createRange")) {
            testRange = document.createRange();
            if (areHostMethods(testRange, domRangeMethods) && areHostProperties(testRange, domRangeProperties)) {
                implementsDomRange = true;
            }
        }

        var body = getBody(document);
        if (!body || body.nodeName.toLowerCase() != "body") {
            fail("No body element found");
            return;
        }

        if (body && isHostMethod(body, "createTextRange")) {
            testRange = body.createTextRange();
            if (isTextRange(testRange)) {
                implementsTextRange = true;
            }
        }

        if (!implementsDomRange && !implementsTextRange) {
            fail("Neither Range nor TextRange are available");
            return;
        }

        api.initialized = true;
        api.features = {
            implementsDomRange: implementsDomRange,
            implementsTextRange: implementsTextRange
        };

        // Initialize modules
        var module, errorMessage;
        for (var moduleName in modules) {
            if ((module = modules[moduleName]) instanceof Module) {
                module.init(module, api);
            }
        }

        // Call init listeners
        for (var i = 0, len = initListeners.length; i < len; ++i) {
            try {
                initListeners[i](api);
            } catch (ex) {
                errorMessage = "Rangy init listener threw an exception. Continuing. Detail: " + getErrorDesc(ex);
                consoleLog(errorMessage);
            }
        }
    }

    function deprecationNotice(deprecated, replacement, module) {
        if (module) {
            deprecated += " in module " + module.name;
        }
        api.warn("DEPRECATED: " + deprecated + " is deprecated. Please use " +
            replacement + " instead.");
    }

    function createAliasForDeprecatedMethod(owner, deprecated, replacement, module) {
        owner[deprecated] = function() {
            deprecationNotice(deprecated, replacement, module);
            return owner[replacement].apply(owner, util.toArray(arguments));
        };
    }

    util.deprecationNotice = deprecationNotice;
    util.createAliasForDeprecatedMethod = createAliasForDeprecatedMethod;

    // Allow external scripts to initialize this library in case it's loaded after the document has loaded
    api.init = init;

    // Execute listener immediately if already initialized
    api.addInitListener = function(listener) {
        if (api.initialized) {
            listener(api);
        } else {
            initListeners.push(listener);
        }
    };

    var shimListeners = [];

    api.addShimListener = function(listener) {
        shimListeners.push(listener);
    };

    function shim(win) {
        win = win || window;
        init();

        // Notify listeners
        for (var i = 0, len = shimListeners.length; i < len; ++i) {
            shimListeners[i](win);
        }
    }

    if (isBrowser) {
        api.shim = api.createMissingNativeApi = shim;
        createAliasForDeprecatedMethod(api, "createMissingNativeApi", "shim");
    }

    function Module(name, dependencies, initializer) {
        this.name = name;
        this.dependencies = dependencies;
        this.initialized = false;
        this.supported = false;
        this.initializer = initializer;
    }

    Module.prototype = {
        init: function() {
            var requiredModuleNames = this.dependencies || [];
            for (var i = 0, len = requiredModuleNames.length, requiredModule, moduleName; i < len; ++i) {
                moduleName = requiredModuleNames[i];

                requiredModule = modules[moduleName];
                if (!requiredModule || !(requiredModule instanceof Module)) {
                    throw new Error("required module '" + moduleName + "' not found");
                }

                requiredModule.init();

                if (!requiredModule.supported) {
                    throw new Error("required module '" + moduleName + "' not supported");
                }
            }

            // Now run initializer
            this.initializer(this);
        },

        fail: function(reason) {
            this.initialized = true;
            this.supported = false;
            throw new Error(reason);
        },

        warn: function(msg) {
            api.warn("Module " + this.name + ": " + msg);
        },

        deprecationNotice: function(deprecated, replacement) {
            api.warn("DEPRECATED: " + deprecated + " in module " + this.name + " is deprecated. Please use " +
                replacement + " instead");
        },

        createError: function(msg) {
            return new Error("Error in Rangy " + this.name + " module: " + msg);
        }
    };

    function createModule(name, dependencies, initFunc) {
        var newModule = new Module(name, dependencies, function(module) {
            if (!module.initialized) {
                module.initialized = true;
                try {
                    initFunc(api, module);
                    module.supported = true;
                } catch (ex) {
                    var errorMessage = "Module '" + name + "' failed to load: " + getErrorDesc(ex);
                    consoleLog(errorMessage);
                    if (ex.stack) {
                        consoleLog(ex.stack);
                    }
                }
            }
        });
        modules[name] = newModule;
        return newModule;
    }

    api.createModule = function(name) {
        // Allow 2 or 3 arguments (second argument is an optional array of dependencies)
        var initFunc, dependencies;
        if (arguments.length == 2) {
            initFunc = arguments[1];
            dependencies = [];
        } else {
            initFunc = arguments[2];
            dependencies = arguments[1];
        }

        var module = createModule(name, dependencies, initFunc);

        // Initialize the module immediately if the core is already initialized
        if (api.initialized && api.supported) {
            module.init();
        }
    };

    api.createCoreModule = function(name, dependencies, initFunc) {
        createModule(name, dependencies, initFunc);
    };

    /*----------------------------------------------------------------------------------------------------------------*/

    // Ensure rangy.rangePrototype and rangy.selectionPrototype are available immediately

    function RangePrototype() {}
    api.RangePrototype = RangePrototype;
    api.rangePrototype = new RangePrototype();

    function SelectionPrototype() {}
    api.selectionPrototype = new SelectionPrototype();

    /*----------------------------------------------------------------------------------------------------------------*/

    // DOM utility methods used by Rangy
    api.createCoreModule("DomUtil", [], function(api, module) {
        var UNDEF = "undefined";
        var util = api.util;
        var getBody = util.getBody;

        // Perform feature tests
        if (!util.areHostMethods(document, ["createDocumentFragment", "createElement", "createTextNode"])) {
            module.fail("document missing a Node creation method");
        }

        if (!util.isHostMethod(document, "getElementsByTagName")) {
            module.fail("document missing getElementsByTagName method");
        }

        var el = document.createElement("div");
        if (!util.areHostMethods(el, ["insertBefore", "appendChild", "cloneNode"] ||
                !util.areHostObjects(el, ["previousSibling", "nextSibling", "childNodes", "parentNode"]))) {
            module.fail("Incomplete Element implementation");
        }

        // innerHTML is required for Range's createContextualFragment method
        if (!util.isHostProperty(el, "innerHTML")) {
            module.fail("Element is missing innerHTML property");
        }

        var textNode = document.createTextNode("test");
        if (!util.areHostMethods(textNode, ["splitText", "deleteData", "insertData", "appendData", "cloneNode"] ||
                !util.areHostObjects(el, ["previousSibling", "nextSibling", "childNodes", "parentNode"]) ||
                !util.areHostProperties(textNode, ["data"]))) {
            module.fail("Incomplete Text Node implementation");
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // Removed use of indexOf because of a bizarre bug in Opera that is thrown in one of the Acid3 tests. I haven't been
        // able to replicate it outside of the test. The bug is that indexOf returns -1 when called on an Array that
        // contains just the document as a single element and the value searched for is the document.
        var arrayContains =
            /*Array.prototype.indexOf ?
                       function(arr, val) {
                           return arr.indexOf(val) > -1;
                       }:*/

            function(arr, val) {
                var i = arr.length;
                while (i--) {
                    if (arr[i] === val) {
                        return true;
                    }
                }
                return false;
            };

        // Opera 11 puts HTML elements in the null namespace, it seems, and IE 7 has undefined namespaceURI
        function isHtmlNamespace(node) {
            var ns;
            return typeof node.namespaceURI == UNDEF || ((ns = node.namespaceURI) === null || ns == "http://www.w3.org/1999/xhtml");
        }

        function parentElement(node) {
            var parent = node.parentNode;
            return (parent.nodeType == 1) ? parent : null;
        }

        function getNodeIndex(node) {
            var i = 0;
            while ((node = node.previousSibling)) {
                ++i;
            }
            return i;
        }

        function getNodeLength(node) {
            switch (node.nodeType) {
                case 7:
                case 10:
                    return 0;
                case 3:
                case 8:
                    return node.length;
                default:
                    return node.childNodes.length;
            }
        }

        function getCommonAncestor(node1, node2) {
            var ancestors = [],
                n;
            for (n = node1; n; n = n.parentNode) {
                ancestors.push(n);
            }

            for (n = node2; n; n = n.parentNode) {
                if (arrayContains(ancestors, n)) {
                    return n;
                }
            }

            return null;
        }

        function isAncestorOf(ancestor, descendant, selfIsAncestor) {
            var n = selfIsAncestor ? descendant : descendant.parentNode;
            while (n) {
                if (n === ancestor) {
                    return true;
                } else {
                    n = n.parentNode;
                }
            }
            return false;
        }

        function isOrIsAncestorOf(ancestor, descendant) {
            return isAncestorOf(ancestor, descendant, true);
        }

        function getClosestAncestorIn(node, ancestor, selfIsAncestor) {
            var p, n = selfIsAncestor ? node : node.parentNode;
            while (n) {
                p = n.parentNode;
                if (p === ancestor) {
                    return n;
                }
                n = p;
            }
            return null;
        }

        function isCharacterDataNode(node) {
            var t = node.nodeType;
            return t == 3 || t == 4 || t == 8; // Text, CDataSection or Comment
        }

        function isTextOrCommentNode(node) {
            if (!node) {
                return false;
            }
            var t = node.nodeType;
            return t == 3 || t == 8; // Text or Comment
        }

        function insertAfter(node, precedingNode) {
            var nextNode = precedingNode.nextSibling,
                parent = precedingNode.parentNode;
            if (nextNode) {
                parent.insertBefore(node, nextNode);
            } else {
                parent.appendChild(node);
            }
            return node;
        }

        // Note that we cannot use splitText() because it is bugridden in IE 9.
        function splitDataNode(node, index, positionsToPreserve) {
            var newNode = node.cloneNode(false);
            newNode.deleteData(0, index);
            node.deleteData(index, node.length - index);
            insertAfter(newNode, node);

            // Preserve positions
            if (positionsToPreserve) {
                for (var i = 0, position; position = positionsToPreserve[i++];) {
                    // Handle case where position was inside the portion of node after the split point
                    if (position.node == node && position.offset > index) {
                        position.node = newNode;
                        position.offset -= index;
                    }
                    // Handle the case where the position is a node offset within node's parent
                    else if (position.node == node.parentNode && position.offset > getNodeIndex(node)) {
                        ++position.offset;
                    }
                }
            }
            return newNode;
        }

        function getDocument(node) {
            if (node.nodeType == 9) {
                return node;
            } else if (typeof node.ownerDocument != UNDEF) {
                return node.ownerDocument;
            } else if (typeof node.document != UNDEF) {
                return node.document;
            } else if (node.parentNode) {
                return getDocument(node.parentNode);
            } else {
                throw module.createError("getDocument: no document found for node");
            }
        }

        function getWindow(node) {
            var doc = getDocument(node);
            if (typeof doc.defaultView != UNDEF) {
                return doc.defaultView;
            } else if (typeof doc.parentWindow != UNDEF) {
                return doc.parentWindow;
            } else {
                throw module.createError("Cannot get a window object for node");
            }
        }

        function getIframeDocument(iframeEl) {
            if (typeof iframeEl.contentDocument != UNDEF) {
                return iframeEl.contentDocument;
            } else if (typeof iframeEl.contentWindow != UNDEF) {
                return iframeEl.contentWindow.document;
            } else {
                throw module.createError("getIframeDocument: No Document object found for iframe element");
            }
        }

        function getIframeWindow(iframeEl) {
            if (typeof iframeEl.contentWindow != UNDEF) {
                return iframeEl.contentWindow;
            } else if (typeof iframeEl.contentDocument != UNDEF) {
                return iframeEl.contentDocument.defaultView;
            } else {
                throw module.createError("getIframeWindow: No Window object found for iframe element");
            }
        }

        // This looks bad. Is it worth it?
        function isWindow(obj) {
            return obj && util.isHostMethod(obj, "setTimeout") && util.isHostObject(obj, "document");
        }

        function getContentDocument(obj, module, methodName) {
            var doc;

            if (!obj) {
                doc = document;
            }

            // Test if a DOM node has been passed and obtain a document object for it if so
            else if (util.isHostProperty(obj, "nodeType")) {
                doc = (obj.nodeType == 1 && obj.tagName.toLowerCase() == "iframe") ?
                    getIframeDocument(obj) : getDocument(obj);
            }

            // Test if the doc parameter appears to be a Window object
            else if (isWindow(obj)) {
                doc = obj.document;
            }

            if (!doc) {
                throw module.createError(methodName + "(): Parameter must be a Window object or DOM node");
            }

            return doc;
        }

        function getRootContainer(node) {
            var parent;
            while ((parent = node.parentNode)) {
                node = parent;
            }
            return node;
        }

        function comparePoints(nodeA, offsetA, nodeB, offsetB) {
            // See http://www.w3.org/TR/DOM-Level-2-Traversal-Range/ranges.html#Level-2-Range-Comparing
            var nodeC, root, childA, childB, n;
            if (nodeA == nodeB) {
                // Case 1: nodes are the same
                return offsetA === offsetB ? 0 : (offsetA < offsetB) ? -1 : 1;
            } else if ((nodeC = getClosestAncestorIn(nodeB, nodeA, true))) {
                // Case 2: node C (container B or an ancestor) is a child node of A
                return offsetA <= getNodeIndex(nodeC) ? -1 : 1;
            } else if ((nodeC = getClosestAncestorIn(nodeA, nodeB, true))) {
                // Case 3: node C (container A or an ancestor) is a child node of B
                return getNodeIndex(nodeC) < offsetB ? -1 : 1;
            } else {
                root = getCommonAncestor(nodeA, nodeB);
                if (!root) {
                    throw new Error("comparePoints error: nodes have no common ancestor");
                }

                // Case 4: containers are siblings or descendants of siblings
                childA = (nodeA === root) ? root : getClosestAncestorIn(nodeA, root, true);
                childB = (nodeB === root) ? root : getClosestAncestorIn(nodeB, root, true);

                if (childA === childB) {
                    // This shouldn't be possible
                    throw module.createError("comparePoints got to case 4 and childA and childB are the same!");
                } else {
                    n = root.firstChild;
                    while (n) {
                        if (n === childA) {
                            return -1;
                        } else if (n === childB) {
                            return 1;
                        }
                        n = n.nextSibling;
                    }
                }
            }
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // Test for IE's crash (IE 6/7) or exception (IE >= 8) when a reference to garbage-collected text node is queried
        var crashyTextNodes = false;

        function isBrokenNode(node) {
            var n;
            try {
                n = node.parentNode;
                return false;
            } catch (e) {
                return true;
            }
        }

        (function() {
            var el = document.createElement("b");
            el.innerHTML = "1";
            var textNode = el.firstChild;
            el.innerHTML = "<br />";
            crashyTextNodes = isBrokenNode(textNode);

            api.features.crashyTextNodes = crashyTextNodes;
        })();

        /*----------------------------------------------------------------------------------------------------------------*/

        function inspectNode(node) {
            if (!node) {
                return "[No node]";
            }
            if (crashyTextNodes && isBrokenNode(node)) {
                return "[Broken node]";
            }
            if (isCharacterDataNode(node)) {
                return '"' + node.data + '"';
            }
            if (node.nodeType == 1) {
                var idAttr = node.id ? ' id="' + node.id + '"' : "";
                return "<" + node.nodeName + idAttr + ">[index:" + getNodeIndex(node) + ",length:" + node.childNodes.length + "][" + (node.innerHTML || "[innerHTML not supported]").slice(0, 25) + "]";
            }
            return node.nodeName;
        }

        function fragmentFromNodeChildren(node) {
            var fragment = getDocument(node).createDocumentFragment(),
                child;
            while ((child = node.firstChild)) {
                fragment.appendChild(child);
            }
            return fragment;
        }

        var getComputedStyleProperty;
        if (typeof window.getComputedStyle != UNDEF) {
            getComputedStyleProperty = function(el, propName) {
                return getWindow(el).getComputedStyle(el, null)[propName];
            };
        } else if (typeof document.documentElement.currentStyle != UNDEF) {
            getComputedStyleProperty = function(el, propName) {
                return el.currentStyle ? el.currentStyle[propName] : "";
            };
        } else {
            module.fail("No means of obtaining computed style properties found");
        }

        function createTestElement(doc, html, contentEditable) {
            var body = getBody(doc);
            var el = doc.createElement("div");
            el.contentEditable = "" + !!contentEditable;
            if (html) {
                el.innerHTML = html;
            }

            // Insert the test element at the start of the body to prevent scrolling to the bottom in iOS (issue #292)
            var bodyFirstChild = body.firstChild;
            if (bodyFirstChild) {
                body.insertBefore(el, bodyFirstChild);
            } else {
                body.appendChild(el);
            }

            return el;
        }

        function removeNode(node) {
            return node.parentNode.removeChild(node);
        }

        function NodeIterator(root) {
            this.root = root;
            this._next = root;
        }

        NodeIterator.prototype = {
            _current: null,

            hasNext: function() {
                return !!this._next;
            },

            next: function() {
                var n = this._current = this._next;
                var child, next;
                if (this._current) {
                    child = n.firstChild;
                    if (child) {
                        this._next = child;
                    } else {
                        next = null;
                        while ((n !== this.root) && !(next = n.nextSibling)) {
                            n = n.parentNode;
                        }
                        this._next = next;
                    }
                }
                return this._current;
            },

            detach: function() {
                this._current = this._next = this.root = null;
            }
        };

        function createIterator(root) {
            return new NodeIterator(root);
        }

        function DomPosition(node, offset) {
            this.node = node;
            this.offset = offset;
        }

        DomPosition.prototype = {
            equals: function(pos) {
                return !!pos && this.node === pos.node && this.offset == pos.offset;
            },

            inspect: function() {
                return "[DomPosition(" + inspectNode(this.node) + ":" + this.offset + ")]";
            },

            toString: function() {
                return this.inspect();
            }
        };

        function DOMException(codeName) {
            this.code = this[codeName];
            this.codeName = codeName;
            this.message = "DOMException: " + this.codeName;
        }

        DOMException.prototype = {
            INDEX_SIZE_ERR: 1,
            HIERARCHY_REQUEST_ERR: 3,
            WRONG_DOCUMENT_ERR: 4,
            NO_MODIFICATION_ALLOWED_ERR: 7,
            NOT_FOUND_ERR: 8,
            NOT_SUPPORTED_ERR: 9,
            INVALID_STATE_ERR: 11,
            INVALID_NODE_TYPE_ERR: 24
        };

        DOMException.prototype.toString = function() {
            return this.message;
        };

        api.dom = {
            arrayContains: arrayContains,
            isHtmlNamespace: isHtmlNamespace,
            parentElement: parentElement,
            getNodeIndex: getNodeIndex,
            getNodeLength: getNodeLength,
            getCommonAncestor: getCommonAncestor,
            isAncestorOf: isAncestorOf,
            isOrIsAncestorOf: isOrIsAncestorOf,
            getClosestAncestorIn: getClosestAncestorIn,
            isCharacterDataNode: isCharacterDataNode,
            isTextOrCommentNode: isTextOrCommentNode,
            insertAfter: insertAfter,
            splitDataNode: splitDataNode,
            getDocument: getDocument,
            getWindow: getWindow,
            getIframeWindow: getIframeWindow,
            getIframeDocument: getIframeDocument,
            getBody: getBody,
            isWindow: isWindow,
            getContentDocument: getContentDocument,
            getRootContainer: getRootContainer,
            comparePoints: comparePoints,
            isBrokenNode: isBrokenNode,
            inspectNode: inspectNode,
            getComputedStyleProperty: getComputedStyleProperty,
            createTestElement: createTestElement,
            removeNode: removeNode,
            fragmentFromNodeChildren: fragmentFromNodeChildren,
            createIterator: createIterator,
            DomPosition: DomPosition
        };

        api.DOMException = DOMException;
    });

    /*----------------------------------------------------------------------------------------------------------------*/

    // Pure JavaScript implementation of DOM Range
    api.createCoreModule("DomRange", ["DomUtil"], function(api, module) {
        var dom = api.dom;
        var util = api.util;
        var DomPosition = dom.DomPosition;
        var DOMException = api.DOMException;

        var isCharacterDataNode = dom.isCharacterDataNode;
        var getNodeIndex = dom.getNodeIndex;
        var isOrIsAncestorOf = dom.isOrIsAncestorOf;
        var getDocument = dom.getDocument;
        var comparePoints = dom.comparePoints;
        var splitDataNode = dom.splitDataNode;
        var getClosestAncestorIn = dom.getClosestAncestorIn;
        var getNodeLength = dom.getNodeLength;
        var arrayContains = dom.arrayContains;
        var getRootContainer = dom.getRootContainer;
        var crashyTextNodes = api.features.crashyTextNodes;

        var removeNode = dom.removeNode;

        /*----------------------------------------------------------------------------------------------------------------*/

        // Utility functions

        function isNonTextPartiallySelected(node, range) {
            return (node.nodeType != 3) &&
                (isOrIsAncestorOf(node, range.startContainer) || isOrIsAncestorOf(node, range.endContainer));
        }

        function getRangeDocument(range) {
            return range.document || getDocument(range.startContainer);
        }

        function getRangeRoot(range) {
            return getRootContainer(range.startContainer);
        }

        function getBoundaryBeforeNode(node) {
            return new DomPosition(node.parentNode, getNodeIndex(node));
        }

        function getBoundaryAfterNode(node) {
            return new DomPosition(node.parentNode, getNodeIndex(node) + 1);
        }

        function insertNodeAtPosition(node, n, o) {
            var firstNodeInserted = node.nodeType == 11 ? node.firstChild : node;
            if (isCharacterDataNode(n)) {
                if (o == n.length) {
                    dom.insertAfter(node, n);
                } else {
                    n.parentNode.insertBefore(node, o == 0 ? n : splitDataNode(n, o));
                }
            } else if (o >= n.childNodes.length) {
                n.appendChild(node);
            } else {
                n.insertBefore(node, n.childNodes[o]);
            }
            return firstNodeInserted;
        }

        function rangesIntersect(rangeA, rangeB, touchingIsIntersecting) {
            assertRangeValid(rangeA);
            assertRangeValid(rangeB);

            if (getRangeDocument(rangeB) != getRangeDocument(rangeA)) {
                throw new DOMException("WRONG_DOCUMENT_ERR");
            }

            var startComparison = comparePoints(rangeA.startContainer, rangeA.startOffset, rangeB.endContainer, rangeB.endOffset),
                endComparison = comparePoints(rangeA.endContainer, rangeA.endOffset, rangeB.startContainer, rangeB.startOffset);

            return touchingIsIntersecting ? startComparison <= 0 && endComparison >= 0 : startComparison < 0 && endComparison > 0;
        }

        function cloneSubtree(iterator) {
            var partiallySelected;
            for (var node, frag = getRangeDocument(iterator.range).createDocumentFragment(), subIterator; node = iterator.next();) {
                partiallySelected = iterator.isPartiallySelectedSubtree();
                node = node.cloneNode(!partiallySelected);
                if (partiallySelected) {
                    subIterator = iterator.getSubtreeIterator();
                    node.appendChild(cloneSubtree(subIterator));
                    subIterator.detach();
                }

                if (node.nodeType == 10) { // DocumentType
                    throw new DOMException("HIERARCHY_REQUEST_ERR");
                }
                frag.appendChild(node);
            }
            return frag;
        }

        function iterateSubtree(rangeIterator, func, iteratorState) {
            var it, n;
            iteratorState = iteratorState || {
                stop: false
            };
            for (var node, subRangeIterator; node = rangeIterator.next();) {
                if (rangeIterator.isPartiallySelectedSubtree()) {
                    if (func(node) === false) {
                        iteratorState.stop = true;
                        return;
                    } else {
                        // The node is partially selected by the Range, so we can use a new RangeIterator on the portion of
                        // the node selected by the Range.
                        subRangeIterator = rangeIterator.getSubtreeIterator();
                        iterateSubtree(subRangeIterator, func, iteratorState);
                        subRangeIterator.detach();
                        if (iteratorState.stop) {
                            return;
                        }
                    }
                } else {
                    // The whole node is selected, so we can use efficient DOM iteration to iterate over the node and its
                    // descendants
                    it = dom.createIterator(node);
                    while ((n = it.next())) {
                        if (func(n) === false) {
                            iteratorState.stop = true;
                            return;
                        }
                    }
                }
            }
        }

        function deleteSubtree(iterator) {
            var subIterator;
            while (iterator.next()) {
                if (iterator.isPartiallySelectedSubtree()) {
                    subIterator = iterator.getSubtreeIterator();
                    deleteSubtree(subIterator);
                    subIterator.detach();
                } else {
                    iterator.remove();
                }
            }
        }

        function extractSubtree(iterator) {
            for (var node, frag = getRangeDocument(iterator.range).createDocumentFragment(), subIterator; node = iterator.next();) {

                if (iterator.isPartiallySelectedSubtree()) {
                    node = node.cloneNode(false);
                    subIterator = iterator.getSubtreeIterator();
                    node.appendChild(extractSubtree(subIterator));
                    subIterator.detach();
                } else {
                    iterator.remove();
                }
                if (node.nodeType == 10) { // DocumentType
                    throw new DOMException("HIERARCHY_REQUEST_ERR");
                }
                frag.appendChild(node);
            }
            return frag;
        }

        function getNodesInRange(range, nodeTypes, filter) {
            var filterNodeTypes = !!(nodeTypes && nodeTypes.length),
                regex;
            var filterExists = !!filter;
            if (filterNodeTypes) {
                regex = new RegExp("^(" + nodeTypes.join("|") + ")$");
            }

            var nodes = [];
            iterateSubtree(new RangeIterator(range, false), function(node) {
                if (filterNodeTypes && !regex.test(node.nodeType)) {
                    return;
                }
                if (filterExists && !filter(node)) {
                    return;
                }
                // Don't include a boundary container if it is a character data node and the range does not contain any
                // of its character data. See issue 190.
                var sc = range.startContainer;
                if (node == sc && isCharacterDataNode(sc) && range.startOffset == sc.length) {
                    return;
                }

                var ec = range.endContainer;
                if (node == ec && isCharacterDataNode(ec) && range.endOffset == 0) {
                    return;
                }

                nodes.push(node);
            });
            return nodes;
        }

        function inspect(range) {
            var name = (typeof range.getName == "undefined") ? "Range" : range.getName();
            return "[" + name + "(" + dom.inspectNode(range.startContainer) + ":" + range.startOffset + ", " +
                dom.inspectNode(range.endContainer) + ":" + range.endOffset + ")]";
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // RangeIterator code partially borrows from IERange by Tim Ryan (http://github.com/timcameronryan/IERange)

        function RangeIterator(range, clonePartiallySelectedTextNodes) {
            this.range = range;
            this.clonePartiallySelectedTextNodes = clonePartiallySelectedTextNodes;


            if (!range.collapsed) {
                this.sc = range.startContainer;
                this.so = range.startOffset;
                this.ec = range.endContainer;
                this.eo = range.endOffset;
                var root = range.commonAncestorContainer;

                if (this.sc === this.ec && isCharacterDataNode(this.sc)) {
                    this.isSingleCharacterDataNode = true;
                    this._first = this._last = this._next = this.sc;
                } else {
                    this._first = this._next = (this.sc === root && !isCharacterDataNode(this.sc)) ?
                        this.sc.childNodes[this.so] : getClosestAncestorIn(this.sc, root, true);
                    this._last = (this.ec === root && !isCharacterDataNode(this.ec)) ?
                        this.ec.childNodes[this.eo - 1] : getClosestAncestorIn(this.ec, root, true);
                }
            }
        }

        RangeIterator.prototype = {
            _current: null,
            _next: null,
            _first: null,
            _last: null,
            isSingleCharacterDataNode: false,

            reset: function() {
                this._current = null;
                this._next = this._first;
            },

            hasNext: function() {
                return !!this._next;
            },

            next: function() {
                // Move to next node
                var current = this._current = this._next;
                if (current) {
                    this._next = (current !== this._last) ? current.nextSibling : null;

                    // Check for partially selected text nodes
                    if (isCharacterDataNode(current) && this.clonePartiallySelectedTextNodes) {
                        if (current === this.ec) {
                            (current = current.cloneNode(true)).deleteData(this.eo, current.length - this.eo);
                        }
                        if (this._current === this.sc) {
                            (current = current.cloneNode(true)).deleteData(0, this.so);
                        }
                    }
                }

                return current;
            },

            remove: function() {
                var current = this._current,
                    start, end;

                if (isCharacterDataNode(current) && (current === this.sc || current === this.ec)) {
                    start = (current === this.sc) ? this.so : 0;
                    end = (current === this.ec) ? this.eo : current.length;
                    if (start != end) {
                        current.deleteData(start, end - start);
                    }
                } else {
                    if (current.parentNode) {
                        removeNode(current);
                    } else {}
                }
            },

            // Checks if the current node is partially selected
            isPartiallySelectedSubtree: function() {
                var current = this._current;
                return isNonTextPartiallySelected(current, this.range);
            },

            getSubtreeIterator: function() {
                var subRange;
                if (this.isSingleCharacterDataNode) {
                    subRange = this.range.cloneRange();
                    subRange.collapse(false);
                } else {
                    subRange = new Range(getRangeDocument(this.range));
                    var current = this._current;
                    var startContainer = current,
                        startOffset = 0,
                        endContainer = current,
                        endOffset = getNodeLength(current);

                    if (isOrIsAncestorOf(current, this.sc)) {
                        startContainer = this.sc;
                        startOffset = this.so;
                    }
                    if (isOrIsAncestorOf(current, this.ec)) {
                        endContainer = this.ec;
                        endOffset = this.eo;
                    }

                    updateBoundaries(subRange, startContainer, startOffset, endContainer, endOffset);
                }
                return new RangeIterator(subRange, this.clonePartiallySelectedTextNodes);
            },

            detach: function() {
                this.range = this._current = this._next = this._first = this._last = this.sc = this.so = this.ec = this.eo = null;
            }
        };

        /*----------------------------------------------------------------------------------------------------------------*/

        var beforeAfterNodeTypes = [1, 3, 4, 5, 7, 8, 10];
        var rootContainerNodeTypes = [2, 9, 11];
        var readonlyNodeTypes = [5, 6, 10, 12];
        var insertableNodeTypes = [1, 3, 4, 5, 7, 8, 10, 11];
        var surroundNodeTypes = [1, 3, 4, 5, 7, 8];

        function createAncestorFinder(nodeTypes) {
            return function(node, selfIsAncestor) {
                var t, n = selfIsAncestor ? node : node.parentNode;
                while (n) {
                    t = n.nodeType;
                    if (arrayContains(nodeTypes, t)) {
                        return n;
                    }
                    n = n.parentNode;
                }
                return null;
            };
        }

        var getDocumentOrFragmentContainer = createAncestorFinder([9, 11]);
        var getReadonlyAncestor = createAncestorFinder(readonlyNodeTypes);
        var getDocTypeNotationEntityAncestor = createAncestorFinder([6, 10, 12]);

        function assertNoDocTypeNotationEntityAncestor(node, allowSelf) {
            if (getDocTypeNotationEntityAncestor(node, allowSelf)) {
                throw new DOMException("INVALID_NODE_TYPE_ERR");
            }
        }

        function assertValidNodeType(node, invalidTypes) {
            if (!arrayContains(invalidTypes, node.nodeType)) {
                throw new DOMException("INVALID_NODE_TYPE_ERR");
            }
        }

        function assertValidOffset(node, offset) {
            if (offset < 0 || offset > (isCharacterDataNode(node) ? node.length : node.childNodes.length)) {
                throw new DOMException("INDEX_SIZE_ERR");
            }
        }

        function assertSameDocumentOrFragment(node1, node2) {
            if (getDocumentOrFragmentContainer(node1, true) !== getDocumentOrFragmentContainer(node2, true)) {
                throw new DOMException("WRONG_DOCUMENT_ERR");
            }
        }

        function assertNodeNotReadOnly(node) {
            if (getReadonlyAncestor(node, true)) {
                throw new DOMException("NO_MODIFICATION_ALLOWED_ERR");
            }
        }

        function assertNode(node, codeName) {
            if (!node) {
                throw new DOMException(codeName);
            }
        }

        function isValidOffset(node, offset) {
            return offset <= (isCharacterDataNode(node) ? node.length : node.childNodes.length);
        }

        function isRangeValid(range) {
            return (!!range.startContainer && !!range.endContainer &&
                !(crashyTextNodes && (dom.isBrokenNode(range.startContainer) || dom.isBrokenNode(range.endContainer))) &&
                getRootContainer(range.startContainer) == getRootContainer(range.endContainer) &&
                isValidOffset(range.startContainer, range.startOffset) &&
                isValidOffset(range.endContainer, range.endOffset));
        }

        function assertRangeValid(range) {
            if (!isRangeValid(range)) {
                throw new Error("Range error: Range is not valid. This usually happens after DOM mutation. Range: (" + range.inspect() + ")");
            }
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // Test the browser's innerHTML support to decide how to implement createContextualFragment
        var styleEl = document.createElement("style");
        var htmlParsingConforms = false;
        try {
            styleEl.innerHTML = "<b>x</b>";
            htmlParsingConforms = (styleEl.firstChild.nodeType == 3); // Opera incorrectly creates an element node
        } catch (e) {
            // IE 6 and 7 throw
        }

        api.features.htmlParsingConforms = htmlParsingConforms;

        var createContextualFragment = htmlParsingConforms ?

            // Implementation as per HTML parsing spec, trusting in the browser's implementation of innerHTML. See
            // discussion and base code for this implementation at issue 67.
            // Spec: http://html5.org/specs/dom-parsing.html#extensions-to-the-range-interface
            // Thanks to Aleks Williams.
            function(fragmentStr) {
                // "Let node the context object's start's node."
                var node = this.startContainer;
                var doc = getDocument(node);

                // "If the context object's start's node is null, raise an INVALID_STATE_ERR
                // exception and abort these steps."
                if (!node) {
                    throw new DOMException("INVALID_STATE_ERR");
                }

                // "Let element be as follows, depending on node's interface:"
                // Document, Document Fragment: null
                var el = null;

                // "Element: node"
                if (node.nodeType == 1) {
                    el = node;

                    // "Text, Comment: node's parentElement"
                } else if (isCharacterDataNode(node)) {
                    el = dom.parentElement(node);
                }

                // "If either element is null or element's ownerDocument is an HTML document
                // and element's local name is "html" and element's namespace is the HTML
                // namespace"
                if (el === null || (
                        el.nodeName == "HTML" &&
                        dom.isHtmlNamespace(getDocument(el).documentElement) &&
                        dom.isHtmlNamespace(el)
                    )) {

                    // "let element be a new Element with "body" as its local name and the HTML
                    // namespace as its namespace.""
                    el = doc.createElement("body");
                } else {
                    el = el.cloneNode(false);
                }

                // "If the node's document is an HTML document: Invoke the HTML fragment parsing algorithm."
                // "If the node's document is an XML document: Invoke the XML fragment parsing algorithm."
                // "In either case, the algorithm must be invoked with fragment as the input
                // and element as the context element."
                el.innerHTML = fragmentStr;

                // "If this raises an exception, then abort these steps. Otherwise, let new
                // children be the nodes returned."

                // "Let fragment be a new DocumentFragment."
                // "Append all new children to fragment."
                // "Return fragment."
                return dom.fragmentFromNodeChildren(el);
            } :

            // In this case, innerHTML cannot be trusted, so fall back to a simpler, non-conformant implementation that
            // previous versions of Rangy used (with the exception of using a body element rather than a div)
            function(fragmentStr) {
                var doc = getRangeDocument(this);
                var el = doc.createElement("body");
                el.innerHTML = fragmentStr;

                return dom.fragmentFromNodeChildren(el);
            };

        function splitRangeBoundaries(range, positionsToPreserve) {
            assertRangeValid(range);

            var sc = range.startContainer,
                so = range.startOffset,
                ec = range.endContainer,
                eo = range.endOffset;
            var startEndSame = (sc === ec);

            if (isCharacterDataNode(ec) && eo > 0 && eo < ec.length) {
                splitDataNode(ec, eo, positionsToPreserve);
            }

            if (isCharacterDataNode(sc) && so > 0 && so < sc.length) {
                sc = splitDataNode(sc, so, positionsToPreserve);
                if (startEndSame) {
                    eo -= so;
                    ec = sc;
                } else if (ec == sc.parentNode && eo >= getNodeIndex(sc)) {
                    eo++;
                }
                so = 0;
            }
            range.setStartAndEnd(sc, so, ec, eo);
        }

        function rangeToHtml(range) {
            assertRangeValid(range);
            var container = range.commonAncestorContainer.parentNode.cloneNode(false);
            container.appendChild(range.cloneContents());
            return container.innerHTML;
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        var rangeProperties = ["startContainer", "startOffset", "endContainer", "endOffset", "collapsed",
            "commonAncestorContainer"
        ];

        var s2s = 0,
            s2e = 1,
            e2e = 2,
            e2s = 3;
        var n_b = 0,
            n_a = 1,
            n_b_a = 2,
            n_i = 3;

        util.extend(api.rangePrototype, {
            compareBoundaryPoints: function(how, range) {
                assertRangeValid(this);
                assertSameDocumentOrFragment(this.startContainer, range.startContainer);

                var nodeA, offsetA, nodeB, offsetB;
                var prefixA = (how == e2s || how == s2s) ? "start" : "end";
                var prefixB = (how == s2e || how == s2s) ? "start" : "end";
                nodeA = this[prefixA + "Container"];
                offsetA = this[prefixA + "Offset"];
                nodeB = range[prefixB + "Container"];
                offsetB = range[prefixB + "Offset"];
                return comparePoints(nodeA, offsetA, nodeB, offsetB);
            },

            insertNode: function(node) {
                assertRangeValid(this);
                assertValidNodeType(node, insertableNodeTypes);
                assertNodeNotReadOnly(this.startContainer);

                if (isOrIsAncestorOf(node, this.startContainer)) {
                    throw new DOMException("HIERARCHY_REQUEST_ERR");
                }

                // No check for whether the container of the start of the Range is of a type that does not allow
                // children of the type of node: the browser's DOM implementation should do this for us when we attempt
                // to add the node

                var firstNodeInserted = insertNodeAtPosition(node, this.startContainer, this.startOffset);
                this.setStartBefore(firstNodeInserted);
            },

            cloneContents: function() {
                assertRangeValid(this);

                var clone, frag;
                if (this.collapsed) {
                    return getRangeDocument(this).createDocumentFragment();
                } else {
                    if (this.startContainer === this.endContainer && isCharacterDataNode(this.startContainer)) {
                        clone = this.startContainer.cloneNode(true);
                        clone.data = clone.data.slice(this.startOffset, this.endOffset);
                        frag = getRangeDocument(this).createDocumentFragment();
                        frag.appendChild(clone);
                        return frag;
                    } else {
                        var iterator = new RangeIterator(this, true);
                        clone = cloneSubtree(iterator);
                        iterator.detach();
                    }
                    return clone;
                }
            },

            canSurroundContents: function() {
                assertRangeValid(this);
                assertNodeNotReadOnly(this.startContainer);
                assertNodeNotReadOnly(this.endContainer);

                // Check if the contents can be surrounded. Specifically, this means whether the range partially selects
                // no non-text nodes.
                var iterator = new RangeIterator(this, true);
                var boundariesInvalid = (iterator._first && (isNonTextPartiallySelected(iterator._first, this)) ||
                    (iterator._last && isNonTextPartiallySelected(iterator._last, this)));
                iterator.detach();
                return !boundariesInvalid;
            },

            surroundContents: function(node) {
                assertValidNodeType(node, surroundNodeTypes);

                if (!this.canSurroundContents()) {
                    throw new DOMException("INVALID_STATE_ERR");
                }

                // Extract the contents
                var content = this.extractContents();

                // Clear the children of the node
                if (node.hasChildNodes()) {
                    while (node.lastChild) {
                        node.removeChild(node.lastChild);
                    }
                }

                // Insert the new node and add the extracted contents
                insertNodeAtPosition(node, this.startContainer, this.startOffset);
                node.appendChild(content);

                this.selectNode(node);
            },

            cloneRange: function() {
                assertRangeValid(this);
                var range = new Range(getRangeDocument(this));
                var i = rangeProperties.length,
                    prop;
                while (i--) {
                    prop = rangeProperties[i];
                    range[prop] = this[prop];
                }
                return range;
            },

            toString: function() {
                assertRangeValid(this);
                var sc = this.startContainer;
                if (sc === this.endContainer && isCharacterDataNode(sc)) {
                    return (sc.nodeType == 3 || sc.nodeType == 4) ? sc.data.slice(this.startOffset, this.endOffset) : "";
                } else {
                    var textParts = [],
                        iterator = new RangeIterator(this, true);
                    iterateSubtree(iterator, function(node) {
                        // Accept only text or CDATA nodes, not comments
                        if (node.nodeType == 3 || node.nodeType == 4) {
                            textParts.push(node.data);
                        }
                    });
                    iterator.detach();
                    return textParts.join("");
                }
            },

            // The methods below are all non-standard. The following batch were introduced by Mozilla but have since
            // been removed from Mozilla.

            compareNode: function(node) {
                assertRangeValid(this);

                var parent = node.parentNode;
                var nodeIndex = getNodeIndex(node);

                if (!parent) {
                    throw new DOMException("NOT_FOUND_ERR");
                }

                var startComparison = this.comparePoint(parent, nodeIndex),
                    endComparison = this.comparePoint(parent, nodeIndex + 1);

                if (startComparison < 0) { // Node starts before
                    return (endComparison > 0) ? n_b_a : n_b;
                } else {
                    return (endComparison > 0) ? n_a : n_i;
                }
            },

            comparePoint: function(node, offset) {
                assertRangeValid(this);
                assertNode(node, "HIERARCHY_REQUEST_ERR");
                assertSameDocumentOrFragment(node, this.startContainer);

                if (comparePoints(node, offset, this.startContainer, this.startOffset) < 0) {
                    return -1;
                } else if (comparePoints(node, offset, this.endContainer, this.endOffset) > 0) {
                    return 1;
                }
                return 0;
            },

            createContextualFragment: createContextualFragment,

            toHtml: function() {
                return rangeToHtml(this);
            },

            // touchingIsIntersecting determines whether this method considers a node that borders a range intersects
            // with it (as in WebKit) or not (as in Gecko pre-1.9, and the default)
            intersectsNode: function(node, touchingIsIntersecting) {
                assertRangeValid(this);
                if (getRootContainer(node) != getRangeRoot(this)) {
                    return false;
                }

                var parent = node.parentNode,
                    offset = getNodeIndex(node);
                if (!parent) {
                    return true;
                }

                var startComparison = comparePoints(parent, offset, this.endContainer, this.endOffset),
                    endComparison = comparePoints(parent, offset + 1, this.startContainer, this.startOffset);

                return touchingIsIntersecting ? startComparison <= 0 && endComparison >= 0 : startComparison < 0 && endComparison > 0;
            },

            isPointInRange: function(node, offset) {
                assertRangeValid(this);
                assertNode(node, "HIERARCHY_REQUEST_ERR");
                assertSameDocumentOrFragment(node, this.startContainer);

                return (comparePoints(node, offset, this.startContainer, this.startOffset) >= 0) &&
                    (comparePoints(node, offset, this.endContainer, this.endOffset) <= 0);
            },

            // The methods below are non-standard and invented by me.

            // Sharing a boundary start-to-end or end-to-start does not count as intersection.
            intersectsRange: function(range) {
                return rangesIntersect(this, range, false);
            },

            // Sharing a boundary start-to-end or end-to-start does count as intersection.
            intersectsOrTouchesRange: function(range) {
                return rangesIntersect(this, range, true);
            },

            intersection: function(range) {
                if (this.intersectsRange(range)) {
                    var startComparison = comparePoints(this.startContainer, this.startOffset, range.startContainer, range.startOffset),
                        endComparison = comparePoints(this.endContainer, this.endOffset, range.endContainer, range.endOffset);

                    var intersectionRange = this.cloneRange();
                    if (startComparison == -1) {
                        intersectionRange.setStart(range.startContainer, range.startOffset);
                    }
                    if (endComparison == 1) {
                        intersectionRange.setEnd(range.endContainer, range.endOffset);
                    }
                    return intersectionRange;
                }
                return null;
            },

            union: function(range) {
                if (this.intersectsOrTouchesRange(range)) {
                    var unionRange = this.cloneRange();
                    if (comparePoints(range.startContainer, range.startOffset, this.startContainer, this.startOffset) == -1) {
                        unionRange.setStart(range.startContainer, range.startOffset);
                    }
                    if (comparePoints(range.endContainer, range.endOffset, this.endContainer, this.endOffset) == 1) {
                        unionRange.setEnd(range.endContainer, range.endOffset);
                    }
                    return unionRange;
                } else {
                    throw new DOMException("Ranges do not intersect");
                }
            },

            containsNode: function(node, allowPartial) {
                if (allowPartial) {
                    return this.intersectsNode(node, false);
                } else {
                    return this.compareNode(node) == n_i;
                }
            },

            containsNodeContents: function(node) {
                return this.comparePoint(node, 0) >= 0 && this.comparePoint(node, getNodeLength(node)) <= 0;
            },

            containsRange: function(range) {
                var intersection = this.intersection(range);
                return intersection !== null && range.equals(intersection);
            },

            containsNodeText: function(node) {
                var nodeRange = this.cloneRange();
                nodeRange.selectNode(node);
                var textNodes = nodeRange.getNodes([3]);
                if (textNodes.length > 0) {
                    nodeRange.setStart(textNodes[0], 0);
                    var lastTextNode = textNodes.pop();
                    nodeRange.setEnd(lastTextNode, lastTextNode.length);
                    return this.containsRange(nodeRange);
                } else {
                    return this.containsNodeContents(node);
                }
            },

            getNodes: function(nodeTypes, filter) {
                assertRangeValid(this);
                return getNodesInRange(this, nodeTypes, filter);
            },

            getDocument: function() {
                return getRangeDocument(this);
            },

            collapseBefore: function(node) {
                this.setEndBefore(node);
                this.collapse(false);
            },

            collapseAfter: function(node) {
                this.setStartAfter(node);
                this.collapse(true);
            },

            getBookmark: function(containerNode) {
                var doc = getRangeDocument(this);
                var preSelectionRange = api.createRange(doc);
                containerNode = containerNode || dom.getBody(doc);
                preSelectionRange.selectNodeContents(containerNode);
                var range = this.intersection(preSelectionRange);
                var start = 0,
                    end = 0;
                if (range) {
                    preSelectionRange.setEnd(range.startContainer, range.startOffset);
                    start = preSelectionRange.toString().length;
                    end = start + range.toString().length;
                }

                return {
                    start: start,
                    end: end,
                    containerNode: containerNode
                };
            },

            moveToBookmark: function(bookmark) {
                var containerNode = bookmark.containerNode;
                var charIndex = 0;
                this.setStart(containerNode, 0);
                this.collapse(true);
                var nodeStack = [containerNode],
                    node, foundStart = false,
                    stop = false;
                var nextCharIndex, i, childNodes;

                while (!stop && (node = nodeStack.pop())) {
                    if (node.nodeType == 3) {
                        nextCharIndex = charIndex + node.length;
                        if (!foundStart && bookmark.start >= charIndex && bookmark.start <= nextCharIndex) {
                            this.setStart(node, bookmark.start - charIndex);
                            foundStart = true;
                        }
                        if (foundStart && bookmark.end >= charIndex && bookmark.end <= nextCharIndex) {
                            this.setEnd(node, bookmark.end - charIndex);
                            stop = true;
                        }
                        charIndex = nextCharIndex;
                    } else {
                        childNodes = node.childNodes;
                        i = childNodes.length;
                        while (i--) {
                            nodeStack.push(childNodes[i]);
                        }
                    }
                }
            },

            getName: function() {
                return "DomRange";
            },

            equals: function(range) {
                return Range.rangesEqual(this, range);
            },

            isValid: function() {
                return isRangeValid(this);
            },

            inspect: function() {
                return inspect(this);
            },

            detach: function() {
                // In DOM4, detach() is now a no-op.
            }
        });

        function copyComparisonConstantsToObject(obj) {
            obj.START_TO_START = s2s;
            obj.START_TO_END = s2e;
            obj.END_TO_END = e2e;
            obj.END_TO_START = e2s;

            obj.NODE_BEFORE = n_b;
            obj.NODE_AFTER = n_a;
            obj.NODE_BEFORE_AND_AFTER = n_b_a;
            obj.NODE_INSIDE = n_i;
        }

        function copyComparisonConstants(constructor) {
            copyComparisonConstantsToObject(constructor);
            copyComparisonConstantsToObject(constructor.prototype);
        }

        function createRangeContentRemover(remover, boundaryUpdater) {
            return function() {
                assertRangeValid(this);

                var sc = this.startContainer,
                    so = this.startOffset,
                    root = this.commonAncestorContainer;

                var iterator = new RangeIterator(this, true);

                // Work out where to position the range after content removal
                var node, boundary;
                if (sc !== root) {
                    node = getClosestAncestorIn(sc, root, true);
                    boundary = getBoundaryAfterNode(node);
                    sc = boundary.node;
                    so = boundary.offset;
                }

                // Check none of the range is read-only
                iterateSubtree(iterator, assertNodeNotReadOnly);

                iterator.reset();

                // Remove the content
                var returnValue = remover(iterator);
                iterator.detach();

                // Move to the new position
                boundaryUpdater(this, sc, so, sc, so);

                return returnValue;
            };
        }

        function createPrototypeRange(constructor, boundaryUpdater) {
            function createBeforeAfterNodeSetter(isBefore, isStart) {
                return function(node) {
                    assertValidNodeType(node, beforeAfterNodeTypes);
                    assertValidNodeType(getRootContainer(node), rootContainerNodeTypes);

                    var boundary = (isBefore ? getBoundaryBeforeNode : getBoundaryAfterNode)(node);
                    (isStart ? setRangeStart : setRangeEnd)(this, boundary.node, boundary.offset);
                };
            }

            function setRangeStart(range, node, offset) {
                var ec = range.endContainer,
                    eo = range.endOffset;
                if (node !== range.startContainer || offset !== range.startOffset) {
                    // Check the root containers of the range and the new boundary, and also check whether the new boundary
                    // is after the current end. In either case, collapse the range to the new position
                    if (getRootContainer(node) != getRootContainer(ec) || comparePoints(node, offset, ec, eo) == 1) {
                        ec = node;
                        eo = offset;
                    }
                    boundaryUpdater(range, node, offset, ec, eo);
                }
            }

            function setRangeEnd(range, node, offset) {
                var sc = range.startContainer,
                    so = range.startOffset;
                if (node !== range.endContainer || offset !== range.endOffset) {
                    // Check the root containers of the range and the new boundary, and also check whether the new boundary
                    // is after the current end. In either case, collapse the range to the new position
                    if (getRootContainer(node) != getRootContainer(sc) || comparePoints(node, offset, sc, so) == -1) {
                        sc = node;
                        so = offset;
                    }
                    boundaryUpdater(range, sc, so, node, offset);
                }
            }

            // Set up inheritance
            var F = function() {};
            F.prototype = api.rangePrototype;
            constructor.prototype = new F();

            util.extend(constructor.prototype, {
                setStart: function(node, offset) {
                    assertNoDocTypeNotationEntityAncestor(node, true);
                    assertValidOffset(node, offset);

                    setRangeStart(this, node, offset);
                },

                setEnd: function(node, offset) {
                    assertNoDocTypeNotationEntityAncestor(node, true);
                    assertValidOffset(node, offset);

                    setRangeEnd(this, node, offset);
                },

                /**
                 * Convenience method to set a range's start and end boundaries. Overloaded as follows:
                 * - Two parameters (node, offset) creates a collapsed range at that position
                 * - Three parameters (node, startOffset, endOffset) creates a range contained with node starting at
                 *   startOffset and ending at endOffset
                 * - Four parameters (startNode, startOffset, endNode, endOffset) creates a range starting at startOffset in
                 *   startNode and ending at endOffset in endNode
                 */
                setStartAndEnd: function() {
                    var args = arguments;
                    var sc = args[0],
                        so = args[1],
                        ec = sc,
                        eo = so;

                    switch (args.length) {
                        case 3:
                            eo = args[2];
                            break;
                        case 4:
                            ec = args[2];
                            eo = args[3];
                            break;
                    }

                    boundaryUpdater(this, sc, so, ec, eo);
                },

                setBoundary: function(node, offset, isStart) {
                    this["set" + (isStart ? "Start" : "End")](node, offset);
                },

                setStartBefore: createBeforeAfterNodeSetter(true, true),
                setStartAfter: createBeforeAfterNodeSetter(false, true),
                setEndBefore: createBeforeAfterNodeSetter(true, false),
                setEndAfter: createBeforeAfterNodeSetter(false, false),

                collapse: function(isStart) {
                    assertRangeValid(this);
                    if (isStart) {
                        boundaryUpdater(this, this.startContainer, this.startOffset, this.startContainer, this.startOffset);
                    } else {
                        boundaryUpdater(this, this.endContainer, this.endOffset, this.endContainer, this.endOffset);
                    }
                },

                selectNodeContents: function(node) {
                    assertNoDocTypeNotationEntityAncestor(node, true);

                    boundaryUpdater(this, node, 0, node, getNodeLength(node));
                },

                selectNode: function(node) {
                    assertNoDocTypeNotationEntityAncestor(node, false);
                    assertValidNodeType(node, beforeAfterNodeTypes);

                    var start = getBoundaryBeforeNode(node),
                        end = getBoundaryAfterNode(node);
                    boundaryUpdater(this, start.node, start.offset, end.node, end.offset);
                },

                extractContents: createRangeContentRemover(extractSubtree, boundaryUpdater),

                deleteContents: createRangeContentRemover(deleteSubtree, boundaryUpdater),

                canSurroundContents: function() {
                    assertRangeValid(this);
                    assertNodeNotReadOnly(this.startContainer);
                    assertNodeNotReadOnly(this.endContainer);

                    // Check if the contents can be surrounded. Specifically, this means whether the range partially selects
                    // no non-text nodes.
                    var iterator = new RangeIterator(this, true);
                    var boundariesInvalid = (iterator._first && isNonTextPartiallySelected(iterator._first, this) ||
                        (iterator._last && isNonTextPartiallySelected(iterator._last, this)));
                    iterator.detach();
                    return !boundariesInvalid;
                },

                splitBoundaries: function() {
                    splitRangeBoundaries(this);
                },

                splitBoundariesPreservingPositions: function(positionsToPreserve) {
                    splitRangeBoundaries(this, positionsToPreserve);
                },

                normalizeBoundaries: function() {
                    assertRangeValid(this);

                    var sc = this.startContainer,
                        so = this.startOffset,
                        ec = this.endContainer,
                        eo = this.endOffset;

                    var mergeForward = function(node) {
                        var sibling = node.nextSibling;
                        if (sibling && sibling.nodeType == node.nodeType) {
                            ec = node;
                            eo = node.length;
                            node.appendData(sibling.data);
                            removeNode(sibling);
                        }
                    };

                    var mergeBackward = function(node) {
                        var sibling = node.previousSibling;
                        if (sibling && sibling.nodeType == node.nodeType) {
                            sc = node;
                            var nodeLength = node.length;
                            so = sibling.length;
                            node.insertData(0, sibling.data);
                            removeNode(sibling);
                            if (sc == ec) {
                                eo += so;
                                ec = sc;
                            } else if (ec == node.parentNode) {
                                var nodeIndex = getNodeIndex(node);
                                if (eo == nodeIndex) {
                                    ec = node;
                                    eo = nodeLength;
                                } else if (eo > nodeIndex) {
                                    eo--;
                                }
                            }
                        }
                    };

                    var normalizeStart = true;
                    var sibling;

                    if (isCharacterDataNode(ec)) {
                        if (eo == ec.length) {
                            mergeForward(ec);
                        } else if (eo == 0) {
                            sibling = ec.previousSibling;
                            if (sibling && sibling.nodeType == ec.nodeType) {
                                eo = sibling.length;
                                if (sc == ec) {
                                    normalizeStart = false;
                                }
                                sibling.appendData(ec.data);
                                removeNode(ec);
                                ec = sibling;
                            }
                        }
                    } else {
                        if (eo > 0) {
                            var endNode = ec.childNodes[eo - 1];
                            if (endNode && isCharacterDataNode(endNode)) {
                                mergeForward(endNode);
                            }
                        }
                        normalizeStart = !this.collapsed;
                    }

                    if (normalizeStart) {
                        if (isCharacterDataNode(sc)) {
                            if (so == 0) {
                                mergeBackward(sc);
                            } else if (so == sc.length) {
                                sibling = sc.nextSibling;
                                if (sibling && sibling.nodeType == sc.nodeType) {
                                    if (ec == sibling) {
                                        ec = sc;
                                        eo += sc.length;
                                    }
                                    sc.appendData(sibling.data);
                                    removeNode(sibling);
                                }
                            }
                        } else {
                            if (so < sc.childNodes.length) {
                                var startNode = sc.childNodes[so];
                                if (startNode && isCharacterDataNode(startNode)) {
                                    mergeBackward(startNode);
                                }
                            }
                        }
                    } else {
                        sc = ec;
                        so = eo;
                    }

                    boundaryUpdater(this, sc, so, ec, eo);
                },

                collapseToPoint: function(node, offset) {
                    assertNoDocTypeNotationEntityAncestor(node, true);
                    assertValidOffset(node, offset);
                    this.setStartAndEnd(node, offset);
                }
            });

            copyComparisonConstants(constructor);
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // Updates commonAncestorContainer and collapsed after boundary change
        function updateCollapsedAndCommonAncestor(range) {
            range.collapsed = (range.startContainer === range.endContainer && range.startOffset === range.endOffset);
            range.commonAncestorContainer = range.collapsed ?
                range.startContainer : dom.getCommonAncestor(range.startContainer, range.endContainer);
        }

        function updateBoundaries(range, startContainer, startOffset, endContainer, endOffset) {
            range.startContainer = startContainer;
            range.startOffset = startOffset;
            range.endContainer = endContainer;
            range.endOffset = endOffset;
            range.document = dom.getDocument(startContainer);

            updateCollapsedAndCommonAncestor(range);
        }

        function Range(doc) {
            this.startContainer = doc;
            this.startOffset = 0;
            this.endContainer = doc;
            this.endOffset = 0;
            this.document = doc;
            updateCollapsedAndCommonAncestor(this);
        }

        createPrototypeRange(Range, updateBoundaries);

        util.extend(Range, {
            rangeProperties: rangeProperties,
            RangeIterator: RangeIterator,
            copyComparisonConstants: copyComparisonConstants,
            createPrototypeRange: createPrototypeRange,
            inspect: inspect,
            toHtml: rangeToHtml,
            getRangeDocument: getRangeDocument,
            rangesEqual: function(r1, r2) {
                return r1.startContainer === r2.startContainer &&
                    r1.startOffset === r2.startOffset &&
                    r1.endContainer === r2.endContainer &&
                    r1.endOffset === r2.endOffset;
            }
        });

        api.DomRange = Range;
    });

    /*----------------------------------------------------------------------------------------------------------------*/

    // Wrappers for the browser's native DOM Range and/or TextRange implementation
    api.createCoreModule("WrappedRange", ["DomRange"], function(api, module) {
        var WrappedRange, WrappedTextRange;
        var dom = api.dom;
        var util = api.util;
        var DomPosition = dom.DomPosition;
        var DomRange = api.DomRange;
        var getBody = dom.getBody;
        var getContentDocument = dom.getContentDocument;
        var isCharacterDataNode = dom.isCharacterDataNode;


        /*----------------------------------------------------------------------------------------------------------------*/

        if (api.features.implementsDomRange) {
            // This is a wrapper around the browser's native DOM Range. It has two aims:
            // - Provide workarounds for specific browser bugs
            // - provide convenient extensions, which are inherited from Rangy's DomRange

            (function() {
                var rangeProto;
                var rangeProperties = DomRange.rangeProperties;

                function updateRangeProperties(range) {
                    var i = rangeProperties.length,
                        prop;
                    while (i--) {
                        prop = rangeProperties[i];
                        range[prop] = range.nativeRange[prop];
                    }
                    // Fix for broken collapsed property in IE 9.
                    range.collapsed = (range.startContainer === range.endContainer && range.startOffset === range.endOffset);
                }

                function updateNativeRange(range, startContainer, startOffset, endContainer, endOffset) {
                    var startMoved = (range.startContainer !== startContainer || range.startOffset != startOffset);
                    var endMoved = (range.endContainer !== endContainer || range.endOffset != endOffset);
                    var nativeRangeDifferent = !range.equals(range.nativeRange);

                    // Always set both boundaries for the benefit of IE9 (see issue 35)
                    if (startMoved || endMoved || nativeRangeDifferent) {
                        range.setEnd(endContainer, endOffset);
                        range.setStart(startContainer, startOffset);
                    }
                }

                var createBeforeAfterNodeSetter;

                WrappedRange = function(range) {
                    if (!range) {
                        throw module.createError("WrappedRange: Range must be specified");
                    }
                    this.nativeRange = range;
                    updateRangeProperties(this);
                };

                DomRange.createPrototypeRange(WrappedRange, updateNativeRange);

                rangeProto = WrappedRange.prototype;

                rangeProto.selectNode = function(node) {
                    this.nativeRange.selectNode(node);
                    updateRangeProperties(this);
                };

                rangeProto.cloneContents = function() {
                    return this.nativeRange.cloneContents();
                };

                // Due to a long-standing Firefox bug that I have not been able to find a reliable way to detect,
                // insertNode() is never delegated to the native range.

                rangeProto.surroundContents = function(node) {
                    this.nativeRange.surroundContents(node);
                    updateRangeProperties(this);
                };

                rangeProto.collapse = function(isStart) {
                    this.nativeRange.collapse(isStart);
                    updateRangeProperties(this);
                };

                rangeProto.cloneRange = function() {
                    return new WrappedRange(this.nativeRange.cloneRange());
                };

                rangeProto.refresh = function() {
                    updateRangeProperties(this);
                };

                rangeProto.toString = function() {
                    return this.nativeRange.toString();
                };

                // Create test range and node for feature detection

                var testTextNode = document.createTextNode("test");
                getBody(document).appendChild(testTextNode);
                var range = document.createRange();

                /*--------------------------------------------------------------------------------------------------------*/

                // Test for Firefox 2 bug that prevents moving the start of a Range to a point after its current end and
                // correct for it

                range.setStart(testTextNode, 0);
                range.setEnd(testTextNode, 0);

                try {
                    range.setStart(testTextNode, 1);

                    rangeProto.setStart = function(node, offset) {
                        this.nativeRange.setStart(node, offset);
                        updateRangeProperties(this);
                    };

                    rangeProto.setEnd = function(node, offset) {
                        this.nativeRange.setEnd(node, offset);
                        updateRangeProperties(this);
                    };

                    createBeforeAfterNodeSetter = function(name) {
                        return function(node) {
                            this.nativeRange[name](node);
                            updateRangeProperties(this);
                        };
                    };

                } catch (ex) {

                    rangeProto.setStart = function(node, offset) {
                        try {
                            this.nativeRange.setStart(node, offset);
                        } catch (ex) {
                            this.nativeRange.setEnd(node, offset);
                            this.nativeRange.setStart(node, offset);
                        }
                        updateRangeProperties(this);
                    };

                    rangeProto.setEnd = function(node, offset) {
                        try {
                            this.nativeRange.setEnd(node, offset);
                        } catch (ex) {
                            this.nativeRange.setStart(node, offset);
                            this.nativeRange.setEnd(node, offset);
                        }
                        updateRangeProperties(this);
                    };

                    createBeforeAfterNodeSetter = function(name, oppositeName) {
                        return function(node) {
                            try {
                                this.nativeRange[name](node);
                            } catch (ex) {
                                this.nativeRange[oppositeName](node);
                                this.nativeRange[name](node);
                            }
                            updateRangeProperties(this);
                        };
                    };
                }

                rangeProto.setStartBefore = createBeforeAfterNodeSetter("setStartBefore", "setEndBefore");
                rangeProto.setStartAfter = createBeforeAfterNodeSetter("setStartAfter", "setEndAfter");
                rangeProto.setEndBefore = createBeforeAfterNodeSetter("setEndBefore", "setStartBefore");
                rangeProto.setEndAfter = createBeforeAfterNodeSetter("setEndAfter", "setStartAfter");

                /*--------------------------------------------------------------------------------------------------------*/

                // Always use DOM4-compliant selectNodeContents implementation: it's simpler and less code than testing
                // whether the native implementation can be trusted
                rangeProto.selectNodeContents = function(node) {
                    this.setStartAndEnd(node, 0, dom.getNodeLength(node));
                };

                /*--------------------------------------------------------------------------------------------------------*/

                // Test for and correct WebKit bug that has the behaviour of compareBoundaryPoints round the wrong way for
                // constants START_TO_END and END_TO_START: https://bugs.webkit.org/show_bug.cgi?id=20738

                range.selectNodeContents(testTextNode);
                range.setEnd(testTextNode, 3);

                var range2 = document.createRange();
                range2.selectNodeContents(testTextNode);
                range2.setEnd(testTextNode, 4);
                range2.setStart(testTextNode, 2);

                if (range.compareBoundaryPoints(range.START_TO_END, range2) == -1 &&
                    range.compareBoundaryPoints(range.END_TO_START, range2) == 1) {
                    // This is the wrong way round, so correct for it

                    rangeProto.compareBoundaryPoints = function(type, range) {
                        range = range.nativeRange || range;
                        if (type == range.START_TO_END) {
                            type = range.END_TO_START;
                        } else if (type == range.END_TO_START) {
                            type = range.START_TO_END;
                        }
                        return this.nativeRange.compareBoundaryPoints(type, range);
                    };
                } else {
                    rangeProto.compareBoundaryPoints = function(type, range) {
                        return this.nativeRange.compareBoundaryPoints(type, range.nativeRange || range);
                    };
                }

                /*--------------------------------------------------------------------------------------------------------*/

                // Test for IE deleteContents() and extractContents() bug and correct it. See issue 107.

                var el = document.createElement("div");
                el.innerHTML = "123";
                var textNode = el.firstChild;
                var body = getBody(document);
                body.appendChild(el);

                range.setStart(textNode, 1);
                range.setEnd(textNode, 2);
                range.deleteContents();

                if (textNode.data == "13") {
                    // Behaviour is correct per DOM4 Range so wrap the browser's implementation of deleteContents() and
                    // extractContents()
                    rangeProto.deleteContents = function() {
                        this.nativeRange.deleteContents();
                        updateRangeProperties(this);
                    };

                    rangeProto.extractContents = function() {
                        var frag = this.nativeRange.extractContents();
                        updateRangeProperties(this);
                        return frag;
                    };
                } else {}

                body.removeChild(el);
                body = null;

                /*--------------------------------------------------------------------------------------------------------*/

                // Test for existence of createContextualFragment and delegate to it if it exists
                if (util.isHostMethod(range, "createContextualFragment")) {
                    rangeProto.createContextualFragment = function(fragmentStr) {
                        return this.nativeRange.createContextualFragment(fragmentStr);
                    };
                }

                /*--------------------------------------------------------------------------------------------------------*/

                // Clean up
                getBody(document).removeChild(testTextNode);

                rangeProto.getName = function() {
                    return "WrappedRange";
                };

                api.WrappedRange = WrappedRange;

                api.createNativeRange = function(doc) {
                    doc = getContentDocument(doc, module, "createNativeRange");
                    return doc.createRange();
                };
            })();
        }

        if (api.features.implementsTextRange) {
            /*
            This is a workaround for a bug where IE returns the wrong container element from the TextRange's parentElement()
            method. For example, in the following (where pipes denote the selection boundaries):

            <ul id="ul"><li id="a">| a </li><li id="b"> b |</li></ul>

            var range = document.selection.createRange();
            alert(range.parentElement().id); // Should alert "ul" but alerts "b"

            This method returns the common ancestor node of the following:
            - the parentElement() of the textRange
            - the parentElement() of the textRange after calling collapse(true)
            - the parentElement() of the textRange after calling collapse(false)
            */
            var getTextRangeContainerElement = function(textRange) {
                var parentEl = textRange.parentElement();
                var range = textRange.duplicate();
                range.collapse(true);
                var startEl = range.parentElement();
                range = textRange.duplicate();
                range.collapse(false);
                var endEl = range.parentElement();
                var startEndContainer = (startEl == endEl) ? startEl : dom.getCommonAncestor(startEl, endEl);

                return startEndContainer == parentEl ? startEndContainer : dom.getCommonAncestor(parentEl, startEndContainer);
            };

            var textRangeIsCollapsed = function(textRange) {
                return textRange.compareEndPoints("StartToEnd", textRange) == 0;
            };

            // Gets the boundary of a TextRange expressed as a node and an offset within that node. This function started
            // out as an improved version of code found in Tim Cameron Ryan's IERange (http://code.google.com/p/ierange/)
            // but has grown, fixing problems with line breaks in preformatted text, adding workaround for IE TextRange
            // bugs, handling for inputs and images, plus optimizations.
            var getTextRangeBoundaryPosition = function(textRange, wholeRangeContainerElement, isStart, isCollapsed, startInfo) {
                var workingRange = textRange.duplicate();
                workingRange.collapse(isStart);
                var containerElement = workingRange.parentElement();

                // Sometimes collapsing a TextRange that's at the start of a text node can move it into the previous node, so
                // check for that
                if (!dom.isOrIsAncestorOf(wholeRangeContainerElement, containerElement)) {
                    containerElement = wholeRangeContainerElement;
                }


                // Deal with nodes that cannot "contain rich HTML markup". In practice, this means form inputs, images and
                // similar. See http://msdn.microsoft.com/en-us/library/aa703950%28VS.85%29.aspx
                if (!containerElement.canHaveHTML) {
                    var pos = new DomPosition(containerElement.parentNode, dom.getNodeIndex(containerElement));
                    return {
                        boundaryPosition: pos,
                        nodeInfo: {
                            nodeIndex: pos.offset,
                            containerElement: pos.node
                        }
                    };
                }

                var workingNode = dom.getDocument(containerElement).createElement("span");

                // Workaround for HTML5 Shiv's insane violation of document.createElement(). See Rangy issue 104 and HTML5
                // Shiv issue 64: https://github.com/aFarkas/html5shiv/issues/64
                if (workingNode.parentNode) {
                    dom.removeNode(workingNode);
                }

                var comparison, workingComparisonType = isStart ? "StartToStart" : "StartToEnd";
                var previousNode, nextNode, boundaryPosition, boundaryNode;
                var start = (startInfo && startInfo.containerElement == containerElement) ? startInfo.nodeIndex : 0;
                var childNodeCount = containerElement.childNodes.length;
                var end = childNodeCount;

                // Check end first. Code within the loop assumes that the endth child node of the container is definitely
                // after the range boundary.
                var nodeIndex = end;

                while (true) {
                    if (nodeIndex == childNodeCount) {
                        containerElement.appendChild(workingNode);
                    } else {
                        containerElement.insertBefore(workingNode, containerElement.childNodes[nodeIndex]);
                    }
                    workingRange.moveToElementText(workingNode);
                    comparison = workingRange.compareEndPoints(workingComparisonType, textRange);
                    if (comparison == 0 || start == end) {
                        break;
                    } else if (comparison == -1) {
                        if (end == start + 1) {
                            // We know the endth child node is after the range boundary, so we must be done.
                            break;
                        } else {
                            start = nodeIndex;
                        }
                    } else {
                        end = (end == start + 1) ? start : nodeIndex;
                    }
                    nodeIndex = Math.floor((start + end) / 2);
                    containerElement.removeChild(workingNode);
                }


                // We've now reached or gone past the boundary of the text range we're interested in
                // so have identified the node we want
                boundaryNode = workingNode.nextSibling;

                if (comparison == -1 && boundaryNode && isCharacterDataNode(boundaryNode)) {
                    // This is a character data node (text, comment, cdata). The working range is collapsed at the start of
                    // the node containing the text range's boundary, so we move the end of the working range to the
                    // boundary point and measure the length of its text to get the boundary's offset within the node.
                    workingRange.setEndPoint(isStart ? "EndToStart" : "EndToEnd", textRange);

                    var offset;

                    if (/[\r\n]/.test(boundaryNode.data)) {
                        /*
                        For the particular case of a boundary within a text node containing rendered line breaks (within a
                        <pre> element, for example), we need a slightly complicated approach to get the boundary's offset in
                        IE. The facts:

                        - Each line break is represented as \r in the text node's data/nodeValue properties
                        - Each line break is represented as \r\n in the TextRange's 'text' property
                        - The 'text' property of the TextRange does not contain trailing line breaks

                        To get round the problem presented by the final fact above, we can use the fact that TextRange's
                        moveStart() and moveEnd() methods return the actual number of characters moved, which is not
                        necessarily the same as the number of characters it was instructed to move. The simplest approach is
                        to use this to store the characters moved when moving both the start and end of the range to the
                        start of the document body and subtracting the start offset from the end offset (the
                        "move-negative-gazillion" method). However, this is extremely slow when the document is large and
                        the range is near the end of it. Clearly doing the mirror image (i.e. moving the range boundaries to
                        the end of the document) has the same problem.

                        Another approach that works is to use moveStart() to move the start boundary of the range up to the
                        end boundary one character at a time and incrementing a counter with the value returned by the
                        moveStart() call. However, the check for whether the start boundary has reached the end boundary is
                        expensive, so this method is slow (although unlike "move-negative-gazillion" is largely unaffected
                        by the location of the range within the document).

                        The approach used below is a hybrid of the two methods above. It uses the fact that a string
                        containing the TextRange's 'text' property with each \r\n converted to a single \r character cannot
                        be longer than the text of the TextRange, so the start of the range is moved that length initially
                        and then a character at a time to make up for any trailing line breaks not contained in the 'text'
                        property. This has good performance in most situations compared to the previous two methods.
                        */
                        var tempRange = workingRange.duplicate();
                        var rangeLength = tempRange.text.replace(/\r\n/g, "\r").length;

                        offset = tempRange.moveStart("character", rangeLength);
                        while ((comparison = tempRange.compareEndPoints("StartToEnd", tempRange)) == -1) {
                            offset++;
                            tempRange.moveStart("character", 1);
                        }
                    } else {
                        offset = workingRange.text.length;
                    }
                    boundaryPosition = new DomPosition(boundaryNode, offset);
                } else {

                    // If the boundary immediately follows a character data node and this is the end boundary, we should favour
                    // a position within that, and likewise for a start boundary preceding a character data node
                    previousNode = (isCollapsed || !isStart) && workingNode.previousSibling;
                    nextNode = (isCollapsed || isStart) && workingNode.nextSibling;
                    if (nextNode && isCharacterDataNode(nextNode)) {
                        boundaryPosition = new DomPosition(nextNode, 0);
                    } else if (previousNode && isCharacterDataNode(previousNode)) {
                        boundaryPosition = new DomPosition(previousNode, previousNode.data.length);
                    } else {
                        boundaryPosition = new DomPosition(containerElement, dom.getNodeIndex(workingNode));
                    }
                }

                // Clean up
                dom.removeNode(workingNode);

                return {
                    boundaryPosition: boundaryPosition,
                    nodeInfo: {
                        nodeIndex: nodeIndex,
                        containerElement: containerElement
                    }
                };
            };

            // Returns a TextRange representing the boundary of a TextRange expressed as a node and an offset within that
            // node. This function started out as an optimized version of code found in Tim Cameron Ryan's IERange
            // (http://code.google.com/p/ierange/)
            var createBoundaryTextRange = function(boundaryPosition, isStart) {
                var boundaryNode, boundaryParent, boundaryOffset = boundaryPosition.offset;
                var doc = dom.getDocument(boundaryPosition.node);
                var workingNode, childNodes, workingRange = getBody(doc).createTextRange();
                var nodeIsDataNode = isCharacterDataNode(boundaryPosition.node);

                if (nodeIsDataNode) {
                    boundaryNode = boundaryPosition.node;
                    boundaryParent = boundaryNode.parentNode;
                } else {
                    childNodes = boundaryPosition.node.childNodes;
                    boundaryNode = (boundaryOffset < childNodes.length) ? childNodes[boundaryOffset] : null;
                    boundaryParent = boundaryPosition.node;
                }

                // Position the range immediately before the node containing the boundary
                workingNode = doc.createElement("span");

                // Making the working element non-empty element persuades IE to consider the TextRange boundary to be within
                // the element rather than immediately before or after it
                workingNode.innerHTML = "&#feff;";

                // insertBefore is supposed to work like appendChild if the second parameter is null. However, a bug report
                // for IERange suggests that it can crash the browser: http://code.google.com/p/ierange/issues/detail?id=12
                if (boundaryNode) {
                    boundaryParent.insertBefore(workingNode, boundaryNode);
                } else {
                    boundaryParent.appendChild(workingNode);
                }

                workingRange.moveToElementText(workingNode);
                workingRange.collapse(!isStart);

                // Clean up
                boundaryParent.removeChild(workingNode);

                // Move the working range to the text offset, if required
                if (nodeIsDataNode) {
                    workingRange[isStart ? "moveStart" : "moveEnd"]("character", boundaryOffset);
                }

                return workingRange;
            };

            /*------------------------------------------------------------------------------------------------------------*/

            // This is a wrapper around a TextRange, providing full DOM Range functionality using rangy's DomRange as a
            // prototype

            WrappedTextRange = function(textRange) {
                this.textRange = textRange;
                this.refresh();
            };

            WrappedTextRange.prototype = new DomRange(document);

            WrappedTextRange.prototype.refresh = function() {
                var start, end, startBoundary;

                // TextRange's parentElement() method cannot be trusted. getTextRangeContainerElement() works around that.
                var rangeContainerElement = getTextRangeContainerElement(this.textRange);

                if (textRangeIsCollapsed(this.textRange)) {
                    end = start = getTextRangeBoundaryPosition(this.textRange, rangeContainerElement, true,
                        true).boundaryPosition;
                } else {
                    startBoundary = getTextRangeBoundaryPosition(this.textRange, rangeContainerElement, true, false);
                    start = startBoundary.boundaryPosition;

                    // An optimization used here is that if the start and end boundaries have the same parent element, the
                    // search scope for the end boundary can be limited to exclude the portion of the element that precedes
                    // the start boundary
                    end = getTextRangeBoundaryPosition(this.textRange, rangeContainerElement, false, false,
                        startBoundary.nodeInfo).boundaryPosition;
                }

                this.setStart(start.node, start.offset);
                this.setEnd(end.node, end.offset);
            };

            WrappedTextRange.prototype.getName = function() {
                return "WrappedTextRange";
            };

            DomRange.copyComparisonConstants(WrappedTextRange);

            var rangeToTextRange = function(range) {
                if (range.collapsed) {
                    return createBoundaryTextRange(new DomPosition(range.startContainer, range.startOffset), true);
                } else {
                    var startRange = createBoundaryTextRange(new DomPosition(range.startContainer, range.startOffset), true);
                    var endRange = createBoundaryTextRange(new DomPosition(range.endContainer, range.endOffset), false);
                    var textRange = getBody(DomRange.getRangeDocument(range)).createTextRange();
                    textRange.setEndPoint("StartToStart", startRange);
                    textRange.setEndPoint("EndToEnd", endRange);
                    return textRange;
                }
            };

            WrappedTextRange.rangeToTextRange = rangeToTextRange;

            WrappedTextRange.prototype.toTextRange = function() {
                return rangeToTextRange(this);
            };

            api.WrappedTextRange = WrappedTextRange;

            // IE 9 and above have both implementations and Rangy makes both available. The next few lines sets which
            // implementation to use by default.
            if (!api.features.implementsDomRange || api.config.preferTextRange) {
                // Add WrappedTextRange as the Range property of the global object to allow expression like Range.END_TO_END to work
                var globalObj = (function(f) {
                    return f("return this;")();
                })(Function);
                if (typeof globalObj.Range == "undefined") {
                    globalObj.Range = WrappedTextRange;
                }

                api.createNativeRange = function(doc) {
                    doc = getContentDocument(doc, module, "createNativeRange");
                    return getBody(doc).createTextRange();
                };

                api.WrappedRange = WrappedTextRange;
            }
        }

        api.createRange = function(doc) {
            doc = getContentDocument(doc, module, "createRange");
            return new api.WrappedRange(api.createNativeRange(doc));
        };

        api.createRangyRange = function(doc) {
            doc = getContentDocument(doc, module, "createRangyRange");
            return new DomRange(doc);
        };

        util.createAliasForDeprecatedMethod(api, "createIframeRange", "createRange");
        util.createAliasForDeprecatedMethod(api, "createIframeRangyRange", "createRangyRange");

        api.addShimListener(function(win) {
            var doc = win.document;
            if (typeof doc.createRange == "undefined") {
                doc.createRange = function() {
                    return api.createRange(doc);
                };
            }
            doc = win = null;
        });
    });

    /*----------------------------------------------------------------------------------------------------------------*/

    // This module creates a selection object wrapper that conforms as closely as possible to the Selection specification
    // in the HTML Editing spec (http://dvcs.w3.org/hg/editing/raw-file/tip/editing.html#selections)
    api.createCoreModule("WrappedSelection", ["DomRange", "WrappedRange"], function(api, module) {
        api.config.checkSelectionRanges = true;

        var BOOLEAN = "boolean";
        var NUMBER = "number";
        var dom = api.dom;
        var util = api.util;
        var isHostMethod = util.isHostMethod;
        var DomRange = api.DomRange;
        var WrappedRange = api.WrappedRange;
        var DOMException = api.DOMException;
        var DomPosition = dom.DomPosition;
        var getNativeSelection;
        var selectionIsCollapsed;
        var features = api.features;
        var CONTROL = "Control";
        var getDocument = dom.getDocument;
        var getBody = dom.getBody;
        var rangesEqual = DomRange.rangesEqual;


        // Utility function to support direction parameters in the API that may be a string ("backward", "backwards",
        // "forward" or "forwards") or a Boolean (true for backwards).
        function isDirectionBackward(dir) {
            return (typeof dir == "string") ? /^backward(s)?$/i.test(dir) : !!dir;
        }

        function getWindow(win, methodName) {
            if (!win) {
                return window;
            } else if (dom.isWindow(win)) {
                return win;
            } else if (win instanceof WrappedSelection) {
                return win.win;
            } else {
                var doc = dom.getContentDocument(win, module, methodName);
                return dom.getWindow(doc);
            }
        }

        function getWinSelection(winParam) {
            return getWindow(winParam, "getWinSelection").getSelection();
        }

        function getDocSelection(winParam) {
            return getWindow(winParam, "getDocSelection").document.selection;
        }

        function winSelectionIsBackward(sel) {
            var backward = false;
            if (sel.anchorNode) {
                backward = (dom.comparePoints(sel.anchorNode, sel.anchorOffset, sel.focusNode, sel.focusOffset) == 1);
            }
            return backward;
        }

        // Test for the Range/TextRange and Selection features required
        // Test for ability to retrieve selection
        var implementsWinGetSelection = isHostMethod(window, "getSelection"),
            implementsDocSelection = util.isHostObject(document, "selection");

        features.implementsWinGetSelection = implementsWinGetSelection;
        features.implementsDocSelection = implementsDocSelection;

        var useDocumentSelection = implementsDocSelection && (!implementsWinGetSelection || api.config.preferTextRange);

        if (useDocumentSelection) {
            getNativeSelection = getDocSelection;
            api.isSelectionValid = function(winParam) {
                var doc = getWindow(winParam, "isSelectionValid").document,
                    nativeSel = doc.selection;

                // Check whether the selection TextRange is actually contained within the correct document
                return (nativeSel.type != "None" || getDocument(nativeSel.createRange().parentElement()) == doc);
            };
        } else if (implementsWinGetSelection) {
            getNativeSelection = getWinSelection;
            api.isSelectionValid = function() {
                return true;
            };
        } else {
            module.fail("Neither document.selection or window.getSelection() detected.");
            return false;
        }

        api.getNativeSelection = getNativeSelection;

        var testSelection = getNativeSelection();

        // In Firefox, the selection is null in an iframe with display: none. See issue #138.
        if (!testSelection) {
            module.fail("Native selection was null (possibly issue 138?)");
            return false;
        }

        var testRange = api.createNativeRange(document);
        var body = getBody(document);

        // Obtaining a range from a selection
        var selectionHasAnchorAndFocus = util.areHostProperties(testSelection, ["anchorNode", "focusNode", "anchorOffset", "focusOffset"]);

        features.selectionHasAnchorAndFocus = selectionHasAnchorAndFocus;

        // Test for existence of native selection extend() method
        var selectionHasExtend = isHostMethod(testSelection, "extend");
        features.selectionHasExtend = selectionHasExtend;

        // Test if rangeCount exists
        var selectionHasRangeCount = (typeof testSelection.rangeCount == NUMBER);
        features.selectionHasRangeCount = selectionHasRangeCount;

        var selectionSupportsMultipleRanges = false;
        var collapsedNonEditableSelectionsSupported = true;

        var addRangeBackwardToNative = selectionHasExtend ?
            function(nativeSelection, range) {
                var doc = DomRange.getRangeDocument(range);
                var endRange = api.createRange(doc);
                endRange.collapseToPoint(range.endContainer, range.endOffset);
                nativeSelection.addRange(getNativeRange(endRange));
                nativeSelection.extend(range.startContainer, range.startOffset);
            } : null;

        if (util.areHostMethods(testSelection, ["addRange", "getRangeAt", "removeAllRanges"]) &&
            typeof testSelection.rangeCount == NUMBER && features.implementsDomRange) {

            (function() {
                // Previously an iframe was used but this caused problems in some circumstances in IE, so tests are
                // performed on the current document's selection. See issue 109.

                // Note also that if a selection previously existed, it is wiped and later restored by these tests. This
                // will result in the selection direction begin reversed if the original selection was backwards and the
                // browser does not support setting backwards selections (Internet Explorer, I'm looking at you).
                var sel = window.getSelection();
                if (sel) {
                    // Store the current selection
                    var originalSelectionRangeCount = sel.rangeCount;
                    var selectionHasMultipleRanges = (originalSelectionRangeCount > 1);
                    var originalSelectionRanges = [];
                    var originalSelectionBackward = winSelectionIsBackward(sel);
                    for (var i = 0; i < originalSelectionRangeCount; ++i) {
                        originalSelectionRanges[i] = sel.getRangeAt(i);
                    }

                    // Create some test elements
                    var testEl = dom.createTestElement(document, "", false);
                    var textNode = testEl.appendChild(document.createTextNode("\u00a0\u00a0\u00a0"));

                    // Test whether the native selection will allow a collapsed selection within a non-editable element
                    var r1 = document.createRange();

                    r1.setStart(textNode, 1);
                    r1.collapse(true);
                    sel.removeAllRanges();
                    sel.addRange(r1);
                    collapsedNonEditableSelectionsSupported = (sel.rangeCount == 1);
                    sel.removeAllRanges();

                    // Test whether the native selection is capable of supporting multiple ranges.
                    if (!selectionHasMultipleRanges) {
                        // Doing the original feature test here in Chrome 36 (and presumably later versions) prints a
                        // console error of "Discontiguous selection is not supported." that cannot be suppressed. There's
                        // nothing we can do about this while retaining the feature test so we have to resort to a browser
                        // sniff. I'm not happy about it. See
                        // https://code.google.com/p/chromium/issues/detail?id=399791
                        var chromeMatch = window.navigator.appVersion.match(/Chrome\/(.*?) /);
                        if (chromeMatch && parseInt(chromeMatch[1]) >= 36) {
                            selectionSupportsMultipleRanges = false;
                        } else {
                            var r2 = r1.cloneRange();
                            r1.setStart(textNode, 0);
                            r2.setEnd(textNode, 3);
                            r2.setStart(textNode, 2);
                            sel.addRange(r1);
                            sel.addRange(r2);
                            selectionSupportsMultipleRanges = (sel.rangeCount == 2);
                        }
                    }

                    // Clean up
                    dom.removeNode(testEl);
                    sel.removeAllRanges();

                    for (i = 0; i < originalSelectionRangeCount; ++i) {
                        if (i == 0 && originalSelectionBackward) {
                            if (addRangeBackwardToNative) {
                                addRangeBackwardToNative(sel, originalSelectionRanges[i]);
                            } else {
                                api.warn("Rangy initialization: original selection was backwards but selection has been restored forwards because the browser does not support Selection.extend");
                                sel.addRange(originalSelectionRanges[i]);
                            }
                        } else {
                            sel.addRange(originalSelectionRanges[i]);
                        }
                    }
                }
            })();
        }

        features.selectionSupportsMultipleRanges = selectionSupportsMultipleRanges;
        features.collapsedNonEditableSelectionsSupported = collapsedNonEditableSelectionsSupported;

        // ControlRanges
        var implementsControlRange = false,
            testControlRange;

        if (body && isHostMethod(body, "createControlRange")) {
            testControlRange = body.createControlRange();
            if (util.areHostProperties(testControlRange, ["item", "add"])) {
                implementsControlRange = true;
            }
        }
        features.implementsControlRange = implementsControlRange;

        // Selection collapsedness
        if (selectionHasAnchorAndFocus) {
            selectionIsCollapsed = function(sel) {
                return sel.anchorNode === sel.focusNode && sel.anchorOffset === sel.focusOffset;
            };
        } else {
            selectionIsCollapsed = function(sel) {
                return sel.rangeCount ? sel.getRangeAt(sel.rangeCount - 1).collapsed : false;
            };
        }

        function updateAnchorAndFocusFromRange(sel, range, backward) {
            var anchorPrefix = backward ? "end" : "start",
                focusPrefix = backward ? "start" : "end";
            sel.anchorNode = range[anchorPrefix + "Container"];
            sel.anchorOffset = range[anchorPrefix + "Offset"];
            sel.focusNode = range[focusPrefix + "Container"];
            sel.focusOffset = range[focusPrefix + "Offset"];
        }

        function updateAnchorAndFocusFromNativeSelection(sel) {
            var nativeSel = sel.nativeSelection;
            sel.anchorNode = nativeSel.anchorNode;
            sel.anchorOffset = nativeSel.anchorOffset;
            sel.focusNode = nativeSel.focusNode;
            sel.focusOffset = nativeSel.focusOffset;
        }

        function updateEmptySelection(sel) {
            sel.anchorNode = sel.focusNode = null;
            sel.anchorOffset = sel.focusOffset = 0;
            sel.rangeCount = 0;
            sel.isCollapsed = true;
            sel._ranges.length = 0;
        }

        function getNativeRange(range) {
            var nativeRange;
            if (range instanceof DomRange) {
                nativeRange = api.createNativeRange(range.getDocument());
                nativeRange.setEnd(range.endContainer, range.endOffset);
                nativeRange.setStart(range.startContainer, range.startOffset);
            } else if (range instanceof WrappedRange) {
                nativeRange = range.nativeRange;
            } else if (features.implementsDomRange && (range instanceof dom.getWindow(range.startContainer).Range)) {
                nativeRange = range;
            }
            return nativeRange;
        }

        function rangeContainsSingleElement(rangeNodes) {
            if (!rangeNodes.length || rangeNodes[0].nodeType != 1) {
                return false;
            }
            for (var i = 1, len = rangeNodes.length; i < len; ++i) {
                if (!dom.isAncestorOf(rangeNodes[0], rangeNodes[i])) {
                    return false;
                }
            }
            return true;
        }

        function getSingleElementFromRange(range) {
            var nodes = range.getNodes();
            if (!rangeContainsSingleElement(nodes)) {
                throw module.createError("getSingleElementFromRange: range " + range.inspect() + " did not consist of a single element");
            }
            return nodes[0];
        }

        // Simple, quick test which only needs to distinguish between a TextRange and a ControlRange
        function isTextRange(range) {
            return !!range && typeof range.text != "undefined";
        }

        function updateFromTextRange(sel, range) {
            // Create a Range from the selected TextRange
            var wrappedRange = new WrappedRange(range);
            sel._ranges = [wrappedRange];

            updateAnchorAndFocusFromRange(sel, wrappedRange, false);
            sel.rangeCount = 1;
            sel.isCollapsed = wrappedRange.collapsed;
        }

        function updateControlSelection(sel) {
            // Update the wrapped selection based on what's now in the native selection
            sel._ranges.length = 0;
            if (sel.docSelection.type == "None") {
                updateEmptySelection(sel);
            } else {
                var controlRange = sel.docSelection.createRange();
                if (isTextRange(controlRange)) {
                    // This case (where the selection type is "Control" and calling createRange() on the selection returns
                    // a TextRange) can happen in IE 9. It happens, for example, when all elements in the selected
                    // ControlRange have been removed from the ControlRange and removed from the document.
                    updateFromTextRange(sel, controlRange);
                } else {
                    sel.rangeCount = controlRange.length;
                    var range, doc = getDocument(controlRange.item(0));
                    for (var i = 0; i < sel.rangeCount; ++i) {
                        range = api.createRange(doc);
                        range.selectNode(controlRange.item(i));
                        sel._ranges.push(range);
                    }
                    sel.isCollapsed = sel.rangeCount == 1 && sel._ranges[0].collapsed;
                    updateAnchorAndFocusFromRange(sel, sel._ranges[sel.rangeCount - 1], false);
                }
            }
        }

        function addRangeToControlSelection(sel, range) {
            var controlRange = sel.docSelection.createRange();
            var rangeElement = getSingleElementFromRange(range);

            // Create a new ControlRange containing all the elements in the selected ControlRange plus the element
            // contained by the supplied range
            var doc = getDocument(controlRange.item(0));
            var newControlRange = getBody(doc).createControlRange();
            for (var i = 0, len = controlRange.length; i < len; ++i) {
                newControlRange.add(controlRange.item(i));
            }
            try {
                newControlRange.add(rangeElement);
            } catch (ex) {
                throw module.createError("addRange(): Element within the specified Range could not be added to control selection (does it have layout?)");
            }
            newControlRange.select();

            // Update the wrapped selection based on what's now in the native selection
            updateControlSelection(sel);
        }

        var getSelectionRangeAt;

        if (isHostMethod(testSelection, "getRangeAt")) {
            // try/catch is present because getRangeAt() must have thrown an error in some browser and some situation.
            // Unfortunately, I didn't write a comment about the specifics and am now scared to take it out. Let that be a
            // lesson to us all, especially me.
            getSelectionRangeAt = function(sel, index) {
                try {
                    return sel.getRangeAt(index);
                } catch (ex) {
                    return null;
                }
            };
        } else if (selectionHasAnchorAndFocus) {
            getSelectionRangeAt = function(sel) {
                var doc = getDocument(sel.anchorNode);
                var range = api.createRange(doc);
                range.setStartAndEnd(sel.anchorNode, sel.anchorOffset, sel.focusNode, sel.focusOffset);

                // Handle the case when the selection was selected backwards (from the end to the start in the
                // document)
                if (range.collapsed !== this.isCollapsed) {
                    range.setStartAndEnd(sel.focusNode, sel.focusOffset, sel.anchorNode, sel.anchorOffset);
                }

                return range;
            };
        }

        function WrappedSelection(selection, docSelection, win) {
            this.nativeSelection = selection;
            this.docSelection = docSelection;
            this._ranges = [];
            this.win = win;
            this.refresh();
        }

        WrappedSelection.prototype = api.selectionPrototype;

        function deleteProperties(sel) {
            sel.win = sel.anchorNode = sel.focusNode = sel._ranges = null;
            sel.rangeCount = sel.anchorOffset = sel.focusOffset = 0;
            sel.detached = true;
        }

        var cachedRangySelections = [];

        function actOnCachedSelection(win, action) {
            var i = cachedRangySelections.length,
                cached, sel;
            while (i--) {
                cached = cachedRangySelections[i];
                sel = cached.selection;
                if (action == "deleteAll") {
                    deleteProperties(sel);
                } else if (cached.win == win) {
                    if (action == "delete") {
                        cachedRangySelections.splice(i, 1);
                        return true;
                    } else {
                        return sel;
                    }
                }
            }
            if (action == "deleteAll") {
                cachedRangySelections.length = 0;
            }
            return null;
        }

        var getSelection = function(win) {
            // Check if the parameter is a Rangy Selection object
            if (win && win instanceof WrappedSelection) {
                win.refresh();
                return win;
            }

            win = getWindow(win, "getNativeSelection");

            var sel = actOnCachedSelection(win);
            var nativeSel = getNativeSelection(win),
                docSel = implementsDocSelection ? getDocSelection(win) : null;
            if (sel) {
                sel.nativeSelection = nativeSel;
                sel.docSelection = docSel;
                sel.refresh();
            } else {
                sel = new WrappedSelection(nativeSel, docSel, win);
                cachedRangySelections.push({
                    win: win,
                    selection: sel
                });
            }
            return sel;
        };

        api.getSelection = getSelection;

        util.createAliasForDeprecatedMethod(api, "getIframeSelection", "getSelection");

        var selProto = WrappedSelection.prototype;

        function createControlSelection(sel, ranges) {
            // Ensure that the selection becomes of type "Control"
            var doc = getDocument(ranges[0].startContainer);
            var controlRange = getBody(doc).createControlRange();
            for (var i = 0, el, len = ranges.length; i < len; ++i) {
                el = getSingleElementFromRange(ranges[i]);
                try {
                    controlRange.add(el);
                } catch (ex) {
                    throw module.createError("setRanges(): Element within one of the specified Ranges could not be added to control selection (does it have layout?)");
                }
            }
            controlRange.select();

            // Update the wrapped selection based on what's now in the native selection
            updateControlSelection(sel);
        }

        // Selecting a range
        if (!useDocumentSelection && selectionHasAnchorAndFocus && util.areHostMethods(testSelection, ["removeAllRanges", "addRange"])) {
            selProto.removeAllRanges = function() {
                this.nativeSelection.removeAllRanges();
                updateEmptySelection(this);
            };

            var addRangeBackward = function(sel, range) {
                addRangeBackwardToNative(sel.nativeSelection, range);
                sel.refresh();
            };

            if (selectionHasRangeCount) {
                selProto.addRange = function(range, direction) {
                    if (implementsControlRange && implementsDocSelection && this.docSelection.type == CONTROL) {
                        addRangeToControlSelection(this, range);
                    } else {
                        if (isDirectionBackward(direction) && selectionHasExtend) {
                            addRangeBackward(this, range);
                        } else {
                            var previousRangeCount;
                            if (selectionSupportsMultipleRanges) {
                                previousRangeCount = this.rangeCount;
                            } else {
                                this.removeAllRanges();
                                previousRangeCount = 0;
                            }
                            // Clone the native range so that changing the selected range does not affect the selection.
                            // This is contrary to the spec but is the only way to achieve consistency between browsers. See
                            // issue 80.
                            var clonedNativeRange = getNativeRange(range).cloneRange();
                            try {
                                this.nativeSelection.addRange(clonedNativeRange);
                            } catch (ex) {}

                            // Check whether adding the range was successful
                            this.rangeCount = this.nativeSelection.rangeCount;

                            if (this.rangeCount == previousRangeCount + 1) {
                                // The range was added successfully

                                // Check whether the range that we added to the selection is reflected in the last range extracted from
                                // the selection
                                if (api.config.checkSelectionRanges) {
                                    var nativeRange = getSelectionRangeAt(this.nativeSelection, this.rangeCount - 1);
                                    if (nativeRange && !rangesEqual(nativeRange, range)) {
                                        // Happens in WebKit with, for example, a selection placed at the start of a text node
                                        range = new WrappedRange(nativeRange);
                                    }
                                }
                                this._ranges[this.rangeCount - 1] = range;
                                updateAnchorAndFocusFromRange(this, range, selectionIsBackward(this.nativeSelection));
                                this.isCollapsed = selectionIsCollapsed(this);
                            } else {
                                // The range was not added successfully. The simplest thing is to refresh
                                this.refresh();
                            }
                        }
                    }
                };
            } else {
                selProto.addRange = function(range, direction) {
                    if (isDirectionBackward(direction) && selectionHasExtend) {
                        addRangeBackward(this, range);
                    } else {
                        this.nativeSelection.addRange(getNativeRange(range));
                        this.refresh();
                    }
                };
            }

            selProto.setRanges = function(ranges) {
                if (implementsControlRange && implementsDocSelection && ranges.length > 1) {
                    createControlSelection(this, ranges);
                } else {
                    this.removeAllRanges();
                    for (var i = 0, len = ranges.length; i < len; ++i) {
                        this.addRange(ranges[i]);
                    }
                }
            };
        } else if (isHostMethod(testSelection, "empty") && isHostMethod(testRange, "select") &&
            implementsControlRange && useDocumentSelection) {

            selProto.removeAllRanges = function() {
                // Added try/catch as fix for issue #21
                try {
                    this.docSelection.empty();

                    // Check for empty() not working (issue #24)
                    if (this.docSelection.type != "None") {
                        // Work around failure to empty a control selection by instead selecting a TextRange and then
                        // calling empty()
                        var doc;
                        if (this.anchorNode) {
                            doc = getDocument(this.anchorNode);
                        } else if (this.docSelection.type == CONTROL) {
                            var controlRange = this.docSelection.createRange();
                            if (controlRange.length) {
                                doc = getDocument(controlRange.item(0));
                            }
                        }
                        if (doc) {
                            var textRange = getBody(doc).createTextRange();
                            textRange.select();
                            this.docSelection.empty();
                        }
                    }
                } catch (ex) {}
                updateEmptySelection(this);
            };

            selProto.addRange = function(range) {
                if (this.docSelection.type == CONTROL) {
                    addRangeToControlSelection(this, range);
                } else {
                    api.WrappedTextRange.rangeToTextRange(range).select();
                    this._ranges[0] = range;
                    this.rangeCount = 1;
                    this.isCollapsed = this._ranges[0].collapsed;
                    updateAnchorAndFocusFromRange(this, range, false);
                }
            };

            selProto.setRanges = function(ranges) {
                this.removeAllRanges();
                var rangeCount = ranges.length;
                if (rangeCount > 1) {
                    createControlSelection(this, ranges);
                } else if (rangeCount) {
                    this.addRange(ranges[0]);
                }
            };
        } else {
            module.fail("No means of selecting a Range or TextRange was found");
            return false;
        }

        selProto.getRangeAt = function(index) {
            if (index < 0 || index >= this.rangeCount) {
                throw new DOMException("INDEX_SIZE_ERR");
            } else {
                // Clone the range to preserve selection-range independence. See issue 80.
                return this._ranges[index].cloneRange();
            }
        };

        var refreshSelection;

        if (useDocumentSelection) {
            refreshSelection = function(sel) {
                var range;
                if (api.isSelectionValid(sel.win)) {
                    range = sel.docSelection.createRange();
                } else {
                    range = getBody(sel.win.document).createTextRange();
                    range.collapse(true);
                }

                if (sel.docSelection.type == CONTROL) {
                    updateControlSelection(sel);
                } else if (isTextRange(range)) {
                    updateFromTextRange(sel, range);
                } else {
                    updateEmptySelection(sel);
                }
            };
        } else if (isHostMethod(testSelection, "getRangeAt") && typeof testSelection.rangeCount == NUMBER) {
            refreshSelection = function(sel) {
                if (implementsControlRange && implementsDocSelection && sel.docSelection.type == CONTROL) {
                    updateControlSelection(sel);
                } else {
                    sel._ranges.length = sel.rangeCount = sel.nativeSelection.rangeCount;
                    if (sel.rangeCount) {
                        for (var i = 0, len = sel.rangeCount; i < len; ++i) {
                            sel._ranges[i] = new api.WrappedRange(sel.nativeSelection.getRangeAt(i));
                        }
                        updateAnchorAndFocusFromRange(sel, sel._ranges[sel.rangeCount - 1], selectionIsBackward(sel.nativeSelection));
                        sel.isCollapsed = selectionIsCollapsed(sel);
                    } else {
                        updateEmptySelection(sel);
                    }
                }
            };
        } else if (selectionHasAnchorAndFocus && typeof testSelection.isCollapsed == BOOLEAN && typeof testRange.collapsed == BOOLEAN && features.implementsDomRange) {
            refreshSelection = function(sel) {
                var range, nativeSel = sel.nativeSelection;
                if (nativeSel.anchorNode) {
                    range = getSelectionRangeAt(nativeSel, 0);
                    sel._ranges = [range];
                    sel.rangeCount = 1;
                    updateAnchorAndFocusFromNativeSelection(sel);
                    sel.isCollapsed = selectionIsCollapsed(sel);
                } else {
                    updateEmptySelection(sel);
                }
            };
        } else {
            module.fail("No means of obtaining a Range or TextRange from the user's selection was found");
            return false;
        }

        selProto.refresh = function(checkForChanges) {
            var oldRanges = checkForChanges ? this._ranges.slice(0) : null;
            var oldAnchorNode = this.anchorNode,
                oldAnchorOffset = this.anchorOffset;

            refreshSelection(this);
            if (checkForChanges) {
                // Check the range count first
                var i = oldRanges.length;
                if (i != this._ranges.length) {
                    return true;
                }

                // Now check the direction. Checking the anchor position is the same is enough since we're checking all the
                // ranges after this
                if (this.anchorNode != oldAnchorNode || this.anchorOffset != oldAnchorOffset) {
                    return true;
                }

                // Finally, compare each range in turn
                while (i--) {
                    if (!rangesEqual(oldRanges[i], this._ranges[i])) {
                        return true;
                    }
                }
                return false;
            }
        };

        // Removal of a single range
        var removeRangeManually = function(sel, range) {
            var ranges = sel.getAllRanges();
            sel.removeAllRanges();
            for (var i = 0, len = ranges.length; i < len; ++i) {
                if (!rangesEqual(range, ranges[i])) {
                    sel.addRange(ranges[i]);
                }
            }
            if (!sel.rangeCount) {
                updateEmptySelection(sel);
            }
        };

        if (implementsControlRange && implementsDocSelection) {
            selProto.removeRange = function(range) {
                if (this.docSelection.type == CONTROL) {
                    var controlRange = this.docSelection.createRange();
                    var rangeElement = getSingleElementFromRange(range);

                    // Create a new ControlRange containing all the elements in the selected ControlRange minus the
                    // element contained by the supplied range
                    var doc = getDocument(controlRange.item(0));
                    var newControlRange = getBody(doc).createControlRange();
                    var el, removed = false;
                    for (var i = 0, len = controlRange.length; i < len; ++i) {
                        el = controlRange.item(i);
                        if (el !== rangeElement || removed) {
                            newControlRange.add(controlRange.item(i));
                        } else {
                            removed = true;
                        }
                    }
                    newControlRange.select();

                    // Update the wrapped selection based on what's now in the native selection
                    updateControlSelection(this);
                } else {
                    removeRangeManually(this, range);
                }
            };
        } else {
            selProto.removeRange = function(range) {
                removeRangeManually(this, range);
            };
        }

        // Detecting if a selection is backward
        var selectionIsBackward;
        if (!useDocumentSelection && selectionHasAnchorAndFocus && features.implementsDomRange) {
            selectionIsBackward = winSelectionIsBackward;

            selProto.isBackward = function() {
                return selectionIsBackward(this);
            };
        } else {
            selectionIsBackward = selProto.isBackward = function() {
                return false;
            };
        }

        // Create an alias for backwards compatibility. From 1.3, everything is "backward" rather than "backwards"
        selProto.isBackwards = selProto.isBackward;

        // Selection stringifier
        // This is conformant to the old HTML5 selections draft spec but differs from WebKit and Mozilla's implementation.
        // The current spec does not yet define this method.
        selProto.toString = function() {
            var rangeTexts = [];
            for (var i = 0, len = this.rangeCount; i < len; ++i) {
                rangeTexts[i] = "" + this._ranges[i];
            }
            return rangeTexts.join("");
        };

        function assertNodeInSameDocument(sel, node) {
            if (sel.win.document != getDocument(node)) {
                throw new DOMException("WRONG_DOCUMENT_ERR");
            }
        }

        // No current browser conforms fully to the spec for this method, so Rangy's own method is always used
        selProto.collapse = function(node, offset) {
            assertNodeInSameDocument(this, node);
            var range = api.createRange(node);
            range.collapseToPoint(node, offset);
            this.setSingleRange(range);
            this.isCollapsed = true;
        };

        selProto.collapseToStart = function() {
            if (this.rangeCount) {
                var range = this._ranges[0];
                this.collapse(range.startContainer, range.startOffset);
            } else {
                throw new DOMException("INVALID_STATE_ERR");
            }
        };

        selProto.collapseToEnd = function() {
            if (this.rangeCount) {
                var range = this._ranges[this.rangeCount - 1];
                this.collapse(range.endContainer, range.endOffset);
            } else {
                throw new DOMException("INVALID_STATE_ERR");
            }
        };

        // The spec is very specific on how selectAllChildren should be implemented and not all browsers implement it as
        // specified so the native implementation is never used by Rangy.
        selProto.selectAllChildren = function(node) {
            assertNodeInSameDocument(this, node);
            var range = api.createRange(node);
            range.selectNodeContents(node);
            this.setSingleRange(range);
        };

        selProto.deleteFromDocument = function() {
            // Sepcial behaviour required for IE's control selections
            if (implementsControlRange && implementsDocSelection && this.docSelection.type == CONTROL) {
                var controlRange = this.docSelection.createRange();
                var element;
                while (controlRange.length) {
                    element = controlRange.item(0);
                    controlRange.remove(element);
                    dom.removeNode(element);
                }
                this.refresh();
            } else if (this.rangeCount) {
                var ranges = this.getAllRanges();
                if (ranges.length) {
                    this.removeAllRanges();
                    for (var i = 0, len = ranges.length; i < len; ++i) {
                        ranges[i].deleteContents();
                    }
                    // The spec says nothing about what the selection should contain after calling deleteContents on each
                    // range. Firefox moves the selection to where the final selected range was, so we emulate that
                    this.addRange(ranges[len - 1]);
                }
            }
        };

        // The following are non-standard extensions
        selProto.eachRange = function(func, returnValue) {
            for (var i = 0, len = this._ranges.length; i < len; ++i) {
                if (func(this.getRangeAt(i))) {
                    return returnValue;
                }
            }
        };

        selProto.getAllRanges = function() {
            var ranges = [];
            this.eachRange(function(range) {
                ranges.push(range);
            });
            return ranges;
        };

        selProto.setSingleRange = function(range, direction) {
            this.removeAllRanges();
            this.addRange(range, direction);
        };

        selProto.callMethodOnEachRange = function(methodName, params) {
            var results = [];
            this.eachRange(function(range) {
                results.push(range[methodName].apply(range, params || []));
            });
            return results;
        };

        function createStartOrEndSetter(isStart) {
            return function(node, offset) {
                var range;
                if (this.rangeCount) {
                    range = this.getRangeAt(0);
                    range["set" + (isStart ? "Start" : "End")](node, offset);
                } else {
                    range = api.createRange(this.win.document);
                    range.setStartAndEnd(node, offset);
                }
                this.setSingleRange(range, this.isBackward());
            };
        }

        selProto.setStart = createStartOrEndSetter(true);
        selProto.setEnd = createStartOrEndSetter(false);

        // Add select() method to Range prototype. Any existing selection will be removed.
        api.rangePrototype.select = function(direction) {
            getSelection(this.getDocument()).setSingleRange(this, direction);
        };

        selProto.changeEachRange = function(func) {
            var ranges = [];
            var backward = this.isBackward();

            this.eachRange(function(range) {
                func(range);
                ranges.push(range);
            });

            this.removeAllRanges();
            if (backward && ranges.length == 1) {
                this.addRange(ranges[0], "backward");
            } else {
                this.setRanges(ranges);
            }
        };

        selProto.containsNode = function(node, allowPartial) {
            return this.eachRange(function(range) {
                return range.containsNode(node, allowPartial);
            }, true) || false;
        };

        selProto.getBookmark = function(containerNode) {
            return {
                backward: this.isBackward(),
                rangeBookmarks: this.callMethodOnEachRange("getBookmark", [containerNode])
            };
        };

        selProto.moveToBookmark = function(bookmark) {
            var selRanges = [];
            for (var i = 0, rangeBookmark, range; rangeBookmark = bookmark.rangeBookmarks[i++];) {
                range = api.createRange(this.win);
                range.moveToBookmark(rangeBookmark);
                selRanges.push(range);
            }
            if (bookmark.backward) {
                this.setSingleRange(selRanges[0], "backward");
            } else {
                this.setRanges(selRanges);
            }
        };

        selProto.saveRanges = function() {
            return {
                backward: this.isBackward(),
                ranges: this.callMethodOnEachRange("cloneRange")
            };
        };

        selProto.restoreRanges = function(selRanges) {
            this.removeAllRanges();
            for (var i = 0, range; range = selRanges.ranges[i]; ++i) {
                this.addRange(range, (selRanges.backward && i == 0));
            }
        };

        selProto.toHtml = function() {
            var rangeHtmls = [];
            this.eachRange(function(range) {
                rangeHtmls.push(DomRange.toHtml(range));
            });
            return rangeHtmls.join("");
        };

        if (features.implementsTextRange) {
            selProto.getNativeTextRange = function() {
                var sel, textRange;
                if ((sel = this.docSelection)) {
                    var range = sel.createRange();
                    if (isTextRange(range)) {
                        return range;
                    } else {
                        throw module.createError("getNativeTextRange: selection is a control selection");
                    }
                } else if (this.rangeCount > 0) {
                    return api.WrappedTextRange.rangeToTextRange(this.getRangeAt(0));
                } else {
                    throw module.createError("getNativeTextRange: selection contains no range");
                }
            };
        }

        function inspect(sel) {
            var rangeInspects = [];
            var anchor = new DomPosition(sel.anchorNode, sel.anchorOffset);
            var focus = new DomPosition(sel.focusNode, sel.focusOffset);
            var name = (typeof sel.getName == "function") ? sel.getName() : "Selection";

            if (typeof sel.rangeCount != "undefined") {
                for (var i = 0, len = sel.rangeCount; i < len; ++i) {
                    rangeInspects[i] = DomRange.inspect(sel.getRangeAt(i));
                }
            }
            return "[" + name + "(Ranges: " + rangeInspects.join(", ") +
                ")(anchor: " + anchor.inspect() + ", focus: " + focus.inspect() + "]";
        }

        selProto.getName = function() {
            return "WrappedSelection";
        };

        selProto.inspect = function() {
            return inspect(this);
        };

        selProto.detach = function() {
            actOnCachedSelection(this.win, "delete");
            deleteProperties(this);
        };

        WrappedSelection.detachAll = function() {
            actOnCachedSelection(null, "deleteAll");
        };

        WrappedSelection.inspect = inspect;
        WrappedSelection.isDirectionBackward = isDirectionBackward;

        api.Selection = WrappedSelection;

        api.selectionPrototype = selProto;

        api.addShimListener(function(win) {
            if (typeof win.getSelection == "undefined") {
                win.getSelection = function() {
                    return getSelection(win);
                };
            }
            win = null;
        });
    });


    /*----------------------------------------------------------------------------------------------------------------*/

    // Wait for document to load before initializing
    var docReady = false;

    var loadHandler = function(e) {
        if (!docReady) {
            docReady = true;
            if (!api.initialized && api.config.autoInitialize) {
                init();
            }
        }
    };

    if (isBrowser) {
        // Test whether the document has already been loaded and initialize immediately if so
        if (document.readyState == "complete") {
            loadHandler();
        } else {
            if (isHostMethod(document, "addEventListener")) {
                document.addEventListener("DOMContentLoaded", loadHandler, false);
            }

            // Add a fallback in case the DOMContentLoaded event isn't supported
            addListener(window, "load", loadHandler);
        }
    }

    return api;
}, this);
/**
 * Text range module for Rangy.
 * Text-based manipulation and searching of ranges and selections.
 *
 * Features
 *
 * - Ability to move range boundaries by character or word offsets
 * - Customizable word tokenizer
 * - Ignores text nodes inside <script> or <style> elements or those hidden by CSS display and visibility properties
 * - Range findText method to search for text or regex within the page or within a range. Flags for whole words and case
 *   sensitivity
 * - Selection and range save/restore as text offsets within a node
 * - Methods to return visible text within a range or selection
 * - innerText method for elements
 *
 * References
 *
 * https://www.w3.org/Bugs/Public/show_bug.cgi?id=13145
 * http://aryeh.name/spec/innertext/innertext.html
 * http://dvcs.w3.org/hg/editing/raw-file/tip/editing.html
 *
 * Part of Rangy, a cross-browser JavaScript range and selection library
 * https://github.com/timdown/rangy
 *
 * Depends on Rangy core.
 *
 * Copyright 2015, Tim Down
 * Licensed under the MIT license.
 * Version: 1.3.1-dev
 * Build date: 20 May 2015
 */

/**
 * Problem: handling of trailing spaces before line breaks is handled inconsistently between browsers.
 *
 * First, a <br>: this is relatively simple. For the following HTML:
 *
 * 1 <br>2
 *
 * - IE and WebKit render the space, include it in the selection (i.e. when the content is selected and pasted into a
 *   textarea, the space is present) and allow the caret to be placed after it.
 * - Firefox does not acknowledge the space in the selection but it is possible to place the caret after it.
 * - Opera does not render the space but has two separate caret positions on either side of the space (left and right
 *   arrow keys show this) and includes the space in the selection.
 *
 * The other case is the line break or breaks implied by block elements. For the following HTML:
 *
 * <p>1 </p><p>2<p>
 *
 * - WebKit does not acknowledge the space in any way
 * - Firefox, IE and Opera as per <br>
 *
 * One more case is trailing spaces before line breaks in elements with white-space: pre-line. For the following HTML:
 *
 * <p style="white-space: pre-line">1
 * 2</p>
 *
 * - Firefox and WebKit include the space in caret positions
 * - IE does not support pre-line up to and including version 9
 * - Opera ignores the space
 * - Trailing space only renders if there is a non-collapsed character in the line
 *
 * Problem is whether Rangy should ever acknowledge the space and if so, when. Another problem is whether this can be
 * feature-tested
 */
(function(factory, root) {
    if (typeof define == "function" && define.amd) {
        // AMD. Register as an anonymous module with a dependency on Rangy.
        define(["./rangy-core"], factory);
    } else if (typeof module != "undefined" && typeof exports == "object") {
        // Node/CommonJS style
        module.exports = factory(require("rangy"));
    } else {
        // No AMD or CommonJS support so we use the rangy property of root (probably the global variable)
        factory(root.rangy);
    }
})(function(rangy) {
    rangy.createModule("TextRange", ["WrappedSelection"], function(api, module) {
        var UNDEF = "undefined";
        var CHARACTER = "character",
            WORD = "word";
        var dom = api.dom,
            util = api.util;
        var extend = util.extend;
        var createOptions = util.createOptions;
        var getBody = dom.getBody;


        var spacesRegex = /^[ \t\f\r\n]+$/;
        var spacesMinusLineBreaksRegex = /^[ \t\f\r]+$/;
        var allWhiteSpaceRegex = /^[\t-\r \u0085\u00A0\u1680\u180E\u2000-\u200B\u2028\u2029\u202F\u205F\u3000]+$/;
        var nonLineBreakWhiteSpaceRegex = /^[\t \u00A0\u1680\u180E\u2000-\u200B\u202F\u205F\u3000]+$/;
        var lineBreakRegex = /^[\n-\r\u0085\u2028\u2029]$/;

        var defaultLanguage = "en";

        var isDirectionBackward = api.Selection.isDirectionBackward;

        // Properties representing whether trailing spaces inside blocks are completely collapsed (as they are in WebKit,
        // but not other browsers). Also test whether trailing spaces before <br> elements are collapsed.
        var trailingSpaceInBlockCollapses = false;
        var trailingSpaceBeforeBrCollapses = false;
        var trailingSpaceBeforeBlockCollapses = false;
        var trailingSpaceBeforeLineBreakInPreLineCollapses = true;

        (function() {
            var el = dom.createTestElement(document, "<p>1 </p><p></p>", true);
            var p = el.firstChild;
            var sel = api.getSelection();
            sel.collapse(p.lastChild, 2);
            sel.setStart(p.firstChild, 0);
            trailingSpaceInBlockCollapses = ("" + sel).length == 1;

            el.innerHTML = "1 <br />";
            sel.collapse(el, 2);
            sel.setStart(el.firstChild, 0);
            trailingSpaceBeforeBrCollapses = ("" + sel).length == 1;

            el.innerHTML = "1 <p>1</p>";
            sel.collapse(el, 2);
            sel.setStart(el.firstChild, 0);
            trailingSpaceBeforeBlockCollapses = ("" + sel).length == 1;

            dom.removeNode(el);
            sel.removeAllRanges();
        })();

        /*----------------------------------------------------------------------------------------------------------------*/

        // This function must create word and non-word tokens for the whole of the text supplied to it
        function defaultTokenizer(chars, wordOptions) {
            var word = chars.join(""),
                result, tokenRanges = [];

            function createTokenRange(start, end, isWord) {
                tokenRanges.push({
                    start: start,
                    end: end,
                    isWord: isWord
                });
            }

            // Match words and mark characters
            var lastWordEnd = 0,
                wordStart, wordEnd;
            while ((result = wordOptions.wordRegex.exec(word))) {
                wordStart = result.index;
                wordEnd = wordStart + result[0].length;

                // Create token for non-word characters preceding this word
                if (wordStart > lastWordEnd) {
                    createTokenRange(lastWordEnd, wordStart, false);
                }

                // Get trailing space characters for word
                if (wordOptions.includeTrailingSpace) {
                    while (nonLineBreakWhiteSpaceRegex.test(chars[wordEnd])) {
                        ++wordEnd;
                    }
                }
                createTokenRange(wordStart, wordEnd, true);
                lastWordEnd = wordEnd;
            }

            // Create token for trailing non-word characters, if any exist
            if (lastWordEnd < chars.length) {
                createTokenRange(lastWordEnd, chars.length, false);
            }

            return tokenRanges;
        }

        function convertCharRangeToToken(chars, tokenRange) {
            var tokenChars = chars.slice(tokenRange.start, tokenRange.end);
            var token = {
                isWord: tokenRange.isWord,
                chars: tokenChars,
                toString: function() {
                    return tokenChars.join("");
                }
            };
            for (var i = 0, len = tokenChars.length; i < len; ++i) {
                tokenChars[i].token = token;
            }
            return token;
        }

        function tokenize(chars, wordOptions, tokenizer) {
            var tokenRanges = tokenizer(chars, wordOptions);
            var tokens = [];
            for (var i = 0, tokenRange; tokenRange = tokenRanges[i++];) {
                tokens.push(convertCharRangeToToken(chars, tokenRange));
            }
            return tokens;
        }

        var defaultCharacterOptions = {
            includeBlockContentTrailingSpace: true,
            includeSpaceBeforeBr: true,
            includeSpaceBeforeBlock: true,
            includePreLineTrailingSpace: true,
            ignoreCharacters: ""
        };

        function normalizeIgnoredCharacters(ignoredCharacters) {
            // Check if character is ignored
            var ignoredChars = ignoredCharacters || "";

            // Normalize ignored characters into a string consisting of characters in ascending order of character code
            var ignoredCharsArray = (typeof ignoredChars == "string") ? ignoredChars.split("") : ignoredChars;
            ignoredCharsArray.sort(function(char1, char2) {
                return char1.charCodeAt(0) - char2.charCodeAt(0);
            });

            /// Convert back to a string and remove duplicates
            return ignoredCharsArray.join("").replace(/(.)\1+/g, "$1");
        }

        var defaultCaretCharacterOptions = {
            includeBlockContentTrailingSpace: !trailingSpaceBeforeLineBreakInPreLineCollapses,
            includeSpaceBeforeBr: !trailingSpaceBeforeBrCollapses,
            includeSpaceBeforeBlock: !trailingSpaceBeforeBlockCollapses,
            includePreLineTrailingSpace: true
        };

        var defaultWordOptions = {
            "en": {
                wordRegex: /[a-z0-9]+('[a-z0-9]+)*/gi,
                includeTrailingSpace: false,
                tokenizer: defaultTokenizer
            }
        };

        var defaultFindOptions = {
            caseSensitive: false,
            withinRange: null,
            wholeWordsOnly: false,
            wrap: false,
            direction: "forward",
            wordOptions: null,
            characterOptions: null
        };

        var defaultMoveOptions = {
            wordOptions: null,
            characterOptions: null
        };

        var defaultExpandOptions = {
            wordOptions: null,
            characterOptions: null,
            trim: false,
            trimStart: true,
            trimEnd: true
        };

        var defaultWordIteratorOptions = {
            wordOptions: null,
            characterOptions: null,
            direction: "forward"
        };

        function createWordOptions(options) {
            var lang, defaults;
            if (!options) {
                return defaultWordOptions[defaultLanguage];
            } else {
                lang = options.language || defaultLanguage;
                defaults = {};
                extend(defaults, defaultWordOptions[lang] || defaultWordOptions[defaultLanguage]);
                extend(defaults, options);
                return defaults;
            }
        }

        function createNestedOptions(optionsParam, defaults) {
            var options = createOptions(optionsParam, defaults);
            if (defaults.hasOwnProperty("wordOptions")) {
                options.wordOptions = createWordOptions(options.wordOptions);
            }
            if (defaults.hasOwnProperty("characterOptions")) {
                options.characterOptions = createOptions(options.characterOptions, defaultCharacterOptions);
            }
            return options;
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        /* DOM utility functions */
        var getComputedStyleProperty = dom.getComputedStyleProperty;

        // Create cachable versions of DOM functions

        // Test for old IE's incorrect display properties
        var tableCssDisplayBlock;
        (function() {
            var table = document.createElement("table");
            var body = getBody(document);
            body.appendChild(table);
            tableCssDisplayBlock = (getComputedStyleProperty(table, "display") == "block");
            body.removeChild(table);
        })();

        var defaultDisplayValueForTag = {
            table: "table",
            caption: "table-caption",
            colgroup: "table-column-group",
            col: "table-column",
            thead: "table-header-group",
            tbody: "table-row-group",
            tfoot: "table-footer-group",
            tr: "table-row",
            td: "table-cell",
            th: "table-cell"
        };

        // Corrects IE's "block" value for table-related elements
        function getComputedDisplay(el, win) {
            var display = getComputedStyleProperty(el, "display", win);
            var tagName = el.tagName.toLowerCase();
            return (display == "block" &&
                    tableCssDisplayBlock &&
                    defaultDisplayValueForTag.hasOwnProperty(tagName)) ?
                defaultDisplayValueForTag[tagName] : display;
        }

        function isHidden(node) {
            var ancestors = getAncestorsAndSelf(node);
            for (var i = 0, len = ancestors.length; i < len; ++i) {
                if (ancestors[i].nodeType == 1 && getComputedDisplay(ancestors[i]) == "none") {
                    return true;
                }
            }

            return false;
        }

        function isVisibilityHiddenTextNode(textNode) {
            var el;
            return textNode.nodeType == 3 &&
                (el = textNode.parentNode) &&
                getComputedStyleProperty(el, "visibility") == "hidden";
        }

        /*----------------------------------------------------------------------------------------------------------------*/


        // "A block node is either an Element whose "display" property does not have
        // resolved value "inline" or "inline-block" or "inline-table" or "none", or a
        // Document, or a DocumentFragment."
        function isBlockNode(node) {
            return node &&
                ((node.nodeType == 1 && !/^(inline(-block|-table)?|none)$/.test(getComputedDisplay(node))) ||
                    node.nodeType == 9 || node.nodeType == 11);
        }

        function getLastDescendantOrSelf(node) {
            var lastChild = node.lastChild;
            return lastChild ? getLastDescendantOrSelf(lastChild) : node;
        }

        function containsPositions(node) {
            return dom.isCharacterDataNode(node) ||
                !/^(area|base|basefont|br|col|frame|hr|img|input|isindex|link|meta|param)$/i.test(node.nodeName);
        }

        function getAncestors(node) {
            var ancestors = [];
            while (node.parentNode) {
                ancestors.unshift(node.parentNode);
                node = node.parentNode;
            }
            return ancestors;
        }

        function getAncestorsAndSelf(node) {
            return getAncestors(node).concat([node]);
        }

        function nextNodeDescendants(node) {
            while (node && !node.nextSibling) {
                node = node.parentNode;
            }
            if (!node) {
                return null;
            }
            return node.nextSibling;
        }

        function nextNode(node, excludeChildren) {
            if (!excludeChildren && node.hasChildNodes()) {
                return node.firstChild;
            }
            return nextNodeDescendants(node);
        }

        function previousNode(node) {
            var previous = node.previousSibling;
            if (previous) {
                node = previous;
                while (node.hasChildNodes()) {
                    node = node.lastChild;
                }
                return node;
            }
            var parent = node.parentNode;
            if (parent && parent.nodeType == 1) {
                return parent;
            }
            return null;
        }

        // Adpated from Aryeh's code.
        // "A whitespace node is either a Text node whose data is the empty string; or
        // a Text node whose data consists only of one or more tabs (0x0009), line
        // feeds (0x000A), carriage returns (0x000D), and/or spaces (0x0020), and whose
        // parent is an Element whose resolved value for "white-space" is "normal" or
        // "nowrap"; or a Text node whose data consists only of one or more tabs
        // (0x0009), carriage returns (0x000D), and/or spaces (0x0020), and whose
        // parent is an Element whose resolved value for "white-space" is "pre-line"."
        function isWhitespaceNode(node) {
            if (!node || node.nodeType != 3) {
                return false;
            }
            var text = node.data;
            if (text === "") {
                return true;
            }
            var parent = node.parentNode;
            if (!parent || parent.nodeType != 1) {
                return false;
            }
            var computedWhiteSpace = getComputedStyleProperty(node.parentNode, "whiteSpace");

            return (/^[\t\n\r ]+$/.test(text) && /^(normal|nowrap)$/.test(computedWhiteSpace)) ||
                (/^[\t\r ]+$/.test(text) && computedWhiteSpace == "pre-line");
        }

        // Adpated from Aryeh's code.
        // "node is a collapsed whitespace node if the following algorithm returns
        // true:"
        function isCollapsedWhitespaceNode(node) {
            // "If node's data is the empty string, return true."
            if (node.data === "") {
                return true;
            }

            // "If node is not a whitespace node, return false."
            if (!isWhitespaceNode(node)) {
                return false;
            }

            // "Let ancestor be node's parent."
            var ancestor = node.parentNode;

            // "If ancestor is null, return true."
            if (!ancestor) {
                return true;
            }

            // "If the "display" property of some ancestor of node has resolved value "none", return true."
            if (isHidden(node)) {
                return true;
            }

            return false;
        }

        function isCollapsedNode(node) {
            var type = node.nodeType;
            return type == 7 /* PROCESSING_INSTRUCTION */ ||
                type == 8 /* COMMENT */ ||
                isHidden(node) ||
                /^(script|style)$/i.test(node.nodeName) ||
                isVisibilityHiddenTextNode(node) ||
                isCollapsedWhitespaceNode(node);
        }

        function isIgnoredNode(node, win) {
            var type = node.nodeType;
            return type == 7 /* PROCESSING_INSTRUCTION */ ||
                type == 8 /* COMMENT */ ||
                (type == 1 && getComputedDisplay(node, win) == "none");
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // Possibly overengineered caching system to prevent repeated DOM calls slowing everything down

        function Cache() {
            this.store = {};
        }

        Cache.prototype = {
            get: function(key) {
                return this.store.hasOwnProperty(key) ? this.store[key] : null;
            },

            set: function(key, value) {
                return this.store[key] = value;
            }
        };

        var cachedCount = 0,
            uncachedCount = 0;

        function createCachingGetter(methodName, func, objProperty) {
            return function(args) {
                var cache = this.cache;
                if (cache.hasOwnProperty(methodName)) {
                    cachedCount++;
                    return cache[methodName];
                } else {
                    uncachedCount++;
                    var value = func.call(this, objProperty ? this[objProperty] : this, args);
                    cache[methodName] = value;
                    return value;
                }
            };
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        function NodeWrapper(node, session) {
            this.node = node;
            this.session = session;
            this.cache = new Cache();
            this.positions = new Cache();
        }

        var nodeProto = {
            getPosition: function(offset) {
                var positions = this.positions;
                return positions.get(offset) || positions.set(offset, new Position(this, offset));
            },

            toString: function() {
                return "[NodeWrapper(" + dom.inspectNode(this.node) + ")]";
            }
        };

        NodeWrapper.prototype = nodeProto;

        var EMPTY = "EMPTY",
            NON_SPACE = "NON_SPACE",
            UNCOLLAPSIBLE_SPACE = "UNCOLLAPSIBLE_SPACE",
            COLLAPSIBLE_SPACE = "COLLAPSIBLE_SPACE",
            TRAILING_SPACE_BEFORE_BLOCK = "TRAILING_SPACE_BEFORE_BLOCK",
            TRAILING_SPACE_IN_BLOCK = "TRAILING_SPACE_IN_BLOCK",
            TRAILING_SPACE_BEFORE_BR = "TRAILING_SPACE_BEFORE_BR",
            PRE_LINE_TRAILING_SPACE_BEFORE_LINE_BREAK = "PRE_LINE_TRAILING_SPACE_BEFORE_LINE_BREAK",
            TRAILING_LINE_BREAK_AFTER_BR = "TRAILING_LINE_BREAK_AFTER_BR",
            INCLUDED_TRAILING_LINE_BREAK_AFTER_BR = "INCLUDED_TRAILING_LINE_BREAK_AFTER_BR";

        extend(nodeProto, {
            isCharacterDataNode: createCachingGetter("isCharacterDataNode", dom.isCharacterDataNode, "node"),
            getNodeIndex: createCachingGetter("nodeIndex", dom.getNodeIndex, "node"),
            getLength: createCachingGetter("nodeLength", dom.getNodeLength, "node"),
            containsPositions: createCachingGetter("containsPositions", containsPositions, "node"),
            isWhitespace: createCachingGetter("isWhitespace", isWhitespaceNode, "node"),
            isCollapsedWhitespace: createCachingGetter("isCollapsedWhitespace", isCollapsedWhitespaceNode, "node"),
            getComputedDisplay: createCachingGetter("computedDisplay", getComputedDisplay, "node"),
            isCollapsed: createCachingGetter("collapsed", isCollapsedNode, "node"),
            isIgnored: createCachingGetter("ignored", isIgnoredNode, "node"),
            next: createCachingGetter("nextPos", nextNode, "node"),
            previous: createCachingGetter("previous", previousNode, "node"),

            getTextNodeInfo: createCachingGetter("textNodeInfo", function(textNode) {
                var spaceRegex = null,
                    collapseSpaces = false;
                var cssWhitespace = getComputedStyleProperty(textNode.parentNode, "whiteSpace");
                var preLine = (cssWhitespace == "pre-line");
                if (preLine) {
                    spaceRegex = spacesMinusLineBreaksRegex;
                    collapseSpaces = true;
                } else if (cssWhitespace == "normal" || cssWhitespace == "nowrap") {
                    spaceRegex = spacesRegex;
                    collapseSpaces = true;
                }

                return {
                    node: textNode,
                    text: textNode.data,
                    spaceRegex: spaceRegex,
                    collapseSpaces: collapseSpaces,
                    preLine: preLine
                };
            }, "node"),

            hasInnerText: createCachingGetter("hasInnerText", function(el, backward) {
                var session = this.session;
                var posAfterEl = session.getPosition(el.parentNode, this.getNodeIndex() + 1);
                var firstPosInEl = session.getPosition(el, 0);

                var pos = backward ? posAfterEl : firstPosInEl;
                var endPos = backward ? firstPosInEl : posAfterEl;

                /*
                 <body><p>X  </p><p>Y</p></body>

                 Positions:

                 body:0:""
                 p:0:""
                 text:0:""
                 text:1:"X"
                 text:2:TRAILING_SPACE_IN_BLOCK
                 text:3:COLLAPSED_SPACE
                 p:1:""
                 body:1:"\n"
                 p:0:""
                 text:0:""
                 text:1:"Y"

                 A character is a TRAILING_SPACE_IN_BLOCK iff:

                 - There is no uncollapsed character after it within the visible containing block element

                 A character is a TRAILING_SPACE_BEFORE_BR iff:

                 - There is no uncollapsed character after it preceding a <br> element

                 An element has inner text iff

                 - It is not hidden
                 - It contains an uncollapsed character

                 All trailing spaces (pre-line, before <br>, end of block) require definite non-empty characters to render.
                 */

                while (pos !== endPos) {
                    pos.prepopulateChar();
                    if (pos.isDefinitelyNonEmpty()) {
                        return true;
                    }
                    pos = backward ? pos.previousVisible() : pos.nextVisible();
                }

                return false;
            }, "node"),

            isRenderedBlock: createCachingGetter("isRenderedBlock", function(el) {
                // Ensure that a block element containing a <br> is considered to have inner text
                var brs = el.getElementsByTagName("br");
                for (var i = 0, len = brs.length; i < len; ++i) {
                    if (!isCollapsedNode(brs[i])) {
                        return true;
                    }
                }
                return this.hasInnerText();
            }, "node"),

            getTrailingSpace: createCachingGetter("trailingSpace", function(el) {
                if (el.tagName.toLowerCase() == "br") {
                    return "";
                } else {
                    switch (this.getComputedDisplay()) {
                        case "inline":
                            var child = el.lastChild;
                            while (child) {
                                if (!isIgnoredNode(child)) {
                                    return (child.nodeType == 1) ? this.session.getNodeWrapper(child).getTrailingSpace() : "";
                                }
                                child = child.previousSibling;
                            }
                            break;
                        case "inline-block":
                        case "inline-table":
                        case "none":
                        case "table-column":
                        case "table-column-group":
                            break;
                        case "table-cell":
                            return "\t";
                        default:
                            return this.isRenderedBlock(true) ? "\n" : "";
                    }
                }
                return "";
            }, "node"),

            getLeadingSpace: createCachingGetter("leadingSpace", function(el) {
                switch (this.getComputedDisplay()) {
                    case "inline":
                    case "inline-block":
                    case "inline-table":
                    case "none":
                    case "table-column":
                    case "table-column-group":
                    case "table-cell":
                        break;
                    default:
                        return this.isRenderedBlock(false) ? "\n" : "";
                }
                return "";
            }, "node")
        });

        /*----------------------------------------------------------------------------------------------------------------*/

        function Position(nodeWrapper, offset) {
            this.offset = offset;
            this.nodeWrapper = nodeWrapper;
            this.node = nodeWrapper.node;
            this.session = nodeWrapper.session;
            this.cache = new Cache();
        }

        function inspectPosition() {
            return "[Position(" + dom.inspectNode(this.node) + ":" + this.offset + ")]";
        }

        var positionProto = {
            character: "",
            characterType: EMPTY,
            isBr: false,

            /*
            This method:
            - Fully populates positions that have characters that can be determined independently of any other characters.
            - Populates most types of space positions with a provisional character. The character is finalized later.
             */
            prepopulateChar: function() {
                var pos = this;
                if (!pos.prepopulatedChar) {
                    var node = pos.node,
                        offset = pos.offset;
                    var visibleChar = "",
                        charType = EMPTY;
                    var finalizedChar = false;
                    if (offset > 0) {
                        if (node.nodeType == 3) {
                            var text = node.data;
                            var textChar = text.charAt(offset - 1);

                            var nodeInfo = pos.nodeWrapper.getTextNodeInfo();
                            var spaceRegex = nodeInfo.spaceRegex;
                            if (nodeInfo.collapseSpaces) {
                                if (spaceRegex.test(textChar)) {
                                    // "If the character at position is from set, append a single space (U+0020) to newdata and advance
                                    // position until the character at position is not from set."

                                    // We also need to check for the case where we're in a pre-line and we have a space preceding a
                                    // line break, because such spaces are collapsed in some browsers
                                    if (offset > 1 && spaceRegex.test(text.charAt(offset - 2))) {} else if (nodeInfo.preLine && text.charAt(offset) === "\n") {
                                        visibleChar = " ";
                                        charType = PRE_LINE_TRAILING_SPACE_BEFORE_LINE_BREAK;
                                    } else {
                                        visibleChar = " ";
                                        //pos.checkForFollowingLineBreak = true;
                                        charType = COLLAPSIBLE_SPACE;
                                    }
                                } else {
                                    visibleChar = textChar;
                                    charType = NON_SPACE;
                                    finalizedChar = true;
                                }
                            } else {
                                visibleChar = textChar;
                                charType = UNCOLLAPSIBLE_SPACE;
                                finalizedChar = true;
                            }
                        } else {
                            var nodePassed = node.childNodes[offset - 1];
                            if (nodePassed && nodePassed.nodeType == 1 && !isCollapsedNode(nodePassed)) {
                                if (nodePassed.tagName.toLowerCase() == "br") {
                                    visibleChar = "\n";
                                    pos.isBr = true;
                                    charType = COLLAPSIBLE_SPACE;
                                    finalizedChar = false;
                                } else {
                                    pos.checkForTrailingSpace = true;
                                }
                            }

                            // Check the leading space of the next node for the case when a block element follows an inline
                            // element or text node. In that case, there is an implied line break between the two nodes.
                            if (!visibleChar) {
                                var nextNode = node.childNodes[offset];
                                if (nextNode && nextNode.nodeType == 1 && !isCollapsedNode(nextNode)) {
                                    pos.checkForLeadingSpace = true;
                                }
                            }
                        }
                    }

                    pos.prepopulatedChar = true;
                    pos.character = visibleChar;
                    pos.characterType = charType;
                    pos.isCharInvariant = finalizedChar;
                }
            },

            isDefinitelyNonEmpty: function() {
                var charType = this.characterType;
                return charType == NON_SPACE || charType == UNCOLLAPSIBLE_SPACE;
            },

            // Resolve leading and trailing spaces, which may involve prepopulating other positions
            resolveLeadingAndTrailingSpaces: function() {
                if (!this.prepopulatedChar) {
                    this.prepopulateChar();
                }
                if (this.checkForTrailingSpace) {
                    var trailingSpace = this.session.getNodeWrapper(this.node.childNodes[this.offset - 1]).getTrailingSpace();
                    if (trailingSpace) {
                        this.isTrailingSpace = true;
                        this.character = trailingSpace;
                        this.characterType = COLLAPSIBLE_SPACE;
                    }
                    this.checkForTrailingSpace = false;
                }
                if (this.checkForLeadingSpace) {
                    var leadingSpace = this.session.getNodeWrapper(this.node.childNodes[this.offset]).getLeadingSpace();
                    if (leadingSpace) {
                        this.isLeadingSpace = true;
                        this.character = leadingSpace;
                        this.characterType = COLLAPSIBLE_SPACE;
                    }
                    this.checkForLeadingSpace = false;
                }
            },

            getPrecedingUncollapsedPosition: function(characterOptions) {
                var pos = this,
                    character;
                while ((pos = pos.previousVisible())) {
                    character = pos.getCharacter(characterOptions);
                    if (character !== "") {
                        return pos;
                    }
                }

                return null;
            },

            getCharacter: function(characterOptions) {
                this.resolveLeadingAndTrailingSpaces();

                var thisChar = this.character,
                    returnChar;

                // Check if character is ignored
                var ignoredChars = normalizeIgnoredCharacters(characterOptions.ignoreCharacters);
                var isIgnoredCharacter = (thisChar !== "" && ignoredChars.indexOf(thisChar) > -1);

                // Check if this position's  character is invariant (i.e. not dependent on character options) and return it
                // if so
                if (this.isCharInvariant) {
                    returnChar = isIgnoredCharacter ? "" : thisChar;
                    return returnChar;
                }

                var cacheKey = ["character", characterOptions.includeSpaceBeforeBr, characterOptions.includeBlockContentTrailingSpace, characterOptions.includePreLineTrailingSpace, ignoredChars].join("_");
                var cachedChar = this.cache.get(cacheKey);
                if (cachedChar !== null) {
                    return cachedChar;
                }

                // We need to actually get the character now
                var character = "";
                var collapsible = (this.characterType == COLLAPSIBLE_SPACE);

                var nextPos, previousPos;
                var gotPreviousPos = false;
                var pos = this;

                function getPreviousPos() {
                    if (!gotPreviousPos) {
                        previousPos = pos.getPrecedingUncollapsedPosition(characterOptions);
                        gotPreviousPos = true;
                    }
                    return previousPos;
                }

                // Disallow a collapsible space that is followed by a line break or is the last character
                if (collapsible) {
                    // Allow a trailing space that we've previously determined should be included
                    if (this.type == INCLUDED_TRAILING_LINE_BREAK_AFTER_BR) {
                        character = "\n";
                    }
                    // Disallow a collapsible space that follows a trailing space or line break, or is the first character,
                    // or follows a collapsible included space
                    else if (thisChar == " " &&
                        (!getPreviousPos() || previousPos.isTrailingSpace || previousPos.character == "\n" || (previousPos.character == " " && previousPos.characterType == COLLAPSIBLE_SPACE))) {}
                    // Allow a leading line break unless it follows a line break
                    else if (thisChar == "\n" && this.isLeadingSpace) {
                        if (getPreviousPos() && previousPos.character != "\n") {
                            character = "\n";
                        } else {}
                    } else {
                        nextPos = this.nextUncollapsed();
                        if (nextPos) {
                            if (nextPos.isBr) {
                                this.type = TRAILING_SPACE_BEFORE_BR;
                            } else if (nextPos.isTrailingSpace && nextPos.character == "\n") {
                                this.type = TRAILING_SPACE_IN_BLOCK;
                            } else if (nextPos.isLeadingSpace && nextPos.character == "\n") {
                                this.type = TRAILING_SPACE_BEFORE_BLOCK;
                            }

                            if (nextPos.character == "\n") {
                                if (this.type == TRAILING_SPACE_BEFORE_BR && !characterOptions.includeSpaceBeforeBr) {} else if (this.type == TRAILING_SPACE_BEFORE_BLOCK && !characterOptions.includeSpaceBeforeBlock) {} else if (this.type == TRAILING_SPACE_IN_BLOCK && nextPos.isTrailingSpace && !characterOptions.includeBlockContentTrailingSpace) {} else if (this.type == PRE_LINE_TRAILING_SPACE_BEFORE_LINE_BREAK && nextPos.type == NON_SPACE && !characterOptions.includePreLineTrailingSpace) {} else if (thisChar == "\n") {
                                    if (nextPos.isTrailingSpace) {
                                        if (this.isTrailingSpace) {} else if (this.isBr) {
                                            nextPos.type = TRAILING_LINE_BREAK_AFTER_BR;

                                            if (getPreviousPos() && previousPos.isLeadingSpace && !previousPos.isTrailingSpace && previousPos.character == "\n") {
                                                nextPos.character = "";
                                            } else {
                                                nextPos.type = INCLUDED_TRAILING_LINE_BREAK_AFTER_BR;
                                            }
                                        }
                                    } else {
                                        character = "\n";
                                    }
                                } else if (thisChar == " ") {
                                    character = " ";
                                } else {}
                            } else {
                                character = thisChar;
                            }
                        } else {}
                    }
                }

                if (ignoredChars.indexOf(character) > -1) {
                    character = "";
                }


                this.cache.set(cacheKey, character);

                return character;
            },

            equals: function(pos) {
                return !!pos && this.node === pos.node && this.offset === pos.offset;
            },

            inspect: inspectPosition,

            toString: function() {
                return this.character;
            }
        };

        Position.prototype = positionProto;

        extend(positionProto, {
            next: createCachingGetter("nextPos", function(pos) {
                var nodeWrapper = pos.nodeWrapper,
                    node = pos.node,
                    offset = pos.offset,
                    session = nodeWrapper.session;
                if (!node) {
                    return null;
                }
                var nextNode, nextOffset, child;
                if (offset == nodeWrapper.getLength()) {
                    // Move onto the next node
                    nextNode = node.parentNode;
                    nextOffset = nextNode ? nodeWrapper.getNodeIndex() + 1 : 0;
                } else {
                    if (nodeWrapper.isCharacterDataNode()) {
                        nextNode = node;
                        nextOffset = offset + 1;
                    } else {
                        child = node.childNodes[offset];
                        // Go into the children next, if children there are
                        if (session.getNodeWrapper(child).containsPositions()) {
                            nextNode = child;
                            nextOffset = 0;
                        } else {
                            nextNode = node;
                            nextOffset = offset + 1;
                        }
                    }
                }

                return nextNode ? session.getPosition(nextNode, nextOffset) : null;
            }),

            previous: createCachingGetter("previous", function(pos) {
                var nodeWrapper = pos.nodeWrapper,
                    node = pos.node,
                    offset = pos.offset,
                    session = nodeWrapper.session;
                var previousNode, previousOffset, child;
                if (offset == 0) {
                    previousNode = node.parentNode;
                    previousOffset = previousNode ? nodeWrapper.getNodeIndex() : 0;
                } else {
                    if (nodeWrapper.isCharacterDataNode()) {
                        previousNode = node;
                        previousOffset = offset - 1;
                    } else {
                        child = node.childNodes[offset - 1];
                        // Go into the children next, if children there are
                        if (session.getNodeWrapper(child).containsPositions()) {
                            previousNode = child;
                            previousOffset = dom.getNodeLength(child);
                        } else {
                            previousNode = node;
                            previousOffset = offset - 1;
                        }
                    }
                }
                return previousNode ? session.getPosition(previousNode, previousOffset) : null;
            }),

            /*
             Next and previous position moving functions that filter out

             - Hidden (CSS visibility/display) elements
             - Script and style elements
             */
            nextVisible: createCachingGetter("nextVisible", function(pos) {
                var next = pos.next();
                if (!next) {
                    return null;
                }
                var nodeWrapper = next.nodeWrapper,
                    node = next.node;
                var newPos = next;
                if (nodeWrapper.isCollapsed()) {
                    // We're skipping this node and all its descendants
                    newPos = nodeWrapper.session.getPosition(node.parentNode, nodeWrapper.getNodeIndex() + 1);
                }
                return newPos;
            }),

            nextUncollapsed: createCachingGetter("nextUncollapsed", function(pos) {
                var nextPos = pos;
                while ((nextPos = nextPos.nextVisible())) {
                    nextPos.resolveLeadingAndTrailingSpaces();
                    if (nextPos.character !== "") {
                        return nextPos;
                    }
                }
                return null;
            }),

            previousVisible: createCachingGetter("previousVisible", function(pos) {
                var previous = pos.previous();
                if (!previous) {
                    return null;
                }
                var nodeWrapper = previous.nodeWrapper,
                    node = previous.node;
                var newPos = previous;
                if (nodeWrapper.isCollapsed()) {
                    // We're skipping this node and all its descendants
                    newPos = nodeWrapper.session.getPosition(node.parentNode, nodeWrapper.getNodeIndex());
                }
                return newPos;
            })
        });

        /*----------------------------------------------------------------------------------------------------------------*/

        var currentSession = null;

        var Session = (function() {
            function createWrapperCache(nodeProperty) {
                var cache = new Cache();

                return {
                    get: function(node) {
                        var wrappersByProperty = cache.get(node[nodeProperty]);
                        if (wrappersByProperty) {
                            for (var i = 0, wrapper; wrapper = wrappersByProperty[i++];) {
                                if (wrapper.node === node) {
                                    return wrapper;
                                }
                            }
                        }
                        return null;
                    },

                    set: function(nodeWrapper) {
                        var property = nodeWrapper.node[nodeProperty];
                        var wrappersByProperty = cache.get(property) || cache.set(property, []);
                        wrappersByProperty.push(nodeWrapper);
                    }
                };
            }

            var uniqueIDSupported = util.isHostProperty(document.documentElement, "uniqueID");

            function Session() {
                this.initCaches();
            }

            Session.prototype = {
                initCaches: function() {
                    this.elementCache = uniqueIDSupported ? (function() {
                        var elementsCache = new Cache();

                        return {
                            get: function(el) {
                                return elementsCache.get(el.uniqueID);
                            },

                            set: function(elWrapper) {
                                elementsCache.set(elWrapper.node.uniqueID, elWrapper);
                            }
                        };
                    })() : createWrapperCache("tagName");

                    // Store text nodes keyed by data, although we may need to truncate this
                    this.textNodeCache = createWrapperCache("data");
                    this.otherNodeCache = createWrapperCache("nodeName");
                },

                getNodeWrapper: function(node) {
                    var wrapperCache;
                    switch (node.nodeType) {
                        case 1:
                            wrapperCache = this.elementCache;
                            break;
                        case 3:
                            wrapperCache = this.textNodeCache;
                            break;
                        default:
                            wrapperCache = this.otherNodeCache;
                            break;
                    }

                    var wrapper = wrapperCache.get(node);
                    if (!wrapper) {
                        wrapper = new NodeWrapper(node, this);
                        wrapperCache.set(wrapper);
                    }
                    return wrapper;
                },

                getPosition: function(node, offset) {
                    return this.getNodeWrapper(node).getPosition(offset);
                },

                getRangeBoundaryPosition: function(range, isStart) {
                    var prefix = isStart ? "start" : "end";
                    return this.getPosition(range[prefix + "Container"], range[prefix + "Offset"]);
                },

                detach: function() {
                    this.elementCache = this.textNodeCache = this.otherNodeCache = null;
                }
            };

            return Session;
        })();

        /*----------------------------------------------------------------------------------------------------------------*/

        function startSession() {
            endSession();
            return (currentSession = new Session());
        }

        function getSession() {
            return currentSession || startSession();
        }

        function endSession() {
            if (currentSession) {
                currentSession.detach();
            }
            currentSession = null;
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // Extensions to the rangy.dom utility object

        extend(dom, {
            nextNode: nextNode,
            previousNode: previousNode
        });

        /*----------------------------------------------------------------------------------------------------------------*/

        function createCharacterIterator(startPos, backward, endPos, characterOptions) {

            // Adjust the end position to ensure that it is actually reached
            if (endPos) {
                if (backward) {
                    if (isCollapsedNode(endPos.node)) {
                        endPos = startPos.previousVisible();
                    }
                } else {
                    if (isCollapsedNode(endPos.node)) {
                        endPos = endPos.nextVisible();
                    }
                }
            }

            var pos = startPos,
                finished = false;

            function next() {
                var charPos = null;
                if (backward) {
                    charPos = pos;
                    if (!finished) {
                        pos = pos.previousVisible();
                        finished = !pos || (endPos && pos.equals(endPos));
                    }
                } else {
                    if (!finished) {
                        charPos = pos = pos.nextVisible();
                        finished = !pos || (endPos && pos.equals(endPos));
                    }
                }
                if (finished) {
                    pos = null;
                }
                return charPos;
            }

            var previousTextPos, returnPreviousTextPos = false;

            return {
                next: function() {
                    if (returnPreviousTextPos) {
                        returnPreviousTextPos = false;
                        return previousTextPos;
                    } else {
                        var pos, character;
                        while ((pos = next())) {
                            character = pos.getCharacter(characterOptions);
                            if (character) {
                                previousTextPos = pos;
                                return pos;
                            }
                        }
                        return null;
                    }
                },

                rewind: function() {
                    if (previousTextPos) {
                        returnPreviousTextPos = true;
                    } else {
                        throw module.createError("createCharacterIterator: cannot rewind. Only one position can be rewound.");
                    }
                },

                dispose: function() {
                    startPos = endPos = null;
                }
            };
        }

        var arrayIndexOf = Array.prototype.indexOf ?
            function(arr, val) {
                return arr.indexOf(val);
            } :
            function(arr, val) {
                for (var i = 0, len = arr.length; i < len; ++i) {
                    if (arr[i] === val) {
                        return i;
                    }
                }
                return -1;
            };

        // Provides a pair of iterators over text positions, tokenized. Transparently requests more text when next()
        // is called and there is no more tokenized text
        function createTokenizedTextProvider(pos, characterOptions, wordOptions) {
            var forwardIterator = createCharacterIterator(pos, false, null, characterOptions);
            var backwardIterator = createCharacterIterator(pos, true, null, characterOptions);
            var tokenizer = wordOptions.tokenizer;

            // Consumes a word and the whitespace beyond it
            function consumeWord(forward) {
                var pos, textChar;
                var newChars = [],
                    it = forward ? forwardIterator : backwardIterator;

                var passedWordBoundary = false,
                    insideWord = false;

                while ((pos = it.next())) {
                    textChar = pos.character;


                    if (allWhiteSpaceRegex.test(textChar)) {
                        if (insideWord) {
                            insideWord = false;
                            passedWordBoundary = true;
                        }
                    } else {
                        if (passedWordBoundary) {
                            it.rewind();
                            break;
                        } else {
                            insideWord = true;
                        }
                    }
                    newChars.push(pos);
                }


                return newChars;
            }

            // Get initial word surrounding initial position and tokenize it
            var forwardChars = consumeWord(true);
            var backwardChars = consumeWord(false).reverse();
            var tokens = tokenize(backwardChars.concat(forwardChars), wordOptions, tokenizer);

            // Create initial token buffers
            var forwardTokensBuffer = forwardChars.length ?
                tokens.slice(arrayIndexOf(tokens, forwardChars[0].token)) : [];

            var backwardTokensBuffer = backwardChars.length ?
                tokens.slice(0, arrayIndexOf(tokens, backwardChars.pop().token) + 1) : [];

            function inspectBuffer(buffer) {
                var textPositions = ["[" + buffer.length + "]"];
                for (var i = 0; i < buffer.length; ++i) {
                    textPositions.push("(word: " + buffer[i] + ", is word: " + buffer[i].isWord + ")");
                }
                return textPositions;
            }


            return {
                nextEndToken: function() {
                    var lastToken, forwardChars;

                    // If we're down to the last token, consume character chunks until we have a word or run out of
                    // characters to consume
                    while (forwardTokensBuffer.length == 1 &&
                        !(lastToken = forwardTokensBuffer[0]).isWord &&
                        (forwardChars = consumeWord(true)).length > 0) {

                        // Merge trailing non-word into next word and tokenize
                        forwardTokensBuffer = tokenize(lastToken.chars.concat(forwardChars), wordOptions, tokenizer);
                    }

                    return forwardTokensBuffer.shift();
                },

                previousStartToken: function() {
                    var lastToken, backwardChars;

                    // If we're down to the last token, consume character chunks until we have a word or run out of
                    // characters to consume
                    while (backwardTokensBuffer.length == 1 &&
                        !(lastToken = backwardTokensBuffer[0]).isWord &&
                        (backwardChars = consumeWord(false)).length > 0) {

                        // Merge leading non-word into next word and tokenize
                        backwardTokensBuffer = tokenize(backwardChars.reverse().concat(lastToken.chars), wordOptions, tokenizer);
                    }

                    return backwardTokensBuffer.pop();
                },

                dispose: function() {
                    forwardIterator.dispose();
                    backwardIterator.dispose();
                    forwardTokensBuffer = backwardTokensBuffer = null;
                }
            };
        }

        function movePositionBy(pos, unit, count, characterOptions, wordOptions) {
            var unitsMoved = 0,
                currentPos, newPos = pos,
                charIterator, nextPos, absCount = Math.abs(count),
                token;
            if (count !== 0) {
                var backward = (count < 0);

                switch (unit) {
                    case CHARACTER:
                        charIterator = createCharacterIterator(pos, backward, null, characterOptions);
                        while ((currentPos = charIterator.next()) && unitsMoved < absCount) {
                            ++unitsMoved;
                            newPos = currentPos;
                        }
                        nextPos = currentPos;
                        charIterator.dispose();
                        break;
                    case WORD:
                        var tokenizedTextProvider = createTokenizedTextProvider(pos, characterOptions, wordOptions);
                        var next = backward ? tokenizedTextProvider.previousStartToken : tokenizedTextProvider.nextEndToken;

                        while ((token = next()) && unitsMoved < absCount) {
                            if (token.isWord) {
                                ++unitsMoved;
                                newPos = backward ? token.chars[0] : token.chars[token.chars.length - 1];
                            }
                        }
                        break;
                    default:
                        throw new Error("movePositionBy: unit '" + unit + "' not implemented");
                }

                // Perform any necessary position tweaks
                if (backward) {
                    newPos = newPos.previousVisible();
                    unitsMoved = -unitsMoved;
                } else if (newPos && newPos.isLeadingSpace && !newPos.isTrailingSpace) {
                    // Tweak the position for the case of a leading space. The problem is that an uncollapsed leading space
                    // before a block element (for example, the line break between "1" and "2" in the following HTML:
                    // "1<p>2</p>") is considered to be attached to the position immediately before the block element, which
                    // corresponds with a different selection position in most browsers from the one we want (i.e. at the
                    // start of the contents of the block element). We get round this by advancing the position returned to
                    // the last possible equivalent visible position.
                    if (unit == WORD) {
                        charIterator = createCharacterIterator(pos, false, null, characterOptions);
                        nextPos = charIterator.next();
                        charIterator.dispose();
                    }
                    if (nextPos) {
                        newPos = nextPos.previousVisible();
                    }
                }
            }


            return {
                position: newPos,
                unitsMoved: unitsMoved
            };
        }

        function createRangeCharacterIterator(session, range, characterOptions, backward) {
            var rangeStart = session.getRangeBoundaryPosition(range, true);
            var rangeEnd = session.getRangeBoundaryPosition(range, false);
            var itStart = backward ? rangeEnd : rangeStart;
            var itEnd = backward ? rangeStart : rangeEnd;

            return createCharacterIterator(itStart, !!backward, itEnd, characterOptions);
        }

        function getRangeCharacters(session, range, characterOptions) {

            var chars = [],
                it = createRangeCharacterIterator(session, range, characterOptions),
                pos;
            while ((pos = it.next())) {
                chars.push(pos);
            }

            it.dispose();
            return chars;
        }

        function isWholeWord(startPos, endPos, wordOptions) {
            var range = api.createRange(startPos.node);
            range.setStartAndEnd(startPos.node, startPos.offset, endPos.node, endPos.offset);
            return !range.expand("word", {
                wordOptions: wordOptions
            });
        }

        function findTextFromPosition(initialPos, searchTerm, isRegex, searchScopeRange, findOptions) {
            var backward = isDirectionBackward(findOptions.direction);
            var it = createCharacterIterator(
                initialPos,
                backward,
                initialPos.session.getRangeBoundaryPosition(searchScopeRange, backward),
                findOptions.characterOptions
            );
            var text = "",
                chars = [],
                pos, currentChar, matchStartIndex, matchEndIndex;
            var result, insideRegexMatch;
            var returnValue = null;

            function handleMatch(startIndex, endIndex) {
                var startPos = chars[startIndex].previousVisible();
                var endPos = chars[endIndex - 1];
                var valid = (!findOptions.wholeWordsOnly || isWholeWord(startPos, endPos, findOptions.wordOptions));

                return {
                    startPos: startPos,
                    endPos: endPos,
                    valid: valid
                };
            }

            while ((pos = it.next())) {
                currentChar = pos.character;
                if (!isRegex && !findOptions.caseSensitive) {
                    currentChar = currentChar.toLowerCase();
                }

                if (backward) {
                    chars.unshift(pos);
                    text = currentChar + text;
                } else {
                    chars.push(pos);
                    text += currentChar;
                }

                if (isRegex) {
                    result = searchTerm.exec(text);
                    if (result) {
                        matchStartIndex = result.index;
                        matchEndIndex = matchStartIndex + result[0].length;
                        if (insideRegexMatch) {
                            // Check whether the match is now over
                            if ((!backward && matchEndIndex < text.length) || (backward && matchStartIndex > 0)) {
                                returnValue = handleMatch(matchStartIndex, matchEndIndex);
                                break;
                            }
                        } else {
                            insideRegexMatch = true;
                        }
                    }
                } else if ((matchStartIndex = text.indexOf(searchTerm)) != -1) {
                    returnValue = handleMatch(matchStartIndex, matchStartIndex + searchTerm.length);
                    break;
                }
            }

            // Check whether regex match extends to the end of the range
            if (insideRegexMatch) {
                returnValue = handleMatch(matchStartIndex, matchEndIndex);
            }
            it.dispose();

            return returnValue;
        }

        function createEntryPointFunction(func) {
            return function() {
                var sessionRunning = !!currentSession;
                var session = getSession();
                var args = [session].concat(util.toArray(arguments));
                var returnValue = func.apply(this, args);
                if (!sessionRunning) {
                    endSession();
                }
                return returnValue;
            };
        }

        /*----------------------------------------------------------------------------------------------------------------*/

        // Extensions to the Rangy Range object

        function createRangeBoundaryMover(isStart, collapse) {
            /*
             Unit can be "character" or "word"
             Options:

             - includeTrailingSpace
             - wordRegex
             - tokenizer
             - collapseSpaceBeforeLineBreak
             */
            return createEntryPointFunction(
                function(session, unit, count, moveOptions) {
                    if (typeof count == UNDEF) {
                        count = unit;
                        unit = CHARACTER;
                    }
                    moveOptions = createNestedOptions(moveOptions, defaultMoveOptions);

                    var boundaryIsStart = isStart;
                    if (collapse) {
                        boundaryIsStart = (count >= 0);
                        this.collapse(!boundaryIsStart);
                    }
                    var moveResult = movePositionBy(session.getRangeBoundaryPosition(this, boundaryIsStart), unit, count, moveOptions.characterOptions, moveOptions.wordOptions);
                    var newPos = moveResult.position;
                    this[boundaryIsStart ? "setStart" : "setEnd"](newPos.node, newPos.offset);
                    return moveResult.unitsMoved;
                }
            );
        }

        function createRangeTrimmer(isStart) {
            return createEntryPointFunction(
                function(session, characterOptions) {
                    characterOptions = createOptions(characterOptions, defaultCharacterOptions);
                    var pos;
                    var it = createRangeCharacterIterator(session, this, characterOptions, !isStart);
                    var trimCharCount = 0;
                    while ((pos = it.next()) && allWhiteSpaceRegex.test(pos.character)) {
                        ++trimCharCount;
                    }
                    it.dispose();
                    var trimmed = (trimCharCount > 0);
                    if (trimmed) {
                        this[isStart ? "moveStart" : "moveEnd"](
                            "character",
                            isStart ? trimCharCount : -trimCharCount, {
                                characterOptions: characterOptions
                            }
                        );
                    }
                    return trimmed;
                }
            );
        }

        extend(api.rangePrototype, {
            moveStart: createRangeBoundaryMover(true, false),

            moveEnd: createRangeBoundaryMover(false, false),

            move: createRangeBoundaryMover(true, true),

            trimStart: createRangeTrimmer(true),

            trimEnd: createRangeTrimmer(false),

            trim: createEntryPointFunction(
                function(session, characterOptions) {
                    var startTrimmed = this.trimStart(characterOptions),
                        endTrimmed = this.trimEnd(characterOptions);
                    return startTrimmed || endTrimmed;
                }
            ),

            expand: createEntryPointFunction(
                function(session, unit, expandOptions) {
                    var moved = false;
                    expandOptions = createNestedOptions(expandOptions, defaultExpandOptions);
                    var characterOptions = expandOptions.characterOptions;
                    if (!unit) {
                        unit = CHARACTER;
                    }
                    if (unit == WORD) {
                        var wordOptions = expandOptions.wordOptions;
                        var startPos = session.getRangeBoundaryPosition(this, true);
                        var endPos = session.getRangeBoundaryPosition(this, false);

                        var startTokenizedTextProvider = createTokenizedTextProvider(startPos, characterOptions, wordOptions);
                        var startToken = startTokenizedTextProvider.nextEndToken();
                        var newStartPos = startToken.chars[0].previousVisible();
                        var endToken, newEndPos;

                        if (this.collapsed) {
                            endToken = startToken;
                        } else {
                            var endTokenizedTextProvider = createTokenizedTextProvider(endPos, characterOptions, wordOptions);
                            endToken = endTokenizedTextProvider.previousStartToken();
                        }
                        newEndPos = endToken.chars[endToken.chars.length - 1];

                        if (!newStartPos.equals(startPos)) {
                            this.setStart(newStartPos.node, newStartPos.offset);
                            moved = true;
                        }
                        if (newEndPos && !newEndPos.equals(endPos)) {
                            this.setEnd(newEndPos.node, newEndPos.offset);
                            moved = true;
                        }

                        if (expandOptions.trim) {
                            if (expandOptions.trimStart) {
                                moved = this.trimStart(characterOptions) || moved;
                            }
                            if (expandOptions.trimEnd) {
                                moved = this.trimEnd(characterOptions) || moved;
                            }
                        }

                        return moved;
                    } else {
                        return this.moveEnd(CHARACTER, 1, expandOptions);
                    }
                }
            ),

            text: createEntryPointFunction(
                function(session, characterOptions) {
                    return this.collapsed ?
                        "" : getRangeCharacters(session, this, createOptions(characterOptions, defaultCharacterOptions)).join("");
                }
            ),

            selectCharacters: createEntryPointFunction(
                function(session, containerNode, startIndex, endIndex, characterOptions) {
                    var moveOptions = {
                        characterOptions: characterOptions
                    };
                    if (!containerNode) {
                        containerNode = getBody(this.getDocument());
                    }
                    this.selectNodeContents(containerNode);
                    this.collapse(true);
                    this.moveStart("character", startIndex, moveOptions);
                    this.collapse(true);
                    this.moveEnd("character", endIndex - startIndex, moveOptions);
                }
            ),

            // Character indexes are relative to the start of node
            toCharacterRange: createEntryPointFunction(
                function(session, containerNode, characterOptions) {
                    if (!containerNode) {
                        containerNode = getBody(this.getDocument());
                    }
                    var parent = containerNode.parentNode,
                        nodeIndex = dom.getNodeIndex(containerNode);
                    var rangeStartsBeforeNode = (dom.comparePoints(this.startContainer, this.endContainer, parent, nodeIndex) == -1);
                    var rangeBetween = this.cloneRange();
                    var startIndex, endIndex;
                    if (rangeStartsBeforeNode) {
                        rangeBetween.setStartAndEnd(this.startContainer, this.startOffset, parent, nodeIndex);
                        startIndex = -rangeBetween.text(characterOptions).length;
                    } else {
                        rangeBetween.setStartAndEnd(parent, nodeIndex, this.startContainer, this.startOffset);
                        startIndex = rangeBetween.text(characterOptions).length;
                    }
                    endIndex = startIndex + this.text(characterOptions).length;

                    return {
                        start: startIndex,
                        end: endIndex
                    };
                }
            ),

            findText: createEntryPointFunction(
                function(session, searchTermParam, findOptions) {
                    // Set up options
                    findOptions = createNestedOptions(findOptions, defaultFindOptions);

                    // Create word options if we're matching whole words only
                    if (findOptions.wholeWordsOnly) {
                        // We don't ever want trailing spaces for search results
                        findOptions.wordOptions.includeTrailingSpace = false;
                    }

                    var backward = isDirectionBackward(findOptions.direction);

                    // Create a range representing the search scope if none was provided
                    var searchScopeRange = findOptions.withinRange;
                    if (!searchScopeRange) {
                        searchScopeRange = api.createRange();
                        searchScopeRange.selectNodeContents(this.getDocument());
                    }

                    // Examine and prepare the search term
                    var searchTerm = searchTermParam,
                        isRegex = false;
                    if (typeof searchTerm == "string") {
                        if (!findOptions.caseSensitive) {
                            searchTerm = searchTerm.toLowerCase();
                        }
                    } else {
                        isRegex = true;
                    }

                    var initialPos = session.getRangeBoundaryPosition(this, !backward);

                    // Adjust initial position if it lies outside the search scope
                    var comparison = searchScopeRange.comparePoint(initialPos.node, initialPos.offset);

                    if (comparison === -1) {
                        initialPos = session.getRangeBoundaryPosition(searchScopeRange, true);
                    } else if (comparison === 1) {
                        initialPos = session.getRangeBoundaryPosition(searchScopeRange, false);
                    }

                    var pos = initialPos;
                    var wrappedAround = false;

                    // Try to find a match and ignore invalid ones
                    var findResult;
                    while (true) {
                        findResult = findTextFromPosition(pos, searchTerm, isRegex, searchScopeRange, findOptions);

                        if (findResult) {
                            if (findResult.valid) {
                                this.setStartAndEnd(findResult.startPos.node, findResult.startPos.offset, findResult.endPos.node, findResult.endPos.offset);
                                return true;
                            } else {
                                // We've found a match that is not a whole word, so we carry on searching from the point immediately
                                // after the match
                                pos = backward ? findResult.startPos : findResult.endPos;
                            }
                        } else if (findOptions.wrap && !wrappedAround) {
                            // No result found but we're wrapping around and limiting the scope to the unsearched part of the range
                            searchScopeRange = searchScopeRange.cloneRange();
                            pos = session.getRangeBoundaryPosition(searchScopeRange, !backward);
                            searchScopeRange.setBoundary(initialPos.node, initialPos.offset, backward);
                            wrappedAround = true;
                        } else {
                            // Nothing found and we can't wrap around, so we're done
                            return false;
                        }
                    }
                }
            ),

            pasteHtml: function(html) {
                this.deleteContents();
                if (html) {
                    var frag = this.createContextualFragment(html);
                    var lastChild = frag.lastChild;
                    this.insertNode(frag);
                    this.collapseAfter(lastChild);
                }
            }
        });

        /*----------------------------------------------------------------------------------------------------------------*/

        // Extensions to the Rangy Selection object

        function createSelectionTrimmer(methodName) {
            return createEntryPointFunction(
                function(session, characterOptions) {
                    var trimmed = false;
                    this.changeEachRange(function(range) {
                        trimmed = range[methodName](characterOptions) || trimmed;
                    });
                    return trimmed;
                }
            );
        }

        extend(api.selectionPrototype, {
            expand: createEntryPointFunction(
                function(session, unit, expandOptions) {
                    this.changeEachRange(function(range) {
                        range.expand(unit, expandOptions);
                    });
                }
            ),

            move: createEntryPointFunction(
                function(session, unit, count, options) {
                    var unitsMoved = 0;
                    if (this.focusNode) {
                        this.collapse(this.focusNode, this.focusOffset);
                        var range = this.getRangeAt(0);
                        if (!options) {
                            options = {};
                        }
                        options.characterOptions = createOptions(options.characterOptions, defaultCaretCharacterOptions);
                        unitsMoved = range.move(unit, count, options);
                        this.setSingleRange(range);
                    }
                    return unitsMoved;
                }
            ),

            trimStart: createSelectionTrimmer("trimStart"),
            trimEnd: createSelectionTrimmer("trimEnd"),
            trim: createSelectionTrimmer("trim"),

            selectCharacters: createEntryPointFunction(
                function(session, containerNode, startIndex, endIndex, direction, characterOptions) {
                    var range = api.createRange(containerNode);
                    range.selectCharacters(containerNode, startIndex, endIndex, characterOptions);
                    this.setSingleRange(range, direction);
                }
            ),

            saveCharacterRanges: createEntryPointFunction(
                function(session, containerNode, characterOptions) {
                    var ranges = this.getAllRanges(),
                        rangeCount = ranges.length;
                    var rangeInfos = [];

                    var backward = rangeCount == 1 && this.isBackward();

                    for (var i = 0, len = ranges.length; i < len; ++i) {
                        rangeInfos[i] = {
                            characterRange: ranges[i].toCharacterRange(containerNode, characterOptions),
                            backward: backward,
                            characterOptions: characterOptions
                        };
                    }

                    return rangeInfos;
                }
            ),

            restoreCharacterRanges: createEntryPointFunction(
                function(session, containerNode, saved) {
                    this.removeAllRanges();
                    for (var i = 0, len = saved.length, range, rangeInfo, characterRange; i < len; ++i) {
                        rangeInfo = saved[i];
                        characterRange = rangeInfo.characterRange;
                        range = api.createRange(containerNode);
                        range.selectCharacters(containerNode, characterRange.start, characterRange.end, rangeInfo.characterOptions);
                        this.addRange(range, rangeInfo.backward);
                    }
                }
            ),

            text: createEntryPointFunction(
                function(session, characterOptions) {
                    var rangeTexts = [];
                    for (var i = 0, len = this.rangeCount; i < len; ++i) {
                        rangeTexts[i] = this.getRangeAt(i).text(characterOptions);
                    }
                    return rangeTexts.join("");
                }
            )
        });

        /*----------------------------------------------------------------------------------------------------------------*/

        // Extensions to the core rangy object

        api.innerText = function(el, characterOptions) {
            var range = api.createRange(el);
            range.selectNodeContents(el);
            var text = range.text(characterOptions);
            return text;
        };

        api.createWordIterator = function(startNode, startOffset, iteratorOptions) {
            var session = getSession();
            iteratorOptions = createNestedOptions(iteratorOptions, defaultWordIteratorOptions);
            var startPos = session.getPosition(startNode, startOffset);
            var tokenizedTextProvider = createTokenizedTextProvider(startPos, iteratorOptions.characterOptions, iteratorOptions.wordOptions);
            var backward = isDirectionBackward(iteratorOptions.direction);

            return {
                next: function() {
                    return backward ? tokenizedTextProvider.previousStartToken() : tokenizedTextProvider.nextEndToken();
                },

                dispose: function() {
                    tokenizedTextProvider.dispose();
                    this.next = function() {};
                }
            };
        };

        /*----------------------------------------------------------------------------------------------------------------*/

        api.noMutation = function(func) {
            var session = getSession();
            func(session);
            endSession();
        };

        api.noMutation.createEntryPointFunction = createEntryPointFunction;

        api.textRange = {
            isBlockNode: isBlockNode,
            isCollapsedWhitespaceNode: isCollapsedWhitespaceNode,

            createPosition: createEntryPointFunction(
                function(session, node, offset) {
                    return session.getPosition(node, offset);
                }
            )
        };
    });

    return rangy;
}, this);
/* globals ZE,ZE_Init,document*/

// TODO Fix all camelCase variables

ZE.prototype.createToolbar = function() {
    "use strict"; // No I18N
    var editor = this,
        toolbarobject = {},
        toolbararray,
        initObjToolbar = editor.initobj.toolbar,
        _document = document,
        _body = _document.body,
        fragment = _document.createDocumentFragment(),
        I18N = ZE.i18n,
        imgPath = ZE_Init.imgPath,
        zeEditor,
        toolbardiv,
        btnonclick,
        i = 0,
        toolbarArrayLength,
        _ul,
        _li,
        _div,
        toolbarinnerarray,
        j,
        toolbarInnerArrayLength,
        commandArray,
        commandName,
        _class,
        executeAction;

    if (editor.initobj.toolbarOrder) {
        toolbararray = editor.initobj.toolbarOrder;
    } else if (initObjToolbar) {
        toolbararray = ZE_Init.toolbarOrderGenerate(initObjToolbar);
    } else {
        toolbararray = ZE_Init.toolbarOrder;
    }
    /* toolbar onclick start*/
    btnonclick = function(command) {

        return function(ev) {

            editor._stopEvent(ev); // in ze.js
            // editor.win.focus();
            var sel = editor._getSelection();
            try {
                var range = editor._createRange(sel);
            } catch (e) {
                if (editor.range) {
                    editor.range.select();
                    delete editor.range;
                } else {
                    editor.win.focus();
                }
            }
            editor.execCommand(ev, command);
            return false;
        };
    };
    /* toolbar onclick end*/

    /* creating editor div containing toolbar and editor start*/
    zeEditor = _document.createElement("div");
    zeEditor.className = "ze";

    if (!ZE_Init.needEditorBorder) {
        zeEditor.style.borderWidth = "0px"; // No I18N
    }

    editor.editordiv = zeEditor;
    fragment.appendChild(zeEditor);
    /* creating editor div containing toolbar and editor end*/

    editor.toolbarobject = toolbarobject;

    /* creating toolbardiv start*/
    toolbardiv = _document.createElement("div");
    toolbardiv.className = "ze_SCmb";
    zeEditor.appendChild(toolbardiv);
    editor.toolbardiv = toolbardiv;

    /* creating toolbardiv end*/
    var stopEv = function(ev) {
        editor._stopEvent(ev);
        return false;
    };
    executeAction = function() {
        return function(ev) {
            editor._stopEvent(ev); // in ze.js
            var _className = ev.target.className,
                _command,
                sel = editor._getSelection();
            try {
                var range = editor._createRange(sel);
            } catch (e) {
                if (editor.range) {
                    editor.range.select();
                    delete editor.range;
                } else {
                    editor.win.focus();
                }
            }
            switch (_className) {
                case "zei-order": // No I18N
                    _command = "insertorderedlist"; // No I18N
                    break;
                case "zei-unorder": // No I18N
                    _command = "insertunorderedlist"; // No I18N
                    break;
                case "zei-textleft": // No I18N
                    _command = "j-left"; // No I18N
                    break;
                case "zei-textright": // No I18N
                    _command = "j-right"; // No I18N
                    break;
                case "zei-textjustify": // No I18N
                    _command = "j-justify"; // No I18N
                    break;
                case "zei-textcenter": // No I18N
                    _command = "j-center"; // No I18N
                    break;
            }
            editor.execCommand(ev, _command);
            editor.saveCurrentState();
            return false;
        };
    };
    var _alternateToolbar,
        editorWidth,
        altToolCheck = 0,
        soFarWidth = 0,
        _b;

    editorWidth = editor.outerdiv.offsetWidth;

    editor.outerdiv.appendChild(fragment);
    var createAlternateToolbar = function() {
        _alternateToolbar = _document.createElement('div');
        _alternateToolbar.id = "alter_toolbar";
        _alternateToolbar.className = "ze_SCmb ze_alttool";
        // _body.appendChild(_alternateToolbar);
        editor.editordiv.appendChild(_alternateToolbar);
        // editor.outerdiv.a(alternateToolbar,nextSibling);

        _alternateToolbar.style.display = "none";
        editor.alterTool = _alternateToolbar;
    };
    toolbarArrayLength = toolbararray.length;
    for (i = 0; i < toolbarArrayLength; i++) {

        _ul = _document.createElement("ul");

        if (soFarWidth > toolbardiv.offsetWidth - 150 && altToolCheck === 0 && i !== toolbarArrayLength - 1 && !editor.initobj.avoidMoreOption) {

            // createAlternateToolbar();
            // toolbarinnerarray = [
            //     ["more", "More", "zei-more"]
            // ]; // No I18N
            // i--; // to insert more options
            // altToolCheck = 1; // to denote more has been already inserted
            toolbarinnerarray = toolbararray[i];
        }
         else
          {
            toolbarinnerarray = toolbararray[i];
        }
        for (j = 0, toolbarInnerArrayLength = toolbarinnerarray.length; j < toolbarInnerArrayLength; j++) {
            commandArray = toolbarinnerarray[j]; // ["bold","Bold Ctrl+B","zei-bold"]
            commandName = commandArray[0]; // bold
            _class = commandArray[2]; // zei-bold

            _li = _document.createElement("li");
            _ul.appendChild(_li);

            if (commandName === "otheroptions") {
                _ul.className = "ze_frt";
                _ul.style.display = "";
            }

            _b = _document.createElement("b");

            if (commandName === "attach") {
                _b.className = "ze_Sel ze_bg";
            }
            if (commandName === "fontsize") {
                var s = _document.createElement('span');
                _b.style.minWidth = "36px"; // No I18N
                _b.appendChild(s);
                s.className = "ze_pdl";
            }

            var _span = _document.createElement("span"),
                span2;
            _span.className = _class;
            _b.appendChild(_span);

            if (commandName === "alignoptions" || commandName === "listoptions") {
                span2 = document.createElement("span");
                span2.className = "zei-arrow";
                _b.appendChild(span2);
            }
            _b.setAttribute("data-toggle", "tooltip");

            _li.appendChild(_b);

            _b.title = I18N(commandArray[1]);
            if (commandName === "alignoptions" || commandName === "listoptions") {
                // arrow object to create dropdown
                ZE._addEvent(span2, "click", btnonclick(commandName)); // No I18N
                ZE._addEvent(span2, "mousedown", stopEv); // No I18N
                // clicked straightly at the element
                ZE._addEvent(_span, "click", executeAction()); // No I18N
                ZE._addEvent(_span, "mousedown", stopEv); // No I18N
            } else if (commandName === "custom") {
                ZE._addEvent(_b, "click", commandArray[3]);
                ZE._addEvent(_b, "mousedown", stopEv);
            } else {
                ZE._addEvent(_b, "click", btnonclick(commandName)); // No I18N
                ZE._addEvent(_b, "mousedown", stopEv); // No I18N
            }
            /* _b.addEventListener("click",btnonclick(commandName),true);
            		_b.addEventListener("mousedown",function(ev){
            			editor._stopEvent(ev);
            			return false;
            		},true);
            			*/
            toolbarobject[commandName] = _b;

            if (j !== 0) {
                _div = document.createElement('div');
                // _div.className="ze_hd";
                _b.appendChild(_div);
            }

        }
        var currentToolbar;
        /* avoid adding more option,other options inalternate toolbar*/
        if (commandName !== "more" && commandName !== "otheroptions" && altToolCheck === 1) {
            currentToolbar = _alternateToolbar;
        } else {
            currentToolbar = toolbardiv;
        }
        currentToolbar.appendChild(_ul);
        soFarWidth += _ul.offsetWidth;

        if (i !== toolbarArrayLength - 1 && commandName !== "more") {
            var fontElem = document.createElement("font");
            currentToolbar.appendChild(fontElem);
        }
    }

    if (toolbarobject.heading) {
        (function() {
            var _span1 = toolbarobject.heading.appendChild(_document.createElement("span"));
            _span1.className = "ze_heading_menu";
            _span1.appendChild(_document.createTextNode("Nr")); // No I18N
        }());
    }

    if (typeof ZE_Init.afterToolbarGenerate === "function") {
        ZE_Init.afterToolbarGenerate(toolbarobject);
    }

    editor.outerdiv.appendChild(fragment);
};

ZE.prototype.expandToolbar = function(ev) {
    "use strict"; // No I18N
    var editor = this,
        _anchorelement,
        _alternateToolbar,
        _document = document,
        _body = _document.body,
        _altToolbarStyle,
        removeEventListeners;
    _anchorelement = ev.currentTarget; // holds the anchor element;
    _alternateToolbar = editor.alterTool;
    _altToolbarStyle = _alternateToolbar.style;
    if (_altToolbarStyle.display !== "none") {
        _altToolbarStyle.display = "none";
        _anchorelement.parentNode.style.backgroundColor = "";
        return;
    }

    var setPositions = function() {
        var _alterToolbarStyle = editor.alterTool.style;
        var offsets = ZE.getPos(_anchorelement);
        // _alterToolbarStyle.top = offsets.offsetTop + _anchorelement.offsetHeight + 3 + "px";  // No I18N
        // _alterToolbarStyle.right=(document.body.getBoundingClientRect().width - (_anchorelement.offsetLeft + _anchorelement.getBoundingClientRect().width) - 5) + "px";            //No I18N
        _alterToolbarStyle.left = (_anchorelement.offsetParent.offsetLeft + _anchorelement.offsetLeft + _anchorelement.offsetWidth) - editor.alterTool.offsetWidth + "px"; // NO I18N
        // _alterToolbarStyle.left = _anchorelement.offsetLeft + "px";
    };

    var mouseDown = function(event) { // if user clicks outside the iframe
        var alterToolbar = editor.alterTool,
            _target;
        if (ev) {
            _target = event.target;
            for (; _target !== null; _target = _target.parentNode) {
                if (_target === alterToolbar || _target === _anchorelement) {
                    break;
                }
            }
        }
        if (!_target) {
            removeEventListeners();
        }
    };

    removeEventListeners = function() {
        var alterToolbar = editor.alterTool;
        if (alterToolbar) {
            alterToolbar.style.display = "none";
            _anchorelement.parentNode.style.backgroundColor = ""; // No I18N
            ZE._removeEvent(document, "mousedown", mouseDown); // No I18N
            ZE._removeEvent(editor.doc, "mousedown", mouseDown); // No I18N
        }
    };

    _altToolbarStyle.display = ""; // No I18N
    _anchorelement.parentNode.style.backgroundColor = "#f1f1f1"; // No I18N
    setPositions();
    editor.removeAlterToolbar = function() {
        if (editor.alterTool.style.display !== "none") {
            removeEventListeners();
        }
    };
    ZE._addEvent(document, "mousedown", mouseDown); // No I18N
    ZE._addEvent(editor.doc, "mousedown", mouseDown); // No I18N
};

ZE.prototype.resizeToolbar = function(_pos) {
    "use strict"; // No I18N

    var editor = this,
        oldPos,
        i;

    if (!editor.initToolbarBlock) {
        oldPos = ZE_Init.initToolbarBlock;
    } else {
        oldPos = editor.initToolbarBlock;
    }

    editor.initToolbarBlock = _pos;

    var ulList = editor.toolbardiv.getElementsByTagName("ul"),
        fontList = editor.toolbardiv.getElementsByTagName("font"),
        toolbararrayLength = ulList.length;
    if (_pos === oldPos) {
        return;
    }


    var element = ulList[oldPos - 1];

    element.style.display = "";
    element.parentNode.removeChild(element);


    if (_pos > oldPos) {
        for (i = oldPos - 1; i < _pos - 1; i++) {
            ulList[i].style.display = "";
            fontList[i - 1].style.display = "";
        }
    } else {

        fontList[_pos - 1].style.display = "none";
        for (i = _pos - 1; i < toolbararrayLength - 2; i++) {
            ulList[i].style.display = "none";
            fontList[i - 1].style.display = "none";
        }
        // fontList[i].style.display="";
    }
    ulList[_pos - 1].parentNode.insertBefore(element, ulList[_pos - 1]);
    element.previousSibling.style.display = "";

};

/* globals ZE,ZE_Init,Squire,ze_Undo*/
ZE.prototype.updateToolbar = function() {
    "use strict"; // No I18N
    var editor = this,
        toolbarobject = editor.toolbarobject,
        doc = editor.doc,
        j,
        color,
        value;
        ZE_Init.currentEditor = editor;
        var   sel = ZE_Init.currentEditor.win.getSelection();
        ZE_Init.textNode = sel.focusNode;
        ZE_Init.newOffset = sel.focusOffset;
        //ZE_Init.currentEditor.doc.body.focus();
    for (j in toolbarobject) {
        switch (j) {
            case "bold": // No I18N
            case "italic": // No I18N
            case "underline": // No I18N
            case "strikethrough": // No I18N
            case "superscript": // No I18N
            case "subscript": // No I18N
            case "insertorderedlist": // No I18N
            case "insertunorderedlist": // No I18N
                try
                {
                    if (doc.queryCommandState(j)) {
                        if (toolbarobject[j].className.search("ze_esel") < 0) { // No I18N
                            ZE.addClass(toolbarobject[j], "ze_esel"); // No I18N
                        }
                    } else {
                        ZE.removeClass(toolbarobject[j], "ze_esel"); // No I18N
                    }
                }
                catch(e)
                {
                    // Empty block statement
                }
                break;
            case "alignoptions": // No I18N
                try
                {
                    if (doc.queryCommandState("justifyright")) { // No I18N
                        toolbarobject[j].firstChild.setAttribute("class", "zei-textright"); // No I18N
                    } else if (doc.queryCommandState("justifycenter")) { // No I18N
                        toolbarobject[j].firstChild.setAttribute("class", "zei-textcenter"); // No I18N
                    } else if (doc.queryCommandState("justifyfull")) { // No I18N
                        toolbarobject[j].firstChild.setAttribute("class", "zei-textjustify"); // No I18N
                    } else {
                        toolbarobject[j].firstChild.setAttribute("class", "zei-textleft"); // No I18N
                    }
                }
                catch(e)
                {
                    // Empty block statement
                }
                break;
            case "listoptions": // No I18N
                /*	if(doc.queryCommandState("insertunorderedlist")) {
                		toolbarobject[j].firstChild.setAttribute("class","zei-unorder");
                	}
                	else if(doc.queryCommandState("insertorderedlist")) {
                		toolbarobject[j].firstChild.setAttribute("class","zei-order");
                }*/
                break;
            case "forecolor": // No I18N
                try
                {
                    var fontcolor = doc.queryCommandValue("forecolor") || "black"; // No I18N
                    value = fontcolor;
                    if (typeof value === "number") {
                        toolbarobject[j].firstChild.style.color = "rgb(" + (value & 0xFF) + "," + ((value >> 8) & 0xFF) + "," + ((value >> 16) & 0xFF) + ")"; // No I18N
                    } else {
                        toolbarobject[j].firstChild.style.color = fontcolor;
                    }
                }
                catch(e)
                {
                    // Empty block statement
                }
                break;
            case "backcolor": // No I18N
                try {
                    color = doc.queryCommandValue("backcolor") || doc.queryCommandValue("hilitecolor"); // No I18N

                    if (/transparent/i.test(color)) { // firefox returns transparent
                        color = editor.getFormattingValues("highlight") || "white"; // No I18N
                    } else if (color === "rgba(0, 0, 0, 0)") { //  Mozilla and Chrome // No I18N
                        color = "white"; // No I18N
                    }
                    value = color;
                    if (typeof value === "number") { // No I18N
                        parseInt(value + "");
                        toolbarobject[j].firstChild.style.borderBottom = "3px rgb(" + (value & 0xFF) + "," + ((value >> 8) & 0xFF) + "," + ((value >> 16) & 0xFF) + ") solid"; // No I18N
                    } else {
                        toolbarobject[j].firstChild.style.borderBottom = "3px " + color + " solid"; // No I18N
                    }
                } catch (e) {
                    // Empty block statement
                }
                break;
            case "fontfamily": // No I18N
                try {
                    //	var fname = doc.queryCommandValue("fontname") || ZE_Init.defaultFontFamily;		//No I18N
                    //	toolbarobject[j].firstChild.style.fontFamily = fname;
                    //	fname = fname.split(",")[0];
                    //	fname = fname.replace(/['"]/gi, '');
                    //	toolbarobject[j].firstChild.innerHTML = ZE.ffDisp[fname.toLowerCase()];
                } catch (e) {
                    // Empty Block Statement
                }
                break;
            case "fontsize": // No I18N
                try {
                    var fsize = doc.queryCommandValue("fontsize"); // No I18N
                    var isIE = /*@cc_on!@*/false || !!document.documentMode;    
                    var isEdge = !isIE && !!window.StyleMedia;
                    if (fsize) 
                    {
                        if(isEdge && fsize.includes('px'))
                        {
                            toolbarobject[j].firstChild.innerHTML = Math.round(3/4*fsize.slice(0, -2));
                        }
                        else
                        {
                            toolbarobject[j].firstChild.innerHTML = ZE.fsDisp[fsize];
                        }

                    } else {
                        var fontsize = editor.getFormattingValues("size"); // No I18N


                        if (fontsize) {
                            toolbarobject[j].firstChild.innerHTML = editor.fontsizeConversion("pxtopt", parseInt(fontsize)); // No I18N
                        } else if (fsize === 0) {
                            toolbarobject[j].firstChild.innerHTML = ZE.fsDisp[2];
                        } else {
                            toolbarobject[j].firstChild.innerHTML = parseInt(ZE_Init.defaultFontSize);
                        }
                    }
                } catch (e) {
                    // Empty Block Statement
                }
                break;
        }
    }
};

ZE.prototype.createEditor = function() {
    "use strict"; // No I18N
    var editor = this,
        _document = document,
        _iframe,
        _initobj = editor.initobj,
        parentDiv = _document.getElementById(_initobj.id),
        _editorheight = _initobj.editorheight,
        constructIframe,
        handleDragOver,
        handleDragLeave;

    ZE.is_chrome = navigator.userAgent.toLowerCase().indexOf('chrome') > -1; // No I18N
    /* creating editor start */
    _iframe = _document.createElement('iframe'); // No I18N
    editor.iframe = _iframe;
    _iframe.className = "ze_area"; // No I18N
    _iframe.id="ze_id";

    // if (_editorheight) {
    //     _iframe.style.height = _editorheight + "px"; // No I18N
    // } else {
    //     _iframe.style.height = (parentDiv.getBoundingClientRect().height -
    //         editor.toolbardiv.getBoundingClientRect().height + "px"); // No I18N
    // }

    /* creating editor end */


    constructIframe = function() {
        var win = _iframe.contentWindow,
            doc = win.document || _iframe.contentDocument,
            docBody = doc.body,
            _initobjContent = _initobj.content,
            afterLoadArray,
            afterLoadArrayLength,
            setClassOnBody,
            fontFamily,
            fontSize,
            loadEditorCss;

        editor.win = win;
        editor.doc = doc;
        _iframe.onload = null;
        if (doc.write) {
            doc.open();
            doc.write("<!DOCTYPE html><html><body><div><br/></div></body></html>"); // No I18N
            doc.close();
        }

        loadEditorCss = function(cssFile) { // No I18N
            var _head = doc.getElementsByTagName("head")[0]; // No I18N
            var css = doc.createElement("link"); // No I18N
            css.type = 'text/css'; // No I18N
            css.rel = 'stylesheet'; // No I18N
            // css.href = ZE_Init.cssPath + '/css/' + cssFile;// No I18N

            /* mac safari 3.2 will not have head tag*/
            if (!_head) {
                docBody.parentNode.insertBefore(doc.createElement("head"), docBody); // No I18N
                _head = doc.getElementsByTagName("head")[0]; // No I18N
            }
            if (_head) {
                _head.appendChild(css);
            }
        };
        editor.doc.body.contentEditable = true;

        /* setting event listeners for document*/
        ZE._addEvent(doc, "mousedown", function(ev) { // No I18N
            var _anchorElement = ev.target;
            var imgBlock = editor.doc.getElementById("ze_imgBlock"); // No I18N

            while (_anchorElement !== null) {
                if (_anchorElement.nodeName === "IMG" && _anchorElement.hasAttribute("orig_width")) { // No I18N
                    editor._stopEvent(ev);
                    return false;
                } else if (_anchorElement === imgBlock) {
                    ev.preventDefault();
                    return false;
                }

                _anchorElement = _anchorElement.parentNode;
            }
        });
         ZE._addEvent(doc.body, "focus", function(ev) 
         {
            ZE_Init.currentEditor = editor;
        });
        /* handles mouse move event listeners for document */
        ZE._addEvent(doc, "mousemove", function(ev) {
            editor.updateToolbar();
            var _anchorTarget = ev.target;
            // if (doc.getElementById("_resizecolDivs")) {
            // 	var _resize = doc.getElementById("_resizecolDivs");
            // 	_resize.parentElement.removeChild(_resize);
            // }
            while (_anchorTarget !== null) {
                if (_anchorTarget.nodeName === "TABLE" && ZE_Init.resizeTableAllowed) {

                    editor.resizeColumn(_anchorTarget);
                    break;
                } else {
                    _anchorTarget = _anchorTarget.parentNode;
                }
            }
            // if (doc.getElementById("_resizecolDivs")) {
            // 	var _resize = doc.getElementById("_resizecolDivs");
            // 	_resize.parentElement.removeChild(_resize);
            // }
        });

        /* hanldes mouse up event listeners for the document*/
        ZE._addEvent(doc, "mouseup", function(ev) { // No I18N
            editor.updateToolbar(); // present above
            if (doc.getElementById("_enclosingDiv")) {
                return false;
            }
            if (doc.getElementsByClassName("enc").length >= 1) {
                return false;
            }
            if (doc.getElementById("_colEncloseDiv")) {
                // var _resize = doc.getElementById("_resizecolDivs");
                // _resize.parentElement.removeChild(_resize);
                return false;
            }
            var _anchorElement = ev.target;
            while (_anchorElement !== null) {
                if (_anchorElement.nodeName === "A") { // No I18N
                    editor._stopEvent(ev);
                    editor.showAnchorTag(_anchorElement, ev);
                    return false;
                } else if (_anchorElement.nodeName === "IMG" && _anchorElement.hasAttribute("orig_width")) { // No I18N

                    if (_anchorElement.parentNode.nodeName === "A") { // No I18N
                        editor._stopEvent(ev);
                        editor.showAnchorTag(_anchorElement.parentNode, ev);
                    } else {
                        var zeLinkBlock = doc.getElementById("ze_imgBlock"); // No I18N
                        if (!zeLinkBlock) {
                            editor._stopEvent(ev);
                            editor.resizeElement(_anchorElement, ev);
                        }
                    }
                    return false;
                } else if (_anchorElement.nodeName === "TABLE") {
                    if (doc.getElementById("_enclosingDiv")) {
                        return false;
                    } else{
                        editor._stopEvent(ev);
                        if(ZE_Init.resizeTableAllowed)
                        {
                            editor.resizeTable(_anchorElement);
                        }
                        return false;
                    }
                } else {
                    _anchorElement = _anchorElement.parentNode;
                }
            }
        });

        handleDragOver = function(evt) { // No I18N
            var dt = evt.dataTransfer,
                I18N = ZE.i18n,
                effectAllowed;
            editor.win.focus();
            if ((dt.types !== null || (dt.files && dt.files.length > 0)) && !evt.fromPaste) {
                if ((dt.files && dt.files.length > 0) ||
                    (dt.types.indexOf ? dt.types.indexOf('Files') !== -1 : dt.types.contains('application/x-moz-file')) || // No I18N
                    dt.types[0] === "Files") { // No I18N
                    clearTimeout(editor.dragTimer);
                    effectAllowed = dt.effectAllowed;
                    dt.dropEffect = (effectAllowed === 'move' || effectAllowed === 'linkMove') ? 'move' : 'copy'; // No I18N
                    var _selection;
                    _selection = editor.saveSelection();
                    var _iframeValues,
                        scrollYval,
                        $mask,
                        $innerMask,
                        maskStyle;

                    $mask = doc.getElementById("mask_editor"); // No I18N
                    if (!$mask) {
                        $mask = doc.createElement('div'); // No I18N
                        $mask.contentEditable = "false"; // No I18N
                        $mask.id = "mask_editor"; // No I18N
                        doc.body.appendChild($mask);
                        maskStyle = $mask.style;
                        _iframeValues = editor.iframe.getBoundingClientRect();
                        if (editor.win.scrollY) {
                            scrollYval = editor.win.scrollY;
                        } else {
                            scrollYval = editor.win.pageYOffset;
                        }
                        maskStyle.height = _iframeValues.height + "px"; // No I18N
                        maskStyle.width = _iframeValues.width + "px"; // No I18N
                        maskStyle.left = "0px"; // No I18N
                        if (editor.win.scrollY) {
                            scrollYval = editor.win.scrollY;
                        } else {
                            scrollYval = editor.win.pageYOffset;
                        }
                        maskStyle.top = (0 + scrollYval) + "px"; // No I18N
                        maskStyle.position = "absolute"; // No I18N
                        $innerMask = doc.createElement('div'); // No I18N
                        $innerMask.className = "ze_drag"; // No I18N// No I18N
                        $innerMask.contentEditable = "false"; // No I18N
                        var $span = doc.createElement('span'); // No I18N
                        $innerMask.appendChild($span);
                        $span.innerHTML = I18N("Drop Files to Attach"); // No I18N
                        $mask.appendChild($innerMask);
                        $innerMask.style.height = (editor.iframe.offsetHeight * (0.70)) + "px"; // No I18N
                        $innerMask.style.marginTop = "-" + ((editor.iframe.offsetHeight * (0.70)) / 2) + "px"; // No I18N
                        if (_selection) {
                            editor.restoreSelection(_selection);
                        }
                        editor.win.focus();
                    }
                }
            }
            editor._stopEvent(evt);
        };

        handleDragLeave = function(evt) { // No I18N
            editor.dragTimer = setTimeout(function() {
                var mask = doc.getElementById("mask_editor"); // No I18N
                if (mask) {
                    mask.parentElement.removeChild(mask);
                }
            }, 250);
            editor._stopEvent(evt);
        };

        var removeElementFromMain = function(editor1, file) {
            var i;
            for (i = 0; i < editor1.inlineImagesToBe.length; i++) {
                if (editor1.inlineImagesToBe[i] === file) {
                    editor1.inlineImagesToBe.splice(i, 1);
                    break;
                }
            }
        };

        var removeElementFromWait = function(editor1, file) {
            var i;
            for (i = 0; i < editor1.waitForResponse.length; i++) {
                if (editor1.waitForResponse[i] === file) {
                    editor1.waitForResponse.splice(i, 1);
                    break;
                }
            }
        };

        var inlineImageUpload = function(file, editorRef) {
            var activeeditor = editorRef,
                xhr = new XMLHttpRequest(),
                form = new FormData(),
                csrf = ZE.getCSRFCookie(editorRef),
                _formAction,
                contextParam,
                imgAction;

            form.append(ZE.getCSRFParamName(), csrf); // No I18N

            if (file) {
                form.append("img_file", file, "test.png"); // No I18N
            }
            imgAction = ZE_Init.imgAction;
            if (ZE_Init.imgParameters) {
                imgAction += ZE_Init.imgParameters;
            }
            if (ZE_Init.context) {
                if (ZE_Init.imgParameters) {
                    _formAction = imgAction + "&context=" + ZE_Init.context; // No I18N
                } else {
                    _formAction = imgAction + "?context=" + ZE_Init.context; // No I18N
                }
                contextParam = "&context=" + ZE_Init.context; // No I18N
            }
            if (ZE.captchaParam) {
                if (ZE_Init.imgParameters || ZE_Init.context) { // If service team pass some other parameter
                    _formAction = imgAction + "&" + ZE.captchaParam + contextParam; // NO I18N
                } else {
                    _formAction = imgAction + "?" + ZE.captchaParam + contextParam; // NO I18N
                }
                delete(ZE.captchaParam);
            }
            _formAction += "&uploadMode=drop"; // No I18N

            var img = activeeditor.doc.createElement('img'), // No I18N
                newsel,
                newrange;
            try {
                activeeditor.win.focus();
                img.src = ZE_Init.imgPath + "/images/loading.gif"; // No I18N
                newsel = activeeditor._getSelection();
                newrange = activeeditor._createRange(newsel);
                newrange.insertNode(img);
                newrange.selectNode(img);
                newrange.collapse(false);
                newsel.removeAllRanges();
                newsel.addRange(newrange);
                removeElementFromMain(activeeditor, file); // remove from main array
                activeeditor.waitForResponse.push(file); // push in wait for response
            } catch (e) {
                return null;
            }

            xhr.onreadystatechange = function() {
                var _file = file,
                    _img = img,
                    insertImageInline;
                if (xhr.readyState == 4) {
                    removeElementFromWait(activeeditor, _file);
                    if (xhr.status == 200) {
                        var resp = ZE_Init.jQuery.parseJSON(xhr.responseText);
                        if (resp.fileName) {
                            if (activeeditor.inlineImagesToBe.length == 0) {
                                delete ZE_Init.captchaProcessing;
                            }
                            insertImageInline = function(_img) {
                                return function(_imgUrl) {
                                    _img.onload = function() {
                                        _img.setAttribute("orig_width", this.width);
                                        _img.setAttribute("orig_height", this.height);
                                        _img.setAttribute("size_option", "original");

                                        ZE.setImageSizeOptions(this, "bestfit", editorInstance.editordiv.offsetWidth); // NO I18N
                                        _img.removeAttribute("data-zeload");
                                    };
                                    _img.setAttribute("data-zeload", true);
                                    _img.src = _imgUrl;
                                    editorRef.saveCurrentState();
                                };
                            };
                            ZE_Init.inlineImage(insertImageInline(_img), resp); // insert Image
                        } else {
                            activeeditor.inlineImagesToBe.push(_file);
                            _img.parentNode.removeChild(_img);

                            if (resp.errorMsg == "HIP_REQUIRED") {
                                ZE_Init.latesthip = resp.hipUrl; // updating latest hip
                                ZE.captchaProcessing = function() {
                                    uploadInlineImages(activeeditor);
                                };
                                ZE_Init.captchaInline = true; // need to process captcha
                            }
                        }
                    } else if (xhr.status == 500) {
                        _img.parentNode.removeChild(_img);
                    }
                }
            };
            xhr.open("POST", _formAction, true); // No I18N
            xhr.send(form);
            return xhr;
        };

        var uploadInlineImages = function(editorRef) {
            var i,
                file,
                filesArray,
                filesArrayLength,
                xhrObj;

            /* Make sure editor has focus before you insert the image*/
            editorRef.win.focus();
            ZE_Init.captchaInline = false;
            if (!editorRef.waitForResponse) {
                editorRef.waitForResponse = [];
            }
            /* doing this will not alter the main array*/
            filesArray = editorRef.inlineImagesToBe.slice(0);
            filesArrayLength = filesArray.length;
            for (i = 0; i < filesArrayLength; i++) {
                /* Send out individual parallel requests all along*/
                xhrObj = inlineImageUpload(filesArray[i], editorRef);
                if (!xhrObj) { // in order to avoid break
                    editorRef.inlineImagesToBe.splice(0);
                    break;
                }
            }
            setTimeout(function() {
                if (ZE_Init.captchaInline) {
                    ZE.show_CaptchaImage(ZE_Init.latesthip, editorRef);
                }
            }, 1000);
        };

        var _uploadInlineImages = function(editorRef, imgFile) {

            var img = editorRef.doc.createElement('img'); // No I18N

            var insertImageInline = function() {
                return function(_imgUrl, uniqId) {
                    uniqId = "ze_" + uniqId + "_refresh"; // No I18N
                    var _img = editorRef.doc.getElementById(uniqId);
                    delete editor._pendingImagesList[uniqId];
                    if (!_img) {
                        editor._unusedImagesList[uniqId] = _imgUrl;
                        return;
                    }
                    _img.onload = function() {
                        _img.setAttribute("orig_width", this.width); // No I18N
                        _img.setAttribute("orig_height", this.height); // No I18N
                        ZE.setImageSizeOptions(_img, "bestfit", editor.editordiv.offsetWidth); // No I18N
                        _img.removeAttribute("data-zeload"); // No I18N
                    };
                    _img.setAttribute("data-zeload", true); // No I18N
                    _img.src = _imgUrl;
                    _img.removeAttribute("id"); // No I18N
                    _img.removeAttribute("class"); // No I18N
                    editorRef.saveCurrentState();
                };
            };

            var initiate = function() {
                return function(uniqId) {
                    img.src = ZE_Init.imgPath + "/images/loading.gif"; // No I18N
                    img.id = "ze_" + uniqId + "_refresh"; // No I18N
                    editor._pendingImagesList[img.id] = true;
                    img.className = "ze_img_upload"; // No I18N
                    var newsel = editorRef._getSelection();
                    var newrange = editorRef._createRange(newsel);
                    newrange.insertNode(img);
                    newrange.selectNode(img);
                    newrange.collapse(false);
                    newsel.removeAllRanges();
                    newsel.addRange(newrange);
                };
            };

            var onFailure = function() {
                return function(uniqId) {
                    uniqId = "ze_" + uniqId + "_refresh"; // No I18N
                    var _img = editorRef.doc.getElementById(uniqId);
                    delete editor._pendingImagesList[uniqId];
                    if (_img) {
                        _img.parentNode.removeChild(_img);
                    }
                };
            };

            if (typeof editor.initobj.processPastedFile === "function") {
                editor.initobj.processPastedFile(imgFile, editorRef, initiate(), insertImageInline(), onFailure());
            }

        };

        var handleEditorPasteImages = function(evt) {
            var items = evt.dataTransfer.items,
                itemsLength = items.length;


            for (var i = 0; i < itemsLength; i++) {
                if (items[i].kind === "file" && items[i].type === "image/png") { // No I18N
                    var imageFile = items[i].getAsFile();
                    if (!imageFile.name) {
                        imageFile.name = "Inline_image" + new Date().getTime() + Math.floor((Math.random() * 1000) + 1); // No I18N
                    }
                    editor._uploadInlineImages({
                        file: imageFile
                    });
                }
            }

        };
        var handleEditorDrop = function(evt) {
            editor._stopEvent(evt);
            var mask = doc.getElementById("mask_editor"); // No I18N
            if (mask) {
                mask.parentElement.removeChild(mask);
            }
            editor.win.focus();

            /* handle paste image as drop and move it separately */
            if (evt.editorCustomPaste) {
                if (editor.initobj.handlePasteImages) {
                    handleEditorPasteImages(evt);
                }
                return;
            }
            var files = evt.dataTransfer.files;
            if (!files || files.length === 0) { /* no file api support or no files are chosen */
                return;
            }

            var I18N = ZE.i18n,
                uploadType = "inline", // No I18N
                errorFiles = "",
                i;

            for (i = 0; i < files.length; i++) {
                if (!files[i].type || files[i].type.indexOf("image") < 0) { // No I18N
                    uploadType = "attachments"; // No I18N
                    break;
                }
            }
            if (uploadType === "inline" && (ZE_Init.dropInlineImage)) {
                if (!editor.inlineImagesToBe) { // inlineImagesToBeUploaded
                    editor.inlineImagesToBe = [];
                }

                for (i = 0; i < files.length; i++) {
                    if (files[i].size > 0 && files[i].size / (1024 * 1024) < 3) {
                        editor.inlineImagesToBe.push(files[i]);
                    } else {
                        errorFiles += files[i].name + ",";
                    }
                }
                if (errorFiles !== "") {
                    // alert(I18N("Files " + errorFiles + " cant be uploaded as they violate size restriction")); // No I18N
                }
                uploadInlineImages(editor);
            } else {
                ZE_Init.fileUpload(editor, files, evt);
            }
        };

        ZE._addEvent(doc, 'drop', handleEditorDrop); // No I18N
        ZE._addEvent(doc, 'dragover', handleDragOver); // No I18N
        ZE._addEvent(doc, 'dragleave', handleDragLeave); // No I18N
        editor._unusedImagesList = {};
        editor._pendingImagesList = {};

        var stack;
        var initializeUndo = function() {
            // editor.initiateUndoRedo();
            editor.stack = new ze_Undo.Stack();
            stack = editor.stack;
            editor.EditorState = {};
            editor.EditorState = function(textarea, newValue, _currentselection) {
                this.textarea = textarea;
                this.newValue = newValue;
                this._currentselection = _currentselection;

                this.undo = function() {
                    editor.setContent(this.newValue, true);
                };
                this.redo = function() {
                    editor.setContent(this.newValue, true);
                };
                this.setFocus = function() {
                    var _object = this._currentselection;
                    editor.restoreCursorPosition(editor.doc.body, _object);
                    editor.win.focus();
                };
            };

            var startValue = editor.getContent(),
                timer;
            if (editor.initobj.handleAutoFill) {
                editor.mentionsHandler();
            }
            ZE._addEvent(doc, "keyup", function(ev) { // No I18N
                var kcode = ev.keyCode;
                if (kcode === 33 || kcode === 34) {
                    ev.stopPropagation();
                }
                // key = String.fromCharCode(kcode).toLowerCase();
                // 	var _targetElement = editor._getSelection().anchorNode.parentElement;
                // 	while (_targetElement !== null) {
                // 		if (_targetElement.nodeName === "TABLE") {
                // 			// editor._stopEvent(ev);
                // 			editor.resizeTable(_targetElement);
                // 			break;
                // 		} else {
                // 			_targetElement = _targetElement.parentNode;
                // 	}
                // }

                if (editor.undo || editor.redo) {
                    startValue = editor.getContent();
                    return;
                }

                clearTimeout(timer);
                timer = setTimeout(function() {
                    var newValue = editor.getContent();
                    /* ignore meta key presses*/
                    if (!ev.metaKey) {
                        // key = String.fromCharCode(kcode).toLowerCase();
                        editor.saveCurrentState();
                        startValue = newValue;
                    }
                }, 250);
            });
        };

        initializeUndo();

        ZE._addEvent(doc, "keydown", function(ev) { // No I18N
            /* variables caching*/
            var kcode = ev.keyCode,
                shift = ev.shiftKey,
                meta = ev.metaKey,
                alt = ev.altKey,
                ctrl = ev.ctrlKey,
                key,
                editorStack = editor.stack;

            editor.undo = editor.redo = false;

            if ((ctrl || meta) && !alt && !shift) {
                key = String.fromCharCode(kcode).toLowerCase();
                switch (key) {
                    case 'b': // No I18N
                        editor.execCommand(ev, "bold"); // No I18N
                        break;
                    case 'u': // No I18N
                        editor.execCommand(ev, "underline"); // No I18N
                        break;
                    case 'i': // No I18N
                        editor.execCommand(ev, "italic"); // No I18N
                        break;
                    case 'l': // No I18N
                        editor.execCommand(ev, "j-left"); // No I18N
                        break;
                    case 'e': // No I18N
                        editor.execCommand(ev, "j-center"); // No I18N
                        break;
                    case 'r': // No I18N
                        editor.execCommand(ev, "j-right"); // No I18N
                        break;
                    case 'j': // No I18N
                        editor.execCommand(ev, "j-justify"); // No I18N
                        break;
                    case 'k': // No I18N
                        editor.execCommand(ev, "link"); // No I18N
                        break;
                    case 'z': // No I18N
                        editor._stopEvent(ev);
                        if (editorStack.canUndo()) {
                            editorStack.undo();
                        }
                        editor.undo = true;
                        break;
                    case 'y': // No I18N
                        editor._stopEvent(ev);
                        if (editorStack.canRedo()) {
                            editorStack.redo();
                        }
                        editor.redo = true;
                        break;
                }
            }

            editor.updateToolbar();
        });

        setClassOnBody = function(_fontFamily, _fontSize) { // No I18N
            var _style,
                _style1,
                FontSize,
                PtToPx = {
                    8: 10,
                    10: 13,
                    12: 16,
                    14: 18,
                    18: 24,
                    24: 32,
                    36: 48
                };

            if (_fontSize.indexOf("px") !== -1) { // No I18N
                FontSize = _fontSize;
            } else {
                FontSize = PtToPx[parseInt(_fontSize)] + "px"; // No I18N
            }

            _style = editor.doc.createElement("style"); // No I18N
            _style.type = "text/css"; // No I18N
            _style.innerHTML = ".ze_body{font-family:" + _fontFamily + ";font-size:" + FontSize + ";margin:15px;height:calc(100% - 30px);}html{height:100%;};"; // No I18N

            _style1 = editor.doc.createElement("link"); // No I18N
            _style1.type = 'text/css'; // No I18N
            _style1.rel = 'stylesheet'; // No I18N
            _style1.href = ZE_Init.cssPath; // No I18N

            var _head = editor.doc.getElementsByTagName("head")[0]; // No I18N

            if (_head) {
                _head.appendChild(_style);
                _head.appendChild(_style1);
                editor.doc.body.className = "ze_body"; // No I18N
            }
        };

        fontFamily = _initobj.defaultfontfamily || ZE_Init.defaultFontFamily || "";
        fontSize = _initobj.defaultfontsize || ZE_Init.defaultFontSize || "";
        setClassOnBody(fontFamily, fontSize);
        delete editor.state;
        if (ZE_Init.needResizeImage) { // For loading other css in editor body
            loadEditorCss('editor.min.css'); // No I18N
        }
        loadEditorCss('editor1.min.css'); // No I18N

        var forceRepaint = function(containerEl) {
            var temp = containerEl.createElement("span"); // No I18N
            containerEl.body.appendChild(temp);

            setTimeout(function() {
                temp.parentNode.removeChild(temp);
            }, 100);
        };

        if (ZE_Init.is_safari && window.onblur) {
            ZE._addEvent(editor.doc.body, "focus", function() { // No I18N
                forceRepaint(document);
            });
            ZE._addEvent(editor.doc.body, "blur", function() { // No I18N
                var _selection = editor.win.getSelection();
                if (_selection.isCollapsed) {
                    if (editor.pasteHTML) {
                        editor.pasteHTML("<span id='temp_123paint'></span>"); // No I18N
                    }
                    var temp1 = editor.doc.getElementById("temp_123paint"); // No I18N
                    if (temp1) {
                        temp1.parentNode.removeChild(temp1);
                    }
                }
            });
        }

        ZE._addEvent(editor.win, "scroll", function() { // No I18N
            var zeLinkBlock = document.getElementById("ze_linkBlock"); // No I18N
            if (zeLinkBlock) {
                document.body.removeChild(zeLinkBlock);
            }
        });

        ZE._addEvent(editor.doc.body, "contextmenu", function(ev) { // No I18N
            var _anchorElement = ev.target;
            while (_anchorElement !== null) {
                if (ZE_Init.allowTableEditorOptions && (_anchorElement.nodeName === "TABLE" && ZE.getAttribute(_anchorElement, "data-avoidContext") !== "true"))// No I18N 
                { 
                    editor._stopEvent(ev);
                    editor.showContextMenu(ev, "table", _anchorElement); // No I18N
                    return false;
                } else {
                    _anchorElement = _anchorElement.offsetParent;
                }
            }
        });

        editor.squireInstance = new Squire(editor.doc, {
            getEditorInstance: function() {
                return editor;
            }
        });
        editor.squireInstance.addEventListener("dragover", function(ev) { // No I18N
            editor._stopEvent(ev);
        });
        editor.squireInstance.addEventListener("drop", handleEditorDrop); // No I18N
        if (_initobj.mode !== "plaintext") { // No I18N
            if (!_initobjContent) {
                _initobjContent = ""; // No I18N
            }
            editor.squireInstance.setHTML(_initobjContent);
        }
        if (editor.afterload) {
            afterLoadArray = editor.afterload;
            afterLoadArrayLength = afterLoadArray.length;
            while (afterLoadArrayLength--) {
                (afterLoadArray.shift())();
            }
        }
        delete editor.afterload;

        if (editor.mode === "richtext") { // No I18N
            if (ZE_Init.needEditorFocus || editor.initobj.needEditorFocus) {
                win.focus();
                editor.squireInstance.focus();
            }
            editor.updateToolbar();
        }
        editor.saveCurrentState({
            cursorPosition: {
                start: 0,
                end: 0
            },
            suppressContentChange: true
        });
        if (!(ZE_Init.needEditorFocus || editor.initobj.needEditorFocus) && editor.mode === "richtext") { // No I18N
            var selection = win.getSelection() || editor.doc.selection;
            selection.removeAllRanges();
        }
    };

    _iframe.onload = constructIframe;
    _iframe.srcdoc = "<!DOCTYPE html>"; // No I18N
    editor.editordiv.appendChild(_iframe);
};

ZE.prototype._stopEvent = function(ev) {
    "use strict"; // No I18N
    try {
        ev.preventDefault(); // preventing the default action happening
        ev.stopPropagation(); // preventing events of parent node
    } catch (e1) {
        ev.cancelBubble = true;
        ev.returnValue = true;
    }
};

ZE.getAttribute = function(element, attrName) {
    "use strict"; // No I18N
    if (element.hasAttribute(attrName)) {
        return element.getAttribute(attrName);
    }
};

/* updates undo redo stack html at any specific point */
ZE.prototype.updateStateHTML = function(stackPosition, html) {
    "use strict"; // NO I18N
    var editor = this;
    editor.stack.commands[stackPosition].newValue = html;
};

/* Accepts img as input and alters it height based on the input passed*/
ZE.setImageSizeOptions = function(img, option, editorWidth) {
    "use strict"; // No I18N
    var MAX_BESTFIT_WIDTH = 400,
        reduceRatio,
        returnObj = {},
        imgWidth = img.width || img.naturalWidth,
        imgHeight = img.height | img.naturalHeight;


    var bestFitWidth = parseInt(editorWidth * (3 / 4)); // 3/4th of the editor's width is the bestFitWidth
    if (bestFitWidth > MAX_BESTFIT_WIDTH) {
        bestFitWidth = MAX_BESTFIT_WIDTH;
    }

    if (option === "small") { // No I18N
        reduceRatio = 2.5;
        if (imgWidth > bestFitWidth) {
            reduceRatio = imgWidth / 150;
        }
        returnObj.width = (imgWidth / reduceRatio) + "px"; // No I18N
        returnObj.height = (imgHeight / reduceRatio) + "px"; // No I18N
        returnObj.sizeOption = "small"; // No I18N
    } else if (option === "bestfit") { // No I18N
        reduceRatio = 1;
        if (imgWidth > bestFitWidth) {
            reduceRatio = imgWidth / bestFitWidth;
        }
        returnObj.width = (imgWidth / reduceRatio) + "px"; // No I18N
        returnObj.height = (imgHeight / reduceRatio) + "px"; // No I18N
        returnObj.sizeOption = "bestfit"; // No I18N
    } else {
        returnObj.width = imgWidth + "px"; // No I18N
        returnObj.height = imgHeight + "px"; // No I18N
        returnObj.sizeOption = "original"; // No I18N
    }
    img.style.width = returnObj.width;
    img.style.height = returnObj.height;
    img.setAttribute("size_option", returnObj.sizeOption); // No I18N
};

ZE.prototype.checkForPendingImages = function() {
    "use strict"; // No I18N
    var editor = this,
        list = Object.keys(editor._pendingImagesList),
        pendingTags,
        status = false;

    if (list.length) {
        pendingTags = editor.doc.body.getElementsByClassName("ze_img_upload"); // No I18N
        if (pendingTags.length) {
            status = true;
        }
    }
    return status;
};

ZE.prototype.clearPendingImages = function() {
    "use strict"; // No I18N
    var editor = this,
        pendingTags = editor.doc.body.getElementsByClassName("ze_img_upload"), // No I18N
        i,
        length = pendingTags.length,
        node;

    editor._pendingImagesList = {};
    for (i = 0; i < length; i++) {
        node = pendingTags[i];
        if (node.nodeName === "IMG") { // No I18N
            node.parentNode.removeChild(node);
        }
    }
};

ZE.prototype.pasteContent = function(content) {
    // debugger;
    // content = content.replace(/<meta .*>/g, "");
    "use strict"; // NO I18N
    var _len = JSON.stringify(localStorage).length;
    var _locasize = (((_len * 16) / (8 * 1024)) / 1000);
    var _contentLen = content.length;
    var _contentsize = (((_contentLen * 16) / (8 * 1024)) / 1000);
    var _date = new Date();
    var _year = _date.getFullYear();
    var _month = _date.getMonth() + 1;
    if (_month < 10) {
        _month = "0" + _month;
    }
    var _days = _date.getDate();
    var _hours = _date.getHours();
    var _minutes = _date.getMinutes();
    var _seconds = _date.getSeconds();
    _date = _year + "-" + _month + "-" + _days + "\t" + _hours + ":" + _minutes + ":" + _seconds;
    if ((_contentsize + _locasize) <= 10) {

        localStorage.setItem(_date, JSON.stringify(content));
    } else {
        localStorage.clear();
        localStorage.setItem(_date, JSON.stringify(content));
    }
};

ZE.prototype._uploadInlineImages = function(dataObject) {
    "use strict"; // NO I18N
    var editor = this;
    var img = editor.doc.createElement('img'); // No I18N

    var insertImageInline = function() {
        return function(_imgUrl, uniqId) {
            uniqId = "ze_" + uniqId + "_refresh"; // No I18N
            var _img = editor.doc.getElementById(uniqId);
            delete editor._pendingImagesList[uniqId];
            if (!_img) {
                editor._unusedImagesList[uniqId] = _imgUrl;
                return;
            }
            _img.onload = function() {
                _img.setAttribute("orig_width", this.width); // No I18N
                _img.setAttribute("orig_height", this.height); // No I18N
                ZE.setImageSizeOptions(_img, "bestfit", editor.editordiv.offsetWidth); // No I18N
                _img.removeAttribute("data-zeload"); // No I18N
            };
            _img.setAttribute("data-zeload", true); // No I18N
            _img.src = _imgUrl;
            _img.removeAttribute("id"); // No I18N
            _img.removeAttribute("class"); // No I18N
            editor.saveCurrentState();
        };
    };



    var initiate = function() {
        return function(uniqId) {
            img.src = ZE_Init.imgPath + "/images/loading.gif"; // No I18N
            img.id = "ze_" + uniqId + "_refresh"; // No I18N
            editor._pendingImagesList[img.id] = true;
            img.className = "ze_img_upload"; // No I18N
            var newsel = editor._getSelection();
            var newrange = editor._createRange(newsel);
            newrange.insertNode(img);
            newrange.selectNode(img);
            newrange.collapse(false);
            newsel.removeAllRanges();
            newsel.addRange(newrange);
        };
    };

    var onFailure = function() {
        return function(uniqId) {
            uniqId = "ze_" + uniqId + "_refresh"; // No I18N
            var _img = editor.doc.getElementById(uniqId);
            delete editor._pendingImagesList[uniqId];
            if (_img) {
                _img.parentNode.removeChild(_img);
            }
        };
    };
    if (typeof editor.initobj.processPastedFile === "function") {
        editor.initobj.processPastedFile(dataObject, editor, initiate(), insertImageInline(), onFailure());
    }
};

/* global ZE,$,document,window */

ZE.prototype.mentionsHandler = function() {
    "use strict"; // No I18N
    var editor = this,
        setContent,
        handleNavigationAndCommandKeys,
        hideContextMenu,
        mouseDown,
        constructAndShow,
        setPositions,
        _document = document,
        _body = _document.body;

    ZE_Init.jQuery(editor.doc).on('keydown', function(ev) { // NO I18N
        var keyCode = ev.keyCode;
        if (keyCode === 38 || keyCode === 40) {
            /* If up or down arrow is pressed while the autofill dropdown is opened*/
            if (ZE_Init.jQuery('#ze_autofill').length) { // NO I18N
                ev.preventDefault();
            }
        } else if (keyCode === 13) {
            /* If up or down arrow is pressed while the autofill dropdown is opened*/
            if (ZE_Init.jQuery('#ze_autofill li.sel').length) { // NO I18N
                /* Make sure enter is not handled when enter is pressed while autofill is opened*/
                ev.preventDefault();
                ev.stopPropagation();
                ev.stopImmediatePropagation();
            }
        }
    });

    setContent = function(data, curElem, pos) {
        if (pos > -1 && ZE_Init.jQuery(curElem).length) {
            var tempPos = pos,
                _selection = editor.win.getSelection(),
                _range = _selection.getRangeAt(0);
            _range.setStart(curElem, tempPos);
            _selection.removeAllRanges();
            _selection.addRange(_range);
            editor.insertHTML('<a class="ze_mention" href=\'mailto:' + data.eid + '\'>' + data.fn + '</a>&nbsp;'); // NO I18N
            if (editor.initobj.triggerOnMention) {
                editor.initobj.triggerOnMention(data);
            }
        }
        hideContextMenu();
    };

    handleNavigationAndCommandKeys = function(ev, curElem, pos) {
        var $curSelectedElem,
            dataToSet,
            keyCode = ev.keyCode;
        if (keyCode === 40) { // This code doesnt throw error when ze_autofill is not there
            $curSelectedElem = ZE_Init.jQuery('#ze_autofill li.sel'); // NO I18N
            $curSelectedElem.removeClass('sel'); // NO I18N
            if ($curSelectedElem.next().length) {
                $curSelectedElem.next().addClass('sel'); // NO I18N
            } else {
                ZE_Init.jQuery('#ze_autofill li').first().addClass('sel'); // NO I18N
            }
            return true;
        } else if (keyCode === 38) {
            $curSelectedElem = ZE_Init.jQuery('#ze_autofill li.sel'); // NO I18N
            $curSelectedElem.removeClass('sel'); // NO I18N
            if ($curSelectedElem.prev().length) {
                $curSelectedElem.prev().addClass('sel'); // NO I18N
            } else {
                ZE_Init.jQuery('#ze_autofill li').last().addClass('sel'); // NO I18N
            }
            return true;
        } else if (keyCode === 13) {
            if (ZE_Init.jQuery('#ze_autofill').length && ZE_Init.jQuery('#ze_autofill').is(':visible')) { // NO I18N
                ev.preventDefault();
                ev.stopPropagation();
                ev.stopImmediatePropagation();
                $curSelectedElem = ZE_Init.jQuery('#ze_autofill li.sel'); // NO I18N
                dataToSet = $curSelectedElem.data('mention'); // NO I18N
                setContent(dataToSet, curElem, pos);
            }
            return true;
        }
    };

    var handleAutoFill = function(ev) {

        var _selection = editor.win.getSelection(),
            _anchorNode = _selection.anchorNode,
            range = _selection.getRangeAt(0),
            newRange = range.cloneRange(),
            contents,
            res,
            currText,
            textContent,
            pos,
            handleKeys;

        newRange.setStart(_anchorNode, 0);
        contents = newRange.cloneContents();
        textContent = contents.textContent;
        pos = textContent.lastIndexOf('@'); // NO I18N

        handleKeys = handleNavigationAndCommandKeys(ev, _anchorNode, pos);
        /*
        The above method checks whether up , down or enter keys is present with autofill div being opened already , if
        so dont need to do anthing regarding new autofill .So handle the corresponding keys
        */
        if (!handleKeys) {
            if (pos === 0 || (pos > 0 &&
                    (textContent.charAt(pos - 1) === ' ' || textContent.charCodeAt(pos - 1) === 160))) { // NO I18N
                currText = ZE_Init.jQuery.trim(textContent.substr(pos + 1));
                res = (currText && editor.initobj.getAutofillContacts && editor.initobj.getAutofillContacts(currText)) || {};
                if (res.result && res.result.length) {
                    constructAndShow(res.result, _anchorNode, pos);
                } else {
                    ZE_Init.jQuery('#ze_autofill').remove(); // NO I18N
                }
            } else {
                ZE_Init.jQuery('#ze_autofill').remove(); // NO I18N
            }
        }
    };

    ZE_Init.jQuery(editor.doc).on('keyup', handleAutoFill); // NO I18N

    hideContextMenu = function() {
        var zeAutofillDiv = _document.getElementById('ze_autofill'), // NO I18N
            _doc = editor.doc;
        if (zeAutofillDiv) {
            _body.removeChild(zeAutofillDiv);
            ZE._removeEvent(_document, 'mousedown', mouseDown); // NO I18N
            ZE._removeEvent(_doc, 'mousedown', mouseDown); // NO I18N
        }
    };

    mouseDown = function(ev) { // if user clicks outside the iframe
        var zeAutofillDiv = _document.getElementById('ze_autofill'); // NO I18N
        var _target;
        if (ev) {
            _target = ev.target;
            for (; _target !== null; _target = _target.parentNode) {
                if (_target === zeAutofillDiv) {
                    break;
                }
            }
        }
        if (!_target) {
            hideContextMenu();
        }
    };

    setPositions = function(elem, anchorNode, pos) {
        var value1 = editor.iframe.getBoundingClientRect();
        var value2,
            posy,
            posx,
            style = elem.style,
            editorPos = ZE.getPos(editor.editordiv);
        if (editor.doc.createRange && anchorNode.nodeType === 3) {
            var range = editor.doc.createRange();
            range.setStart(anchorNode, pos);
            range.setEnd(anchorNode, pos + 1);
            if (range.getBoundingClientRect) {
                value2 = range.getBoundingClientRect();
            }
        }
        if (!value2) {
            value2 = anchorNode.parentNode.getBoundingClientRect();
        }
        posy = value1.top + value2.top + value2.height;
        posx = value1.left + value2.left;
        style.top = parseInt(posy) + 'px'; // NO I18N
        style.left = parseInt(posx) + 'px'; // NO I18N
        if (posy + elem.offsetHeight > editor.editordiv.offsetHeight + editorPos.offsetTop) {
            style.top = 'auto'; // NO I18N
            posy = window.innerHeight - posy + value2.height;
            style.bottom = parseInt(posy) + 'px'; // NO I18N
        }

    };

    constructAndShow = function(result, elem, pos) {
        var i,
            mentionsDiv = _document.createElement('div'), // NO I18N
            ulArea = _document.createElement('ul'), // NO I18N
            liArea,
            imgArea;

        if (ZE_Init.jQuery('#ze_autofill').length) { // NO I18N
            ZE_Init.jQuery('#ze_autofill').remove(); // NO I18N
        }
        mentionsDiv.id = 'ze_autofill'; // NO I18N
        mentionsDiv.className = 'ze_dd ze_autoFill shw '; // NO I18N
        ulArea.className = "ze_tbdr"; // NO I18N
        for (i = 0; i < result.length; i++) {
            liArea = _document.createElement('li'); // NO I18N
            if (result[i].photo) {
                imgArea = _document.createElement('img'); // NO I18N
                imgArea.src = result[i].photo;
                liArea.appendChild(imgArea);
            }
            liArea.appendChild(_document.createTextNode(result[i].fn));
            ZE_Init.jQuery(liArea).data('mention', result[i]); // NO I18N
            ulArea.appendChild(liArea);
        }
        mentionsDiv.appendChild(ulArea);
        _body.appendChild(mentionsDiv);
        setPositions(mentionsDiv, elem, pos);
        ZE._addEvent(ulArea, 'click', function(ev) { // NO I18N
            var curElem = elem,
                tempPos = pos,
                $targetElem = ev.target || ev.srcTarget,
                mentionData;
            $targetElem = ZE_Init.jQuery($targetElem).closest('li'); // NO I18N
            if ($targetElem.length) {
                mentionData = ZE_Init.jQuery($targetElem).data('mention'); // NO I18N
                setContent(mentionData, curElem, tempPos);
                hideContextMenu();
            }
        });

        ZE._addEvent(_document, 'mousedown', mouseDown); // NO I18N
        ZE._addEvent(editor.doc, 'mousedown', mouseDown); // NO I18N
    };
};


ZE.checkMacro = function(sel, selection,isIE,backward) {    // To check the selected text is a macro 

    if (sel && sel.rangeCount) {
        var selectionRanges = sel.getRangeAt(0).cloneRange();
        if (!selectionRanges.collapsed) {
            if (selectionRanges.toString().length > 0) {
                var data = ((selectionRanges.toString()).split(" ")).filter(function(entry) {  //  Seperate selected text to words
                    return entry.trim() != '';
                });
                while (selectionRanges.toString()[0].match(/^[\w%]/)) {  // Increase and decrease range upto word end
                    try {
                        selectionRanges.setStart(selectionRanges.startContainer, selectionRanges.startOffset - 1);
                        if(selectionRanges.toString()[0].match(/(\s+)/))
                        {       
                            selectionRanges.setStart(selectionRanges.startContainer, selectionRanges.startOffset + 1);    
                            break;                
                        }

                    } catch (e) 
                    {                       
                        break;
                    }
                }
                while (selectionRanges.toString()[selectionRanges.toString().length - 1].match(/^[\w%]/)) {
                    try 
					{
                        selectionRanges.setEnd(selectionRanges.endContainer, selectionRanges.endOffset + 1);
                        if(selectionRanges.toString()[selectionRanges.toString().length-1].match(/(\s+)/))
                        {       
                            selectionRanges.setEnd(selectionRanges.endContainer, selectionRanges.endOffset - 1);
                            break;                
                        }
                   }
                   catch (e) 
                   {
                       break;
                   }
                }
                var string = selectionRanges.toString();

                var selectionRangesChng = sel.getRangeAt(0);
                             
                data = ((selectionRanges.toString()).split(/(\s+)/)).filter(function(entry) {
                    return entry.trim() != '';
                });

                var isMacro = false;
                try {
                    if ((data[0][0] == "%" && data[0][data[0].length - 1] == "%") || (data[data.length - 1][0] == "%" && data[data.length - 1][data[data.length - 1].length - 1] == "%")) {   //Check the word is macro
                        if (data[0].match(/%([^ ]*)%/) && !backward) {
                            selectionRangesChng.setStart(selectionRanges.startContainer, selectionRanges.startOffset);
                            isMacro = true;
                        }
                        if (data[data.length - 1].match(/%([^ ]*)%/) && !backward) {
                            selectionRangesChng.setEnd(selectionRanges.endContainer, selectionRanges.endOffset);
                            isMacro = true;
                        }
                    }
                    if (isMacro) {
                        if (ZE_Init.keyPressed == 37 && !backward) {  // unselect full macro word 
                            if (data[data.length - 1].match(/%([^ ]*)%/)) 
                            {
                                selectionRangesChng.setEnd(selectionRanges.endContainer, selectionRanges.endOffset - (data[data.length - 1].length + 1));
                                return selectionRangesChng;      
                            }
                        } else 
                        {
                          
                            return selectionRangesChng;
                        }
                    }
                    if (backward && (data[0].match(/%([^ ]*)%/) || data[data.length - 1].match(/%([^ ]*)%/)))  //Check the word is macro and set selection range for backward selection
                    {
                        if(!isIE)
                        {
                            if (ZE_Init.keyPressed == 39 && (data[0].match(/%([^ ]*)%/))) {
                                sel.modify('extend', 'forward', 'word');
                                return selectionRangesChng;
                            }
                            else if ((data[0][0] == "%" && data[0][data[0].length - 1] == "%") || (data[data.length - 1][0] == "%" && data[data.length - 1][data[data.length - 1].length - 1] == "%"))
                            {
                               
                               if (data[data.length - 1][0] == "%" && data[data.length - 1][data[data.length - 1].length - 1] == "%") 
                               {
                                   sel.extend(selectionRanges.endContainer, selectionRanges.endOffset);
                                   selectionRangesChng.setEnd(selectionRanges.endContainer, selectionRanges.endOffset);
                               }
                               else
                               {
                                    sel.extend(selectionRanges.endContainer, selection.endOffset);  // Increase the selection range upto macro 
                                }

                               sel.modify("move", "backward", "character");
                               sel.modify("move", "forward", "character");
                               if ((data[0][0] == "%" && data[0][data[0].length - 1] == "%"))
                                {
                                   sel.extend(selectionRanges.startContainer, selectionRanges.startOffset);
                                   selectionRangesChng.setStart(selectionRanges.startContainer, selectionRanges.startOffset);
                               } 
                               else
                                {
                                   sel.extend(selection.startContainer, selection.startOffset);
                               }
                               
                            return selectionRangesChng;
                           }
                        }
                        else
                        {
                            if (ZE_Init.keyPressed == 39 && (data[0].match(/%([^ ]*)%/)))  // unselect full macro word at backard
                            {
                                selectionRangesChng.setStart(selectionRanges.startContainer, selectionRanges.startOffset+(data[0].length + 1));
                            }
                            else
                            {
                                selectionRangesChng.setStart(selectionRanges.startContainer, selectionRanges.startOffset);
                            }
                            selectionRangesChng.setEnd(selectionRanges.endContainer, selectionRanges.endOffset);
                            return selectionRangesChng;
                        }
                    }
                } catch (e) {

                }
            }
        }
    }
    return selection;
};
